#! /usr/bin/perl -w 

# 360-FAAR (Firewall Analysis, Audit, and Repair)

# The purpose of this script is to provide detailed analysis of a firewalls configuration by combining logs and config
#---------------------------------------------------------------------------------------------------

# Currently supported input amd output firewall config types are:
#---------------------------------------------------------------------------------------------------
#		 - Cisco ASA: show run
#		 - Netscreen ScreenOS 6: get config
#		 - Checkpoint Firewall-1: odumper/ofiller csv format in, fwdoc nats in, dbedit out
#		 - Many similar typed configs can be "cat'ed" together for comparison via 'print' modes or duplicates Data::Dumper prints

# Currently supported input firewall log types are:
#---------------------------------------------------------------------------------------------------
#		 - Cisco ASA: syslog text log
#		 - Netscreen ScreenOS 6: syslog text log
#		 - Checkpoint Firewall-1: logexport utility format, 
#		 - Many log files can be "cat'ed" together, in line log headers and prefixes are accounted for

# This script is hopefully written in a way that will make its workings understandable to firewall and network engineers
#---------------------------------------------------------------------------------------------------

# The latest version of this code can be found at http://sourceforge.net/projects/faar/ 
#---------------------------------------------------------------------------------------------------

# Version v0.3.0 - This release further updates the 'print' and 'fltprint' mode spreadsheets to include VPN tunnel usage info
#		   and source / destination negation from the policy as well as "install on" info.
#		   'print' modes now include most all of the "important" details pulled from the configs and logs.
# Version v0.2.9 - This release further upgrades the NAT analysis capabilities, more NAT details are listed in 'print' mode
# Version v0.2.8 - This release adds new columns to the 'print' mode spreadsheets to list the policy and log NAT translations.
#		   The NAT rule processing is further updated to include log and policy information in the network objects.
# Version v0.2.7 - This release completely dropps the previous NAT methodology and integrates NATs into the rule processing subs 
#		   and also sports a rewrite of the NAT structures and nat rule processing, this new method is much more robust
#		 - Negated rules are now identified in Netscreen and excluded from rr mode rulebases
# Version v0.2.6 - Corrected MIP interface NAT ANY service name and added nat dst ip statements to NATs tables
#		 - Correctly reads disabled rules in netscreen and adds further checks to the rr mode rulebase builters
#		 - Netscreen reader now reads tunnel vpn rules
# Version v0.2.5 - Added 'end.' comments to rr mode "enter search INC EX string" instructions
#		 - Added 'exit' to menu and tried to resolve looping issue when using CTRL-c ...did it work?
#		 - This release also resolves netscreen MIP(ipaddr) objects from interface mip statements and adds them to the NATs
#		 - Issues resolved: incorrect protocol definitions (used when merging between checkpoint - netscreen) are skipped,
#		   and unknown rule types are skipped and reported - e.g. netscreen tunnel rules
# Version v0.2.4 - Further updates the cisco policy writer and resolves issues with service group access lists
#		 - This release also resolves a few cisco reader bugs that printed undefined warnings
# Version v0.2.3 - Further updates to dbedit output - od mode now outputs object and service groups
#		 - Dbedit output is also now printed straight to file 
# Version v0.2.2 - Added object output to dbedit text in od mode, and NOTE: statements to the policy reader sections.
#		 - net and service_builder subs now catch and report circular groups and sub groups
#		 - fixed several bugs in cisco object, group and rule readers and writers
#		 - changed proto port and toZone fromZone divider character from . to ~
# Version v0.2.1 - Removed default service definitions that were not recognised in FW-1 r75.10 and caused dbedit policy build to fail.
# Version v0.2.0 - Changed project status to BETA - feedback needed!!!
#		 - Signigicantly upgraded the cisco object readers and writers and added more object checks to the netscreen and odumper
#		   readers, plus fixed the policy src print field and many other bugs
# Version v0.1.9 - Log to binary log conversion now writes log and rule usage hits to netobjects and 'print' mode prints this info
#		 - The log object resolution matches to the most specific CIDR range, to properly match traffic to rules use 'rr' mode
#		 - Print mode also now lists src and dst service associations from rules for each object
# Version 0.1.8.1- Updated netscreen obj reader to flag DNS names in set address cmd's and capture service timeout cmd's
#		 - Thanks to M.T. for flagging these issues so concicely!! Let me know if you want your name here if you read this.
# Version v0.1.8 - Added cisco policy output subroutine and sub groups to cisco reader
# Version 0.1.7.1- Fixed underfined warning in checkpoint log file reader for logs without service_id field.
# Version v0.1.7 - Fixed autovivication problem in bin log zone check, rule comments on original filtered rules, netscreen
#		   Any object name fixed, cisco apen protocol rules improved, add_srvc protocol issue fixed and log reader added.
# Version v0.1.6 - Bug Fixed and improved 'print' mode, fixed duplicate issue in cs mode, and many more bugs fixed in 
#		   in the cisco asa rule reading, as well as fixing misses in the binary log translation service matches.
#		 - the improved print mode gives object duplicates, supernets, subnets, hosts on nets, rule obj usage etc.
#		 - Added the 'fltprint mode', that filters the object analysis spreadsheet as its output
# Version v0.1.5 - ASA/PIX reader working well, new 'print' mode working, better named and organised subs
#		 - print mode is a little noisy (warnings) but the warnings are for window dressing that is missing
# Version v0.1.3 - better bldobj mode and notes and zone mappings sorted in netscreen out, and groups translated
#                - service groups translated and odumper service group field spelling corrected.

# This program was writen by Dan Martin of 360 Analytics Ltd. 
#---------------------------------------------------------------------------------------------------
# www.360analytics.co.uk dan@360analytics.co.uk +44 7960 028 070 <- no one has ever called me on this number

#---------------------------------------------------------------------------------------------------
#  Copyright (C) 2009-2012  Dan Martin
#
#   This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

#---------------------------------------------------------------------------------------------------
# NOTE: everything in here is writtin in Perl "baby speak" ...because i speak Perl "baby speak", better ideas welcome
# NOTE: <- is a note to me and is probably wrong, badly worded, full of redundant info and completely unnecessary expletives:
# NOTE:  ";" <- the more lined up they are, the happier I was with the code, yippie!! :-D

#---------------------------------------------------------------------------------------------------
# PRINT BANNER
#---------------------------------------------------------------------------------------------------

print "\n\n";
print "=========================================================================================\n";
print "            360 Analytics Ltd.   Firewall Analysis Audit and Repair			\n";
print "=========================================================================================\n";
print "                 360-FAAR Copyright (C) 2009-2012  Dan Martin				\n";
print "\n";
print "This program comes with ABSOLUTELY NO WARRANTY.						\n";
print "This is free software, and you are welcome to redistribute it				\n";
print "under certain conditions; see the GPLv3 license.						\n";


#===================================================================================================
# SET OPTIONS FOR THE SCRIPT
#===================================================================================================

use strict            		;
use Data::Dumper      		;
use Getopt::Long      		;
use IO::Handle			;
use Sys::Hostname		;
require 'shellwords.pl'		;

#===================================================================================================
# PRINTINHG SHORT HELP IF NO CMD LINE ARGS 
#===================================================================================================

unless (defined($ARGV[0])) {
	print "\n\n360-faar.pl v0.3.0 Help\n";
	print "---------------------------------------------------------\n\n";
	print "How to run:\n";
	print "---------------------------------------------------------\n";
	print "./360-faar.pl <cfg_type> <log_file> <cfg_file> <nats_file> <cfg_type2> <log_file2> <cfg_file2> <nats_file2> <cfg_type3> <log_file3> <cfg_file3> <nats_file3>\n\n";
	print "you can cat many log files together, checkpoint and syslog headers are recognised within the new log file\n";
	print "if you dont have a file, touch (create) a file called fake and use this as a place holder\n\n\n";
	print "CONFIG TYPES:\n";
	print "---------------------------------------------------------\n";
	print "odumper/ofiller format    = od		checkpoint logexported logs, csv format config, fwdoc format nats\n";
	print "netscreen screenos format = ns		syslog format netscreen logs, screenos6 \"get config\" format config, fwdoc nats\n";
	print "cisco pix or asa format   = cs		syslog format pix asa logs, pix asa 8.0 config, fwdoc nats\n";
	print "\n\n";
	exit;
}

#===================================================================================================
# GETTING INPUT FROM THE COMMAND LINE
#===================================================================================================

my $configtype1	= $ARGV[0]	;
my $logfile1 	= $ARGV[1] 	;
my $objfile1  	= $ARGV[2] 	;
my $routefile1  = $ARGV[3] 	;
my $configtype2	= $ARGV[4]	;
my $logfile2 	= $ARGV[5] 	;
my $objfile2  	= $ARGV[6] 	;
my $routefile2	= $ARGV[7]	;
my $configtype3	= $ARGV[8]	;
my $logfile3 	= $ARGV[9] 	;
my $objfile3  	= $ARGV[10] 	;
my $routefile3	= $ARGV[11]	;

#===================================================================================================
# SETTING THE GLOBAL HASHES AND ARRAYS
#===================================================================================================

my %configbundles		;	# all config information to be worked on is stored in here to avoid the lexical values goins out of scope and FUCKING EVERYTHING!
my %confignames			;	# filenames of config files
my %resobjectshrd		;	# resolved objects from logs
my %lastrashrulebase		;	# the very latest rationalized rulebase made

# NOTE: this kills the CTRL-C so that you cant accidentally exit after processing for many days

STDOUT->autoflush(1);
$SIG{INT} = \&interrupthandler;

sub interrupthandler {
	print STDERR "\n\nCTRL-C not active!!  This is to prevent accidentially exiting.\n";
	print STDERR "Type 'exit' to quit or anything else to continue: ";
	my $exit = <STDIN> ;
	chomp($exit);
	$exit =~ /[\r|\n]+$/ ;
	if ($exit eq 'exit') {
		exit;
	}
}

#===================================================================================================
# STARTING THE CONFIG BUNDLE BUILDER LOOP 
#===================================================================================================

$confignames{$objfile1}{'type'} 	= $configtype1	;
$confignames{$objfile1}{'logfile'} 	= $logfile1	;
$confignames{$objfile1}{'routefile'} 	= $routefile1	;

$confignames{$objfile2}{'type'} 	= $configtype2	;
$confignames{$objfile2}{'logfile'} 	= $logfile2	;
$confignames{$objfile2}{'routefile'} 	= $routefile2	;

$confignames{$objfile3}{'type'} 	= $configtype3	;
$confignames{$objfile3}{'logfile'} 	= $logfile3	;
$confignames{$objfile3}{'routefile'} 	= $routefile3	;

# NOTE: !!!!!!IMPORTANT!!!!! loop starting no tabs though - screen space

foreach my $config (keys %confignames) {

# NOTE: setting input details

my $configtype = $confignames{$config}{'type'};	# assigning config types to each config bundle

# NOTE: Print the firewall type we are analyzing as we start up

my $configtypetxt;
if ($configtype eq 'cs') {
	$configtypetxt = 'Cisco ASA' 		;
} elsif ($configtype eq 'od') {
	$configtypetxt = 'Checkpoint FW-1' 	;
} elsif ($configtype eq 'ns') {
	$configtypetxt = 'Netscreen SreenOS'	;
}

print "\nBeginning Analysis of $configtypetxt Config: \n";
print "-------------------------------------------------\n";
print "$config...\n";
print "-------------------------------------------------\n";


#===================================================================================================
# SETTING THE CONFIG HASHES AND ARRAYS
#===================================================================================================

# NOTE: config processing

my %netobjects 			;
my %netexceptions 		;
my %srvcexceptions 		;
my %ruleexceptions 		;
my %portexceptions		;
my @netobjects			;	# in order of appeareance
my @clusterobjects		;	# in order of appeareance
my @rangeobjects		;	# in order of appeareance
my @orderedports		;
my @orderedportranges		;
my @orderedhighports		;
my @orderedlowports		;
my %duplnetobjects 		;
my %srvcobjects 		;
my %ports 			;
my %duplports 			;
my %netgroups 			;
my %exclgroups 			;
my %srvcgroups 			;
my %objectstokeep 		;
my %installon			;
my %tinstallon			;	# translate install on, used to make install ons for cisco rules, with interface names from access-groups

my %interfaces			;	# from ASA config
my %zones			;	# derived from ASA config access-lists, or netscreen config

# NOTE: subgroup processing

my %networkgroups		;
my %netgroupobjs		;
my %srvcgroupobjs		;
my %servicegroups		;
my %allgroups			;

# NOTE: binary ip processing

my %ips 			;       # Called by all their 32 bits if they are hosts and by their masked bits if they are networks
my %duplips			;	
my @orderedfwobj		;
my %bingroups			;	# all binary ips belonging to members all members of a group
my %bingroupsizes		;

# NOTE: rule processing 

my %resobjectshrd		;	# holds the last set of resolved names from the 'or' menu option
my %rules			;
my %drops			;	# used for masking drop rules during the policy expansion
my $rulegroup			;	# for checkpoint to pull different rulebases and for ASAs different access-lists
my %rulegroups			;
my %rlgrpzones			;
my %netgroupzones		;
my %srvcgroupzones		;
my %rulecsvs			;
my %binrules			;
my $aclname 			;	# for ASA ACL processing
my $difflast			;	# compair with last rulebase made
my %lastrashrulebase		;	# the last rulebase rationalized
my %lastrashprintbase		;	# the last rulebase rationalized
my %prevrashrulebase		;	# the previous rulebase rationalized
my $sectionheader		;	# comment rules in cisco and section headers in checkpoint
my %mergerulebases		;	# the rulebases that are the destination for merged rules
my %mergetorulebases		;	# the rulebase used to remove rules from the rationalized rules when you are merging rulebases, rule rule rules!! 
my %logtypes			;	# the type of loging used in the rulebase 

# NOTE: variables for rationalizing rules - to be handed between subroutines

my $incconobjs			;
my %rashrules			;
my %rashrulegroups		;
my %includeips			;
my %excludeips			;
my %groupsinuse			;

# NOTE: port processing

my %portgroups			;
my %portgroupsizes		;

# NOTE: nat rule processing

my %nats;

# NOTE: route processing 

my %interfacebins 		;
my %routes			;
my %spoofgroups 		;

# NOTE: log processing

my %fromstree			;
my %deststree			;
my %srvcstree			;
my %actionfromstree		;
my %actiondeststree		;
my %servicefromstree		;
my %servicedeststree		;
my %actionservicefromstree	;
my %actionservicedeststree	;
my %daystree			;
my %rulehits			;
my %uniqueiphits		;
my %logbins			;
my %natstree			;

# NOTE: compairing logs and config

my %rulenumberhits		;
my %unusedrulehits 		; 
my %foundsrvcobjects		;

# NOTE: setting default vaules

my $aclcount					= 0			;	# for ASA ACL processing
my $rulecount 					= 0			;
my $rbcount					= 0			;
my $logheaddercount 				= 0			;
my $loglinecount 				= 0			;
my $loglinecountquick 				= 0 			;
my $loglinecountholder 				= 0 			;

# NOTE: setting default service any objects and default service definitions for each firewall type
	
unless ($config eq 'fake') {

	if ($configtype eq 'od') {

# NOTE: setting DEFAULT objects for CHECKPOINT FIREWALL-1 
	
		$netobjects{'Any'}{'ip'} 			= '0.0.0.0' 		;
		$netobjects{'Any'}{'nm'} 			= '0.0.0.0' 		;
		$netobjects{'Any'}{'type'} 			= 'any' 		;
		$netobjects{'Any'}{'colour'} 			= 'white' 		;
		$netobjects{'Any'}{'description'} 		= 'DefaultALL' 		;
		$netobjects{'Any'}{'ipbin'}{''}++ 					;

		$ips{''}{'name'} 				= 'Any'			;
		$interfacebins{''}{'name'} 			= "default"		;

		$srvcobjects{'Any'}{'type'} 			= 'any'			;
		$srvcobjects{'Any'}{'port'}{'any'} 		= 'any'			;
		$srvcobjects{'Any'}{'ports'}{'any'}{'any'}++				;
		$srvcobjects{'any'}{'type'} 			= 'any'			;
		$srvcobjects{'any'}{'port'}{'any'} 		= 'any'			;
		$srvcobjects{'any'}{'ports'}{'any'}{'any'}++				;

		$ports{'any'}{'any'}{'name'} = 'Any'				;
		$ports{'any'}{'Any'}{'name'} = 'Any'				;

		$netobjects{'empty'}{'ip'} 			= '255.255.255.255' 	;
		$netobjects{'empty'}{'nm'} 			= '255.255.255.255' 	;
		$netobjects{'empty'}{'type'} 			= 'empty' 		;

		$sectionheader = 'none';

		set_checkpoint_defaults(\%srvcobjects, \%ports);
		set_checkpoint_group_defaults(\%netgroups);

	} elsif ($configtype eq 'ns') {

# NOTE: setting DEFAULT objects for NETSCREEN SCREENOS

		$netobjects{'Any'}{'ip'} 			= '0.0.0.0' 		;
		$netobjects{'Any'}{'nm'} 			= '0.0.0.0' 		;
		$netobjects{'Any'}{'type'} 			= 'any' 		;
		$netobjects{'Any'}{'colour'} 			= 'white' 		;
		$netobjects{'Any'}{'description'} 		= 'DefaultALL' 		;
		$netobjects{'Any'}{'ipbin'}{''}++ 					;

		$ips{''}{'name'} 				= 'Any'			;
		$ips{''}{'zone'} 				= 'Global'		;
		$interfacebins{''}{'name'} 			= "default"		;

		$srvcobjects{'ANY'}{'type'} 			= 'any'			;
		$srvcobjects{'ANY'}{'port'}{'any'} 		= 'any'			;
		$srvcobjects{'ANY'}{'ports'}{'any'}{'any'}++				;

		$ports{'any'}{'any'}{'name'} = 'ANY'				;
		$ports{'any'}{'Any'}{'name'} = 'ANY'				;

		set_netscreen_defaults(\%srvcobjects);
		set_netscreen_group_defaults(\%srvcgroups);

	} elsif ($configtype eq 'cs') {

# NOTE: setting DEFAULT objects for CISCO PIX / ASA

		$sectionheader = 'none';
	
		$netobjects{'any'}{'ip'} 			= '0.0.0.0' 		;
		$netobjects{'any'}{'nm'} 			= '0.0.0.0' 		;
		$netobjects{'any'}{'type'} 			= 'any' 		;
		$netobjects{'any'}{'colour'} 			= 'white' 		;
		$netobjects{'any'}{'ipbin'}{''}++ 					;
		$netobjects{'any'}{'description'} 		= 'DefaultALL' 		;

		$ips{''}{'name'} 				= 'any'			;
		$interfacebins{''}{'name'} 			= "default"		;

		$srvcobjects{'any'}{'type'} 			= 'any'			;
		$srvcobjects{'any'}{'port'}{'any'} 		= 'any'			;
		$srvcobjects{'any'}{'ports'}{'any'}{'any'}++				;

		$ports{'any'}{'any'}{'name'} = 'any'				;
		$ports{'any'}{'Any'}{'name'} = 'any'				;

		set_cisco_defaults(\%srvcobjects, \%ports);
	}

# NOTE: adding service objects to the orderd port list BEFORE newly configured objects

	(@orderedports) = keys %srvcobjects ; 
}

#===================================================================================================
# Building Base Config from NETSCREEN config file
#===================================================================================================

if ($configtype eq 'ns') {
	
#===================================================================================================
# OPENING THE NETSCREEN CONFIG FILE 
#===================================================================================================

	open NETSCREENFILE, "$config" or warn "Can't open $config: $!\n"	;

#===================================================================================================
# PROCESSING THE NETSCREEN CONFIG FILE 
#===================================================================================================

# NOTE: Define MIP NAT entries for interface host mip starting at NAT Rule number 1000000

	my $natcount = 2000000									;

      NETINPUTSTAGE: 
	while (<NETSCREENFILE>) {
		chomp;

	# NOTE: read NETWORK objects

		if (/^set address/) {
			$_ =~ s/\n//g								;
			$_ =~ s/\r//g								;
			my @line = shellwords($_);

			if (exists ($netobjects{$line[3]})) {
				$duplnetobjects{$line[3]}++					;
			} else {
				if (is_ip($line[4]) && defined($line[5]) && ($line[5] =~ /^0\./)) {
					my ($ip1, $ip2, $ip3, $ip4) = split(/\./, $line[4]);
					my ($nm1, $nm2, $nm3, $nm4) = split(/\./, $line[5]);
					$ip2 = $ip2 + $nm2;
					$ip3 = $ip3 + $nm3;
					$ip4 = $ip4 + $nm4;
					push (@rangeobjects				, $line[3])	;
					$netobjects{$line[3]}{'zone'} 			= $line[2] 	;
					$netobjects{$line[3]}{'description'} 		= $line[6] 	;
					$netobjects{$line[3]}{'rangestart'} 		= $line[4] 		;
					$netobjects{$line[3]}{'rangeend'} 		= "$ip1.$ip2.$ip3.$ip4" ;
					$netobjects{$line[3]}{'type'} 			= 'range' 		;
				} elsif ( is_ip( $line[4] ) && defined($line[5]) && is_netmask( $line[5] ) ) {
					push (@netobjects				, $line[3])	;
					$netobjects{$line[3]}{'zone'} 			= $line[2] 	;
					$netobjects{$line[3]}{'description'} 		= $line[6] 	;
					$netobjects{$line[3]}{'ip'} 			= $line[4] 	;
					$netobjects{$line[3]}{'nm'} 			= $line[5] 	;
					$netobjects{$line[3]}{'type'} 			= 'net' 	;
				} elsif (isnt_ip( $line[4]) ) {
					print "  WARNING: NET OBJECT did NOT RESOLVE to an IP ADDRESS!!   To RESOLVE ADD:\n";
					print "       set address \"$line[2]\" \"$line[3]\" IP MASK \"Description: DNS Name $line[4]\"\n";
					print "       set address \"$line[2]\" \"$line[4]\" IP MASK \"Description: OBJ Name $line[3]\"\n";
					print "           to the config file before the line that caused this error and run again.\n";
					print "           NOTE:  the second command is mostly for log reading as it will be noted as an IP duplicate.\n";
				}
			}
	
	# NOTE: read SERVICE objects

		} elsif (/^set service/) {
			my @line = shellwords($_);

			if ($line[3] eq 'timeout') {
				if (exists ($srvcobjects{$line[2]})) {
					$srvcobjects{$line[2]}{'timeout'}	= $line[4]	;
					next;
				} else {
					print "  WARNING: TIMEOUT specified for UNKNOWN SERVICE $line[2]\n";
					next;
				}
				
			} elsif ($line[8] =~ (/^\d+\-\d+$/)) {
				push (@orderedportranges, 		  $line[2])		;
			} else {
				push (@orderedports,			  $line[2])		;
			}
			if ($line[4] !~ 'icmp') {
				$srvcobjects{$line[2]}{'port'}{$line[4]}	= $line[8]	;
				$srvcobjects{$line[2]}{'type'} 			= $line[4] 	;
			} else {
				$srvcobjects{$line[2]}{'port'}{$line[4]}	= $line[6]	;
				$srvcobjects{$line[2]}{'type'} 			= $line[4] 	;
			}

	# NOTE: read NETWORK groups

		} elsif (/^set group address/) {
			my @line = shellwords($_);

			if ($#line >= 5  && $line[5] eq 'add') {
				if (is_netobj_name($line[6], \%netobjects)) {
					$netgroups{$line[4]}{$line[6]}++				;
					$netgroupzones{$line[4]}{$line[3]}++				;
				} elsif (net_group_is_known($line[6], \%netgroups)) {
					$netgroups{$line[4]}{$line[6]}++				;
					$netgroupzones{$line[4]}{$line[3]}++				;
				} else {
					print "  WARNING: UNKNOWN OBJECT $line[6] used in GROUP $line[4] in ZONE $line[3]  NET OBJECT DROPPED\n";
				}
			}

	# NOTE: read SERVICE groups

		} elsif (/^set group service/) {
			my @line = shellwords($_);

			if (defined($line[4]) && $line[4] eq 'add') {
				if (is_srvcobj_name($line[5], \%srvcobjects)) {
					$srvcgroups{$line[3]}{$line[5]}++				;
					#$srvcgroupzones{$line[3]}{$line[3]}++				;
				} elsif (service_group_is_known($line[5], \%srvcgroups)) {
					$srvcgroups{$line[3]}{$line[5]}++				;
				} else {
					print "  WARNING: UNKNOWN SERVICE $line[5] used in GROUP $line[3]  SERVICE DROPPED\n";
				}
			}

	# NOTE: read INTERFACE details

		} elsif (/^set interface /) {
			my @line = shellwords($_);

			if ($line[3] eq 'tag') {
				print "FOUND INT: $line[2], 	ZONE: $line[6]\n"		;
				$interfaces{$line[2]}{'vlan'} = $line[4]			;
				$interfaces{$line[2]}{'zone'} = $line[6]			;
			} elsif ($line[3] eq 'zone') {
				print "FOUND INT: $line[2], 	ZONE: $line[4]\n"		;
				$interfaces{$line[2]}{'zone'} = $line[4]			;
			} elsif (($line[3] eq 'mip') && ($line[5] eq 'host')) {
				$natcount++; 
				my $mip = 	$line[4]					;
				my $miphost = 	$line[6]					;
				$nats{$natcount}{'enabled'}   = "yes"				; 
				$nats{$natcount}{'installon'} = 'Any'				; 
				$nats{$natcount}{'comment'}   = 'MIP NAT ADDED from interface mip host statement';

				$nats{$natcount}{'origsrc'}{"Any"}++				; 
				$nats{$natcount}{'origdst'}{"MIP\($mip\)"}++			; 
				$nats{$natcount}{'origsrvc'}{"ANY"}++				; 

				$nats{$natcount}{'natsrc'}  = 'ORIGINAL'			; 
				$nats{$natcount}{'natdst'}  = "MIP_Host-$miphost"		; 
				$nats{$natcount}{'natsrvc'} = 'ORIGINAL'			; 

				add_host("MIP\($mip\)", $mip, \@netobjects, \%netobjects, \%ips);
				$netobjects{"MIP\($mip\)"}{'zone'} 		= $line[10] 	;

				add_host("MIP_Host-$miphost", $miphost, \@netobjects, \%netobjects, \%ips);
				$netobjects{"MIP_Host-$miphost"}{'zone'} 	= $line[10] 	;

			}

	# NOTE: read ROUTE statements

		} elsif (/^set route /) {
			my @line = shellwords($_);

			my ($routenet, $routemask) 		= split(/\//, $line[2])		;
			my ($netbin) 		 		= ip_to_bin($routenet)		;
			my ($maskedbits) 			= substr($netbin, 0, $routemask);
			if (exists $interfaces{$line[4]}) {
				$zones{$maskedbits}{'zone'} 	= $interfaces{$line[4]}{'zone'}	;
			} else {
				print "NOT   INT: specified in route:  $line[4]\n"		;
			}

	# NOTE: read POLICY statements

		} elsif (/^set policy id \d+ from|^set policy id \d+ name/) {
			my $offset = 0								;
			my $rulecsv = "$_\n"							;
			my @line = shellwords($_)						;
			if ($line[4] eq 'name') {
				$offset = 2							;
			} elsif ($line[4] eq 'global') {
				$offset = 1							;
			} 									

			$rulecount++								;	
			$rbcount = $line[3]							;
			#print "RULE HIT: $rulecount, $rbcount\n";
			$installon{$line[$offset + 5]}++					;
			$rulegroups{"$line[$offset + 5]~$line[$offset + 7]"}{$rulecount}++	;
			if (is_netobj_name($line[8 + $offset], \%netobjects) || net_group_is_known($line[8 + $offset], \%netgroups)) {
				$rules{$rulecount}{'src'}{$line[$offset + 8]}++			;
			} else {
				print "  WARNING: UNKNOWN OBJECT $line[$offset + 8] used as SOURCE in RULE $rulecount\n";
			}
			if (is_netobj_name($line[9 + $offset], \%netobjects) || net_group_is_known($line[9 + $offset], \%netgroups)) {
				$rules{$rulecount}{'dst'}{$line[$offset + 9]}++			;
			} else {
				print "  WARNING: UNKNOWN OBJECT $line[$offset + 9] used as DEST in RULE $rulecount\n";
			}
			if (is_srvcobj_name($line[$offset + 10], \%srvcobjects) || service_group_is_known($line[$offset + 10], \%srvcgroups)) {
				$rules{$rulecount}{'service'}{$line[$offset + 10]}++		;
			} else {
				#$line[$offset + 10] =~ tr/A-Z/a-z/				;
				print "  WARNING: USING UNKNOWN SERVICE $line[$offset + 10] in RULEBASE $line[$offset + 5]~$line[$offset + 7] num $rbcount\n";
				$rules{$rulecount}{'service'}{$line[$offset + 10]}++		;
			}
			$rules{$rulecount}{'installon'}{$line[$offset + 5]}++			;
			$rules{$rulecount}{'rulegroup'} 	= "$line[$offset + 5]~$line[$offset + 7]";
			$rules{$rulecount}{'rbnum'} 		= $rbcount			;
			$rules{$rulecount}{'time'} 		= 'Any'				;
			$rules{$rulecount}{'vpn'} 		= 'Any'				;
			$rules{$rulecount}{'srcneg'} 		= 'no'				;
			$rules{$rulecount}{'dstneg'} 		= 'no'				;
			$rules{$rulecount}{'srvcneg'} 		= 'no'				;
			$rules{$rulecount}{'comment'} 		= 'Netscreen Rule'		;
			$rules{$rulecount}{'header'} 		= 'Migrated'			;

		# NOTE: read POLICY statement ACTIONS

			if ($line[$offset + 11] eq 'permit') {
				#print "PERMIT HIT\n";
				$rules{$rulecount}{'action'}		= 'Accept'		;
				$rules{$rulecount}{'type'} 		= 'security_rule'	;
				if (defined($line[$offset + 12]) && $line[$offset + 12] eq 'log') {
					$logtypes{'Log'}++					;
					$rules{$rulecount}{'track'}	= 'Log'			;
				} else {
					$logtypes{'None'}++					;
					$rules{$rulecount}{'track'}	= 'None'		;
				}

			} elsif ($line[$offset + 11] eq 'deny') {
				#print "deny HIT\n";
				$rules{$rulecount}{'action'}		= 'Drop'		;
				$rules{$rulecount}{'type'} 		= 'security_rule'	;
				unless (defined $line[$offset + 12]) {
					$logtypes{'None'}++					;
					$rules{$rulecount}{'track'}	= 'None'		;
				}

#			} elsif (($line[$offset + 11] eq 'tunnel' ) && ($line[$offset + 12] eq 'vpn') && (is_netobj_name($line[$offset + 13], \%netobjects))) {
			} elsif (($line[$offset + 11] eq 'tunnel' ) && ($line[$offset + 12] eq 'vpn')) {
				$rules{$rulecount}{'vpn'} 		= $line[$offset + 13];				;
				$rules{$rulecount}{'type'} 		= 'security_rule'	;
				$rules{$rulecount}{'action'} 		= 'Encrypt'	;
					#print "TING PING\n";
				if (defined($line[$offset + 17])) {
					#print "PING PING\n";
					$rules{$rulecount}{'polpair'} 		= $line[$offset + 17]	;
				}

		# NOTE: read POLICY NAT statements

			} elsif ($line[$offset + 11] =~ /^nat$/) {
				my $headderoffset = $offset;
				#print "NAT HIT\n";
				$rules{$rulecount}{'type'} 		= 'sec_nat_rule'	;
				for (my $i = 11 ; $offset + $i <= $#line ; $i++) {
					#print "WOOOOHHHH LOOPING $i\n";
					if ($line[$offset + $i] eq 'permit') {
						#print "permit\n";
						$rules{$rulecount}{'action'} 	= 'Accept'	;
						if (defined($line[$offset + $i + 1]) && $line[$offset + $i + 1] eq 'log' ) {
							$logtypes{'Log'}++			;
							$rules{$rulecount}{'track'}	= 'Log';
						} else {
							$logtypes{'None'}++			;
							$rules{$rulecount}{'track'}	= 'None';
						}
					} elsif ($line[$offset + $i] eq 'deny') {
						#print "deny\n";
						$rules{$rulecount}{'action'}	= 'Drop'	;
						unless (defined $line[$offset + $i + 1]) {
							$logtypes{'None'}++			;
							$rules{$rulecount}{'track'}	= 'None';
						}
					} elsif (($line[$offset + $i] eq 'src' ) && ($line[$offset + $i + 1] eq 'dip-ip')) {
						#print "srcdip\n";
						$rules{$rulecount}{'natsrcdip'}		= $line[$offset + $i + 2]		;
						$i += 2										;
					} elsif ($line[$offset + $i] eq 'src' ) {
						#print "src\n";
						$rules{$rulecount}{'natsrc'}++							;
					} elsif (($line[$offset + $i] eq 'dst' ) && ($line[$offset + $i + 1] eq 'dip-ip')) {
						my $candidate	= $line[$offset + $i + 2]		;
						my $canname 	= $candidate;
						if (isnt_netobj_name($candidate, \%netobjects) && network_is_known(name_or_ip_to_ip($candidate,\%netobjects), \%ips, '255.255.255.255', \%ips)) {
							#print "GN ORIG $canname, ";
							$canname = net_to_name($candidate, '255.255.255.255', \%netobjects, \%ips);
						} elsif (is_netobj_name($candidate, \%netobjects)) {
							# GOOD
						} elsif (is_ip($candidate)) {
							$canname = "NDIP_Host-$candidate";
							add_host($canname, $candidate, \@netobjects, \%netobjects, \%ips);
						}
						$rules{$rulecount}{'natdstdip'}		= $canname		;
						$i += 2										;
					} elsif (($line[$offset + $i] eq 'dst' ) && ($line[$offset + $i + 1] eq 'ip')) {
						my $candidate	= $line[$offset + $i + 2]		;
						my $canname 	= $candidate;
						if (isnt_netobj_name($candidate, \%netobjects) && network_is_known($candidate, '255.255.255.255', \%ips)) {
							#print "GN ORIG $canname, ";
							$canname = net_to_name($candidate, '255.255.255.255', \%netobjects, \%ips);
						} elsif (is_netobj_name($candidate, \%netobjects)) {
							# GOOD
						} elsif (is_ip($candidate)) {
							$canname = "DNIP_Host-$candidate";
							add_host($canname, $candidate, \@netobjects, \%netobjects, \%ips);
						}
						$rules{$rulecount}{'natdstip'}		= $canname		;
						$i += 2										;
					} elsif (($line[$offset + $i] eq 'tunnel' ) && ($line[$offset + $i + 1] eq 'vpn') && (is_netobj_name($line[$offset + $i + 2], \%netobjects))) {
						print "PING PING\n";
						$rules{$rulecount}{'vpn'} 		= $line[$offset + $i + 2];				;
						$rules{$rulecount}{'type'} 		= 'security_rule'	;
						$rules{$rulecount}{'action'} 		= 'Encrypt'	;
						if (defined($line[$offset + $i + 6])) {
							$rules{$rulecount}{'polpair'} 		= $line[$offset + $i + 6]	;
						}
					}
				}
			}
			unless (exists $rules{$rulecount}{'track'}) {
				#print "NO LOG $rulecount\n";
				$rules{$rulecount}{'track'} = 'None';
			}

		# NOTE: read MULTILINE POLICY rules

			while (<NETSCREENFILE>) {
				$rulecsv = "$rulecsv $_"				;
				$_ =~ s/\n//g						;
				$_ =~ s/\r//g						;

				chomp							;
				$rulecsvs{$rulecount} = $rulecsv			;
				my @line = shellwords($_)				;
				#print "RULE EXTRAS: $rulecount, $rbcount\n"		;

				next NETINPUTSTAGE if $_ eq 'exit'			;
				if (/^set src-address negate/) {
					$rules{$rulecount}{'srcneg'} 		= 'yes'	;
				} elsif (/^set dst-address negate/) {
					$rules{$rulecount}{'dstneg'} 		= 'yes'	;
				} elsif (/^set service negate/) {
					$rules{$rulecount}{'srvcneg'} 		= 'yes'	;

				} elsif (/^set src-address/) {
					if (is_netobj_name($line[2], \%netobjects) || net_group_is_known($line[2], \%netgroups)) {
						$rules{$rulecount}{'src'}{$line[2]}++	;
					} else {
						print "  WARNING: UNKNOWN OBJECT $line[2] used as SOURCE in RULE $rulecount\n";
					}
				} elsif (/^set dst-address/) {
					if (is_netobj_name($line[2], \%netobjects) || net_group_is_known($line[2], \%netgroups)) {
						$rules{$rulecount}{'dst'}{$line[2]}++		;
					} else {
						print "  WARNING: UNKNOWN OBJECT $line[2] used as DEST in RULE $rulecount\n";
					}
				} elsif (/^set service/) {
					if (is_srvcobj_name($line[2], \%srvcobjects) || service_group_is_known($line[2], \%srvcgroups)) {
						$rules{$rulecount}{'service'}{$line[2]}++	;
					} else {
						print "  WARNING: UNKNOWN SERVICE OBJECT $line[2] used as DEST in RULE $rulecount\n";
					}
				} elsif (/^set log/) {
					$rules{$rulecount}{'track'} = $line[2]		;
					$logtypes{$line[2]}++				;
				} elsif (/set policy id \d+ disable/) {
					if ($rules{$rulecount}{'type'} eq 'sec_nat_rule') {
						$rules{$rulecount}{'type'} 		= 'disabled_sec_nat_rule'	;
					} else {
						$rules{$rulecount}{'type'} 		= 'disabled_sec_rule'	;
					}
				}
			}
		}
	}
}


#===================================================================================================
# Building Full Base Config from ASA config file
#===================================================================================================

	if ($configtype eq 'cs' ) {
		
#===================================================================================================
# OPENING THE ASA CONFIG FILE 
#===================================================================================================
	
		open ASAFILE, "$config" or warn "Can't open $config: $!\n"	;
	
#===================================================================================================
# PROCESSING THE ASA CONFIG FILE 
#===================================================================================================
	
	      INPUTSTAGE: 
		while (<ASAFILE>) {
			chomp;

		# NOTE: read OLD style NETWORK object names

			if (/^name /) {
				#my @line = shellwords($_)				;
				#my $ipbin = ip_to_bin($line[1])				;
				#$netobjects{$line[2]}{'type'} 	= 'host'		;
				#$netobjects{$line[2]}{'ip'} 	= $line[1]		;
				#$netobjects{$line[2]}{'nm'} 	= '255.255.255.255'	;
				#$netobjects{$line[2]}{'ipbin'}{$ipbin}++ 		;
				#$ips{$ipbin}{'name'} = $line[2]     			;
				
				my $line = $_;
				$line =~ s/^\s+//;
				my ($dummy, $ip, $name, @description) = split(/\s+/, $line);

				add_host($name, $ip, \@netobjects, \%netobjects, \%ips);
				if (@description) {
					shift @description;
					$netobjects{$name}{'description'} = "@description";
				}
		
		# NOTE: pull NETWORK object services

			} elsif (/^object network /) {
				
				my $line = $_;
				$line =~ s/^\s+//;
				my ($dummy, $dummy2, $name) = split(/\s+/, $line);

				while (<ASAFILE>) {

					my $line = $_;
					$line =~ s/^\s+//;
					my @line = split(/\s+/, $line);
					#my @line = shellwords($_);

					unless ($line[0] =~ /^host$|^subnet$|^range$|^description$/) {redo INPUTSTAGE;}

					if (($line[0] eq 'host') && (is_ip($line[1]))) {
						my $ip = $line[1];
						add_host($name, $ip, \@netobjects, \%netobjects, \%ips);
					} elsif (($line[0] eq 'host') && (is_netobj_name($line[1], \%netobjects))) {
						my $ip = name_or_ip_to_ip($line[1], \%netobjects, \%ips);
						add_host($name, $ip, \@netobjects, \%netobjects, \%ips);
					} elsif (($line[0] eq 'subnet') && (is_netobj_name($line[1], \%netobjects) && is_netmask($line[2]))) {
						my $ip = name_or_ip_to_ip($line[1], \%netobjects, \%ips);
						my $nm = $line[2];
						add_net($name,$ip,$nm, \@netobjects, \%netobjects, \%ips);
					} elsif (($line[0] eq 'subnet') && (is_ip($line[1])) && (is_netmask($line[2]))) {
						my $ip = $line[1];
						my $nm = $line[2];
						add_net($name,$ip,$nm, \@netobjects, \%netobjects, \%ips);
					} elsif (($line[0] eq 'range') && (is_ip($line[1])) && (is_ip($line[2]))) {
						my $rangestart = $line[1];
						my $rangeend = $line[2];
						add_range($name,$rangestart,$rangeend, \@netobjects, \%netobjects, \%ips);
					} elsif (($line[0] eq 'range') && is_netobj_name($line[1], \%netobjects) && (is_ip($line[2]))) {
						my $ip = name_or_ip_to_ip($line[1], \%netobjects, \%ips);
						my $rangestart = $ip;
						my $rangeend = $line[2];
						add_range($name,$rangestart,$rangeend, \@netobjects, \%netobjects, \%ips);
					} elsif (($line[0] eq 'range') && is_netobj_name($line[2], \%netobjects) && (is_ip($line[1]))) {
						my $ip = name_or_ip_to_ip($line[2], \%netobjects, \%ips);
						my $rangestart = $line[1];
						my $rangeend = $ip;
						add_range($name,$rangestart,$rangeend, \@netobjects, \%netobjects, \%ips);
					} elsif (($line[0] eq 'range') && is_netobj_name($line[1], \%netobjects) && (is_netobj_name($line[2], \%netobjects))) {
						my $rangestart = name_or_ip_to_ip($line[1], \%netobjects, \%ips);
						my $rangeend   = name_or_ip_to_ip($line[2], \%netobjects, \%ips);
						add_range($name,$rangestart,$rangeend, \@netobjects, \%netobjects, \%ips);
					} elsif ($line[0] eq 'description') {
						my $dummy = shift @line;
						if (exists $netobjects{$name}) {
							$netobjects{$name}{'description'} = "@line";
						} else {
							print "   WARNING: DESCRIPTION found for UNKNOWN OBJECT: $name -> @line\n";
						}
					} else {
						print "   WARNING: NETWORK OBJECT $name DROPPED\n";
					}
				}

		# NOTE: pull SERVICE object details

			} elsif (/^object service /) {
				
				my $line = $_;
				$line =~ s/^\s+//;
				my ($dummy, $dummy2, $name) = split(/\s+/, $line);

				while (<ASAFILE>) {	

					my $line = $_;
					$line =~ s/^\s+//;
					my @line = split(/\s+/, $line);
					#my @line = shellwords($_);

					unless ($line[0] =~ /^service$|^description$/ ) { redo INPUTSTAGE; }

					if ($line[0] eq 'service') {

						my $proto;
						if ($line[1] eq 'protocol') {
							$proto = $line[2];
						} else {
							$proto = $line[1];
						}
						my ($srcport, $dstport, $srctype, $dsttype);

						for (my $i = 2; $i < scalar(@line); $i++) {
							if ($line[$i] eq 'source') {
								if (($line[$i + 1] =~ /^eq$/) && ($line[$i + 2] =~ /\d+/)) {
									$srcport = $line[$i + 2];
									$srctype = 'port';
									$i += 2;
									#print "WHIZZ!!\n";
								} elsif (($line[$i + 1] =~ /^eq$/) && is_srvcobj_name($line[$i + 2], \%srvcobjects)) {
									$srcport = $line[$i + 2];
									$srctype = 'service';
									$i += 2;
									#print "SHIZZ!!\n";
								} elsif (($line[$i + 1] =~ /^gt$/) && ($line[$i + 2] =~ /\d+/)) {
									$srcport = $line[$i + 2];
									$srctype = 'highport';
									$i += 2;
									#print "POP!!\n";
								} elsif (($line[$i + 1] =~ /^lt$/) && ($line[$i + 2] =~ /\d+/)) {
									$srcport = $line[$i + 2];
									$srctype = 'lowport';
									$i += 2;
									#print "FIZZLE!!\n";
								} elsif (($line[$i + 1] =~ /range/) && ($line[$i + 2] =~ /\d+/) && ($line[$i + 3] =~ /\d+/)) {
									$srcport = ("$line[$i + 2]\-$line[$i + 3]");
									$srctype = 'rangeport';
									$i += 3;
									#print "POP!!\n";
								} else {
									print "   WARNING: SERVICE OBJECT $name SOURCE position NOT a DEFINED PORT or OBJECT\n";
								}

							} elsif ($line[$i] eq 'destination') {
								if (($line[$i + 1] =~ /^eq$/) && ($line[$i + 2] =~ /\d+/)) {
									$dstport = $line[$i + 2];
									$dsttype = 'port';
									$i += 2;
									#print "CRASH!!\n";
								} elsif (($line[$i + 1] =~ /^eq$/) && is_srvcobj_name($line[$i + 2], \%srvcobjects)) {
									$dstport = $line[$i + 2];
									$dsttype = 'service';
									$i += 2;
									#print "SMASH!!\n";
								} elsif (($line[$i + 1] =~ /^gt$/) && ($line[$i + 2] =~ /\d+/)) {
									$dstport = $line[$i + 2];
									$dsttype = 'highport';
									$i += 2;
									#print "BANG!!\n";
								} elsif (($line[$i + 1] =~ /^lt$/) && ($line[$i + 2] =~ /\d+/)) {
									$dstport = $line[$i + 2];
									$dsttype = 'lowport';
									$i += 2;
									#print "WHOLLOP!!\n";
								} elsif (($line[$i + 1] =~ /range/) && ($line[$i + 2] =~ /\d+/) && ($line[$i + 3] =~ /\d+/)) {
									$dstport = ("$line[$i + 2]\-$line[$i + 3]");
									$dsttype = 'rangeport';
									$i += 3;
									#print "CUNT!!\n";
								} else {
									print "   WARNING: SERVICE OBJECT $name DEST position NOT DEFINED\n";
								}
							}
						}
						if (defined($srcport) && defined($dstport)) {
							if ($dsttype eq 'service') {
								my $dstportin = $srvcobjects{$dstport}{'port'}{$proto};
								#add_srvc($name, $proto, $dstportin, \@orderedports, \%srvcobjects, \%ports);
								$srvcobjects{$name}{'srcport'} = $srcport;
							} elsif ($dsttype eq 'port') {
								if (port_is_known($proto, $dstport, \%ports)) {
									my $name = proto_port_to_srvc_name($proto, $dstport, \%ports);
									#add_srvc($name, $proto, $dstport, \@orderedports, \%srvcobjects, \%ports);
									$srvcobjects{$name}{'srcport'} = $srcport;
								} else {
									add_srvc($name, $proto, $dstport, \@orderedports, \%srvcobjects, \%ports);
									$srvcobjects{$name}{'srcport'} = $srcport;
								}
								$srvcobjects{$name}{'srcport'} = $srcport;
							} elsif ($dsttype eq 'lowport') {
								add_srvc($name, $proto, "\<$dstport", \@orderedlowports, \%srvcobjects, \%ports);
								$srvcobjects{$name}{'srcport'} = $srcport;
							} elsif ($dsttype eq 'highport') {
								add_srvc($name, $proto, "\>$dstport", \@orderedhighports, \%srvcobjects, \%ports);
								$srvcobjects{$name}{'srcport'} = $srcport;
							} elsif ($dsttype eq 'rangeport') {
								add_srvc($name, $proto, $dstport, \@orderedportranges, \%srvcobjects, \%ports);
								$srvcobjects{$name}{'srcport'} = $srcport;
							}
						} elsif (defined($dstport)) {
							if ($dsttype eq 'service') {
								my $dstportin = $srvcobjects{$dstport}{'port'}{$proto};
								#add_srvc($name, $proto, $dstportin, \@orderedports, \%srvcobjects, \%ports);
							} elsif ($dsttype eq 'port') {
								if (port_is_known($proto, $dstport, \%ports)) {
									my $name = proto_port_to_srvc_name($proto, $dstport, \%ports);
								} else {
									add_srvc($name, $proto, $dstport, \@orderedports, \%srvcobjects, \%ports);
								}
								add_srvc($name, $proto, $dstport, \@orderedports, \%srvcobjects, \%ports);
							} elsif ($dsttype eq 'lowport') {
								add_srvc($name, $proto, "\<$dstport", \@orderedlowports, \%srvcobjects, \%ports);
							} elsif ($dsttype eq 'highport') {
								add_srvc($name, $proto, "\>$dstport", \@orderedhighports, \%srvcobjects, \%ports);
							} elsif ($dsttype eq 'rangeport') {
								add_srvc($name, $proto, $dstport, \@orderedportranges, \%srvcobjects, \%ports);
							}
						} else {
							print "   WARNING: SERVICE OBJECT $name PROTO $proto NOT properly DEFINED\n";
						}
					} elsif ($line[0] eq 'description') {
						my $dummy = shift @line;
						if (exists $srvcobjects{$name}) {
							$srvcobjects{$name}{'description'} = "@line";
						} else {
							print "   WARNING: DESCRIPTION found for UNKNOWN SERVICE OBJECT: $name\n";
						}
					}
				}

		# NOTE: build interface details
	
			} elsif (/^interface /) {
				my @line = shellwords($_)					;
				my $interface = $line[1]					;
				while (<ASAFILE>) {	
					redo INPUTSTAGE if /^\S/				;
					@line = shellwords($_)					;
					if (/^ vlan/) {
						$interfaces{$interface}{'vlan'} 		= $line[1]				;
					} elsif (/^ speed/) {
						$interfaces{$interface}{'speed'} 		= $line[1]				;
					} elsif (/^ duplex/) {
						$interfaces{$interface}{'duplex'} 		= $line[1]				;
					} elsif (/^ nameif/) {
						$interfaces{$interface}{'nameif'} 		= $line[1]				;
					} elsif (/^ security\-level/) {
						$interfaces {$interface} {'security-level'} 	= $line[1]				;
					} elsif (/^ ip address/) {
						$interfaces{$interface}{'ip'} 			= $line[2]				;
						$interfaces{$interface}{'nm'} 			= $line[3]				;
						if (defined($line[5])) { 
							$interfaces{$interface}{'standby'} 	= $line[5]				; 
						}
						my ($maskedbits, $masklength) 			= name_or_net_to_ipbin_nmln($line[2], $line[3], \%netobjects, \%ips)	;
						my ($netip) 					= name_or_ip_to_ip($line[2], \%netobjects, \%ips)	;
						my ($cidr) 					= "$netip\/$masklength"			;
						if ($netip !~ $line[2]) {
							$routes{$maskedbits}{'netname'} 	= $line[2]				;
						}
						$routes{$maskedbits}{'ip'} 			= $netip				;
						$routes{$maskedbits}{'nm'} 			= $line[3]				;
						$routes{$maskedbits}{'masklength'} 		= $masklength				;
						$routes{$maskedbits}{'connected'} 		= 'Locally-Connected'			;
						$routes{$maskedbits}{'zone'} 			= $interface				;
						$routes{$maskedbits}{'cidr'} 			= $cidr					;
						#add_network ($netip, $line[3]);
					} elsif (/^ shutdown/) {
						$interfaces{$interface}{'shutdown'} 		= 'shutdown'				;
					} elsif (/^ management\-only/) {
						$interfaces{$interface}{'management'} 		= 'management-only'			;
					} elsif (/^ description LAN Failover Interface/) {
						$interfaces{$interface}{'failover'} 		= 'failoverint'				;
					} elsif (/^ description STATE Failover Interface/) {
						$interfaces{$interface}{'statefailover'} 	= 'statefailover'			;
					}
				}
		
		# NOTE: build route statements

			} elsif (/^route /) {
				my @line 					= shellwords($_)			;
				my ($maskedbits, $masklength) 			= name_or_net_to_ipbin_nmln($line[2], $line[3], \%netobjects, \%ips)	;
				my ($netip) 					= name_or_ip_to_ip($line[2], \%netobjects, \%ips)		;
				my ($cidr) 					= "$netip\/$masklength"			;
				if ($netip !~ $line[2]) {
					$routes {$maskedbits} {'netname'} 	= $line[2]				;
				}
				$routes{$maskedbits}{'netip'} 		= $netip					;
				$routes{$maskedbits}{'mask'} 		= $line[3]					;
				$routes{$maskedbits}{'masklength'} 	= $masklength					;
				$routes{$maskedbits}{'nexthop'} 	= name_or_ip_to_ip($line[4], \%netobjects, \%ips);
				$routes{$maskedbits}{'nexthopname'} 	= ip_to_name($line[4], \%netobjects, \%ips)			;
				$routes{$maskedbits}{'zone'} 		= $line[1]					;
				$routes{$maskedbits}{'weight'} 		= $line[5]					;
				$routes{$maskedbits}{'cidr'} 		= $cidr						;

		# NOTE: the network object groups

			} elsif (/^object\-group network/) {
				my @line 		= shellwords($_)					;
				my $grouptype 		= $line[1]						;
				my $group 		= $line[2]						;
				while (<ASAFILE>) {
					chomp($_)								;
					@line = shellwords($_)							;
					if (/^\S/) {
						redo INPUTSTAGE							;
					} elsif (/^ description /) {
						# NOTE: what do I do here? keep comments?... rarely used and usually out of date	;
					} elsif (/^ network\-object host/) {
						my $addr = $line[2]						;
						if (is_netobj_name($addr, \%netobjects)) {
							$netgroups{$group}{$addr}++  					;
							#print "found obj $addr in group $group\n";
						} elsif (address_is_known($addr, \%ips)) {
							#print "GH ORIG $addr, ";
							$addr = ip_to_name($addr, \%netobjects, \%ips);
							$netgroups{$group}{$addr}++  					;
							#print "TRANS $addr\n";
						} elsif (is_ip($addr) && address_isnt_known($addr, \%ips)) {
							add_host("Host_$addr",$addr, \@netobjects, \%netobjects, \%ips);
							print "   INFO:  Host $addr is listed as IN USE in GROUP $group but no OBJECT is defined with that name or ip... adding Host_$addr AS OBJECT NAME!\n";
							$netgroups{$group}{$addr}++  					;
						} else {
							print "   WARNING: Named host $addr is listed as IN USE in GROUP but no OBJECT is defined with that name... OBJECT DROPPED!\n";
							#add_host($addr,$addr, \@netobjects, \%netobjects, \%ips);
							#$netgroups{$group}{$addr}++  					;
						}

					} elsif (/^ network\-object / && is_netmask($line[2])) {
						my $addr = $line[1]						;
						my $mask = $line[2]						;
						if (isnt_netobj_name($addr, \%netobjects) && network_is_known($addr, $mask, \%ips)) {
							#print "GN ORIG $addr, ";
							$addr = net_to_name("Net_$addr-$mask", $mask, \%netobjects, \%ips);
							$netgroups{$group}{$addr}++  					;
							#print "TRANS $addr\n";
						} elsif (isnt_netobj_name($addr, \%netobjects) && is_ip($addr) && network_isnt_known($addr, $mask, \%ips)) {
							add_net($addr,$addr,$mask, \@netobjects, \%netobjects, \%ips);
							$netgroups{$group}{$addr}++  					;
						} elsif (is_netobj_name($addr, \%netobjects)) {
							my $ip = name_or_ip_to_ip($addr, \%netobjects, \%ips);
							if (network_is_known($ip, $mask, \%ips)) {
								my $name = net_to_name($ip, $mask, \%netobjects, \%ips);
								$netgroups{$group}{$name}++  					;
							} else {
								print "   INFO:  Named Net $addr $mask is listed as IN USE in GROUP $group but no OBJECT is defined with that ip and netmask... adding Net_$ip-$mask AS OBJECT NAME!\n";
								add_net("Net_$ip-$mask",$ip,$mask, \@netobjects, \%netobjects, \%ips);
								$netgroups{$group}{"Net_$ip-$mask"}++  					;
							}
						} else {
							print "   WARNING: Named host $addr is listed as a SOURCE in rulebase but NO OBJECT is defined with that name... OBJECT DROPPED!\n";
							#add_net($addr,$addr,$mask, \@netobjects, \%netobjects, \%ips);
							#$netgroups{$group}{$addr}++  					;
						} 

					} elsif (/^ network\-object / && is_netobj_name($line[1])) {
						my $addr = $line[1]						;
						$netgroups{$group}{$addr}++  					;

					} elsif (/^ object\-group /) {
						my $subgrp = $line[1]						;
						$netgroups{$group}{$subgrp}++  					;
					}
								
				}

		# NOTE: service object groups

			} elsif (/^object\-group service/) {
				my @line = shellwords($_)				;
				my $group = $line[2]					;
				my $proto = $line[3]					;
				while (<ASAFILE>) {
					chomp						;
					@line = shellwords($_)				;
					if (/^\S/) {
						redo INPUTSTAGE				;
					} elsif (/^ description /) {
						# not sure what to do with
					} elsif (/^ port\-object eq / && (is_srvcobj_name($line[2], \%srvcobjects))) {
						$srvcgroups{$group}{$line[2]}++		;

					} elsif (/^ port\-object eq /) {
						$srvcgroups{$group}{$line[2]}++		;
						add_srvc($line[2], $proto, $line[2], \@orderedports, \%srvcobjects, \%ports)	;
		
					} elsif (/^ port\-object range /) {
						my $range = "$line[2]\-$line[3]"	;
						$srvcgroups{$group}{$line[2]}++		;
						add_srvc($range, $proto, $range, \@orderedportranges, \%srvcobjects, \%ports)	;
		
					} elsif (/^ object\-group /) {
						my $subgrp = $line[1]						;
						$srvcgroups{$group}{$subgrp}++  					;
					}
				}		

		# NOTE: protocol object groups - these are treated the same way as service groups

			} elsif (/^object\-group protocol/) {
				my @line = shellwords($_)				;
				my $group = $line[2]					;
				#my $proto = $line[3]					;
				while (<ASAFILE>) {
					chomp						;
					@line = shellwords($_)				;
					if (/^\S/) {
						redo INPUTSTAGE				;
					} elsif (/^ description /) {
						# not sure what to do with
					} elsif (/^ protocol\-object /) {
						$srvcgroups{$group}{$line[1]}++		;
						my $portrange = '0-65535'		;
						add_srvc($line[1], $line[1], $portrange, \@orderedports, \%srvcobjects, \%ports)	;

					} elsif (/^ object\-group /) {
						my $subgrp = $line[1]						;
						$srvcgroups{$group}{$subgrp}++  					;
					}
				}		

		# NOTE: the access lists 
	
			} elsif (/^access\-list /) {
				#next if /remark/;
				my $acltype;
				my $srctype;
				my $srcaddr;
				my $srcmask;
				my $srcport;
				my $srcptyp;
				my $dsttype;
				my $dstaddr;
				my $dstmask;
				my $dstport;
				my $dstptyp;
				my $log;
				my @line = shellwords($_);
				$rulecsvs{$rulecount} = "@line";
	
				unless (defined($aclname)) {
					$aclname = 'noacldefined';
				}
				if ($aclname !~ $line[1]) { 
					print "FOUND RULEBASE: $line[1]\n";
					$aclcount = 0;
				}

				$aclname = $line[1];
				my $index = 0;

			# NOTE: handle line or remark statements

				if ($line[2] eq 'line') {
					$aclcount = $line[3];
					$index += 2;
					 
				} elsif ($line[2] =~ /remark/) {
					$index++; 
					my $remark = "@line";
					$remark =~ s/\.*remark//;
					$sectionheader = $remark;
					next;
				}

			# NOTE: Rule Action Position 

				my $action = $line[3 + $index] ;

			# NOTE: Rule Protocol Position 
	
				my $proto;

			# NOTE: if access list type is STANDARD

				if ($line[2 + $index] =~ /standard/) {
					$acltype = 'security_rule';

				# NOTE: skip protocol field

					$proto = 'any';
					$index++;

				# NOTE: skip source address field

					$srcaddr = 'any';
					$srctype = 'any';
					$index++;

				# NOTE: skip source port field

					$index--;

				} elsif ($line[2 + $index] eq 'extended') {
					$index++;
					$acltype = 'security_rule';

				# NOTE:  OR do extended access list stuff

					if ($line[3 + $index] =~ /^object\-group$/) {
						$proto  = $line[4 + $index] ;
						$index++; 
					} else {
						$proto  = $line[3 + $index] ;
					}

				# NOTE: Source Address Position 
		
					if ($line[4 + $index] =~ /^any$/) {
						$srcaddr = $line[4 + $index];
						$srctype = 'any';
					} elsif ($line[4 + $index] =~ /^host$/) {
						$srcaddr = $line[5 + $index];
						$srctype = 'host';
						
						if (isnt_netobj_name($srcaddr, \%netobjects) && address_is_known($srcaddr, \%ips)) {
							#print "RS ORIG $srcaddr, ";
							$srcaddr = ip_to_name($srcaddr, \%netobjects, \%ips);
							#print "TRANS $srcaddr\n";
						} elsif (isnt_netobj_name($srcaddr, \%netobjects) && is_ip($srcaddr) && address_isnt_known($srcaddr, \%ips)) {
							add_host("Host_$srcaddr",$srcaddr, \@netobjects, \%netobjects, \%ips);
							$srcaddr = "Host_$srcaddr";
						} elsif (is_netobj_name($srcaddr, \%netobjects)) {
							# NOTE: this is mostly to stop the elsebelow picking up known objects
							#print "found src $srcaddr in rule $rulecount++\n";
						} else {
							print "   WARNING: Named host OBJECT $srcaddr is listed as a SOURCE in rulebase but no object is defined with that name. HOST DROPPED!\n";
						}
						$index++;
						 
					} elsif (is_netobj_name($line[4 + $index], \%netobjects) && is_netmask($line[5 + $index]) ) {
						$srcaddr = $line[4 + $index];
						$srcmask = $line[5 + $index];
						$srctype = 'net';

						my $ip = name_or_ip_to_ip($srcaddr, \%netobjects, \%ips);
						if (network_is_known($ip, $srcmask, \%ips)) {
							$srcaddr = net_to_name($ip, $srcmask, \%netobjects, \%ips);
						} else {
							add_net("Net_$ip-$srcmask",$ip,$srcmask, \@netobjects, \%netobjects, \%ips);
							$srcaddr = "Net_$ip-$srcmask"  	;
						}
						$index++;

					} elsif ($line[4 + $index] eq 'object') {
						$srcaddr = $line[5 + $index];
						$srctype = 'object';
						if (is_netobj_name($srcaddr, \%netobjects)) {
							# NOTE: this is mostly to stop the elsebelow picking up known objects
							#print "found src $srcaddr in rule $rulecount++\n";
						} else {
							$srctype = 'unknown';
							print "   WARNING: Named OBJECT $srcaddr is listed as a SOURCE in rulebase but no object is defined with that name... OBJECT DROPPED!\n";
						}
						$index++;

					} elsif ($line[4 + $index] =~ /object\-group/) {
						$srcaddr = $line[5 + $index] ;
						$srctype = 'group';
						$index++;
		
					} elsif (is_ip($line[4 + $index]) && is_netmask($line[5 + $index]) ) {
						$srcaddr = $line[4 + $index]; 
						$srcmask = $line[5 + $index];
						$srctype = 'net';
		
						if (isnt_netobj_name($srcaddr, \%netobjects) && network_is_known($srcaddr, $srcmask, \%ips)) {
							#print "RSN ORIG $srcaddr, ";
							$srcaddr = net_to_name($srcaddr, $srcmask, \%netobjects, \%ips);
							#print "TRANS $srcaddr\n";
						} elsif (isnt_netobj_name($srcaddr, \%netobjects) && network_isnt_known($srcaddr, $srcmask, \%ips)) {
							add_net("Net_$srcaddr-$srcmask",$srcaddr,$srcmask, \@netobjects, \%netobjects, \%ips);
							$srcaddr = "Net_$srcaddr-$srcmask"
						} elsif (is_netobj_name($srcaddr, \%netobjects)) {
							# NOTE: this is mostly to stop the else below picking up known objects
							#print "found src net $srcaddr in rule $rulecount\n";
						} else {
							print "   WARNING: Named NETWORK $srcaddr is listed as a SOURCE in RULEBASE but no object is defined with that name... adding!\n";
							add_net($srcaddr,$srcaddr,$srcmask, \@netobjects, \%netobjects, \%ips);
						}
						$index++;
					} elsif ($line[4 + $index] eq 'interface') {
						$srcaddr = $line[5 + $index] ;
						$srctype = 'interface';
						my $ip   = $interfaces{$srcaddr}{'ip'};
						my $nm   = $interfaces{$srcaddr}{'nm'};
						print "   WARNING: Named INTERFACE $srcaddr is listed as a SOURCE in RULEBASE defining interface name as object... adding!\n";
						add_net($srcaddr,$ip,$nm, \@netobjects, \%netobjects, \%ips);
					} else {
						print "   WARNING: MISSED SOURCE RULEBASE OBJECT $line[4 + $index]\n";
					}
				

				# NOTE: Source Port Position 
		
					if (($line[5 + $index] =~ /^eq$/) && (is_srvcobj_name($line[6 + $index], \%srvcobjects))) {
						$srcport = $line[6 + $index];
						$srcptyp = 'port';
						$index++; 
					} elsif (($line[5 + $index] =~ /^eq$/) && ($line[6 + $index] =~ /\d+/)) {
						$srcport = $line[6 + $index];
						$srcptyp = 'port';
						add_srvc($srcport, $proto, $srcport, \@orderedports, \%srvcobjects, \%ports);
						$index++; 
					} elsif (($line[5 + $index] =~ /^gt$/) && ($line[6 + $index] =~ /\d+/)) {
						$srcport = $line[6 + $index];
						$srcptyp = 'port';
						add_srvc($srcport, $proto, $srcport, \@orderedhighports, \%srvcobjects, \%ports);
						$index++; 
					} elsif (($line[5 + $index] =~ /^lt$/) && ($line[6 + $index] =~ /\d+/)) {
						$srcport = $line[6 + $index];
						$srcptyp = 'port';
						add_srvc($srcport, $proto, $srcport, \@orderedlowports, \%srvcobjects, \%ports);
						$index++; 
					} elsif (($line[5 + $index] eq 'object') && (is_srvcobj_name($line[6 + $index], \%srvcobjects))) {
						$srcport = $line[6 + $index] ;
						$srcptyp = 'object';
						$index++;
					} elsif (($line[5 + $index] =~ /object\-group/) && (service_group_is_known($line[6 + $index], \%srvcgroups))) {
						$srcport = $line[6 + $index] ;
						$srcptyp = 'object';
						$index++;
					} elsif ($line[5 + $index] =~ /range/) {
						$srcport = ("$line[6 + $index]\-$line[7 + $index]");
						$srcptyp = 'range';
						add_srvc($srcport, $proto, $srcport, \@orderedportranges, \%srvcobjects, \%ports);
						$index = $index + 2;
					} else {
						#$srcport = 'none' ;
						$index--;
					}

						# NOTE: end of standard access list daftness
				}

			# NOTE: Destination Address Position 
		
				if ($line[6 + $index] =~ /^any$/) {
					$dstaddr = $line[6 + $index];
					$dsttype = 'any';
				} elsif ($line[6 + $index] =~ /^host$/) {
					$dstaddr = $line[7 + $index];
					$dsttype = 'host';
					
					if (isnt_netobj_name($dstaddr, \%netobjects) && address_is_known($dstaddr, \%ips)) {
						#print "RD ORIG $dstaddr, ";
						$dstaddr = ip_to_name($dstaddr, \%netobjects, \%ips);
						#print "TRANS $dstaddr\n";
					} elsif (isnt_netobj_name($dstaddr, \%netobjects) && is_ip($dstaddr) && address_isnt_known($dstaddr, \%ips)) {
						add_host("Host_$dstaddr",$dstaddr, \@netobjects, \%netobjects, \%ips);
						$dstaddr = "Host_$dstaddr";
					} elsif (is_netobj_name($dstaddr, \%netobjects)) {
						# NOTE: this is mostly to stop the else below picking up known objects
						#print "found dst $dstaddr in rule $rulecount++\n";
					} else {
						print "   WARNING:   Named host OBJECT $dstaddr is listed as a DEST in RULEBASE but no object is defined with that name... OBJECT DROPPED!\n";
					}
					$index++; 

				} elsif (is_netobj_name($line[6 + $index], \%netobjects) && is_netmask($line[7 + $index]) ) {
					$dstaddr = $line[6 + $index];
					$dstmask = $line[7 + $index];
					$srctype = 'net';

					my $ip = name_or_ip_to_ip($dstaddr, \%netobjects, \%ips);
					if (network_is_known($ip, $dstmask, \%ips)) {
						$dstaddr = net_to_name($ip, $dstmask, \%netobjects, \%ips);
					} else {
						add_net("Net_$ip-$dstmask",$ip,$dstmask, \@netobjects, \%netobjects, \%ips);
						$dstaddr = "Net_$ip-$dstmask"  	;
					}
					$index++;

				} elsif ($line[6 + $index] eq 'object') {
					$dstaddr = $line[7 + $index];
					$dsttype = 'object';
					if (is_netobj_name($dstaddr, \%netobjects)) {
						#print "found src $srcaddr in rule $rulecount++\n";
					} else {
						$dstaddr = $line[7 + $index];
						$dsttype = 'unknown';
						print "   WARNING:   Named $dsttype OBJECT $dstaddr is listed as a DEST in RULEBASE but no object is defined with that name... OBJECT DROPPED!\n";
					}
					$index++;
				} elsif ($line[6 + $index] =~ /object\-group/) {
					$dstaddr = $line[7 + $index] ;
					$dsttype = 'object';
					$index++;
				} elsif (is_ip($line[6 + $index]) && is_netmask($line[7 + $index])) {
					$dstaddr = $line[6 + $index];
					$dstmask = $line[7 + $index];
					$dsttype = 'net';
	
					if (isnt_netobj_name($dstaddr, \%netobjects) && network_is_known($dstaddr, $dstmask, \%ips)) {
						#print "RDN ORIG $dstaddr, ";
						$dstaddr = net_to_name($dstaddr, $dstmask, \%netobjects, \%ips);
						#print "TRANS $dstaddr\n";
					} elsif (isnt_netobj_name($dstaddr, \%netobjects) && network_isnt_known($dstaddr, $dstmask, \%ips)) {
						add_net("Net_$dstaddr-$dstmask",$dstaddr,$dstmask, \@netobjects, \%netobjects, \%ips);
						$dstaddr = "Net_$dstaddr-$dstmask";
					} elsif (is_netobj_name($dstaddr, \%netobjects)) {
						# NOTE: this is mostly to stop the else below picking up known objects
						#print "found dst $dstaddr in rule $rulecount++\n";
					} else {
						print "   WARNING:   Named network $dstaddr is listed as a DEST in RULEBASE but no object is defined with that name... adding!\n";
						add_net($dstaddr,$dstaddr,$dstmask, \@netobjects, \%netobjects, \%ips);
					}
					$index++;
				} elsif ($line[6 + $index] eq 'interface') {
					$dstaddr = $line[7 + $index] ;
					$dsttype = 'interface';
					my $ip   = $interfaces{$dstaddr}{'ip'};
					my $nm   = $interfaces{$dstaddr}{'nm'};
					print "   WARNING:   Named INTERFACE $dstaddr is listed as a SOURCE in RULEBASE defining interface name as object... adding!\n";
					add_net($dstaddr,$ip,$nm, \@netobjects, \%netobjects, \%ips);
				} else {
					print "   WARNING:   MISSED DEST RULEBASE OBJECT $line[6 + $index]!\n";
				} 

			# NOTE: Destination Port Position 
		
				if (defined ($line[7 + $index])) {
					if (($line[7 + $index] =~ /^eq$/) && (is_srvcobj_name($line[8 + $index], \%srvcobjects)) ) {
						$dstport = $line[8 + $index];
						$dstptyp = 'object';
						$index++; 
					} elsif (($line[7 + $index] =~ /^eq$/) && ($line[8 + $index] =~ /\d+/)) {
						$dstport = $line[8 + $index];
						$dstptyp = 'port';
						#add_srvc($dstport, $proto, $dstport, \@orderedports, \%srvcobjects, \%ports);
						$index++; 
					} elsif (($line[7 + $index] =~ /^gt$/) && (is_srvcobj_name($line[8 + $index], \%srvcobjects))) {
						$dstport = $line[8 + $index];
						$dstptyp = 'range';
						$index++; 
					} elsif (($line[7 + $index] =~ /^gt$/) && ($line[8 + $index] =~ /\d+/)) {
						$dstport = $line[8 + $index];
						$dstptyp = 'range';
						add_srvc($dstport, $proto, $dstport, \@orderedhighports, \%srvcobjects, \%ports);
						$index++; 
					} elsif (($line[7 + $index] =~ /^lt$/) && ($line[8 + $index] =~ /\d+/)) {
						$dstport = $line[8 + $index];
						$dstptyp = 'range';
						add_srvc($dstport, $proto, $dstport, \@orderedlowports, \%srvcobjects, \%ports);
						$index++; 
					} elsif (($line[7 + $index] eq 'object') && (is_srvcobj_name($line[8 + $index], \%srvcobjects))) {
						$dstport = $line[8 + $index] ;
						$dstptyp = 'object' ;
						$index++;
					} elsif (($line[7 + $index] =~ /object\-group/) && (service_group_is_known($line[8 + $index], \%srvcgroups))) {
						$dstport = $line[8 + $index] ;
						$dstptyp = 'object' ;
						$index++;
					} elsif ($line[7 + $index] =~ /object\-group/) {
						$dstport = $line[8 + $index] ;
						$dstptyp = 'object' ;
						print "   WARNING:   UNKNOWN GROUP  $dstport in DEST position, Rule $aclcount, Access-List: $aclname, Group $dstport, CORRUPT GROUP DROPPED\n";
						$index++;
					} elsif ($line[7 + $index] =~ /range/) {
						$dstport = ("$line[8 + $index]\-$line[9 + $index]");
						$dstptyp = 'range';
						add_srvc($dstport, $proto, $dstport, \@orderedportranges, \%srvcobjects, \%ports);
						$index = $index + 2;
					} else {
						$dstport = 'any' ;
						$index--;
						print "   WARNING:   NO DESTINATION PORT specified, Rule $aclcount, Access-List: $aclname, Port $dstport\n    $_\n";
					}
				} else {

			# NOTE: set destination port details if NOT DEFINED in ACE

					if (($proto ne 'ip') && (service_group_is_known($proto, \%srvcgroups))) {
						$dstport = $proto   ;
						$dstptyp = 'group' ;
						print "   WARNING:   USING PROTO AS PORT in open Rule $aclcount, Access-List: $aclname, Port $dstport\n    $_\n";
						$index++;
					} elsif (($proto ne 'ip') && (is_srvcobj_name($proto, \%srvcobjects))) {
						$dstport = $proto   ;
						$dstptyp = 'object' ;
						print "   WARNING:   USING PROTO AS PORT in open Rule $aclcount, Access-List: $aclname, Port $dstport\n    $_\n";
						$index++;
					} elsif ($proto ne 'ip') {
						$dstport = $proto   ;
						$dstptyp = 'object' ;
						add_srvc($dstport, 'portunknown', $dstport, \@orderedportranges, \%srvcobjects, \%ports);
						print "   WARNING:   USING PROTO 'portunknown' AS NEW PORT in open Rule $aclcount, Access-List: $aclname, Port $dstport\n    $_\n";
						$index++;
					} elsif ($proto eq 'ip') {
						$dstport = 'any' ;
						$dstptyp = 'any' ;
						$index--;
						print "   WARNING:   NO DESTINATION PORT specified, Rule $aclcount, Access-List: $aclname, USING PORT: $dstport\n    $_\n";
					} else {
						print "   WARNING:   NO DESTINATION PORT specified, Rule $aclcount, Access-List: $aclname\n    $_\n";
					}
				}
		
			# NOTE: Logging section 
		
				if (defined($line[6 + $index]) && ($line[6 + $index] eq 'log')) {

					if (defined($line[7 + $index]) && ($line[7 + $index] =~ /^warnings$|^critical$|^debugging$/)) {
						$log = $line[7 + $index];
					} else {
						$log = 'log';
					}

				} elsif (defined($line[7 + $index]) && ($line[7 + $index] eq 'log')) {

					if (defined($line[8 + $index]) && ($line[8 + $index] =~ /^warnings$|^critical$|^debugging$/)) {
						$log = $line[8 + $index];
					} else {
						$log = 'log';
					}

				} elsif (defined($line[8 + $index]) && ($line[8 + $index] eq 'log')) {

					if (defined($line[9 + $index]) && ($line[9 + $index] =~ /^warnings$|^critical$|^debugging$/)) {
						$log = $line[9 + $index];
					} else {
						$log = 'log';
					}

				} elsif (defined($line[9 + $index]) && ($line[9 + $index] eq 'log')) {

					if (defined($line[10 + $index]) && ($line[10 + $index] =~ /^warnings$|^critical$|^debugging$/)) {
						$log = $line[10 + $index];
					} else {
						$log = 'log';
					}
				} else {

					$log = 'None';
				}

			# NOTE: Building the ACL array

				$logtypes{$log}++								;
		
				$rulegroups{$aclname}{$rulecount}{'acltype'} 	= $acltype	  		;
				$rulegroups{$aclname}{$rulecount}{'action'} 	= $action	  		;

				$rules{$rulecount}{'type'} 			= $acltype	  		;
				$rules{$rulecount}{'action'} 			= $action	  		;
				$rules{$rulecount}{'proto'} 			= $proto	  		;
				$rules{$rulecount}{'rulegroup'} 		= $aclname	  		;
				if (defined($srcaddr)) {$rules{$rulecount}{'src'}{$srcaddr}++		 	;}
				if (defined($dstaddr)) {$rules{$rulecount}{'dst'}{$dstaddr}++			;}
				$rules{$rulecount}{'srcneg'}			= 'no'				;
				$rules{$rulecount}{'dstneg'}			= 'no'				;
				$rules{$rulecount}{'srvcneg'}			= 'no'				;
				$rules{$rulecount}{'vpn'}			= 'Any'				;
				$rules{$rulecount}{'comment'} 			= 'none'		;
				$rules{$rulecount}{'header'} 			= $sectionheader		;  # NOTE: in here as a place holder, its built just after config pull
				$rules{$rulecount}{'rbnum'} 			= $aclcount			;
				if (defined($srcaddr)) {$rulehits{$srcaddr}++					;}
				if (defined($dstaddr)) {$rulehits{$dstaddr}++					;}
				if (defined($srcmask)) {$rules{$rulecount}{'srcmask'} 	= $srcmask		;}
				if (defined($srctype)) {$rules{$rulecount}{'srctype'} 	= $srctype		;}
				if (defined($srcport)) {$rules{$rulecount}{'srcport'} 	= $srcport		;}
				if (defined($srcptyp)) {$rules{$rulecount}{'srcptyp'} 	= $srcptyp		;}
				if (defined($dstmask)) {$rules{$rulecount}{'dstmask'} 	= $dstmask		;}
				if (defined($dsttype)) {$rules{$rulecount}{'dsttype'} 	= $dsttype		;}
				if (defined($dstport)) {$rules{$rulecount}{'service'}{$dstport}++ 		;
				}
				#} else {                $rules{$rulecount}{'service'}{'any'}++	  		;}
				if (defined($dstptyp)) {$rules{$rulecount}{'dstptyp'} 	= $dstptyp		;}
				if (defined($log))     {$rules{$rulecount}{'track'} 	= $log    		;}

				#$rules{$rulecount}{'time'} 	= $line[8]				;
				$aclcount++							  		;
				$rulecount++							  		;
		
		# NOTE: Associating ACL's with interfaces
		
			} elsif (/^access\-group/) {
				my ($acldir, $aclint, $aclname);
				my @line = shellwords($_);
				$aclname = $line[1];
				$aclint = $line[4];
				$acldir = $line[2];

				$tinstallon{$aclname} = "$acldir"."_"."$aclint" ;

				$rlgrpzones{$aclname}{'acldir'} = $acldir;
				$rlgrpzones{$aclname}{'aclint'} = $aclint;
		
	#		} elsif (/^static /) {
	#			my @line = shellwords($_);
	#			$line[1] =~ tr/\[()]//d ;
	#			my @realormapped = split(/\,/,$line[1]);
	#			$realifip = $realormapped[0];
	#			$mappedip = $realormapped[1];
	#			print "$realormapped[0] mapped to $realormapped[1]\n";
			}
		}

	# NOTE: access group interface as install on

		foreach my $rnum (sort numerically keys %rules) {
			my $rlgrp = $rules{$rnum}{'rulegroup'};

			if (exists $tinstallon{$rlgrp}) {
				my $installon = $tinstallon{$rlgrp} ;
				$rules{$rnum}{'installon'}{$installon}++;
				$installon{$installon}++;
			} else {
				$rules{$rnum}{'installon'}{'no_Installon'}++;
				$installon{'no_Installon'}++;
			}
		}
	}


#===================================================================================================
# Building Groups,  Objects and  Rules from  odumper CSV
#===================================================================================================
	
	if ($configtype eq 'od' ) {
	
#===================================================================================================
# OPENING THE ODUMPER CONFIG FILE 
#===================================================================================================
	
		open OBJFILE, "$config" or warn "Can't open $config: $!\n"	;
		my @config = <OBJFILE> 					;
	
#===================================================================================================
# PROCESSING THE ODUMPER CONFIG FILE 
#===================================================================================================
	
		#print "RULE_NUMBER  RULE_TYPE  SOURCE  DESTINATION  VPN  SERVICE  ACTION  TRACK  INSTALL_ON  TIME  COMMENT\n";
		
		for (@config) {
			$_ =~ s/\n//g									;
			$_ =~ s/\r//g									;
		        chomp($_) 									;
		
		        my @line = split(',', $_, 30) 							;
			next unless defined $line[1]							;
		
		# NOTE: Print fields with numbers as check for field assignment
		#
		#	my $sheepcount = 0								;
		#	print "\n"									;
		#	foreach my $sheep (@line) {
		#		print "$sheepcount $sheep 	"					;
		#		$sheepcount++								;
		#	}
		
		# NOTE: pulling SERVICE GROUPS
		
		        if ($line[1] eq "srvgroup") {
				next if $line[2] eq 'object_permissions'				;
				next if $line[2] eq 'AdminInfo'						;
				next if $line[2] =~ /^chkpf_uid/					;
				next if $line[2] eq 'manage'						;
				next if $line[2] eq 'Any'						;
				next if $line[2] eq 'read'						;
				next if $line[2] eq 'any'						;
				next if $line[2] eq 'use'						;
				next if $line[2] eq 'any'						;
				next if $line[2] eq 'write'						;
				next if $line[2] eq 'owner'						;
				if (is_srvcobj_name($line[2], \%srvcobjects)) {
		                	$srvcgroups{$line[0]}{$line[2]}++ 				;
				} elsif (service_group_is_known($line[2], \%srvcgroups)) {
		                	$srvcgroups{$line[0]}{$line[2]}++ 				;
				} else {
					print "  WARNING: UNKNOWN SERVICE OBJECT: $line[2] used in GROUP $line[0] - it is possible this OBJECT HAS NOT YET BEEN READ\n";
		                	$srvcgroups{$line[0]}{$line[2]}++ 				;
				}
		
		# NOTE: reading NETWORK GROUPS
		
		        } elsif ($line[1] eq "group") {
				next if $line[2] eq 'object_permissions'				;
				next if $line[2] eq 'AdminInfo'						;
				next if $line[2] =~ /^chkpf_uid/					;
				next if $line[2] eq 'manage'						;
				next if $line[2] eq 'Any'						;
				next if $line[2] eq 'read'						;
				next if $line[2] eq 'any'						;
				next if $line[2] eq 'use'						;
				next if $line[2] eq 'any'						;
				next if $line[2] eq 'write'						;
				next if $line[2] eq 'owner'						;
				if (is_netobj_name($line[2], \%netobjects)) {
					$netgroups{$line[0]}{$line[2]}++ 				;
				} elsif (net_group_is_known($line[2], \%netgroups)) {
					$netgroups{$line[0]}{$line[2]}++ 				;
				} else {
					print "  WARNING: UNKNOWN NET OBJECT: $line[2] used in GROUP $line[0] - it is possible this OBJECT HAS NOT YET BEEN READ\n";
					$netgroups{$line[0]}{$line[2]}++ 				;
				}
		
		        } elsif ($line[1] eq "exclgrp") {
				$netgroups{$line[0]}{$line[2]}{'exclgrps'}{$line[3]}++ 			;
				$exclgroups{$line[0]}{$line[2]}++ 					;
		
		        } elsif ($line[1] eq "emptygrp") {
				$netgroups{$line[0]}{'empty'}++ 					;

		# NOTE: pulling NETWORK objects 

		        } elsif ($line[1] 		=~ /^net$|^host$|^member$|^ss$|^idevice$|^plaingw$|^dynamic$|^cpgw$/) {
		
				if (exists ($netobjects{$line[0]})) {
					$duplnetobjects{$line[0]}++					;
				} else {
					push (@netobjects				, $line[0])	;
			                $netobjects{$line[0]}{'ip'} 			= $line[2] 	;
			                $netobjects{$line[0]}{'nm'} 			= $line[3] 	;
			                $netobjects{$line[0]}{'type'} 			= $line[1] 	;
			                $netobjects{$line[0]}{'colour'} 		= $line[4] 	;
					my ($maskbin, $maskbits, $masklength)		= netmask_to_bin($line[3]) ;
			                $netobjects{$line[0]}{'cidr'} 			= "$line[2]\/$masklength" ;
			
					if ($line[6] 		=~ /^static$/ ) { 
						$netobjects{$line[0]}{'staticnat'} 	= $line[5]	;
					}
					if ($line[6] 		=~ /^hide$/ ) { 
						$netobjects{$line[0]}{'hidenat'} 	= $line[5]	;
					}
			                if ($line[8] 		!~ /^$/ ) {
			                        $netobjects{$line[0]}{'description'} 	= $line[8] 	;
					}
				}

		# NOTE: reading SERVICE objects

		        } elsif ($line[1] 		=~ /^tcp$|^udp$|^rcp$|^icmp$/ ) {
				if ($line[2] =~ m/\d+\-\d+/) {
					push (@orderedportranges, 		  $line[0])		;
				} elsif ($line[2] =~ m/\>/) {
					push (@orderedhighports,		  $line[0])		;
				} elsif ($line[2] =~ m/\</) {
					push (@orderedlowports,			  $line[0])		;
				} else {
					push (@orderedports,			  $line[0])		;
				}
				$srvcobjects{$line[0]}{'port'}{$line[1]}	= $line[2]		;
				$srvcobjects{$line[0]}{'type'} 			= $line[1] 		;
		                $srvcobjects{$line[0]}{'colour'} 		= $line[4] 		;
			        $srvcobjects{$line[0]}{'description'} 		= $line[8] 	;
		
		        } elsif ($line[1] 		=~ /^other$/ ) {
				push (@orderedports,			  	  $line[0])		;
				$srvcobjects{$line[0]}{'port'}{$line[1]}	= $line[2] 	 	;
				$srvcobjects{$line[0]}{'type'} 			= $line[1] 		;
		                $srvcobjects{$line[0]}{'colour'} 		= $line[4] 		;
				$srvcobjects{$line[0]}{'replies'} 		= $line[5] 		;
				$srvcobjects{$line[0]}{'parameters'} 		= $line[6] 		;
			        $srvcobjects{$line[0]}{'description'} 		= $line[8] 	;
	
		# NOTE: reading CLUSTER objects
			
			} elsif ($line[1] 		=~ /^cluster$/ ) {
				push (@clusterobjects				, $line[0])		;
		                $netobjects{$line[0]}{'ip'} 			= $line[2]		;
		                $netobjects{$line[0]}{'nm'} 			= '255.255.255.255' 	;
		                $netobjects{$line[0]}{'type'} 			= $line[1] 		;
		                $netobjects{$line[0]}{'colour'} 		= $line[4] 		;
		                $netobjects{$line[0]}{'member'}{$line[3]}++ 				;
			        $netobjects{$line[0]}{'cidr'} 			= "$line[2]\/32" ;
		
		# NOTE: reading RANGE objects
			
		        } elsif ($line[1] 		=~ /^range$/) {
				push (@rangeobjects				, $line[0])		;
		                $netobjects{$line[0]}{'rangestart'} 		= $line[2] 		;
		                $netobjects{$line[0]}{'rangeend'} 		= $line[3] 		;
		                $netobjects{$line[0]}{'type'} 			= $line[1] 		;
		                $netobjects{$line[0]}{'colour'} 		= $line[4] 		;
			        $netobjects{$line[0]}{'description'} 		= $line[8] 	;
			        $netobjects{$line[0]}{'cidr'} 			= "$line[2]\/$line[3]" ;
		
		# NOTE: reading INTERFACE details
			
		        } elsif ($line[1] 		=~ /^interface$/) {
		                $netobjects{$line[4]}{'interface'}{$line[0]}{'ip'} 	= $line[2] 	;
		                $netobjects{$line[4]}{'interface'}{$line[0]}{'nm'} 	= $line[3] 	;
		                $netobjects{$line[4]}{'interface'}{$line[0]}{'zone'} 	= $line[5] 	;
		                $netobjects{$line[4]}{'interface'}{$line[0]}{'antispoof'} = $line[6] 	;

		# NOTE: pulling RULES
			
			} elsif ( $line[0] =~ /^rulebase_header$/ ) {
				#chop ($line[1])								;
				$rulegroup = $line[1]							;
				print "FOUND RULEBASE: $line[1]\n"					;
				$rbcount = 0								;
	
			} elsif ( $line[0] =~ /^section_header$/ ) {
				chop ($line[1])								;
				$sectionheader = $line[1]						;
	
		        } elsif ( $line[0] =~ /^security\_rule$|^disabled_sec_rule$/) {
				$rulecount++								;	
				$rbcount++								;
				$rulecsvs{$rulecount} = "$_"						;
				# NOTE: not client auth rules... yet!
				#next if $line[5] eq 'ClientAuth' 					;
				$rulegroups{$rulegroup}{$rulecount}++					;
		
				#RULE_TYPE,SOURCE,DESTINATION,VPN,SERVICE,ACTION,TRACK,INSTALL_ON,TIME,COMMENT

				my @rulehits								;
				#print "$rulecount  @line\n"						;
				if ($line[1] =~ /^\!/) {
					$line[1] =~ s/^\!//						;
					$rules{$rulecount}{'srcneg'} 	= 'yes'				;
				} else {
					$rules{$rulecount}{'srcneg'}	= 'no'				;
				}
				if ($line[2] =~ /^\!/) {
					$line[2] =~ s/^\!//						;
					$rules{$rulecount}{'dstneg'} 	= 'yes'				;
				} else {
					$rules{$rulecount}{'dstneg'}	= 'no'				;
				}
				if ($line[4] =~ /^\!/) {
					$line[4] =~ s/^\!//						;
					$rules{$rulecount}{'srvcneg'} 	= 'yes'				;
				} else {
					$rules{$rulecount}{'srvcneg'}	= 'no'				;
				}
				
				my @sources 				= split (/\;/, $line[1])	;
				my @dests 				= split (/\;/, $line[2])	;
				my @services 				= split (/\;/, $line[4])	;

				$rules{$rulecount}{'type'} 	= $line[0]				;

			# NOTE: check SOURCE objects EXIST

				foreach my $rulesrcobj (sort @sources) {
					if (is_netobj_name($rulesrcobj, \%netobjects) || net_group_is_known($rulesrcobj, \%netgroups)) { 
						$rules{$rulecount}{'src'}{$rulesrcobj}++			;
					} else {
						print "  WARNING: UNKNOWN OBJECT $rulesrcobj used as SOURCE in RULE $rulegroup no: $rulecount  OBJECT DROPPED\n";
					}
				}

			# NOTE: check DESTINATION objects EXIST

				foreach my $ruledstobj (sort @dests) {
					if (is_netobj_name($ruledstobj, \%netobjects) || net_group_is_known($ruledstobj, \%netgroups)) { 
						$rules{$rulecount}{'dst'}{$ruledstobj}++ 			;
					} else {
						print "  WARNING: UNKNOWN OBJECT $ruledstobj used as DEST in RULE $rulegroup no: $rulecount  OBJECT DROPPED\n";
					}
				}
				$rules{$rulecount}{'vpn'} 	= $line[3]				;
				unless ($line[3] eq 'Any') {
					#print "Rule: $rbcount,$rulecsvs{$rulecount}\n"			;
				}

			# NOTE: check SERVICE objects EXIST

				foreach my $rulesrvcobj (sort @services) {
					if (is_srvcobj_name($rulesrvcobj, \%srvcobjects) || service_group_is_known($rulesrvcobj, \%srvcgroups)) { 
						$rules{$rulecount}{'service'}{$rulesrvcobj}++			;
					} else {
						print "  WARNING: UNKNOWN SERVICE $rulesrvcobj used as DEST in RULE $rulegroup no: $rulecount PORT ADDED AS TYPE: portunknown\n";
						$rules{$rulecount}{'service'}{$rulesrvcobj}++			;
					}
				}
				$rules{$rulecount}{'action'} 	= $line[5]				;
				$rules{$rulecount}{'track'} 	= $line[6]				;
				$logtypes{$line[6]}++							;

			# NOTE: read INSTALLON field

				my @installon = split(/\;/, $line[7])					;
				foreach my $installon (@installon) {
					$rules{$rulecount}{'installon'}{$installon}++			;
					$installon{$installon}++
				}
				$rules{$rulecount}{'time'} 	= $line[8]				;
				$rules{$rulecount}{'comment'} 	= $line[9]				;
				$rules{$rulecount}{'rulegroup'} = $rulegroup				;
				$rules{$rulecount}{'rbnum'} 	= $rbcount				;
				if (defined $sectionheader) {
					$rules{$rulecount}{'header'} = $sectionheader			;
				}
		
				push (@rulehits, @sources, @dests) 					;
		
				foreach my $rulehit (@rulehits) { 
					$rulehit 				=~ s'@Any$'' 		;
					$rulehits{$rulehit}++ 			 			;
				}
			}
		}
	}

#---------------------------------------------------------------------------------------------------
# PRINT OBJECT AND RULE FILE PROCESSING COMPLETE BANNER
#---------------------------------------------------------------------------------------------------

	my $objcount = keys %netobjects			;
	my $srvccount = keys %srvcobjects		;
	my $groupcount = keys %netgroups		;
	my $srvcgroupcount = keys %srvcgroups		;
	my $duplnetobjectcount = keys %duplnetobjects	;
	my $rulehitscount = keys %rulehits		;

	print "-----------------------------------------------------------------------------------------\n";
	print " OBJECT, RULE AND BASE GROUP BUILDING COMPLETE:\n"	;
	print "   network objects processed 	= $objcount\n"		;
	print "   service objects processed 	= $srvccount\n"		;
	print "   network groups  processed 	= $groupcount\n"	;
	print "   service groups  processed 	= $srvcgroupcount\n"	;
	print "   duplicate objects found 	= $duplnetobjectcount\n";
	print "   rules processed 		= $rulecount\n"		;
	print "   rule objects processed 	= $rulehitscount\n"	;


#===================================================================================================
# CHECK THE DATA STRUCTURERS PULLED FROM OBJECT AND RULE FILE                 ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "NET OBJECTS		\n######################################################################################################################\n\n". Dumper(%netobjects) . "\n\n"	;
	#print "RULE HITS		\n######################################################################################################################\n\n". Dumper(%rulehits) . "\n\n"	;
	#print "RULES			\n######################################################################################################################\n\n". Dumper(%rules) . "\n\n"		;
	#print "SERVICE OBJECTS		\n######################################################################################################################\n\n". Dumper(%srvcobjects) . "\n\n"	;
	#print "NET GROUPS		\n######################################################################################################################\n\n". Dumper(%netgroups) . "\n\n"	;
	#print "EXCLUSION GROUPS	\n######################################################################################################################\n\n". Dumper(%exclgroups) . "\n\n"	;
	#print "SRVC GROUPS		\n######################################################################################################################\n\n". Dumper(%srvcgroups) . "\n\n"	;
	#print "ZONES			\n######################################################################################################################\n\n". Dumper(%zones) . "\n\n"	;

	# NOTE: for cisco only because you can define IP's in the groups and rulebases without naming them first

	#print "IPS			\n######################################################################################################################\n\n". Dumper(%ips) . "\n\n"	;

	# NOTE: for Netscreen pull during config read

	#print "NATS			\n######################################################################################################################\n\n". Dumper(%nats) . "\n\n"	;
	
	
	
#===================================================================================================
# BUILDING COMPLETE LISTINGS OF EACH GROUPS MEMBERS INCLUDING SUBGROUP MEMBERS
#===================================================================================================
	
	my $netsubgroupcount = 0				;

	foreach my $topgroups (keys %netgroups) {
	        net_builder ($topgroups, \%netobjects, \%netgroups, \%networkgroups, \%netgroupobjs, \$netsubgroupcount)			;
	}

#---------------------------------------------------------------------------------------------------
# PRINTING THE BANNER FOR NETWORK SUBGROUP BUILDING COMPLETE 
#---------------------------------------------------------------------------------------------------

	print "-----------------------------------------------------------------------------------------\n";
	print " NETWORK SUBGROUP BUILDING COMPLETE:							\n";
	print "   net subgroups found 		= $netsubgroupcount 					\n";


#===================================================================================================
# CHECK THE COMPLETE NETWORK GROUP DATA STRUCTURERS                            ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "COMPLETE NETGROUPS	\n######################################################################################################################\n\n". Dumper(%networkgroups) . "\n"	;
	#print "NET OBJECTS		\n######################################################################################################################\n\n". Dumper(%netobjects) . "\n\n"	;
	#print "NET GROUP OBJECTS	\n######################################################################################################################\n\n". Dumper(%netgroupobjs) . "\n\n"	;



#===================================================================================================
# BUILDING COMPLETE LISTINGS OF EACH GROUPS MEMBERS INCLUDING SUBGROUP MEMBERS
#===================================================================================================

	my $srvcsubgroupcount = 0					;

	foreach my $topsrvcgroups (keys %srvcgroups) {
	        service_builder ($topsrvcgroups, \%srvcobjects, \%srvcgroups, \%servicegroups, \%srvcgroupobjs, \$srvcsubgroupcount)			;
	}

#---------------------------------------------------------------------------------------------------
# PRINTING THE BANNER FOR SERVICE SUBGROUP BUILDING COMPLETE 
#---------------------------------------------------------------------------------------------------

	print "-----------------------------------------------------------------------------------------\n";
	print " SERVICE SUBGROUP BUILDING COMPLETE:\n"							;
	print "   service subgroups found 	= $srvcsubgroupcount 					\n";

#===================================================================================================
# CHECK THE COMPLETE SERVICE GROUP DATA STRUCTURERS                            ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "SERVICE GROUPS		\n######################################################################################################################\n\n". Dumper(%servicegroups) . "\n"	;
	#print "SRVC GROUPS		\n######################################################################################################################\n\n". Dumper(%srvcgroups) . "\n\n"	;
	#print "SRVC OBJCT GROUPS	\n######################################################################################################################\n\n". Dumper(%srvcgroupobjs) . "\n\n"	;



#===================================================================================================
# BUILDING THE BINARY IP ADDRESS TO OBJECT NAME HASH FOR MATCHING AGAINST
#===================================================================================================

	push (@orderedfwobj, @rangeobjects, @netobjects, @clusterobjects)  	;	# in order of significance so as to write over less significant objects

#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR NET OBJECT ADDRESS PROCESSING STARTING
#---------------------------------------------------------------------------------------------------

	print "-----------------------------------------------------------------------------------------\n";
	print " STARTING NETWORK OBJECT TO BINARY IP RESOLUTION:\n";


# NOTE: Checking for NAT entries and adding if found

	foreach my $object (@orderedfwobj) {
		if (exists ($netobjects{$object}{'hidenat'}) ) {
			my $hnatbin 		= ip_to_bin($netobjects{$object}{'hidenat'})				;
			$ips{$hnatbin}{'name'} 	= $object								;
			$netobjects{$object}{'natbin'}{$hnatbin}++							;

		} elsif (exists ($netobjects{$object}{'staticnat'}) ) {
			my $snatbin 		= ip_to_bin($netobjects{$object}{'staticnat'})				;
			$ips{$snatbin}{'name'}		= $object							;
			$netobjects{$object}{'natbin'}{$snatbin}++							;
		}

	# NOTE: Converting decimal IP's to TEXT BINARY and adding them to the %ips hash

	    	if ($netobjects{$object}{'type'} =~ /^net$|^host$|^member$|^ss$|^idevice$|^plaingw$|^dynamic$|^cpgw$|^default$|^empty$|^cluster$/) {

		# NOTE: process INTERFACE binary IP's and ADD TO OBJECT

			if (exists $netobjects{$object}{'interface'}) {
				foreach my $intname (keys %{$netobjects{$object}{'interface'}}) {
	                		my ($inetbin) 		 		= ip_to_bin($netobjects{$object}{'interface'}{$intname}{'ip'});
	               			my ($imaskbin, $imaskbits, $imasklength) = netmask_to_bin($netobjects{$object}{'interface'}{$intname}{'nm'});
	               		 	my ($imaskedbits) 			= substr($inetbin, 0, $imasklength)		;
	
					if (exists ($ips{$imaskedbits})) {
	               		 		my $oldobject	 = $ips{$imaskedbits}{'name'} 					;
						$duplips{$imaskedbits}{$oldobject}++						;
						$duplips{$imaskedbits}{$object}++						;
					}
					if (exists ($ips{$inetbin})) {
	              		 		my $oldobject	 = $ips{$inetbin}{'name'} 					;
						$duplips{$inetbin}{$oldobject}++						;
						$duplips{$inetbin}{$object}++							;
					} else {
						if (exists $netobjects{$object}{'zone'}) {
							my $zone			= $netobjects{$object}{'zone'}		;
							$ips{$inetbin}{'zone'} 	= $zone						;
						}
						#$ips{$imaskedbits}{'name'} = $object						;
						$ips{$inetbin}{'name'} = $object						;
					}
					#$netobjects{$object}{'ipbin'}{$imaskedbits}++						;
					$netobjects{$object}{'ipbin'}{$inetbin}++						;
				}
			}

		# NOTE: process CLUSTER MEMBER IP's and ADD TO CLUSTER

			if (exists $netobjects{$object}{'member'}) {
				foreach my $member (keys %{$netobjects{$object}{'member'}}) {
	                		my ($mnetbin) 		 		= ip_to_bin($netobjects{$member}{'ip'})		;
	                		my ($mmaskbin, $mmaskbits, $mmasklength)= netmask_to_bin($netobjects{$member}{'nm'})	;
	                		my ($mmaskedbits) 			= substr($mnetbin, 0, $mmasklength)		;

					if (exists ($ips{$mmaskedbits})) {
	                			my $oldobject	 = $ips{$mmaskedbits}{'name'} 					;
						$duplips{$mmaskedbits}{$oldobject}++						;
						$duplips{$mmaskedbits}{$object}++						;
					} else {
						if (exists $netobjects{$object}{'zone'}) {
							my $zone			= $netobjects{$object}{'zone'}		;
							$ips{$mmaskedbits}{'zone'} 	= $zone					;
						}
						$ips{$mmaskedbits}{'name'} = $object						;
					}
					$netobjects{$object}{'ipbin'}{$mmaskedbits}++						;
				}
			}

	                my ($netbin) 		 		= ip_to_bin($netobjects{$object}{'ip'})				;
	                my ($maskbin, $maskbits, $masklength) 	= netmask_to_bin($netobjects{$object}{'nm'})			;
	                my ($maskedbits) 			= substr($netbin, 0, $masklength)				;

			if (exists ($ips{$maskedbits}) && ($ips{$maskedbits}{'name'} ne $object)) {
	                	my $oldobject	 = $ips{$maskedbits}{'name'} 							;
				$duplips{$maskedbits}{$oldobject}++								;
				$duplips{$maskedbits}{$object}++								;
			}

			if (exists $netobjects{$object}{'zone'}) {
				my $zone			= $netobjects{$object}{'zone'}					;
				$ips{$maskedbits}{'zone'} 	= $zone								;
			}
			$ips{$maskedbits}{'name'} 		= $object							;
			$netobjects{$object}{'ipbin'}{$maskedbits}++								;

	# NOTE: process RANGE object

	        } elsif ($netobjects{$object}{'type'} =~ /^range$/) {
			my $checkiprangesize											;
			my @ipstart 	= split (/\./, $netobjects{$object}{'rangestart'})  					;
			my @ipend   	= split (/\./, $netobjects{$object}{'rangeend'})  					;
			if (($ipend[0] - $ipstart[0]) != 0) {
				$checkiprangesize   = ( ($ipend[3] - $ipstart[3]) * ($ipend[2] - $ipstart[2]) * ($ipend[1] - $ipstart[1]) * ($ipend[0] - $ipstart[0])) ;
				#print "CHECK-3 $checkiprangesize\n";
			} elsif (($ipend[1] - $ipstart[1]) != 0) {
				$checkiprangesize   = ( ($ipend[3] - $ipstart[3]) * ($ipend[2] - $ipstart[2]) * ($ipend[1] - $ipstart[1]) ) 				;
				#print "CHECK-2 $checkiprangesize\n";
			} elsif (($ipend[2] - $ipstart[2]) != 0) {
				$checkiprangesize   = ( ($ipend[3] - $ipstart[3]) * ($ipend[2] - $ipstart[2]) )							;
				#print "CHECK-1 $checkiprangesize\n";
			} else {
				$checkiprangesize   = ( ($ipend[3] - $ipstart[3]) )											;
				#print "CHECK-0 $checkiprangesize\n";
			}

		# NOTE: print large range WARNINGS and set object EXCEPTIONS 

			if ($checkiprangesize > 1000000) {
				print "   S-ALERT:  Large IPaddr range     \($checkiprangesize IP's\) in range object \"$object\"\n"	;
				print "   	     Ranges of this size      ^^^  should be considered    INSECURE\n"			;
				$netexceptions{$object} = "net_range_to_large"								;
				next													;
			}
	
			if (($checkiprangesize > 20) && ($checkiprangesize < 1000000)) {
				print "   WARNING:  Large IP range         \($checkiprangesize IPs\) in netobject \"$object\"\n"	;
			}
			for (my $i = $ipstart[0]; $i <= $ipend[0]; $i++) {								# first  octet
				for (my $i1 = $ipstart[1]; $i1 <= $ipend[1]; $i1++) {							# second octet
					for (my $i2 = $ipstart[2]; $i2 <= $ipend[2]; $i2++) {						# third  octet
						for (my $i3 = $ipstart[3]; $i3 <= $ipend[3]; $i3++) {					# fourth octet
							my $iptoadd 		= join (".", $i, $i1, $i2, $i3)				;
							my $ipbin 		= ip_to_bin($iptoadd) 					;
	
							if (exists ($ips{$ipbin})) {
	                					my $oldobject	 = $ips{$ipbin}{'name'} 				;
								$duplips{$ipbin}{$oldobject}++						;
								$duplips{$ipbin}{$object}++						;
								$netobjects{$object}{'ipbin'}{$ipbin}++					;
							} else {
								if (exists $netobjects{$object}{'zone'}) {
									my $zone			= $netobjects{$object}{'zone'}	;
									$ips{$ipbin}{'zone'} 		= $zone				;
								}
						                $ips{$ipbin}{'name'} 	= $object					;
								$netobjects{$object}{'ipbin'}{$ipbin}++					;
							}
						}
					}
				}
			}
	        } else {

		# NOTE: print unknown object WARNING

			print "   WARNING:  Object: $object UNKNOWN\n";
		}
	}

# NOTE: build binary groups

	foreach my $groupn (keys %netgroupobjs) {
		foreach my $groupmem (keys %{$netgroupobjs{$groupn}}) {
			foreach my $groupmembin (keys %{$netobjects{$groupmem}{'ipbin'}}) {
				$bingroups{$groupn}{$groupmembin}++							;
			}
		}
	}
	foreach my $groupn (keys %bingroups) {
		my $groupsize = keys %{$bingroups{$groupn}} 								;
		$bingroupsizes{$groupn} = $groupsize									;
	}

#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR BINARY IP PROCESSING COMPLETE
#---------------------------------------------------------------------------------------------------

	my $ipbincount = keys %ips		;
	my $duplipbincount = keys %duplips	;
	my $bingroupscount = keys %bingroups 	;

	print "-----------------------------------------------------------------------------------------\n";
	print " BINARY IP TO OBJECT NAME RESOLUTION TABLE COMPLETE:\n"	;
	print "   IP's and networks processed 	= $ipbincount\n"	;
	print "   Binary IP groups processed 	= $bingroupscount\n"	;
	print "   duplicate IP's processed	= $duplipbincount\n"	;


#===================================================================================================
# CHECK THE BINARY IP DATA STRUCTURER BUILT FROM THE NET OBJECTS               ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "IPS			\n######################################################################################################################\n\n". Dumper(%ips) . "\n\n"		;
	#print "Duplicate IPS		\n######################################################################################################################\n\n". Dumper(%duplips) . "\n\n"	;
	#print "NET OBJECTS		\n######################################################################################################################\n\n". Dumper(%netobjects) . "\n\n"	;
	#print "BINARY GROUPS		\n######################################################################################################################\n\n". Dumper(%bingroups) . "\n\n"	;
	#print "BINARY GROUP SIZES	\n######################################################################################################################\n\n". Dumper(%bingroupsizes) . "\n\n"	;



#===================================================================================================
# BUILDING THE PORT ADDRESS TO SERVICE OBJECT NAME HASH FOR MATCHING AGAINST
#===================================================================================================

#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR SERVICE ADDRESS PROCESSING STARTING
#---------------------------------------------------------------------------------------------------

	print "-----------------------------------------------------------------------------------------\n";
	print " STARTING SERVICE OBJECT TO PROTO/PORT RESOLUTION:\n"		;

	my %rangesizes								;
	my @smalltolargeranges							;

# NOTE: organizing GREATER THAN ports

	foreach my $srvcobject (@orderedhighports) {
		foreach my $proto (keys %{$srvcobjects{$srvcobject}{'port'}}) {
			my $highport = $srvcobjects{$srvcobject}{'port'}{$proto}; 
			$highport =~ s/^\>//					;
			my $portcount = 65536 - $highport			;
			$rangesizes{$portcount}{$srvcobject}++			;
		}
	}

# NOTE: organizing LESS THAN ports

	foreach my $srvcobject (@orderedlowports) {
		foreach my $proto (keys %{$srvcobjects{$srvcobject}{'port'}}) {
			my $lowport = $srvcobjects{$srvcobject}{'port'}{$proto} ; 
			$lowport =~ s/^\<//					;
			$rangesizes{$lowport}{$srvcobject}++			;
		}
	}

# NOTE: organizing RANGE ports

	foreach my $srvcobject (@orderedportranges) {
		foreach my $proto (keys %{$srvcobjects{$srvcobject}{'port'}}) {
			my $portrange = $srvcobjects{$srvcobject}{'port'}{$proto}; 
			if ($portrange =~ /^\d+\-\d+$/) {
				my ($startport, $endport) = split('-', $portrange)	;
				my $portcount = ($endport - $startport) 		;
				$rangesizes{$portcount}{$srvcobject}++			;
			} else {
				$rangesizes{1}{$srvcobject}++				;
			}
		}
	}

# NOTE: organising ports

	foreach my $srvcobject (@orderedports) {
		foreach my $proto (keys %{$srvcobjects{$srvcobject}{'port'}}) {
			my $portrange = $srvcobjects{$srvcobject}{'port'}{$proto}; 
			if ($portrange =~ /^\d+\-\d+$/) {
				my ($startport, $endport) = split('-', $portrange)	;
				my $portcount = ($endport - $startport) 		;
				$rangesizes{$portcount}{$srvcobject}++			;
			} elsif ($portrange =~ /^\d+$/) {
				$rangesizes{1}{$srvcobject}++				;
			} else {
				#print "NON NUMERIC SERVICE: $srvcobject\n"		;
				$rangesizes{1}{$srvcobject}++				;
			}
		}
	}
	#push (@smalltolargeranges, @orderedports) 				;

# NOTE: process small to large ranges in order

	foreach my $rangesize (sort numerically keys %rangesizes) {
		foreach my $srvcobject (keys %{$rangesizes{$rangesize}}) {
			push (@smalltolargeranges, $srvcobject) 		;
		}
	}

	#print "PORT RANGE SIZES		\n######################################################################################################################\n\n". Dumper(%rangesizes) . "\n\n"	;

	foreach my $srvcobject (@smalltolargeranges) {

# NOTE: check if port and proto EXIST already

		if (exists $srvcobjects{$srvcobject}{'ports'}) {
			foreach my $defaultproto (keys %{$srvcobjects{$srvcobject}{'ports'}}) {
				foreach my $defaultport (keys %{$srvcobjects{$srvcobject}{'ports'}{$defaultproto}}) {
					if (exists $ports{$defaultproto} && exists $ports{$defaultproto}{$defaultport}) {
						#print "ADDED SERVICE DEFINITION TO DUPLICATES: $proto, $defaultport, $srvcobject\n";
						$duplports{$defaultproto}{$defaultport}{'name'}{$srvcobject}++;
					} else {
						$ports{$defaultproto}{$defaultport}{'name'} = $srvcobject;
					}
				}
			}
		}

	# NOTE: get PROTO and PORT from Service Object definition

		foreach my $proto (keys %{$srvcobjects{$srvcobject}{'port'}}) {

			my $portt = $srvcobjects{$srvcobject}{'port'}{$proto} 					; 

		# NOTE:  process RANGE port objects

			if ($portt =~ /^\d+\-\d+$/ ) {
				my ($startport, $endport) = split('-', $portt) 					;
				my $checkrangesize = ($endport - $startport)					;
				if (($checkrangesize > 1000) && ($checkrangesize < 20000)) {
					print "   WARNING:  Large port range       \($checkrangesize ports\) in range object \"$srvcobject\"\n";
					$srvcexceptions{$srvcobject} = 'port_range_to_large'			;
					$ports{"srvcexception_$proto"}{$srvcobject}{'name'} = $srvcobject	;
					foreach my $exproto (keys %{$srvcobjects{$srvcobject}{'ports'}}) {
						$ports{"srvcexception_$exproto"}{$srvcobject}{'name'} = $srvcobject	;
					}
				}
				if ($checkrangesize >= 20000) {
					print "   S-ALERT:  Large port range       \($checkrangesize ports\) in range object \"$srvcobject\"\n";
					print "   	     Ranges of this size      ^^^  should be considered    INSECURE\n";
					$srvcexceptions{$srvcobject} = 'port_range_to_large'			;
					$ports{"srvcexception_$proto"}{$srvcobject}{'name'} = $srvcobject	;
					foreach my $exproto (keys %{$srvcobjects{$srvcobject}{'ports'}}) {
						$ports{"srvcexception_$exproto"}{$srvcobject}{'name'} = $srvcobject	;
					}
				}
				for (my $ix = $startport; $ix <= $endport; $ix++) {
					if (exists ($ports{$proto}{$ix})) {
						$srvcobjects{$srvcobject}{'ports'}{$proto}{$ix}++ 		;
						$duplports{$proto}{$ix}{'name'}{$srvcobject}++			;
					} else {
						$srvcobjects{$srvcobject}{'ports'}{$proto}{$ix}++ 		;
						$ports{$proto}{$ix}{'name'} = $srvcobject			;
					}
				}

		# NOTE:  process GREATER THAN RANGE port objects

			} elsif ($portt =~ m/\>\d+/) {
				$portt =~ s/\>//								;
				#print "AM I WORKING HIGH?\n";
				my $startport = $portt								;
				my $checkrangesize = (65536 - $startport)					;
				if (($checkrangesize > 1000) && ($checkrangesize < 20000)) {
					print "   WARNING:  Large high port range  \($checkrangesize ports\) in range object \"$srvcobject\"\n";
					$srvcexceptions{$srvcobject} = 'high_port_range_to_large'		;
					$ports{"srvcexception_$proto"}{$srvcobject}{'name'} = $srvcobject	;
				}
				if ($checkrangesize >= 20000) {
					print "   S-ALERT:  Large high port range  \($checkrangesize ports\) in range object \"$srvcobject\"\n";
					print "   	     Ranges of this size      ^^^  should be considered    INSECURE\n";
					$srvcexceptions{$srvcobject} = 'high_port_range_to_large'		;
					$ports{"srvcexception_$proto"}{$srvcobject}{'name'} = $srvcobject	;
				}
				for (my $ix = $startport; $ix <= 65536; $ix++) {
					if (exists ($ports{$proto}{$ix})) {
						#print "HIGH YEPPER\n";
						$srvcobjects{$srvcobject}{'ports'}{$proto}{$ix}++ 		;
						$duplports{$proto}{$ix}{'name'}{$srvcobject}++			;
					} else {
						#print "HIGH YEP\n";
						$srvcobjects{$srvcobject}{'ports'}{$proto}{$ix}++ 		;
						$ports{$proto}{$ix}{'name'} = $srvcobject			;
					}
				}

		# NOTE:  process LESS THAN RANGE port objects

			} elsif ($portt =~ m/\<\d+/) {
				$portt =~ s/\<//;
				#print "AM I WORKING LOW?\n";
				my $startport = $portt;
				my $checkrangesize = $portt;
				if (($checkrangesize > 1000) && ($checkrangesize < 20000)) {
					print "   WARNING:  Large low port range   \($checkrangesize ports\) in range object \"$srvcobject\"\n";
					$srvcexceptions{$srvcobject} = 'low_port_range_to_large'		;
					$ports{"srvcexception_$proto"}{$srvcobject}{'name'} = $srvcobject	;
				}
				if ($checkrangesize >= 20000) {
					print "   S-ALERT:  Large low port range   \($checkrangesize ports\) in range object \"$srvcobject\"\n";
					print "   	     Ranges of this size      ^^^  should be considered    INSECURE\n";
					$srvcexceptions{$srvcobject} = 'low_port_range_to_large'		;
					$ports{"srvcexception_$proto"}{$srvcobject}{'name'} = $srvcobject	;
				}
				for (my $ix = $startport; $ix >= 1; $ix--) {
					if (exists ($ports{$proto}{$ix})) {
						#print "LOW YEPPER!!\n";
						$srvcobjects{$srvcobject}{'ports'}{$proto}{$ix}++ 		;
						$duplports{$proto}{$ix}{'name'}{$srvcobject}++			;
					} else {
						#print "LOW YEP!!\n";
						$srvcobjects{$srvcobject}{'ports'}{$proto}{$ix}++ 		;
						$ports{$proto}{$ix}{'name'} = $srvcobject			;
					}
				}

		# NOTE:  process PORT objects

	       		} else {
				if (exists ($ports{$proto}{$portt})) {
					$duplports{$proto}{$portt}{'name'}{$srvcobject}++			;
					$srvcobjects{$srvcobject}{'ports'}{$proto}{$portt}++ 			;
				} else {
					$srvcobjects{$srvcobject}{'ports'}{$proto}{$portt}++ 			;
					$ports{$proto}{$portt}{'name'} = $srvcobject 				;
				}
			}
		}
	}

# NOTE: build port groups

	foreach my $groupns (keys %srvcgroupobjs) {
		foreach my $groupmm (keys %{$srvcgroupobjs{$groupns}}) {
			if (exists $srvcobjects{$groupmm}) {
				foreach my $groupmempro (keys %{$srvcobjects{$groupmm}{'ports'}}) {
					foreach my $groupmempor (keys %{$srvcobjects{$groupmm}{'ports'}{$groupmempro}}) {
						$portgroups{$groupns}{"$groupmempro~$groupmempor"}++		;
					}
				}
			} else {
				$portgroups{$groupns}{"portunknown~$groupmm"}++ 				;
			}
		}
	}

#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR SERVICE ADDRESS PROCESSING COMPLETE
#---------------------------------------------------------------------------------------------------

	my $portgroupcount 	= keys %portgroups			;
	my $protocount 		= keys %ports				;
	my $tcpportcount 	= keys %{$ports{'tcp'}} 		;
	my $udpportcount 	= keys %{$ports{'udp'}} 		;
	my $rcpportcount 	= keys %{$ports{'rcp'}} 		;
	my $icmpportcount 	= keys %{$ports{'icmp'}} 		;
	my $igmpportcount 	= keys %{$ports{'igmp'}} 		;
	my $duplprotocount 	= keys %duplports			;
	my $dupltcpportcount 	= keys %{$duplports{'tcp'}} 		;
	my $dupludpportcount 	= keys %{$duplports{'udp'}} 		;
	my $duplrcpportcount 	= keys %{$duplports{'rcp'}} 		;
	my $duplicmpportcount 	= keys %{$duplports{'icmp'}} 		;
	my $dupligmpportcount 	= keys %{$duplports{'igmp'}} 		;
	my $portunknowncount 	= keys %{$ports{'portunknown'}} 	;

	print "-----------------------------------------------------------------------------------------\n";
	print " PORT TO SERVICE OBJECT NAME RESOLUTION TABLE COMPLETE:\n"	;
	print "   portgroups processed		= $portgroupcount\n"		;
	print "   ICMP ports processed		= $icmpportcount\n"		;
	print "   IGMP ports processed		= $igmpportcount\n"		;
	print "   TCP  ports processed		= $tcpportcount\n"		;
	print "   UDP  ports processed		= $udpportcount\n"		;
	print "   RCP  ports processed		= $rcpportcount\n"		;
	print "   Protos     processed		= $protocount\n"		;
	print "   ICMP port duplicates		= $duplicmpportcount\n"		;
	print "   IGMP port duplicates		= $dupligmpportcount\n"		;
	print "   TCP  port duplicates		= $dupltcpportcount\n"		;
	print "   UDP  port duplicates		= $dupludpportcount\n"		;
	print "   RCP  port duplicates		= $duplrcpportcount\n"		;
	print "   Protocol  duplicates		= $duplprotocount\n"		;
	print "   unknown ports processed	= $portunknowncount\n"		;


#===================================================================================================
# CHECK THE PORT ADDRESS STRUCTURER BUILT FROM THE SERVICE OBJECTS             ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "PORTS			\n######################################################################################################################\n\n". Dumper(%ports) . "\n\n"	;
	#print "PORTS			\n######################################################################################################################\n\n". Dumper(%portexceptions) . "\n\n"	;
	#print "SERVICE OBJECTS		\n######################################################################################################################\n\n". Dumper(%srvcobjects) . "\n\n"	;
	#print "PORT GROUPS		\n######################################################################################################################\n\n". Dumper(%portgroups) . "\n\n"	;
	#print "DUPLICATE PORTS		\n######################################################################################################################\n\n". Dumper(%duplports) . "\n\n"	;



#===================================================================================================
# BUILDING THE RULEBASE BINARY HASH FOR MATCHING AGAINST
#===================================================================================================

#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR STARTING RULE PROCESSING
#---------------------------------------------------------------------------------------------------

	print "-----------------------------------------------------------------------------------------\n";
	print " STARTING RULEBASE MATCH ANALYSIS:\n";

	%rashrules = ()										; 
	my $rulebincount = 0									;
	my $rulebincountholder = 0								;
	my $rulebincountquick = 0								;

	my $natrulecount = 1000000								;

	foreach my $testicle (keys %netobjects) {
		unless (defined ($netobjects{$testicle}{'ipbin'}) ) {
			print "   WARNING: NO IP BIN PRE $testicle\n"				;
		}
	}

	foreach my $rulenum (sort numerically keys (%rules)) {
		my @rulesrcs = rule_net_obj_ungrouper($rulenum, 'src', \%netobjects, \%netgroupobjs, \%rules)				;
		foreach my $rulesrc (@rulesrcs) {
			foreach my $srcbin (keys (%{$netobjects{$rulesrc}{'ipbin'}})) {
				my @ruledsts = rule_net_obj_ungrouper($rulenum, 'dst', \%netobjects, \%netgroupobjs, \%rules)		;
				foreach my $ruledst (@ruledsts) {
					foreach my $dstbin (keys (%{$netobjects{$ruledst}{'ipbin'}})) {
						my @rulesrvcs = rule_srvc_obj_ungrouper($rulenum, \%srvcobjects, \%srvcgroupobjs, \%rules);
						foreach my $rulesrvc (@rulesrvcs) {
							if (exists ($srvcexceptions{$rulesrvc})) {
								foreach my $rangeproto (keys %{$srvcobjects{$rulesrvc}{'port'}}) {
									my $ruleproto = "srvcexception_$rangeproto"			; 
									my $ruleport  = $rulesrvc					;
									#$ports{'srvcexceptions'}{$rulesrvc}{'name'} = $rulesrvc	;
									rule_bin_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$natrulecount,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\%netobjects,\%srvcobjects,\%rules,\%nats,\%rashrules,\%binrules);
								}

							} elsif (exists ($srvcobjects{$rulesrvc}{'ports'})) {
								foreach my $ruleproto (keys (%{$srvcobjects{$rulesrvc}{'ports'}})) {
									foreach my $ruleport (keys (%{$srvcobjects{$rulesrvc}{'ports'}{$ruleproto}})) {
										rule_bin_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$natrulecount,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\%netobjects,\%srvcobjects,\%rules,\%nats,\%rashrules,\%binrules);
									}
								}
							} else {
								$srvcobjects{$rulesrvc}{'ports'}{'portunknown'}{$rulesrvc}++ 	;
								$srvcobjects{$rulesrvc}{'port'}{'portunknown'} = $rulesrvc 	;
								$srvcobjects{$rulesrvc}{'type'} = 'portunknown' 		;
								$ports{'portunknown'}{$rulesrvc}{'name'} = $rulesrvc		;
								my $ruleproto = 'portunknown'					;
								my $ruleport  =  $rulesrvc   					;
								rule_bin_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$natrulecount,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\%netobjects,\%srvcobjects,\%rules,\%nats,\%rashrules,\%binrules)			;
								#print "Unknown port: $rulesrvc\n";
							}
						}
					}
				}
			}
		}
	}
	print "\n";


#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR BINARY RULE PROCESSING COMPLETE
#---------------------------------------------------------------------------------------------------

	print "-----------------------------------------------------------------------------------------\n";
	print " BINARY RULE MATCH TABLE COMPLETE:\n"			;
	print "   src/dst/port matches procssd	= $rulebincount\n"	;
	print "   derived from rules numbering	= $rulecount\n"		;

# NOTE: data consistency checks

	foreach my $rule (sort numerically keys %rules) {
		unless (defined ($rules{$rule}{'allsrvcobjs'}) || defined ($rules{$rule}{'srcbins'}) || defined ($rules{$rule}{'dstbins'}) || defined ($rules{$rule}{'allsrvcports'}) || defined ($rules{$rule}{'type'})) {
			print "   WARNING: INCOMPLETE RULE: $rule, $rulecsvs{$rule}\n";
		}
		#unless (defined ($rules{$rule}{'allsrvcobjs'})) {
		#	print "NO SERVICE OBJS $rule\n$rulecsvs{$rule}\n";
		#}
		#unless (defined ($rules{$rule}{'srcbins'})) {
		#	print "NO SRCBINS $rule\n$rulecsvs{$rule}\n"	;
		#}
		#unless (defined ($rules{$rule}{'dstbins'})) {
		#	print "NO DSTBINS $rule\n$rulecsvs{$rule}\n"	;
		#}
		#unless (defined ($rules{$rule}{'allsrvcports'})) {
		#	print "NO SRVCPORTS $rule\n$rulecsvs{$rule}\n"	;
		#}
	}
	foreach my $testicle (sort keys %netobjects) {
		unless (defined ($netobjects{$testicle}{'ipbin'}) ) {
			print "   WARNING: NO IP BIN POST $testicle\n"	;
		}
	}

#===================================================================================================
# CHECK THE BINARY IP DATA STRUCTURER BUILT FROM THE NET OBJECTS               ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "BINARY RULE TABLE	\n######################################################################################################################\n\n". Dumper(%binrules) . "\n\n"	;
	#print "PORT/DST/SRC RULE TABLE	\n######################################################################################################################\n\n". Dumper(%rashrules) . "\n\n"	;
	#print "RULES			\n######################################################################################################################\n\n". Dumper(%rules) . "\n\n"		;
	#print "NET OBJECTS		\n######################################################################################################################\n\n". Dumper(%netobjects) . "\n\n"	;
	#print "SERVICE OBJECTS		\n######################################################################################################################\n\n". Dumper(%srvcobjects) . "\n\n"	;
	#print "PORTS			\n######################################################################################################################\n\n". Dumper(%ports) . "\n\n"	;


#===================================================================================================
# BUILDING THE NAT RULEBASE HASH from FWDOC format FOR MATCHING AGAINST
#===================================================================================================

# NOTE: I'm using fw doc format in odumper mode because I dont know how to export nat rules in odumper
#	the nat file takes the place of a router file on the command line

#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR STARTING NAT RULE PROCESSING
#---------------------------------------------------------------------------------------------------

	print "-----------------------------------------------------------------------------------------\n";
	print " STARTING NAT RULEBASE ANALYSIS:\n";

	my $natcount = 0								;
	my $natlinecountquick  = 0							;
	my $natlinecountholder = 0							;

	if ($configtype =~ /^od$|^cs$|^ns$/) {
		my $routefile = $confignames{$config}{'routefile'}			;
		open NATFILE, "$routefile" or warn "Can't open $routefile: $!\n"		; 

	# NOTE: read nats in the legendary fwdoc format

		while (<NATFILE>) {
			$_ =~ s/\n//g							;
			$_ =~ s/\r//g							;
			next if $_ =~ m/^Number/					;
			my ($number,$enabled,$origfrom,$origto,$origservice,$natfrom,$natto,$natservice,$installon,$comment) = split(/\t/, $_);
			$nats{$number}{'enabled'}   = $enabled				; 
			$nats{$number}{'installon'} = $installon			; 
			$nats{$number}{'comment'}   = $comment				; 
			$nats{$number}{'origsrc'}{$origfrom}++				; 
			$nats{$number}{'origdst'}{$origto}++				; 
			$nats{$number}{'origsrvc'}{$origservice}++			; 
			$nats{$number}{'natsrc'}   = $natfrom				; 
			$nats{$number}{'natdst'}   = $natto				; 
			$nats{$number}{'natsrvc'}  = $natservice			; 
		} 
		foreach my $number (sort numerically keys %nats) {
			my $enabled 	= $nats{$number}{'enabled'} 	;
			my $installon	= $nats{$number}{'installon'}	;
			my $comment	= $nats{$number}{'comment'}	;

			foreach my $origfrom (keys %{$nats{$number}{'origsrc'}}) {
				foreach my $origto (keys %{$nats{$number}{'origdst'}}) {
					foreach my $origservice (keys %{$nats{$number}{'origsrvc'}}) {
						my $natfrom     = $nats{$number}{'natsrc'};
						my $natto       = $nats{$number}{'natdst'};
						my $natservice  = $nats{$number}{'natsrvc'};

			
			unless (defined ($enabled) && defined ($origfrom) && defined ($origto) && defined ($origservice) && defined ($natfrom) && defined ($natto) && defined ($natservice) && defined ($installon) && defined( $comment)) {
				print "   WARNING:  INCOMPLETE NAT RULE:  $number -  ";
				if (defined ($enabled)) 	{ print "ENABLED ($enabled) "		; }
				if (defined ($origfrom)) 	{ print "ORIGFROM ($origfrom) "		; }
				if (defined ($origto)) 		{ print "ORIGTO ($origto) "		; }
				if (defined ($origservice)) 	{ print "ORIGSERVICE ($origservice) "	; }
				if (defined ($natfrom)) 	{ print "NATFROM ($natfrom) "		; }
				if (defined ($natto)) 		{ print "NATTO ($natto) "		; }
				if (defined ($natservice)) 	{ print "NATSERVICE ($natservice) "	; }
				if (defined ($installon)) 	{ print "INSTALLON ($installon) "	; }
				if (defined ($comment)) 	{ print "COMMENT ($comment) "		; }
				print "\n";
				next;
			}

			if (exists $netobjects{$origfrom}) {
				$netobjects{$origfrom}{'natsrc'}{$natfrom} = $number ;
				$netobjects{$origfrom}{'natsrvc'}{$natservice} = $number ;

				foreach my $origfrombin (keys %{$netobjects{$origfrom}{'ipbin'}}) {
					$nats{$number}{'origsrcbins'}{$origfrombin}++	; 
					$natcount++					;
				}
			} elsif (exists $netgroups{$origfrom}) {
				foreach my $origfrombin (keys %{$bingroups{$origfrom}}) {
					my $origname = ipbin_to_name($origfrombin, \%ips);
					$netobjects{$origname}{'natsrc'}{$natfrom} = $number ;
					$netobjects{$origname}{'natsrvc'}{$natservice} = $number ;
					$nats{$number}{'origsrcbins'}{$origfrombin}++	; 
					$natcount++					;
				}
			} else {
				#print "FUCK!! $origfrom\n"				;
			}
			if (exists $netobjects{$origto}) {
				$netobjects{$origto}{'natdst'}{$natto} = $number ;
				$netobjects{$origto}{'natsrvc'}{$natservice} = $number ;

				foreach my $origtobin (keys %{$netobjects{$origto}{'ipbin'}}) {
					$nats{$number}{'origdstbins'}{$origtobin}++	; 
					$natcount++					;
				}
			} elsif (exists $netgroups{$origto}) {
				foreach my $origtobin (keys %{$bingroups{$origto}}) {
					my $origname = ipbin_to_name($origtobin, \%ips);
					$netobjects{$origname}{'natdst'}{$natto} = $number ;
					$netobjects{$origname}{'natsrvc'}{$natservice} = $number ;
					$nats{$number}{'origdstbins'}{$origtobin}++	; 
					$natcount++					;
				}
			} else {
				$natcount++						;
				#print "COCK!! $origto, $number\n"			;
			}
			if (exists $netgroups{$natto}) {
				$natcount++						;
				#print "OH FUCK! $natto, $number\n"			;
			}
			if (exists $netgroups{$natfrom}) {
				$natcount++						;
				#print "OH NOO! $natfrom, $number\n"			;
			}
			if (exists $srvcobjects{$origservice}) {
				#print "COOOL: $origservice\n";
				foreach my $origproto (keys %{$srvcobjects{$origservice}{'ports'}}) {
					#print "COOOL:: $origservice\n";
					foreach my $origport (keys %{$srvcobjects{$origservice}{'ports'}{$origproto}}) {

						if (exists $srvcexceptions{$origservice}) {
							
							$nats{$number}{'origsrvcports'}{"srvcexception_$origproto"}{$origservice}++;
							$natcount++				;
							last;

						} else {
							
							$nats{$number}{'origsrvcports'}{$origproto}{$origport}++;
							$natcount++				;
						}
						if ($natcount >= ($natlinecountquick + 200)) {
							print ".";
							$natlinecountquick = $natcount;
						}
						if ($natcount >= ($natlinecountholder + 10000)) {
							print ".$natcount	nat matches processed\n";
							$natlinecountholder = $natcount;
						}
					}
				}
			}
	# NOTE: Ending foreach loop set
					}
				}
			}
	# NOTE: end of foreach loop set... yippie!
		}
	}


#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR NAT RULE FILE PROCESSING
#---------------------------------------------------------------------------------------------------
	
	my $natscount = keys %nats			;
	
	print "\n-----------------------------------------------------------------------------------------\n";
	print " NAT RULE TABLE BUILD COMPLETE:\n"				;
	print "   objects processed 		= $natcount\n"			;
	print "   from rules numbering  	= $natscount\n"			;
	
#===================================================================================================
# CHECK THE NATS TABLE BUILT FROM THE NET OBJECTS 		               ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "NATS			\n######################################################################################################################\n\n". Dumper(%nats) . "\n\n"	;
	
	
#===================================================================================================
# NETSCREEN LOG FILE ANALYSIS
#===================================================================================================
	
#---------------------------------------------------------------------------------------------------
# PRINT BANNER FOR STARTING LOG FILE PROCESSING
#---------------------------------------------------------------------------------------------------
	
	print "-----------------------------------------------------------------------------------------\n";
	print " STARTING LOG FILE ANALYSIS:\n";
	
#===================================================================================================
# OPENING THE LOG FILE
#===================================================================================================
	
	my $logfile = $confignames{$config}{'logfile'}			;

	open LOGFILE, "$logfile" or warn "Can't open $logfile: $!\n"	;        
	
	if ($configtype eq 'ns') {
		my %protos;
		my %actions;
		$protos{1}	= 'icmp'	;
		$protos{2}	= 'igmp'	;
		$protos{6}	= 'tcp'		;
		$protos{17}	= 'udp'		;
		$protos{47}	= 'GRE'		;
		$protos{50}	= 'AH'		;
		$protos{51}	= 'ESP'		;
		$protos{112}	= 'vrrp'	;
		$protos{115}	= 'l2tp'	;

		my $loglinecount = 0;

		while (<LOGFILE>) {
		        chomp;
		        my @line 	= shellwords($_);
			my $date 	= "$line[0].$line[1]";
			my $time 	= $line[2];
			my $origin_id 	= $line[3];
			my $version	= $line[4];
			my $dev_id	= $line[6];
			my $logtype	= $line[8];
			my $functype	= $line[9];
			my ($starttime,$duration,$rbnum,$service,$proto,$srczone,$dstzone,$action,$sent,$rcvd,$src,$dst,$icmp,$srcport,$dstport,$srcxlate,$dstxlate,$xlsrcport,$xldstport);

			for (my $i = 10; $i <= $#line; $i++) {
				#if ($line[$i] 		=~ m/^start_time=/) 	{ $starttime  	= $line[$i] 		; $starttime	=~ s/^start_time=// 	; 	}	#print "starttime $starttime\n";	
				#elsif ($line[$i] 	=~ m/^duration=/) 	{ $duration 	= $line[$i] 		; $duration 	=~ s/^duration=//  	; 	}	#print "duration $duration\n"; 		
				   if ($line[$i] 	=~ m/^policy_id=/)	{ $rbnum 	= $line[$i] 		; $rbnum 	=~ s/^policy_id=//	; 	} 	#print "policy $rbnum\n";		
				elsif ($line[$i] 	=~ m/^service=/)	{ $service	= $line[$i] 		; $service	=~ s/^service=//	; 	}	#print "service $service\n";		
				elsif ($line[$i] 	=~ m/^proto=/)		{ $proto	= $line[$i]		; $proto	=~ s/^proto=//		; 	}	#print "proto $proto\n";		
				elsif (($line[$i] =~ m/^src$/) && ($line[$i + 1] =~ m/^zone=/)){ $srczone = $line[$i + 1]; $srczone	=~ s/^zone=//		; $i++ ;} 	#print "src zone $srczone\n";			
				elsif (($line[$i] =~ m/^dst$/) && ($line[$i + 1] =~ m/^zone=/)){ $dstzone = $line[$i + 1]; $dstzone	=~ s/^zone=//		; $i++ ;} 	#print "dst zone $dstzone\n";		
				elsif ($line[$i] 	=~ m/^action=/)		{ $action	= $line[$i]		; $action	=~ s/^action=//		; 	}	#print "action $action\n";		
				#elsif ($line[$i] 	=~ m/^sent=/)		{ $sent		= $line[$i]		; $sent		=~ s/^sent=//		; 	}	#print "sent $sent\n";			
				#elsif ($line[$i] 	=~ m/^rcvd=/)		{ $rcvd		= $line[$i]		; $rcvd		=~ s/^rcvd=//		; 	}	#print "rcvd $rcvd\n";
				elsif ($line[$i] 	=~ m/^src=/)		{ $src		= $line[$i]		; $src		=~ s/^src=//		; 	}	#print "src $src\n";
				elsif ($line[$i] 	=~ m/^dst=/)		{ $dst		= $line[$i]		; $dst		=~ s/^dst=//		; 	}	#print "dst $dst\n";
				elsif ($line[$i] 	=~ m/^icmp/)		{ $icmp		= $line[$i + 1]		; $icmp		=~ s/^type=//		; 	}	#print "icmp $icmp\n";
				#elsif ($line[$i] 	=~ m/^src_port=/)	{ $srcport	= $line[$i]		; $srcport	=~ s/^src_port=//	; 	}	#print "src port $srcport\n";
				elsif ($line[$i] 	=~ m/^dst_port=/)	{ $dstport	= $line[$i]		; $dstport	=~ s/^dst_port=//	; 	}	#print "dst port $dstport\n";
				elsif ($line[$i] 	=~ m/^src-xlated$/)	{ $srcxlate	= $line[$i + 1]		; $srcxlate	=~ s/^ip=//		; $i++ ;	#print "src xlate $srcxlate\n"; 
					if ($line[$i + 1] =~ m/^port=/)		{ $xlsrcport 	= $line[$i + 1] 	; $xlsrcport	=~ s/^port=//		; $i++ ;} 	#print "src xlate port $xlsrcport\n"; 
				}
				elsif ($line[$i] =~ m/dst-xlated$/)		{ $dstxlate	= $line[$i + 1]		; $dstxlate	=~ s/^ip=//		; $i++ ; 	#print "dst xlate $dstxlate\n";	
					if ($line[$i + 1] =~ m/^port=/)		{ $xldstport 	= $line[$i + 1] 	; $xldstport	=~ s/^port=//		; $i++ ;} 	#print "dst xlate port $xldstport\n";
				}
			}

			my @hour 	= split ( ':', $time ) 								;
			my $hour 	= $hour[0]									;
		
			if (defined ($src) && defined($dst) && defined($proto) && ($action eq 'Permit') && (defined($dstport) || defined($service) || defined($icmp))) {
				if ($service ne "") {
					if ($service =~ '/port:')   {($proto, $service)	= split('/port:', $service)	; }
					if (exists $protos{$proto}) {$proto 		= $protos{$proto}		; }
					#$srvcstree{$dst}{$src}{$proto}{$service}{'count'}++				;
					#$srvcstree{$dst}{$src}{$proto}{$service}{'hours'}{$hour}++			;
					#$srvcstree{$dst}{$src}{$proto}{$service}{'lastseen'} = "$date:$time"		;
					#$srvcstree{$dst}{$src}{$proto}{$service}{'sourceports'}{$srcport}++		;
					$srvcstree{$dst}{$src}{$proto}{$service}{'rules'}{$rbnum}++			;
					$srvcstree{$dst}{$src}{$proto}{$service}{'zones'} = "$srczone~$dstzone"		;
					if (defined ($dstxlate)) {
						$srvcstree{$dst}{$src}{$proto}{$service}{'lognatdst'}{$dstxlate} = $rbnum			;
					}
					if (defined ($srcxlate)) {
						$srvcstree{$dst}{$src}{$proto}{$service}{'lognatsrc'}{$srcxlate} = $rbnum			;
					}
					if (defined ($xldstport)) {
						$srvcstree{$dst}{$src}{$proto}{$service}{'lognatsrvc'}{$xldstport} = $rbnum			;
					}
				}
				if (defined $dstport && $dstport ne "") {
					if (exists $protos{$proto}) {$proto 		= $protos{$proto}		; }
					#$srvcstree{$dst}{$src}{$proto}{$dstport}{'count'}++				;
					#$srvcstree{$dst}{$src}{$proto}{$dstport}{'hours'}{$hour}++			;
					#$srvcstree{$dst}{$src}{$proto}{$dstport}{'lastseen'} = "$date:$time"		;
					#$srvcstree{$dst}{$src}{$proto}{$dstport}{'sourceports'}{$srcport}++		;
					$srvcstree{$dst}{$src}{$proto}{$dstport}{'rules'}{$rbnum}++			;
					$srvcstree{$dst}{$src}{$proto}{$dstport}{'zones'} = "$srczone~$dstzone"		;
					if (defined ($dstxlate)) {
						$srvcstree{$dst}{$src}{$proto}{$dstport}{'lognatdst'}{$dstxlate} = $rbnum			;
					}
					if (defined ($srcxlate)) {
						$srvcstree{$dst}{$src}{$proto}{$dstport}{'lognatsrc'}{$srcxlate} = $rbnum			;
					}
					if (defined ($xldstport)) {
						$srvcstree{$dst}{$src}{$proto}{$dstport}{'lognatsrvc'}{$xldstport} = $rbnum			;
					}
				}
				if (defined $icmp) {
					$srvcstree{$dst}{$src}{'icmp'}{$icmp}{'rules'}{$rbnum}++			;
					$srvcstree{$dst}{$src}{'icmp'}{$icmp}{'zones'} = "$srczone~$dstzone"		;
					if (defined ($dstxlate)) {
						$srvcstree{$dst}{$src}{'icmp'}{$icmp}{'lognatdst'}{$dstxlate} = $rbnum			;
					}
					if (defined ($srcxlate)) {
						$srvcstree{$dst}{$src}{'icmp'}{$icmp}{'lognatsrc'}{$srcxlate} = $rbnum			;
					}
					if (defined ($xldstport)) {
						$srvcstree{$dst}{$src}{'icmp'}{$icmp}{'lognatsrvc'}{$xldstport} = $rbnum			;
					}
				}
			} elsif (defined ($src) && defined($dst) && defined($proto) && ($action eq 'Deny') && (defined($dstport) || defined($service) || defined($icmp))) {

		# NOTE: build drop trees here, currently this is just preventing the else below picking up the Denied connections

				#print "DROPPED: $_\n";

			} else {
				#print "\n    WARNING:  MISSED LOG ENTRY:  $_";
			}
			if (defined($src) && defined($dst)) {
				$uniqueiphits{$src}++									;
				$uniqueiphits{$dst}++									;
			}

			$daystree{$date}++										;

#---------------------------------------------------------------------------------------------------
# PRINT DOTS DURING PROCESSING
#---------------------------------------------------------------------------------------------------
		
			$loglinecount++	;
			if ($loglinecount == ($loglinecountquick + 2000)) {
				print ".";
				$loglinecountquick = $loglinecount;
			}
			if ($loglinecount == ($loglinecountholder + 100000)) {
				print ".$loglinecount	lines read\n"		;
				$loglinecountholder = $loglinecount;
			}
		}

	} elsif ($configtype eq 'od') {

#===================================================================================================
# START THE NEW VERSION OF THE LOG READER
#===================================================================================================

#		my @header;
#		while (<LOGFILE>) {
#	        	chomp;
#
#		# NOTE: Read header line 
#
#			if (/^num/) {
#				@header = ();
#		        	@header = split (/;/, $_, 150);
#				$logheaddercount++		;
#				next;
#			}
#
#			my %logline=();
#			@logline{@header} = split(/;/, $_, 150);
#
#			next unless $logline{'action'} eq 'accept';
#			next unless exists $logline{'proto'};
#			next unless exists $logline{'src'};
#			next unless exists $logline{'dst'};
#
#			#if (exists ($logline{'src'}) && exists($logline{'dst'})  && exists($logline{'proto'})) {
#				my ($src,$service_id,$service,$dst,$proto,$action,$date,$rule,$time,$s_port) = 
#					($logline{'src'},$logline{'service_id'},$logline{'service'},$logline{'dst'},$logline{'proto'},$logline{'action'},$logline{'date'},$logline{'rule'},$logline{'time'},$logline{'s_port'}); 
#				my @hour 	= split ( ':', $time ) 								;
#				my $hour 	= $hour[0]											;
#
#				#if (($proto eq 'udp') || (($proto eq 'tcp') && ($if_name eq 'daemon'))) {	  
#				if (exists($logline{'service'}) && ($logline{'service'} ne "")) {
#					#$srvcstree{$dst}{$src}{$proto}{$service}{'count'}++							;
#					#$srvcstree{$dst}{$src}{$proto}{$service}{'hours'}{$hour}++						;
#					$srvcstree{$dst}{$src}{$proto}{$service}{'rules'}{$rule}++						;
#					#$srvcstree{$dst}{$src}{$proto}{$service}{'lastseen'} = "$date:$time"					;
#					#$srvcstree{$dst}{$src}{$proto}{$service}{'sourceports'}{$s_port}++					;
#				}
#				if (exists($logline{'service_id'}) ) {
#				#	print "$_\n";
#					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'count'}++							;
#					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'hours'}{$hour}++						;
#					$srvcstree{$dst}{$src}{$proto}{$service_id}{'rules'}{$rule}++						;
#					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'lastseen'} = "$date:$time"					;
#					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'sourceports'}{$s_port}++					;
#				}
#				$uniqueiphits{$src}++											;
#				$uniqueiphits{$dst}++											;
#				$daystree{$date}++												;
#			#}
#
#
##---------------------------------------------------------------------------------------------------
## PRINT DOTS DURING PROCESSING
##---------------------------------------------------------------------------------------------------
#
#			$loglinecount++	;
#			if ($loglinecount == ($loglinecountquick + 2000)) {
#				print ".";
#				$loglinecountquick = $loglinecount;
#			}
#			if ($loglinecount == ($loglinecountholder + 100000)) {
#				print ".$loglinecount	lines read\n"		;
#				$loglinecountholder = $loglinecount;
#			}
#		}

#		print "DAYS TREE 		\n########################################################################################################################\n\n". Dumper(%daystree) . "\n\n"		;
#		print "UNIQUE IPS TREE 		\n########################################################################################################################\n\n". Dumper(%uniqueiphits) . "\n\n"		;
#		print "SERVICES TREE 		\n########################################################################################################################\n\n". Dumper(%srvcstree) . "\n\n"		;

#===================================================================================================
# START THE OLD VERSION OF THE LOG READER
#===================================================================================================
	
# NOTE: Touching variables for log headder retreval

		my $numColumn                   ;
		my $dateColumn                  ;
		my $timeColumn                  ;
#		my $typeColumn                  ;
		my $ruleColumn                  ;
#		my $rule_nameColumn             ;
#		my $rule_uidColumn              ;
#		my $NAT_addtnl_rulenumColumn    ;
#		my $NAT_rulenumColumn           ;
		my $actionColumn                ;
#		my $auth_methodColumn           ;
#		my $userColumn                  ;
#		my $if_nameColumn               ;
#		my $if_dirColumn                ;
#		my $origColumn                  ;
#		my $origin_idColumn             ;
		my $srcColumn                   ;
		my $xlatesrcColumn              ;
		my $s_portColumn                ;
		my $xlatesportColumn            ;
		my $dstColumn                   ;
		my $xlatedstColumn              ;
		my $serviceColumn               ;
		my $service_idColumn            ;
		my $xlatedportColumn            ;
		my $protoColumn                 ;
#		my $tcp_flagsColumn             ;
#		my $rpc_progColumn              ;
#		my $th_flagsColumn              ;
#		my $icmptypeColumn              ;
#		my $icmpcodeColumn              ;
#		my $message_infoColumn          ;
#		my $sys_messageColumn           ;
#		my $log_sys_messageColumn       ;
#		my $tcpstateColumn              ;
#		my $reasonColumn                ;
#		my $alertColumn                 ;
#		my $attackColumn                ;
#		my $productColumn               ;
#		my $attackinfoColumn            ;
#		my $H323messageColumn           ;
#		my $srcphonenumberColumn        ;
#		my $dstphonenumberColumn        ;
#		my $suppressedlogsColumn        ;
#		my $totallogsColumn             ;
#		my $CertificateDNColumn		;
#		my $CookieIColumn		;
#		my $CookieRColumn		;
#		my $DCERPCInterfaceUUIDColumn	;
#		my $ICMPColumn			;
#		my $ICMPCodeColumn		;
#		my $ICMPTypeColumn		;
#		my $IKEIDsColumn		;
#		my $IKEnotificationColumn	;
#		my $IKEColumn			;
#		my $Internal_CAColumn		;
#		my $PacketinfoColumn		;
#		my $SmartDefenseprofileColumn	;
#		my $TCPflagsColumn		;
#		my $TotallogsColumn		;
#		my $communityColumn		;
#		my $dnColumn			;
#		my $dns_queryColumn		;
#		my $dns_typeColumn		;
#		my $dstkeyidColumn		;
#		my $during_secColumn		;
#		my $encryptionfailureColumn	;
#		my $fragments_droppedColumn	;
#		my $fw_messageColumn		;
#		my $fw_subproductColumn		;
#		my $ip_idColumn			;
#		my $ip_lenColumn		;
#		my $ip_offsetColumn		;
#		my $messageColumn		;
#		my $methodsColumn		;
#		my $msgidColumn			;
#		my $partnerColumn		;
#		my $peergatewayColumn		;
#		my $reject_categoryColumn	;
#		my $reject_idColumn		;
#		my $resourceColumn		;
#		my $schemeColumn		;
#		my $serial_numColumn		;
#		my $session_idColumn		;
#		my $srckeyidColumn		;
#		my $vpn_feature_nameColumn	;
		
		
#===================================================================================================
# START THE LOOP THAT WORKS ON EACH LINE AND SPLIT THE LINE INTO CHUNKS
#===================================================================================================
	
		while (<LOGFILE>) {
			chomp;
			my @line = split (/;/, $_, 90 );
		
		
	# NOTE: Print fields with numbers as check for index assignment later on
		#
		#	my $goatcount = 0;
		#	print "\n";
		#	foreach my $goat (@line) {
		#		print "$goatcount $goat 	";
		#		$goatcount++;
		#	}
		#	print "\nLog line count: $loglinecount\n";
		
		
#===================================================================================================
# SETTING VARIABLES AND ASSIGNING COLUMNS IF YOU HAVE **NOT** SET LOGEXPORT.INI (Auto Mode)
#===================================================================================================

#			my $num                 ;
			my $date                ;
#			my $time                ;
#			my $type                ;
			my $rule                ;
#			my $rule_name           ;
#			my $rule_uid            ;
#			my $NAT_addtnl_rulenum  ;
#			my $NAT_rulenum         ;
			my $action              ;
#			my $auth_method         ;
#			my $user                ;
#			my $if_name             ;
#			my $if_dir              ;
#			my $orig                ;
#			my $origin_id           ;
			my $src                 ;
			my $xlatesrc            ;
#			my $s_port              ;
			my $xlatesport          ;
			my $dst                 ;
			my $xlatedst            ;
			my $service             ;
			my $service_id          ;
			my $xlatedport          ;
			my $proto               ;
#			my $tcp_flags           ;
#			my $rpc_prog            ;
#			my $th_flags            ;
#			my $icmptype            ;
#			my $icmpcode            ;
#			my $message_info        ;
#			my $sys_message         ;
#			my $log_sys_message     ;
#			my $tcpoutofstate       ;
#			my $reason              ;
#			my $alert               ;
#			my $attack              ;
#			my $product             ;
#			my $attackinfo          ;
#			my $H323message         ;
#			my $srcphonenumber      ;
#			my $dstphonenumber      ;
#			my $suppressedlogs      ;
#			my $totallogs           ;
#			my $CertificateDN	;
#			my $CookieI		;
#			my $CookieR		;
#			my $DCERPCInterfaceUUID ;
#			my $ICMP		;
#			my $ICMPCode		;
#			my $ICMPType		;
#			my $IKEIDs		;
#			my $IKEnotification	;
#			my $IKE			;
#			my $Internal_CA		;
#			my $Packetinfo		;
#			my $SmartDefenseprofile	;
#			my $TCPflags		;
#			my $Totallogs		;
#			my $community		;
#			my $dn			;
#			my $dns_query		;
#			my $dns_type		;
#			my $dstkeyid		;
#			my $during_sec		;
#			my $encryptionfailure	;
#			my $fragments_dropped	;
#			my $fw_message		;
#			my $fw_subproduct	;
#			my $ip_id		;
#			my $ip_len		;
#			my $ip_offset		;
#			my $message		;
#			my $methods		;
#			my $msgid		;
#			my $partner		;
#			my $peergateway		;
#			my $reject_category	;
#			my $reject_id		;
#			my $resource		;
#			my $scheme		;
#			my $serial_num		;
#			my $session_id		;
#			my $srckeyid		;
#			my $vpn_feature_name	;

	# NOTE: Nothing done yet, just set up variables

#===================================================================================================
# NOW CHECKING FOR HEADINGS IN THE LOG FILE
#===================================================================================================

			if ($line[0] =~ /^num/) {
				$logheaddercount++		;
		
	# NOTE: undefining variables from previous logfiles with different headder positions 

#				undef $numColumn		;                   
				undef $dateColumn		;                  
#				undef $timeColumn		;                  
#				undef $typeColumn		;                  
				undef $ruleColumn		;                  
#				undef $rule_nameColumn		;             
#				undef $rule_uidColumn		;              
#				undef $NAT_addtnl_rulenumColumn ;    
#				undef $NAT_rulenumColumn	;           
				undef $actionColumn		;                
#				undef $auth_methodColumn	;           
#				undef $userColumn		;                  
#				undef $if_nameColumn		;               
#				undef $if_dirColumn		;                
#				undef $origColumn		;                  
#				undef $origin_idColumn		;            
				undef $srcColumn		;                   
				undef $xlatesrcColumn		;              
#				undef $s_portColumn		;                
				undef $xlatesportColumn		;     
				undef $dstColumn		;                   
				undef $xlatedstColumn		;              
				undef $serviceColumn		;               
				undef $service_idColumn		;            
				undef $xlatedportColumn		;            
				undef $protoColumn		;                 
#				undef $tcp_flagsColumn		;             
#				undef $rpc_progColumn		;              
#				undef $th_flagsColumn		;              
#				undef $icmptypeColumn		;              
#				undef $icmpcodeColumn		;              
#				undef $message_infoColumn	;          
#				undef $sys_messageColumn	;           
#				undef $log_sys_messageColumn	;       
#				undef $tcpstateColumn		;              
#				undef $reasonColumn		;                
#				undef $alertColumn		;                 
#				undef $attackColumn		;                
#				undef $productColumn		;               
#				undef $attackinfoColumn		;           
#				undef $H323messageColumn	;           
#				undef $srcphonenumberColumn	;        
#				undef $dstphonenumberColumn	;        
#				undef $suppressedlogsColumn	;        
#				undef $totallogsColumn		;             
#				undef $CertificateDNColumn      ;
#				undef $CookieIColumn            ;
#				undef $CookieRColumn            ;
#				undef $DCERPCInterfaceUUIDColumn;
#				undef $ICMPColumn               ;
#				undef $ICMPCodeColumn           ;
#				undef $ICMPTypeColumn           ;
#				undef $IKEIDsColumn             ;
#				undef $IKEnotificationColumn    ;
#				undef $IKEColumn                ;
#				undef $Internal_CAColumn        ;
#				undef $PacketinfoColumn         ;
#				undef $SmartDefenseprofileColumn;
#				undef $TCPflagsColumn           ;
#				undef $TotallogsColumn          ;
#				undef $communityColumn          ;
#				undef $dnColumn                 ;
#				undef $dns_queryColumn          ;
#				undef $dns_typeColumn           ;
#				undef $dstkeyidColumn           ;
#				undef $during_secColumn         ;
#				undef $encryptionfailureColumn  ;
#				undef $fragments_droppedColumn  ;
#				undef $fw_messageColumn         ;
#				undef $fw_subproductColumn      ;
#				undef $ip_idColumn              ;
#				undef $ip_lenColumn             ;
#				undef $ip_offsetColumn          ;
#				undef $messageColumn            ;
#				undef $methodsColumn            ;
#				undef $msgidColumn              ;
#				undef $partnerColumn            ;
#				undef $peergatewayColumn        ;
#				undef $reject_categoryColumn    ;
#				undef $reject_idColumn          ;
#				undef $resourceColumn           ;
#				undef $schemeColumn             ;
#				undef $serial_numColumn         ;
#				undef $session_idColumn         ;
#				undef $srckeyidColumn           ;
#				undef $vpn_feature_nameColumn   ;

	# NOTE: Setting a counter and finding the log headders positions
		
				for (my $idx=0; $idx<=$#line; $idx++) {
					#   if ($line[$idx] =~ /^num$/)                	{ $numColumn                	= $idx; }
#					   if ($line[$idx] eq 'num')                	{ $numColumn                	= $idx; }
					#elsif ($line[$idx] =~ /^date$/)               	{ $dateColumn               	= $idx; }
					if ($line[$idx] eq 'date')               	{ $dateColumn               	= $idx; }
					#elsif ($line[$idx] =~ /^time$/)               	{ $timeColumn               	= $idx; }
#					elsif ($line[$idx] eq 'time')               	{ $timeColumn               	= $idx; }
#					elsif ($line[$idx] =~ /^type$/)               	{ $typeColumn               	= $idx; }
					#elsif ($line[$idx] =~ /^rule$/)               	{ $ruleColumn               	= $idx; }
					elsif ($line[$idx] eq 'rule')               	{ $ruleColumn               	= $idx; }
#					elsif ($line[$idx] =~ /^rule_name$/)          	{ $rule_nameColumn          	= $idx; }
#					elsif ($line[$idx] =~ /^rule_uid$/)           	{ $rule_uidColumn           	= $idx; }
#					elsif ($line[$idx] =~ /^NAT_addtnl_rulenum$/) 	{ $NAT_addtnl_rulenumColumn 	= $idx; }
#					elsif ($line[$idx] =~ /^NAT_rulenum$/)        	{ $NAT_rulenumColumn        	= $idx; }
					#elsif ($line[$idx] =~ /^action$/)             	{ $actionColumn             	= $idx; }
					elsif ($line[$idx] eq 'action')             	{ $actionColumn             	= $idx; }
#					elsif ($line[$idx] =~ /^auth_method$/)        	{ $auth_methodColumn        	= $idx; }
#					elsif ($line[$idx] =~ /^user$/)               	{ $userColumn               	= $idx; }
#					elsif ($line[$idx] =~ /^i\/f_name$/)          	{ $if_nameColumn            	= $idx; }
#					elsif ($line[$idx] =~ /^i\/f_dir$/)           	{ $if_dirColumn             	= $idx; }
#					elsif ($line[$idx] =~ /^orig$/)               	{ $origColumn               	= $idx; }
#					elsif ($line[$idx] =~ /^origin_id$/)          	{ $origin_idColumn          	= $idx; }
					#elsif ($line[$idx] =~ /^src$/)                	{ $srcColumn                	= $idx; }
					elsif ($line[$idx] eq 'src')                	{ $srcColumn                	= $idx; }
#					elsif ($line[$idx] =~ /^xlatesrc$/)           	{ $xlatesrcColumn           	= $idx; }
					#elsif ($line[$idx] =~ /^s_port$/)             	{ $s_portColumn             	= $idx; }
#					elsif ($line[$idx] eq 's_port')             	{ $s_portColumn             	= $idx; }
#					elsif ($line[$idx] =~ /^xlatesport$/)         	{ $xlatesportColumn         	= $idx; }
					#elsif ($line[$idx] =~ /^dst$/)                	{ $dstColumn                	= $idx; }
					elsif ($line[$idx] eq 'dst')                	{ $dstColumn                	= $idx; }
#					elsif ($line[$idx] =~ /^xlatedst$/)           	{ $xlatedstColumn           	= $idx; }
					#elsif ($line[$idx] =~ /^service$/)            	{ $serviceColumn            	= $idx; }
					elsif ($line[$idx] eq 'service')            	{ $serviceColumn            	= $idx; }
					#elsif ($line[$idx] =~ /^service_id$/)         	{ $service_idColumn         	= $idx; }
					elsif ($line[$idx] eq 'service_id')         	{ $service_idColumn         	= $idx; }
#					elsif ($line[$idx] =~ /^xlatedport$/)         	{ $xlatedportColumn         	= $idx; }
					#elsif ($line[$idx] =~ /^proto$/)              	{ $protoColumn              	= $idx; }
					elsif ($line[$idx] eq 'proto')              	{ $protoColumn              	= $idx; }
#					elsif ($line[$idx] =~ /^tcp_flags$/)          	{ $tcp_flagsColumn          	= $idx; }
#					elsif ($line[$idx] =~ /^rpc_prog$/)           	{ $rpc_progColumn           	= $idx; }
#					elsif ($line[$idx] =~ /^th_flags$/)           	{ $th_flagsColumn           	= $idx; }
#					elsif ($line[$idx] =~ /^icmptype$/)           	{ $icmptypeColumn           	= $idx; }
#					elsif ($line[$idx] =~ /^icmpcode$/)           	{ $icmpcodeColumn           	= $idx; }
#					elsif ($line[$idx] =~ /^message_info$/)       	{ $message_infoColumn       	= $idx; }
#					elsif ($line[$idx] =~ /^sys_message\:$/)      	{ $sys_messageColumn        	= $idx; }
#					elsif ($line[$idx] =~ /^log_sys_message$/)    	{ $log_sys_messageColumn    	= $idx; }
#					elsif ($line[$idx] =~ /^TCP packet out of state$/)  { $tcpstateColumn     	= $idx; }
#					elsif ($line[$idx] =~ /^reason$/)             	{ $reasonColumn             	= $idx; }
#					elsif ($line[$idx] =~ /^alert$/)              	{ $alertColumn              	= $idx; }
#					elsif ($line[$idx] =~ /^attack$/)             	{ $attackColumn             	= $idx; }
#					elsif ($line[$idx] =~ /^product$/)            	{ $productColumn            	= $idx; }
#					elsif ($line[$idx] =~ /^Attack Info$/)        	{ $attackinfoColumn         	= $idx; }
#					elsif ($line[$idx] =~ /^H.323 message$/)      	{ $H323messageColumn        	= $idx; }
#					elsif ($line[$idx] =~ /^src phone number$/)   	{ $srcphonenumberColumn     	= $idx; }
#					elsif ($line[$idx] =~ /^dst phone number$/)   	{ $dstphonenumberColumn     	= $idx; }
#					elsif ($line[$idx] =~ /^Suppressed logs$/)    	{ $suppressedlogsColumn     	= $idx; }
#					elsif ($line[$idx] =~ /^Total logs$/)         	{ $totallogsColumn          	= $idx; }
#		                        elsif ($line[$idx] =~ /^Certificate DN\:$/)   	{ $CertificateDNColumn      	= $idx; }
#		                        elsif ($line[$idx] =~ /^CookieI$/)	      	{ $CookieIColumn	       	= $idx; }
#		                        elsif ($line[$idx] =~ /^CookieR$/)	      	{ $CookieRColumn	       	= $idx; }
#		                        elsif ($line[$idx] =~ /^DCE\-RPC Interface UUID$/) { $DCERPCInterfaceUUIDColumn = $idx; }
#		                        elsif ($line[$idx] =~ /^ICMP$/)		   	{ $ICMPColumn	       		= $idx; }
#		                        elsif ($line[$idx] =~ /^ICMP Code$/)	   	{ $ICMPCodeColumn       	= $idx; }
#		                        elsif ($line[$idx] =~ /^ICMP Type$/)	   	{ $ICMPTypeColumn       	= $idx; }
#		                        elsif ($line[$idx] =~ /^IKE IDs\:$/)	   	{ $IKEIDsColumn	       		= $idx; }
#		                        elsif ($line[$idx] =~ /^IKE notification\:$/) 	{ $IKEnotificationColumn 	= $idx; }
#		                        elsif ($line[$idx] =~ /^IKE\:$/)	   	{ $IKEColumn	        	= $idx; }
#		                        elsif ($line[$idx] =~ /^Internal_CA\:$/) 	{ $Internal_CAColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^Packet info$/)	   	{ $PacketinfoColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^SmartDefense profile$/) { $SmartDefenseprofileColumn 	= $idx; }
#		                        elsif ($line[$idx] =~ /^TCP flags$/)	   	{ $TCPflagsColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^Total logs$/)	   	{ $TotallogsColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^community$/)	   	{ $communityColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^dn\:$/)		   	{ $dnColumn	  		= $idx; }
#		                        elsif ($line[$idx] =~ /^dns_query$/)	   	{ $dns_queryColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^dns_type$/)	   	{ $dns_typeColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^dstkeyid$/)	   	{ $dstkeyidColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^during_sec$/)	   	{ $during_secColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^encryption failure\:$/) { $encryptionfailureColumn 	= $idx; }
#		                        elsif ($line[$idx] =~ /^fragments_dropped$/)   	{ $fragments_droppedColumn 	= $idx; }
#		                        elsif ($line[$idx] =~ /^fw_message$/)	   	{ $fw_messageColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^fw_subproduct$/)	{ $fw_subproductColumn  	= $idx; }
#		                        elsif ($line[$idx] =~ /^ip_id$/)		{ $ip_idColumn	       		= $idx; }
#		                        elsif ($line[$idx] =~ /^ip_len$/)		{ $ip_lenColumn	       		= $idx; }
#		                        elsif ($line[$idx] =~ /^ip_offset$/)	   	{ $ip_offsetColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^message$/)		{ $messageColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^methods\:$/)	   	{ $methodsColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^msgid$/)		{ $msgidColumn	       		= $idx; }
#		                        elsif ($line[$idx] =~ /^partner$/)		{ $partnerColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^peer gateway$/)	   	{ $peergatewayColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^reject_category$/)	{ $reject_categoryColumn 	= $idx; }
#		                        elsif ($line[$idx] =~ /^reject_id$/)	   	{ $reject_idColumn 		= $idx; }
#		                        elsif ($line[$idx] =~ /^resource$/)	   	{ $resourceColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^scheme\:$/)	   	{ $schemeColumn	       		= $idx; }
#		                        elsif ($line[$idx] =~ /^serial_num\:$/)	   	{ $serial_numColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^session_id\:$/)	   	{ $session_idColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^srckeyid$/)	   	{ $srckeyidColumn		= $idx; }
#		                        elsif ($line[$idx] =~ /^vpn_feature_name$/)   	{ $vpn_feature_nameColumn 	= $idx; }
		
					#else {print "MOOOOOOOOOOOOOOOOOOOOOOOOO!!!!!! $line[$idx]\n";}
		
		
#===================================================================================================
# RUNNING TESTING ON BUILDING THE ARRAYS AND COLUMNS
#===================================================================================================
		
#			print "FOR-IDX loop TEST  $numColumn	$dateColumn	$timeColumn	$typeColumn	$ruleColumn	$rule_nameColumn	$rule_uidColumn	$NAT_addtnl_rulenumColumn	$NAT_rulenumColumn	$actionColumn	$auth_methodColumn	$userColumn	$if_nameColumn	$if_dirColumn	$origColumn	$origin_idColumn	$srcColumn	$xlatesrcColumn	$s_portColumn	$xlatesportColumn	$dstColumn	$xlatedstColumn	$serviceColumn	$service_idColumn	$xlatedportColumn	$protoColumn	$tcp_flagsColumn	$rpc_progColumn	$th_flagsColumn	$icmptypeColumn	$icmpcodeColumn	$message_infoColumn	$sys_messageColumn	$log_sys_messageColumn	$tcpstateColumn	$reasonColumn	$alertColumn	$attackColumn	$productColumn	$attackinfoColumn	$H323messageColumn	$srcphonenumberColumn	$dstphonenumberColumn	$suppressedlogsColumn	$totallogsColumn\n" ;
		
				}  ##### <- for loop end
		
#		print "IF-IDX loop TEST  $numColumn	$dateColumn	$timeColumn	$typeColumn	$ruleColumn	$rule_nameColumn	$rule_uidColumn	$NAT_addtnl_rulenumColumn	$NAT_rulenumColumn	$actionColumn	$auth_methodColumn	$userColumn	$if_nameColumn	$if_dirColumn	$origColumn	$origin_idColumn	$srcColumn	$xlatesrcColumn	$s_portColumn	$xlatesportColumn	$dstColumn	$xlatedstColumn	$serviceColumn	$service_idColumn	$xlatedportColumn	$protoColumn	$tcp_flagsColumn	$rpc_progColumn	$th_flagsColumn	$icmptypeColumn	$icmpcodeColumn	$message_infoColumn	$sys_messageColumn	$log_sys_messageColumn	$tcpstateColumn	$reasonColumn	$alertColumn	$attackColumn	$productColumn	$attackinfoColumn	$H323messageColumn	$srcphonenumberColumn	$dstphonenumberColumn	$suppressedlogsColumn	$totallogsColumn\n" ;
		
			#print "   log headder found, $#line fields processed\n";
		
			next;
			}  ##### <- if statement end
		
#	print "WHILE loop TEST  $numColumn	$dateColumn	$timeColumn	$typeColumn	$ruleColumn	$rule_nameColumn	$rule_uidColumn	$NAT_addtnl_rulenumColumn	$NAT_rulenumColumn	$actionColumn	$auth_methodColumn	$userColumn	$if_nameColumn	$if_dirColumn	$origColumn	$origin_idColumn	$srcColumn	$xlatesrcColumn	$s_portColumn	$xlatesportColumn	$dstColumn	$xlatedstColumn	$serviceColumn	$service_idColumn	$xlatedportColumn	$protoColumn	$tcp_flagsColumn	$rpc_progColumn	$th_flagsColumn	$icmptypeColumn	$icmpcodeColumn	$message_infoColumn	$sys_messageColumn	$log_sys_messageColumn	$tcpstateColumn	$reasonColumn	$alertColumn	$attackColumn	$productColumn	$attackinfoColumn	$H323messageColumn	$srcphonenumberColumn	$dstphonenumberColumn	$suppressedlogsColumn	$totallogsColumn\n" ;
		
		
#===================================================================================================
# ASSIGNING EACH COLUMNS VALUE TO ITS RELEVANT VARIABLE FOR USE LATER IN THE SCRIPT  
#===================================================================================================

			#next if ( $num =~ /^num/ );
				 
		# NOTE: fast log reader - proper one is a section below - comment out this one if you use the other

#			if (defined ($actionColumn) && (defined ($serviceColumn) || defined ($service_idColumn)) && defined ($srcColumn) && defined ($dstColumn) && defined ($protoColumn) && defined ($dateColumn) && defined ($ruleColumn)) {
#		        	$date                = $line[$dateColumn]           	; 
#		        	$rule                = $line[$ruleColumn]           	; 
#		        	$action              = $line[$actionColumn]         	; 
#		        	$src                 = $line[$srcColumn]            	; 
#		        	$dst                 = $line[$dstColumn]            	; 
#		        	$proto               = $line[$protoColumn]          	; 
#		        	$service             = $line[$serviceColumn]        	; 
#		        	$service_id          = $line[$service_idColumn]     	; 
#				if ($service_id ne "") {
#					$srvcstree{$dst}{$src}{$proto}{$service_id}{'rules'}{$rule}++						;
#				} 
#				if ($service ne "") {
#					$srvcstree{$dst}{$src}{$proto}{$service}{'rules'}{$rule}++						;
#				}
#				$uniqueiphits{$src}++											;
#				$uniqueiphits{$dst}++											;
#			}
#			$daystree{$date}++												;

		# NOTE: The if statements are to check that each of the log heading exists in this log file so as not to print empty fields
		
#		        if (defined ($numColumn))		{ $num                 = "$line[$numColumn]"            	; }
		        if (defined ($dateColumn))		{ $date                = "$line[$dateColumn]"           	; }
#		        if (defined ($timeColumn))		{ $time                = "$line[$timeColumn]"           	; }
#		        if (defined ($typeColumn))		{ $type                = "$line[$typeColumn]"           	; }
		        if (defined ($ruleColumn))		{ $rule                = "$line[$ruleColumn]"           	; }
#		        if (defined ($rule_nameColumn))		{ $rule_name           = "$line[$rule_nameColumn]"      	; }
#		        if (defined ($rule_uidColumn))		{ $rule_uid            = "$line[$rule_uidColumn]"       	; }
#		        if (defined ($NAT_addtnl_rulenumColumn)){ $NAT_addtnl_rulenum  = "$line[$NAT_addtnl_rulenumColumn]"	; }
#		        if (defined ($NAT_rulenumColumn))	{ $NAT_rulenum         = "$line[$NAT_rulenumColumn]"    	; }
		        if (defined ($actionColumn))		{ $action              = "$line[$actionColumn]"         	; }
#		        if (defined ($auth_methodColumn))	{ $auth_method         = "$line[$auth_methodColumn]"    	; }
#		        if (defined ($userColumn))		{ $user                = "$line[$userColumn]"           	; }
#		        if (defined ($if_nameColumn))		{ $if_name             = "$line[$if_nameColumn]"        	; }
#		        if (defined ($if_dirColumn))		{ $if_dir              = "$line[$if_dirColumn]"         	; }
#		        if (defined ($origColumn))		{ $orig                = "$line[$origColumn]"           	; }
#		        if (defined ($origin_idColumn))		{ $origin_id           = "$line[$origin_idColumn]"      	; }
		        if (defined ($srcColumn))		{ $src                 = "$line[$srcColumn]"            	; }
		        if (defined ($xlatesrcColumn))		{ $xlatesrc            = "$line[$xlatesrcColumn]"       	; }
#		        if (defined ($s_portColumn))		{ $s_port              = "$line[$s_portColumn]"         	; }
		        if (defined ($xlatesportColumn))	{ $xlatesport          = "$line[$xlatesportColumn]"     	; }
		        if (defined ($dstColumn)) 		{ $dst                 = "$line[$dstColumn]"            	; }
		        if (defined ($xlatedstColumn))		{ $xlatedst            = "$line[$xlatedstColumn]"       	; }
		        if (defined ($serviceColumn)) 		{ $service             = "$line[$serviceColumn]"        	; }
		        if (defined ($service_idColumn))	{ $service_id          = "$line[$service_idColumn]"     	; }
		        if (defined ($xlatedportColumn))	{ $xlatedport          = "$line[$xlatedportColumn]"     	; }
		        if (defined ($protoColumn))		{ $proto               = "$line[$protoColumn]"          	; }
#		        if (defined ($tcp_flagsColumn))		{ $tcp_flags           = "$line[$tcp_flagsColumn]"      	; }
#		        if (defined ($rpc_progColumn))		{ $rpc_prog            = "$line[$rpc_progColumn]"       	; }
#		        if (defined ($th_flagsColumn))		{ $th_flags            = "$line[$th_flagsColumn]"       	; }
#		        if (defined ($icmptypeColumn))		{ $icmptype            = "$line[$icmptypeColumn]"       	; }
#		        if (defined ($icmpcodeColumn))		{ $icmpcode            = "$line[$icmpcodeColumn]"       	; }
#		        if (defined ($message_infoColumn))	{ $message_info        = "$line[$message_infoColumn]"   	; }
#		        if (defined ($sys_messageColumn))	{ $sys_message         = "$line[$sys_messageColumn]"    	; }
#		        if (defined ($log_sys_messageColumn))	{ $log_sys_message     = "$line[$log_sys_messageColumn]"	; }
#		        if (defined ($tcpstateColumn))		{ $tcpoutofstate       = "$line[$tcpstateColumn]"       	; }
#		        if (defined ($reasonColumn))		{ $reason              = "$line[$reasonColumn]"         	; }
#		        if (defined ($alertColumn))		{ $alert               = "$line[$alertColumn]"          	; }
#		        if (defined ($attackColumn))		{ $attack              = "$line[$attackColumn]"         	; }
#		        if (defined ($productColumn))		{ $product             = "$line[$productColumn]"        	; }
#		        if (defined ($attackinfoColumn))	{ $attackinfo          = "$line[$attackinfoColumn]"     	; }
#		        if (defined ($H323messageColumn))	{ $H323message         = "$line[$H323messageColumn]"    	; }
#		        if (defined ($srcphonenumberColumn))	{ $srcphonenumber      = "$line[$srcphonenumberColumn]" 	; }
#		        if (defined ($dstphonenumberColumn))	{ $dstphonenumber      = "$line[$dstphonenumberColumn]" 	; }
#		        if (defined ($suppressedlogsColumn))	{ $suppressedlogs      = "$line[$suppressedlogsColumn]" 	; }
#		        if (defined ($totallogsColumn)) 	{ $totallogs           = "$line[$totallogsColumn]"      	; }
#		        if (defined ($CertificateDNColumn)) 	{ $CertificateDN       = "$line[$CertificateDNColumn]"  	; }
#		        if (defined ($CookieIColumn)) 		{ $CookieI             = "$line[$CookieIColumn]"        	; }
#		        if (defined ($CookieRColumn)) 		{ $CookieR             = "$line[$CookieRColumn]"        	; }
#		        if (defined ($DCERPCInterfaceUUIDColumn)) { $DCERPCInterfaceUUID = "$line[$DCERPCInterfaceUUIDColumn]"	; }
#		        if (defined ($ICMPColumn)) 		{ $ICMP                = "$line[$ICMPColumn]"      		; }
#		        if (defined ($ICMPCodeColumn)) 		{ $ICMPCode            = "$line[$ICMPCodeColumn]"       	; }
#		        if (defined ($ICMPTypeColumn)) 		{ $ICMPType            = "$line[$ICMPTypeColumn]"       	; }
#		        if (defined ($IKEIDsColumn)) 		{ $IKEIDs              = "$line[$IKEIDsColumn]"      		; }
#		        if (defined ($IKEnotificationColumn)) 	{ $IKEnotification     = "$line[$IKEnotificationColumn]" 	; }
#		        if (defined ($IKEColumn)) 		{ $IKE                 = "$line[$IKEColumn]"      		; }
#		        if (defined ($Internal_CAColumn)) 	{ $Internal_CA         = "$line[$Internal_CAColumn]"    	; }
#		        if (defined ($PacketinfoColumn)) 	{ $Packetinfo          = "$line[$PacketinfoColumn]"     	; }
#		        if (defined ($SmartDefenseprofileColumn)){ $SmartDefenseprofile = "$line[$SmartDefenseprofileColumn]" 	; }
#		        if (defined ($TCPflagsColumn)) 		{ $TCPflags            = "$line[$TCPflagsColumn]"      		; }
#		        if (defined ($TotallogsColumn)) 	{ $Totallogs           = "$line[$TotallogsColumn]"      	; }
#		        if (defined ($communityColumn)) 	{ $community           = "$line[$communityColumn]"      	; }
#		        if (defined ($dnColumn)) 		{ $dn                  = "$line[$dnColumn]"      		; }
#		        if (defined ($dns_queryColumn)) 	{ $dns_query           = "$line[$dns_queryColumn]"      	; }
#		        if (defined ($dns_typeColumn)) 		{ $dns_type            = "$line[$dns_typeColumn]"       	; }
#		        if (defined ($dstkeyidColumn)) 		{ $dstkeyid            = "$line[$dstkeyidColumn]"       	; }
#		        if (defined ($during_secColumn)) 	{ $during_sec          = "$line[$during_secColumn]"     	; }
#		        if (defined ($encryptionfailureColumn)) { $encryptionfailure   = "$line[$encryptionfailureColumn]" 	; }
#		        if (defined ($fragments_droppedColumn)) { $fragments_dropped   = "$line[$fragments_droppedColumn]" 	; }
#		        if (defined ($fw_messageColumn)) 	{ $fw_message          = "$line[$fw_messageColumn]"     	; }
#		        if (defined ($fw_subproductColumn)) 	{ $fw_subproduct       = "$line[$fw_subproductColumn]"  	; }
#		        if (defined ($ip_idColumn)) 		{ $ip_id               = "$line[$ip_idColumn]"      		; }
#		        if (defined ($ip_lenColumn)) 		{ $ip_len              = "$line[$ip_lenColumn]"      		; }
#		        if (defined ($ip_offsetColumn)) 	{ $ip_offset           = "$line[$ip_offsetColumn]"      	; }
#		        if (defined ($messageColumn)) 		{ $message             = "$line[$messageColumn]"      		; }
#		        if (defined ($methodsColumn)) 		{ $methods             = "$line[$methodsColumn]"      		; }
#		        if (defined ($msgidColumn)) 		{ $msgid               = "$line[$msgidColumn]"      		; }
#		        if (defined ($partnerColumn)) 		{ $partner             = "$line[$partnerColumn]"      		; }
#		        if (defined ($peergatewayColumn)) 	{ $peergateway         = "$line[$peergatewayColumn]"    	; }
#		        if (defined ($reject_categoryColumn)) 	{ $reject_category     = "$line[$reject_categoryColumn]"	; }
#		        if (defined ($reject_idColumn)) 	{ $reject_id           = "$line[$reject_idColumn]"      	; }
#		        if (defined ($resourceColumn)) 		{ $resource            = "$line[$resourceColumn]"       	; }
#		        if (defined ($schemeColumn)) 		{ $scheme              = "$line[$schemeColumn]"      		; }
#		        if (defined ($serial_numColumn)) 	{ $serial_num          = "$line[$serial_numColumn]"     	; }
#		        if (defined ($session_idColumn)) 	{ $session_id          = "$line[$session_idColumn]"     	; }
#		        if (defined ($srckeyidColumn)) 		{ $srckeyid            = "$line[$srckeyidColumn]"      		; }
#		        if (defined ($vpn_feature_nameColumn)) 	{ $vpn_feature_name    = "$line[$vpn_feature_nameColumn]" 	; }
		
		
#===================================================================================================
# TEST THE VARIABLES ABOVE GOT THE CORRECT VALUE
#===================================================================================================
		
#	print "VALUES loop TEST  $num	$date	$time	$type	$rule	$rule_name	$rule_uid	$NAT_addtnl_rulenum	$NAT_rulenum	$action	$auth_method	$user	$if_name	$if_dir	$orig	$origin_id	$src	$xlatesrc	$s_port	$xlatesport	$dst	$xlatedst	$service	$service_id	$xlatedport	$proto	$tcp_flags	$rpc_prog	$th_flags	$icmptype	$icmpcode	$message_info	$sys_message	$log_sys_message	$tcpoutofstate	$reason	$alert	$attack	$product	$attackinfo	$H323message	$srcphonenumber	$dstphonenumber	$suppressedlogs	$totallogs\n" ;
		
		
# IMPORTANT: vvv ### vvv ### vvv ### vvv ### vvv ### vvv ### vvv ### vvv ###vvv ### vvv :IMPORTANT #
# IMPORTANT: vvv ### vvv ### vvv ### vvv ### vvv ### vvv ### vvv ### vvv ###vvv ### vvv :IMPORTANT #
		
#===================================================================================================
# BUILD THE DATASTRUCTURES FROM THE LOGS *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.* DATA STRUCTURES MADE HERE!!
#===================================================================================================
		
			#unless (defined $time) {
			#	$time = 'any'												;
			#}
			#my @hour 	= split ( ':', $time ) 										;
			#my $hour 	= $hour[0]											;
		
			#if (($action eq 'accept') && defined($src) && (defined($service_id) || defined($service)) && defined($dst) && defined($hour) && defined($proto)) {
			if (($action eq 'accept') && defined($src) && (defined($service_id) || defined($service)) && defined($dst) && defined($proto)) {
						
				#if (($proto eq 'udp') || (($proto eq 'tcp') && ($if_name eq 'daemon'))) {	  
				if ((defined ($service)) && ($service ne "")) {
					#$srvcstree{$dst}{$src}{$proto}{$service}{'count'}++							;
					#$srvcstree{$dst}{$src}{$proto}{$service}{'hours'}{$hour}++						;
					$srvcstree{$dst}{$src}{$proto}{$service}{'rules'}{$rule}++						;
					#$srvcstree{$dst}{$src}{$proto}{$service}{'lastseen'} = "$date:$time"					;
					#$srvcstree{$dst}{$src}{$proto}{$service}{'sourceports'}{$s_port}++					;
					if (defined ($xlatedst)) {
						$srvcstree{$dst}{$src}{$proto}{$service}{'lognatdst'}{$xlatedst} = $rule			;
					}
					if (defined ($xlatesrc)) {
						$srvcstree{$dst}{$src}{$proto}{$service}{'lognatsrc'}{$xlatesrc} = $rule			;
					}
					if (defined ($xlatedport)) {
						$srvcstree{$dst}{$src}{$proto}{$service}{'lognatsrvc'}{$xlatedport} = $rule			;
					}
				}
				if ((defined ($service_id)) && ($service_id ne "")) {
					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'count'}++							;
					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'hours'}{$hour}++						;
					$srvcstree{$dst}{$src}{$proto}{$service_id}{'rules'}{$rule}++						;
					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'lastseen'} = "$date:$time"					;
					#$srvcstree{$dst}{$src}{$proto}{$service_id}{'sourceports'}{$s_port}++					;
					if (defined ($xlatedst)) {
						$srvcstree{$dst}{$src}{$proto}{$service_id}{'lognatdst'}{$xlatedst} = $rule			;
					}
					if (defined ($xlatesrc)) {
						$srvcstree{$dst}{$src}{$proto}{$service_id}{'lognatsrc'}{$xlatesrc} = $rule			;
					}
					if (defined ($xlatedport)) {
						$srvcstree{$dst}{$src}{$proto}{$service_id}{'lognatsrvc'}{$xlatedport} = $rule			;
					}
				}
				$uniqueiphits{$src}++											;
				$uniqueiphits{$dst}++											;
	
			}
			$daystree{$date}++												;

			#if (defined ($action) && defined($src) && defined($service) && defined($dst) && defined($hour)) {
				#$actionfromstree{$action}{$src}{$service}{$dst}{$hour}++						;
				#$actiondeststree{$action}{$dst}{$service}{$src}{$hour}++						;
				#$actionservicedeststree{$action}{$service}{$dst}{$hour}++						;
				#$actionservicefromstree{$action}{$service}{$src}{$hour}++						;
			#}
			#if (defined($NAT_rulenum)) {
			#	$natstree{'natrule'}{$NAT_rulenum}++;
			#}
			#if (defined($NAT_addtnl_rulenum)) {
			#	$natstree{'natadnlrule'}{$NAT_addtnl_rulenum}++;
			#}
			#if (defined($xlatesrc)) {
			#	$natstree{'natsrc'}{$xlatesrc}++;
			#}
			#if (defined($xlatedst)) {
			#	$natstree{'natdst'}{$xlatedst}++;
			#}
			#if (defined($xlatedport)) {
			#	$natstree{'natdport'}{$xlatedport}++;
			#}
			#if (defined($xlatesport)) {
			#	$natstree{'natsport'}{$xlatedport}++;
			#}


#---------------------------------------------------------------------------------------------------
# PRINT DOTS DURING PROCESSING
#---------------------------------------------------------------------------------------------------
		
			$loglinecount++	;
			if ($loglinecount == ($loglinecountquick + 2000)) {
				print ".";
				$loglinecountquick = $loglinecount;
			}
			if ($loglinecount == ($loglinecountholder + 100000)) {
				print ".$loglinecount	lines read\n"		;
				$loglinecountholder = $loglinecount;
			}
		}

#===================================================================================================
# START CISCO VERSION OF THE LOG READER
#===================================================================================================
	
	} elsif ($configtype eq 'cs') {

		while (<LOGFILE>) {
			if (/You have an error in your SQL syntax/) {
				print "\n    WARNING:  $_";
				next;
			}
			if (/\%ASA-6-302013/) {
				next if /last message repeated/;
				
			# NOTE: Read Build TCP connection log entry

		                my @line = split(/\s+/, $_);
				my $i = 0;
				my $offset = 0;
				foreach my $linelem (@line) {
					if ($linelem eq '%ASA-6-302013:') {
						$offset = $i;
						#print "OFFSET: $offset\n";
						last;
					}
					$i++;
				}

				my ($source, $sourceintip, $sourceint, $sourceip, $sourceport);
				my ($dest, $destintip, $destint, $destip, $destport);

		                ($source, $dest) = ($line[7 + $offset], $line[10 + $offset]) ;
				#print "SRC: $source, DST: $dest\n";

		                ($sourceintip, $sourceport)     = split(/\//, $source);
		                ($destintip, $destport)         = split(/\//, $dest);

				($destint, $destip)             = split(/\:/, $destintip);
				($sourceint, $sourceip)         = split(/\:/, $sourceintip);

				#unless (defined ($sourceintip) && defined ( $sourceport) && defined ( $destintip) && defined ( $destport) && defined ( $destint) && defined ( $destip) && defined ( $sourceint) && defined ( $sourceip)) {
				#	print "SRC: $source, DST: $dest, $sourceintip, $sourceport, $destintip, $destport, $destint, $destip,$sourceint, $sourceip\n $_";
				#}
				$srvcstree{$destip}{$sourceip}{'tcp'}{$destport}{'rules'}{'0'}++;

			} elsif (/\%ASA-6-302014/) {
				next if /last message repeated/;
				
			# NOTE: Read Teardown TCP connection log entry

		                my @line = split(/\s+/, $_);
				my $i = 0;
				my $offset = 0;
				foreach my $linelem (@line) {
					if ($linelem eq '%ASA-6-302014:') {
						$offset = $i;
						#print "OFFSET: $offset\n";
						last;
					}
					$i++;
				}

				my ($source, $sourceintip, $sourceint, $sourceip, $sourceport);
				my ($dest, $destintip, $destint, $destip, $destport);

		                ($source, $dest) = ($line[6 + $offset], $line[8 + $offset]) ;
				#print "SRC: $source, DST: $dest\n";

		                ($sourceintip, $sourceport)     = split(/\//, $source);
		                ($destintip, $destport)         = split(/\//, $dest);

				($destint, $destip)             = split(/\:/, $destintip);
				($sourceint, $sourceip)         = split(/\:/, $sourceintip);

				#unless (defined ($sourceintip) && defined ( $sourceport) && defined ( $destintip) && defined ( $destport) && defined ( $destint) && defined ( $destip) && defined ( $sourceint) && defined ( $sourceip)) {
				#	print "SRC: $source, DST: $dest, $sourceintip, $sourceport, $destintip, $destport, $destint, $destip,$sourceint, $sourceip\n $_";
				#}
				$srvcstree{$destip}{$sourceip}{'tcp'}{$destport}{'rules'}{'0'}++;

			} elsif (/\%ASA-6-302015/) {
				next if /last message repeated/;
				
			# NOTE: Read Build UDP connection log entry

		                my @line = split(/\s+/, $_);
				my $i = 0;
				my $offset = 0;
				foreach my $linelem (@line) {
					if ($linelem eq '%ASA-6-302015:') {
						$offset = $i;
						#print "OFFSET: $offset\n";
						last;
					}
					$i++;
				}

				my ($source, $sourceintip, $sourceint, $sourceip, $sourceport);
				my ($dest, $destintip, $destint, $destip, $destport);

		                ($source, $dest) = ($line[7 + $offset], $line[10 + $offset]) ;
				#print "SRC: $source, DST: $dest\n";

		                ($sourceintip, $sourceport)     = split(/\//, $source);
		                ($destintip, $destport)         = split(/\//, $dest);

				($destint, $destip)             = split(/\:/, $destintip);
				($sourceint, $sourceip)         = split(/\:/, $sourceintip);

				#unless (defined ($sourceintip) && defined ( $sourceport) && defined ( $destintip) && defined ( $destport) && defined ( $destint) && defined ( $destip) && defined ( $sourceint) && defined ( $sourceip)) {
				#	print "SRC: $source, DST: $dest, $sourceintip, $sourceport, $destintip, $destport, $destint, $destip,$sourceint, $sourceip\n $_";
				#}
				$srvcstree{$destip}{$sourceip}{'udp'}{$destport}{'rules'}{'0'}++;

			} elsif (/\%ASA-6-302016/) {
				next if /last message repeated/;
				
			# NOTE: Read Teardown UDP connection log entry

		                my @line = split(/\s+/, $_);
				my $i = 0;
				my $offset = 0;
				foreach my $linelem (@line) {
					if ($linelem eq '%ASA-6-302016:') {
						$offset = $i;
						#print "OFFSET: $offset\n";
						last;
					}
					$i++;
				}

				my ($source, $sourceintip, $sourceint, $sourceip, $sourceport);
				my ($dest, $destintip, $destint, $destip, $destport);

		                ($source, $dest) = ($line[6 + $offset], $line[8 + $offset]) ;
				#print "SRC: $source, DST: $dest\n";

		                ($sourceintip, $sourceport)     = split(/\//, $source);
		                ($destintip, $destport)         = split(/\//, $dest);

				($destint, $destip)             = split(/\:/, $destintip);
				($sourceint, $sourceip)         = split(/\:/, $sourceintip);

				#unless (defined ($sourceintip) && defined ( $sourceport) && defined ( $destintip) && defined ( $destport) && defined ( $destint) && defined ( $destip) && defined ( $sourceint) && defined ( $sourceip)) {
				#	print "SRC: $source, DST: $dest, $sourceintip, $sourceport, $destintip, $destport, $destint, $destip,$sourceint, $sourceip\n $_";
				#}
				$srvcstree{$destip}{$sourceip}{'udp'}{$destport}{'rules'}{'0'}++;

			} elsif (/\%ASA-6-302020/) {
				next if /last message repeated/;
				
			# NOTE: Read Built ICMP connection log entry

		                my @line = split(/\s+/, $_);
				my $i = 0;
				my $offset = 0;
				foreach my $linelem (@line) {
					if ($linelem eq '%ASA-6-302020:') {
						$offset = $i;
						#print "OFFSET: $offset\n";
						last;
					}
					$i++;
				}

				my ($source, $sourceip, $sourceport);
				my ($dest, $destip, $destport);

		                ($source, $dest) = ($line[7 + $offset], $line[9 + $offset]) ;
				#print "SRC: $source, DST: $dest\n";

		                ($sourceip, $sourceport)     = split(/\//, $source);
		                ($destip, $destport)         = split(/\//, $dest);

				#unless (defined ($sourceport) && defined( $destport) && defined( $destip) && defined( $sourceip)) {
				#	print "SRC: $source, DST: $dest, $sourceport, $destport, $destip, $sourceip\n $_";
				#}
				$srvcstree{$destip}{$sourceip}{'icmp'}{$destport}{'rules'}{'0'}++;

			} elsif (/\%ASA-6-302021/) {
				next if /last message repeated/;
				
			# NOTE: Read Built ICMP connection log entry

		                my @line = split(/\s+/, $_);
				my $i = 0;
				my $offset = 0;
				foreach my $linelem (@line) {
					if ($linelem eq '%ASA-6-302021:') {
						$offset = $i;
						#print "OFFSET: $offset\n";
						last;
					}
					$i++;
				}

				my ($source, $sourceip, $sourceport);
				my ($dest, $destip, $destport);

		                ($source, $dest) = ($line[6 + $offset], $line[8 + $offset]) ;
				#print "SRC: $source, DST: $dest\n";

		                ($sourceip, $sourceport)     = split(/\//, $source);
		                ($destip, $destport)         = split(/\//, $dest);

				#unless (defined ($sourceport) && defined( $destport) && defined( $destip) && defined( $sourceip)) {
				#	print "SRC: $source, DST: $dest, $sourceport, $destport, $destip, $sourceip\n $_";
				#}
				$srvcstree{$destip}{$sourceip}{'icmp'}{$destport}{'rules'}{'0'}++;
			}

			$loglinecount++	;
			if ($loglinecount == ($loglinecountquick + 2000)) {
				print ".";
				$loglinecountquick = $loglinecount;
			}
			if ($loglinecount == ($loglinecountholder + 100000)) {
				print ".$loglinecount	lines read\n"		;
				$loglinecountholder = $loglinecount;
			}
		}
	}
		
	
#===================================================================================================
# CHECK THE DATA STRUCTURERS BUILT FROM THE LOG FILES                          ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================
	
	#print "FROMS TREE         	\n########################################################################################################################\n\n". Dumper(%fromstree) . "\n\n"		;
	#print "SERVICE FROMS TREE 	\n########################################################################################################################\n\n". Dumper(%servicefromstree) . "\n\n"	;
	#print "DESTS TREE         	\n########################################################################################################################\n\n". Dumper(%deststree) . "\n\n"		;
	#print "SERVICE DESTS TREE 	\n########################################################################################################################\n\n". Dumper(%servicedeststree) . "\n\n"	;
	#print "DAYS TREE 		\n########################################################################################################################\n\n". Dumper(%daystree) . "\n\n"		;
	#print "UNIQUE IPS TREE 	\n########################################################################################################################\n\n". Dumper(%uniqueiphits) . "\n\n"		;
	#print "SERVICES TREE 		\n########################################################################################################################\n\n". Dumper(%srvcstree) . "\n\n"		;
	#print "NATS TREE 		\n########################################################################################################################\n\n". Dumper(%natstree) . "\n\n"		;
	
	
#---------------------------------------------------------------------------------------------------
# PRINTING THE BANNER FOR LOG ANALYSIS COMPLETE
#---------------------------------------------------------------------------------------------------
	
	my $logfromscount 	= keys %fromstree 		;
	my $logdestscount 	= keys %deststree 		;
	my $logservicecount 	= keys %servicefromstree	;
	my $dayscount		= keys %daystree		;
	
	print "\n";
	print "-----------------------------------------------------------------------------------------\n";
	print " LOGFILE ANALYSIS COMPLETE:\n";
	print "   log lines processed 		= $loglinecount\n"	;
	print "   log duration	 		= $dayscount days\n"	;
	print "   number of log hddrs found 	= $logheaddercount\n"	;
	print "   sources found  		= $logfromscount\n"	;
	print "   destinations found		= $logdestscount\n"	;
	print "   services found		= $logservicecount\n"	;
	
	
#===================================================================================================
# BUILD THE FILTER TREE OF SEEN CONNECTIONS FROM LOGS
#===================================================================================================

	print "-----------------------------------------------------------------------------------------\n";
	print " STARTING BINARY LOG OBJECT ANALYSIS:\n";
	
	my $logbincount = 0;
	my $logbincheck = 0;
	my %missedobjs;
	foreach my $logdst (keys %srvcstree) {
		foreach my $logsrc (keys %{$srvcstree{$logdst}}) {
			foreach my $logproto (keys %{$srvcstree{$logdst}{$logsrc}}) {
				foreach my $logport (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}}) {
					foreach my $logrule (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'rules'}}) {
						my $hits = $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'rules'}{$logrule};
						$logbincheck++;
						#print "$logdst, $logsrc, $logproto, $logport, $logrule\n";
						my (@bindsts, @binsrcs, @portnums) ;

					# NOTE: if DESTINATION log object exists in config

						if (exists $netobjects{$logdst}) {

						# NOTE: add service and rule usage info to netobject 

							$netobjects{$logdst}{'logdstrules'}{$logrule} += $hits;
							$netobjects{$logdst}{'logdstsrvcs'}{"$logproto~$logport"} += $hits;

							if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatdst'}) {
								foreach my $lognatdst (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatdst'}}) {
									$netobjects{$logdst}{'lognatdst'}{$lognatdst} = $logrule;
								}
							}
							if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrvc'}) {
								foreach my $lognatsrvc (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrvc'}}) {
									$netobjects{$logdst}{'lognatsrvc'}{$lognatsrvc} = $logrule;
								}
							}
									
						# NOTE: check zone details

							if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'}) {
								my ($srczone, $dstzone) = split(/\~/, $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'});
								if (exists $netobjects{$logdst}{'zone'} && ($dstzone ne $netobjects{$logdst}{'zone'})) {
									print "LOG DEST OBJECT: $logdst RESIDES IN ZONE: $dstzone WHILE THE CONFIG OBJECTS ZONE IS: $netobjects{$logdst}{'zone'}\n";
								} else {
									unless (exists $netobjects{$logdst}{'zone'}) {
										$netobjects{$logdst}{'zone'} = $dstzone;
									}
								}
							}

							foreach my $dstbin (keys %{$netobjects{$logdst}{'ipbin'}} ) {
								if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'}) {
									my ($srczone, $dstzone) = split(/\~/, $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'});
									if (exists $ips{$dstbin}{'zone'} && ($dstzone ne $ips{$dstbin}{'zone'})) {
										print "LOG DEST BIN: $logdst RESIDES IN ZONE: $dstzone WHILE THE CONFIG BINS ZONE IS: $ips{$dstbin}{'zone'}\n";
									} else {
										unless (exists $ips{$dstbin}{'zone'}) {
											$ips{$dstbin}{'zone'} = $dstzone;
										}
									}
								}
								push (@bindsts, $dstbin);
							}

					# NOTE: if DESTINATION log object is an IP that exists in the config

						} elsif (is_ip($logdst)) {
							my $dstbin = ip_to_bin($logdst);

						# NOTE: check zone details

							if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'}) {
								my ($srczone, $dstzone) = split(/\~/, $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'});
								if (exists $ips{$dstbin} && exists $ips{$dstbin}{'zone'} && ($dstzone ne $ips{$dstbin}{'zone'})) {
									print "LOG IP DEST BIN: $logdst MATCHED BIN OBJ: $ips{$dstbin}{'name'} IT RESIDES IN ZONE: $dstzone WHILE THE CONFIG BINS ZONE IS: $ips{$dstbin}{'zone'}\n";
								} elsif (exists $ips{$dstbin}) {
									unless (exists $ips{$dstbin}{'zone'}) {
										$ips{$dstbin}{'zone'} = $dstzone;
									}
								} else {
									my $workingdstbin = $dstbin;
									until (exists $ips{$workingdstbin} || $workingdstbin eq "") {
										chop $workingdstbin;
									}
									if (($workingdstbin ne "") && exists $ips{$workingdstbin}{'zone'} && ($dstzone ne $ips{$workingdstbin}{'zone'})) {
										print "LOG NET DEST BIN: $logdst MATCHED NET BIN OBJ: $ips{$workingdstbin}{'name'} IT RESIDES IN ZONE: $dstzone WHILE THE CONFIG NET BINS ZONE IS: $ips{$workingdstbin}{'zone'}\n";
									} elsif (($workingdstbin ne "") && exists $ips{$workingdstbin}) {
										unless (exists $ips{$workingdstbin}{'zone'}) {
											$ips{$workingdstbin}{'zone'} = $dstzone;
										}
									}
								}
							}

						# NOTE: add service and rule usage info to netobject resolved via IP

							my $workingdstbin = $dstbin;
							until (exists $ips{$workingdstbin} || $workingdstbin eq "") {
								chop $workingdstbin;
							}
							if (exists $ips{$workingdstbin}) {
								my $name = $ips{$workingdstbin}{'name'};
								$netobjects{$name}{'logdstrules'}{$logrule}+= $hits;
								$netobjects{$name}{'logdstsrvcs'}{"$logproto~$logport"}+= $hits;

								if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatdst'}) {
									foreach my $lognatdst (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatdst'}}) {
										$netobjects{$name}{'lognatdst'}{$lognatdst} = $logrule;
									}
								}
								if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrvc'}) {
									foreach my $lognatsrvc (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrvc'}}) {
										$netobjects{$name}{'lognatsrvc'}{$lognatsrvc} = $logrule;
									}
								}
							}

							push (@bindsts, $dstbin);
						} else {
							$missedobjs{"    WARNING:  DST log object UNKNOWN: $logdst"}++;
						}

					# NOTE: if SOURCE log object exists in the config
							
						if (exists $netobjects{$logsrc}) {

						# NOTE: add service and rule usage info to netobject 

							$netobjects{$logsrc}{'logdstrules'}{$logrule}+= $hits;
							$netobjects{$logsrc}{'logdstsrvcs'}{"$logproto~$logport"}+= $hits;

							if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrc'}) {
								foreach my $lognatsrc (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrc'}}) {
									$netobjects{$logsrc}{'lognatsrc'}{$lognatsrc} = $logrule;
								}
							}

							if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'}) {
								my ($srczone, $dstzone) = split(/\~/, $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'});
								if (exists $netobjects{$logsrc}{'zone'} && ($srczone ne $netobjects{$logsrc}{'zone'})) {
									print "LOG SRC OBJECT: $logsrc RESIDES IN ZONE: $srczone WHILE THE CONFIG OBJECTS ZONE IS: $netobjects{$logsrc}{'zone'}\n";
								} else {
									unless (exists $netobjects{$logsrc}{'zone'}) {
										$netobjects{$logsrc}{'zone'} = $srczone;
									}
								}
							}

							foreach my $srcbin (keys %{$netobjects{$logsrc}{'ipbin'}} ) {
								if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'}) {
									my ($srczone, $dstzone) = split(/\~/, $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'});
									if (exists $ips{$srcbin}{'zone'} && ($srczone ne $ips{$srcbin}{'zone'})) {
										print "LOG SRC BIN: $logsrc RESIDES IN ZONE: $srczone WHILE THE CONFIG BINS ZONE IS: $ips{$srcbin}{'zone'}\n";
									} elsif (exists $ips{$srcbin}) {
										unless (exists $ips{$srcbin}{'zone'}) {
											$ips{$srcbin}{'zone'} = $srczone;
										}
									}
								}
								push (@binsrcs, $srcbin);
							}

					# NOTE: if SOURCE log object is an IP that exists in the config

						} elsif (is_ip($logsrc)) {
							my $srcbin = ip_to_bin($logsrc);
							if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'}) {
								my ($srczone, $dstzone) = split(/\~/, $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'zones'});
								if (exists $ips{$srcbin} && exists $ips{$srcbin}{'zone'} && ($srczone ne $ips{$srcbin}{'zone'})) {
									print "LOG IP SRC BIN: $logsrc MATCHED BIN OBJ, IT RESIDES IN ZONE: $srczone WHILE THE CONFIG BINS ZONE IS: $ips{$srcbin}{'zone'}\n";
								} elsif (exists $ips{$srcbin}) {
									unless (exists $ips{$srcbin}{'zone'}) {
										$ips{$srcbin}{'zone'} = $srczone;
									}
								} else {
									my $workingsrcbin = $srcbin;
									until (exists $ips{$workingsrcbin} || $workingsrcbin eq "") {
										chop $workingsrcbin;
									}
									if (($workingsrcbin ne "") && exists $ips{$workingsrcbin}{'zone'} && ($srczone ne $ips{$workingsrcbin}{'zone'})) {
										print "LOG NET SRC BIN: $logsrc MATCHED NET BIN OBJ: $ips{$workingsrcbin}{'name'} IT RESIDES IN ZONE: $srczone WHILE THE CONFIG NET BINS ZONE IS: $ips{$workingsrcbin}{'zone'}\n";
									} elsif (($workingsrcbin ne "") && exists $ips{$workingsrcbin}) {
										unless (exists $ips{$workingsrcbin}{'zone'}) {
											$ips{$workingsrcbin}{'zone'} = $srczone;
										}
									}
								}
							}

						# NOTE: add service and rule usage info to netobject resolved via IP

							my $workingsrcbin = $srcbin;
							until (exists $ips{$workingsrcbin} || $workingsrcbin eq "") {
								chop $workingsrcbin;
							}
							if (exists $ips{$workingsrcbin}) {
								my $name = $ips{$workingsrcbin}{'name'};
								$netobjects{$name}{'logsrcrules'}{$logrule}+= $hits;
								$netobjects{$name}{'logsrcsrvcs'}{"$logproto~$logport"}+= $hits;

								if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrc'}) {
									foreach my $lognatsrc (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrc'}}) {
										$netobjects{$name}{'lognatsrc'}{$lognatsrc} = $logrule;
									}
								}
								if (exists $srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrvc'}) {
									foreach my $lognatsrvc (keys %{$srvcstree{$logdst}{$logsrc}{$logproto}{$logport}{'lognatsrvc'}}) {
										$netobjects{$name}{'lognatsrvc'}{$lognatsrvc} = $logrule;
									}
								}
							}

							push (@binsrcs, $srcbin);
						} else {
							$missedobjs{"    WARNING:  SRC log object UNKNOWN: $logsrc"}++;
						}

					# NOTE: if SERVICE log object exists in the config or is a known protocol or a service exception (like large port ranges that would eat all the good info)

						if (exists $srvcobjects{$logport}) {
							if (exists $srvcexceptions{$logport} ) {
								if (exists $srvcobjects{$logport}{'port'}{$logproto}) {
									$logproto = "srvcexception_$logproto";
									push (@portnums, $logport);
								} elsif (($logproto =~ s/srvcexception_//) && (exists $srvcobjects{$logport}{'port'}{$logproto})) {
									$logproto = "srvcexception_$logproto";
									push (@portnums, $logport);
								} else {
									my ($exproto,) = keys %{$srvcobjects{$logport}{'port'}};
									$missedobjs{"    WARNING:  service exception DROPPED: PORT $logport, SRVC PROTO $exproto, LOG PROTO $logproto"}++;
								}
							
							} elsif ($srvcobjects{$logport}{'type'} =~ /^other$|^dce-rpc/) {
								$logproto = $srvcobjects{$logport}{'type'};
								foreach my $portnum (keys %{$srvcobjects{$logport}{'ports'}{$logproto}}) {
									push (@portnums, $portnum);
								}
							} else {
								if (exists $srvcobjects{$logport}{'ports'}{$logproto}) {
									foreach my $portnum (keys %{$srvcobjects{$logport}{'ports'}{$logproto}}) {
										push (@portnums, $portnum);
									}
								} else {
									#$missedobjs{"    WARNING:  UNKNOWN protocol DROPPED: $logproto for object $logport, $logdst, $logsrc, rule: $logrule"}++;
									$missedobjs{"    WARNING:  UNKNOWN protocol DROPPED: $logproto for object $logport, rule: $logrule"}++;
								}
							}
						} elsif ($logport =~ /^\d+$/) {
							push (@portnums, $logport);
							#print "NUMERIC PORT: $logproto for object $logport, $logdst, $logsrc, rule: $logrule\n";
						} elsif (exists $ports{$logproto} && exists $ports{$logproto}{$logport}) {
							#print "WOOPS!! $ports{$logproto}{$logport}{'name'}\n";
							push (@portnums, $ports{$logproto}{$logport}{'name'});
						} else {
							push (@portnums, $logport);
							$missedobjs{"    WARNING:  UNKNOWN port USED: $logproto, $logport"}++;
						}

					# NOTE: build the log bins tree from this itteration of the current rule

						foreach my $bindst (@bindsts) {
							foreach my $binsrc (@binsrcs) {
								foreach my $portnb (@portnums) {
									$logbins{$bindst}{$binsrc}{$logproto}{$portnb}{$logrule}++;
									$logbincount++;
								}
							}
						}
					}
				}
			}
		}
	}
	if (scalar keys %missedobjs > 0) {
		print "-----------------------------------------------------------------------------------------\n";
		print " SOME OBJECTS COULD NOT BE RESOLVED FROM THE LOGS, DETAILS BELOW:\n";
		print "-----------------------------------------------------------------------------------------\n";
	
		foreach my $missedobj (sort keys %missedobjs) {
			print "$missedobj - $missedobjs{$missedobj} instances\n";
		}
	}
	if ($logbincheck > $logbincount) {
		print "   WARNING:  Binary log smaller than original log\n";
	} else {
		print "   BINARY LOG CHECK GOOD!!\n";
	} 

#===================================================================================================
# CHECK THE BINARY DATA STRUCTURER BUILT FROM THE LOG                          ?.?.?.?.?.?.?.?.?.?.?
#===================================================================================================

	#print "BINARY LOG: 		\n########################################################################################################################\n\n". Dumper(%logbins) . "\n\n"		;
	#print "NETWORK OBJECTS: 	\n########################################################################################################################\n\n". Dumper(%netobjects) . "\n\n"		;
	
	
#---------------------------------------------------------------------------------------------------
# PRINTING THE BANNER FOR LOG ANALYSIS COMPLETE
#---------------------------------------------------------------------------------------------------
	
	print "-----------------------------------------------------------------------------------------\n";
	print " LOGFILE CONNECTION ANALYSIS COMPLETE:\n";
	print "   connections processed 	= $logbincount\n"	;
	

#===================================================================================================
# ASSIGNING THE CONFIG OUT TO THE GLOBAL HASH !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#===================================================================================================

# NOTE: config processing

	$configbundles{$config}{'netobjects'} 		= \%netobjects 		;
	$configbundles{$config}{'netexceptions'} 	= \%netexceptions 	;
	$configbundles{$config}{'srvcexceptions'} 	= \%srvcexceptions 	;
	$configbundles{$config}{'ruleexceptions'} 	= \%ruleexceptions 	;
#	$configbundles{$config}{''} = \@netobjects				;	# in order of appeareance
#	$configbundles{$config}{''} = \@clusterobjects				;	# in order of appeareance
#	$configbundles{$config}{''} = \@rangeobjects				;	# in order of appeareance
	$configbundles{$config}{'duplnetobjects'} = \%duplnetobjects 		;
	$configbundles{$config}{'srvcobjects'} = \%srvcobjects 			;
	$configbundles{$config}{'ports'} = \%ports 				;
	$configbundles{$config}{'duplports'} = \%duplports 			;
	$configbundles{$config}{'netgroups'} = \%netgroups 			;
	$configbundles{$config}{'exclgroups'} = \%exclgroups 			;
	$configbundles{$config}{'srvcgroups'} = \%srvcgroups 			;
	$configbundles{$config}{'objectstokeep'} = \%objectstokeep 		;
	$configbundles{$config}{'installon'} = \%installon			;
	
	$configbundles{$config}{'interfaces'} = \%interfaces			;	# from ASA config
	$configbundles{$config}{'zones'} = \%zones				;	# derived from ASA config access-lists
	$configbundles{$config}{'logtypes'} = \%logtypes			;
	
# NOTE: subgroup processing
	
	$configbundles{$config}{'networkgroups'} = \%networkgroups		;
	$configbundles{$config}{'netgroupobjs'} = \%netgroupobjs		;
	$configbundles{$config}{'srvcgroupobjs'} = \%srvcgroupobjs		;
	$configbundles{$config}{'servicegroups'} = \%servicegroups		;
	$configbundles{$config}{'allgroups'} = \%allgroups			;
	
# NOTE: binary ip processing
	
	$configbundles{$config}{'ips'} = \%ips 					;       # Called by all their 32 bits if they are hosts and by their masked bits if they are networks
	$configbundles{$config}{'duplips'} = \%duplips				;	
#	$configbundles{$config}{''} = \@orderedfwobj				;
	$configbundles{$config}{'bingroups'} = \%bingroups			;	# all binary ips belonging to members all members of a group
	$configbundles{$config}{'bingroupsizes'} = \%bingroupsizes		;
	
# NOTE: rule processing 
	
#	$configbundles{$config}{'resobjectshrd'} = \%resobjectshrd		;	# holds the last set of resolved names from the 'or' menu option
	$configbundles{$config}{'rules'} = \%rules				;
	$configbundles{$config}{'drops'} = \%drops				;	# used for masking drop rules during the policy expansion
	$configbundles{$config}{'rulegroup'} = \$rulegroup			;	# for checkpoint to pull different rulebases and for ASAs different access-lists
	$configbundles{$config}{'rulegroups'} = \%rulegroups			;
	$configbundles{$config}{'rlgrpzones'} = \%rlgrpzones			;
	$configbundles{$config}{'rulecsvs'} = \%rulecsvs			;
	$configbundles{$config}{'binrules'} = \%binrules			;
	$configbundles{$config}{'aclname'} = \$aclname 				;	# for ASA ACL processing
	$configbundles{$config}{'difflast'} = \$difflast			;	# compair with last rulebase made
	$configbundles{$config}{'lastrashrulebase'} = \%lastrashrulebase	;	# the last rulebase rationalized
	$configbundles{$config}{'lastrashprintbase'} = \%lastrashprintbase	;	# the last rulebase rationalized
	$configbundles{$config}{'prevrashrulebase'} = \%prevrashrulebase	;	# the previous rulebase rationalized
	$configbundles{$config}{'sectionheader'} = \$sectionheader		;	# comment rules in cisco and section headers in checkpoint
	$configbundles{$config}{'mergerulebases'} = \%mergerulebases		;	# the rulebases that are the destination for merged rules
	$configbundles{$config}{'mergetorulebases'} = \%mergetorulebases	;	# the rulebase used to remove rules from the rationalized rules when you are merging rulebases, rule rule rules!! 

# NOTE: nat rule processing

	$configbundles{$config}{'nats'} = \%nats				;
	
# NOTE: variables for rationalizing rules - to be handed between subroutines
	
#	$configbundles{$config}{'incconobjs'} = \$incconobjs			;
#	$configbundles{$config}{'rashrules'} = \%rashrules			;
#	$configbundles{$config}{'rashrulegroups'} = \%rashrulegroups		;
#	$configbundles{$config}{'includeips'} = \%includeips			;
#	$configbundles{$config}{'excludeips'} = \%excludeips			;
#	$configbundles{$config}{'groupsinuse'} = \%groupsinuse			;
	
# NOTE: port processing
	
	$configbundles{$config}{'portgroups'} = \%portgroups			;
	$configbundles{$config}{'portgroupsizes'} = \%portgroupsizes		;
	
# NOTE: route processing 
	
	$configbundles{$config}{'interfacebins'} = \%interfacebins 		;
	$configbundles{$config}{'routes'} = \%routes				;
	$configbundles{$config}{'spoofgroups'} = \%spoofgroups 			;
	
# NOTE: log processing
	
	$configbundles{$config}{'fromstree'} = \%fromstree			;
	$configbundles{$config}{'deststree'} = \%deststree			;
	#$configbundles{$config}{'srvcstree'} = \%srvcstree			;
	$configbundles{$config}{'actionfromstree'} = \%actionfromstree		;
	$configbundles{$config}{'actiondeststree'} = \%actiondeststree		;
	$configbundles{$config}{'servicefromstree'} = \%servicefromstree	;
	$configbundles{$config}{'servicedeststree'} = \%servicedeststree	;
	$configbundles{$config}{'actionservicefromstree'} = \%actionservicefromstree;
	$configbundles{$config}{'actionservicedeststree'} = \%actionservicedeststree;
	$configbundles{$config}{'daystree'} = \%daystree			;
	$configbundles{$config}{'rulehits'} = \%rulehits			;
	$configbundles{$config}{'uniqueiphits'} = \%uniqueiphits		;
	$configbundles{$config}{'logbins'} = \%logbins				;
	
# NOTE: compairing logs and config
	
	$configbundles{$config}{'rulenumberhits'} = \%rulenumberhits		;
	$configbundles{$config}{'unusedrulehits'} = \%unusedrulehits 		;		 
	$configbundles{$config}{'foundsrvcobjects'} = \%foundsrvcobjects	;
}
#===================================================================================================
# END OF INPUT STAGE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#===================================================================================================

#===================================================================================================
# THE USER INTERACTION BIT
#===================================================================================================

#---------------------------------------------------------------------------------------------------
# PRINTING THE BANNER FOR THE USER INTERACTION BIT 
#---------------------------------------------------------------------------------------------------

print "-----------------------------------------------------------------------------------------\n";
print " STARTING USER INTERACTION LOOP ...hit enter!\n";

# NOTE: this is the user interaction loop, its just an until loop, it never ends because of the \n, use CTRL-C 

until (<STDIN> eq 'ex')  {

	print "
=========================================================================================
            360 Analytics Ltd.   Firewall Analysis Audit and Repair			
=========================================================================================
                 360-FAAR Copyright (C) 2009-2012  Dan Martin				


    360-FAAR v0.3.0 MENU: 
    ------------------------------------

	print	= Prints the details relating to all objects name, ip, rule and policy usage, group membership, supernets,
		  subnets, hosts on networks, etc to a headded CSV, and a reduced csv to the screen for info.

       fltprint = Prints the same format object analysis spreadsheet as 'print' and allows you to specify inclusive and 
		  exclusive, text and CIDR filtering of the objects output.

	rr  	= Rationalize selected rules together and filter using CIDR and strings if required
		  Pull encryption rules from a second config (if traffic is encrypted between to and from firewalls)
		  Merge to a third firewall cluster and match and filter existing connectivity out of new rules.
		  This process can also translate objects and groups and gives details in the od, cs and ns output stage
		  in the commemts section of the object definitions.
		   
	hbin 	= Find a host by entering its ipbin
		  some processes print binary IP's for speed, if you see an interesting bin ip find its objects
		  details using this mode.

	bldobj 	= Resolve rule objects from odumper format file and translate objects and rules to a new firewall cluster
		  Identify objects from the file using two of the loaded configuations and enter a third to translate
		  objects to and write details to the comments.
		  USE this mode to allow you to read modified or new rulebases and associate objects from the configs
		  before writing the dbedit to make the rules to the screen and an od format file

	exit 	= EXIT the script.

    Output Types: 
    ------------------------------------

	od	= The legendary odumper/ofiller format with rules on, and nats in the legendary fwdoc csv file format

		  rr mode	- Outputs odumper format files of its suggested policies, and at the moment uses a blank
				  field for \"Any\" rules so that the files can be read by ofiller, and you can diff
				  mine and fillers dbedit output for double consistency!!.
				  It also the dbedit to create the rulebase to the screen.
				  The dbedit objects and groups are translated, the csv file is not 

		  bldobj mode	- outputs the same file and dbedit but keeps comments and rules from the input config
				- use the numberrules helper script to make the csv's more readable, modify the csv's 
				  and then read them in this or odumper format using the bldobj mode.
				  The dbedit and the csv files objects and groups are translated, rule comments are kept 

	ns	= Netscreen ScreenOS 6 format, you need supply either a netscreen config to  merege to, or
		  ZONE IP NM statements when you output the commands to update the firewalls, or both, if you want to
		  override the configs default route zone

	cs	= Cisco.  Output objects and groups in ASA 8.4+ format, and rules as ACE's in an access list name 
		  specified during the output stage.


		  
    ---------------------------------------------------------
    Chose one: ";

	my ($typ, $typ2);
	chomp ($typ = <STDIN>);

	#print "\nYou chose $typ\n\n";


#===================================================================================================
# RESOLVE OBJECTS FROM IPBINs
#===================================================================================================

	if ($typ eq 'exit') {

	# NOTE: get me the hell out of here... why this fucking thing wont let go??!!
		print "\n\n.............signing out\n\n";
		exit;

	} elsif ($typ eq 'hbin') {
		print " 	Enter the name of the config you want to resolve objects from:\n";
		foreach my $configname (sort keys %configbundles){
			print " 		$configname\n";
		}
		print " 	 -> ";
		my $configname = <STDIN>;
		chomp($configname);
		print "\n";

		print "\n\n	Enter the IPBIN and get your object names back or 'end.' to exit to menu\n";
		print " 	 -> ";
		while (<STDIN>) {
			chomp($_);
			last if $_ eq 'end.';
			my $ipbin = $_;
			my $workbin = $ipbin;
			my $foundobjcount = 0;
			for (my $i = 0; $i <= 32; $i++) {
				if (exists $configbundles{$configname}{'ips'}{$workbin}) {
					$foundobjcount++;
					my $obname = $configbundles{$configname}{'ips'}{$workbin}{'name'};
					print "\n 		Found object:$foundobjcount: $obname";
					print Dumper(%{$configbundles{$configname}{'netobjects'}{$obname}}) . "\n";
				}
				chop ($workbin);
			}
			print "\n\n";
			my $dupworkbin = $ipbin;
			for (my $i = 0; $i <= 32; $i++) {
				if (exists $configbundles{$configname}{'duplips'}{$dupworkbin}) {
					foreach my $dupli (sort keys %{$configbundles{$configname}{'duplips'}{$dupworkbin}}) {
						$foundobjcount++;
						print " 		Duplicate object:$foundobjcount:$dupli\n";
					}
				}
				chop ($dupworkbin);
			}
			print "\n\n	Enter the IPBIN and get your object names back or 'end.' to exit to menu\n";
			print " 	 -> ";
		}
	}

#===================================================================================================
# PRINT ANALYSIS TO FILE
#===================================================================================================
	
	if ($typ =~ /^print$|^fltprint$/) {
		print "\n\n-----------------------------------------------------------------------------------------\n";
		print " OUTOUT OBJECTS DETTAILS AND RULE USAGE INFO SPREADSHEET:\n";
		print "-----------------------------------------------------------------------------------------\n";

		print "\n\n	Enter the name of the spreadsheet you want to print analysis to:\n\n";
		my $rulebase = <STDIN>;
		chomp ($rulebase);
		print "\n";
		open (OBJANALYSIS, ">$rulebase") or warn "Can't open $rulebase: $!\n"	;        

		my %includeips;
		my %excludeips;
		my %includestr;
		my %excludestr;

	# NOTE: collect filters data for 'fltprint' mode

		if ($typ eq 'fltprint') {

			print "\n	Enter the TEXT STRINGS (without spaces) that you wish to either include or exclude in the format:\n"	;
			print " 	[IN|EX] TEXT_STRING\n"		;
			print " 	Enter 'end.' when done: \n\n"	;

		# NOTE: get include and exclude filter strings

			while (<STDIN>) {
				chomp;
				last if $_ eq 'end.'							;
				next if $_ eq ''							;
				my @incexstr = split (/\s+/, $_)					;

				if ($incexstr[0] !~ /^IN|^EX$/ ) {
					print "\n	ERROR: Unknown key word \"$_\" try again!\n"	;

				} elsif ($incexstr[0] eq 'IN') {
					my $string = $incexstr[1] 					;

					$includestr{$string}	 	= 'IN'	 			;

				} elsif ($incexstr[0] eq 'EX') {
					my $string = $incexstr[1] 					;
					
					$excludestr{$string} 	  	= 'EX'				;
				}				 
			}

			print "\n	Enter the IP ADDRESS and MASK LENGTH of networks you wish to either include or exclude in the format:\n"	;
			print " 	[IN|EX] IP MASKLENGTH\n"	;
			print " 	Enter 'end.' when done: \n\n"	;

		# NOTE: get include and exclude CIDR networks

			while (<STDIN>) {
				chomp;
				last if $_ eq 'end.'							;
				next if $_ eq ''							;
				my @incexips = split (/\s+/, $_)					;
				if ($incexips[0] !~ /^IN|^EX$/ ) {
					print "\n	ERROR: Unknown key word \"$_\" try again!\n"	;
				} elsif ($incexips[0] eq 'IN') {
					my $ipbin = ip_to_bin($incexips[1]) 				;
					my ($maskedbits) 		= substr($ipbin, 0, $incexips[2]);
					print " 	Resolved IN to Binary Match $maskedbits\n"	;
					$includeips{$maskedbits} 	= $incexips[1] 			;
				} elsif ($incexips[0] eq 'EX') {
					my $ipbin = ip_to_bin($incexips[1]) 				;
					my ($maskedbits) 		= substr($ipbin, 0, $incexips[2]);
					print " 	Resolved EX to Binary Match: $maskedbits\n"	;
					$excludeips{$maskedbits} 	= $incexips[1]  		;
				}				 
			}
		}

		#print "INCLUDE GROUPS        	\n########################################################################################################################\n\n". Dumper(%includeips) . "\n\n";
		#print "EXCLUDE GROUPS        	\n########################################################################################################################\n\n". Dumper(%excludeips) . "\n\n";

#---------------------------------------------------------------------------------------------------
# PRINTING THE BANNER FOR THE ANALYSIS SPREADSHEET
#---------------------------------------------------------------------------------------------------
	
		foreach my $cfgfile (sort keys %configbundles) {
			print "\n===================================================================================================\n";
			print "CONFIG BUNDLE: $cfgfile\n";
			print "===================================================================================================\n";
			print "Object and Rule Analysis output using 'print' mode in 360-FAAR\n";
			print "\n";
			print "NAME, TYPE, IP, NM, SUB AND SUPERGROUP MEMBERSHIP, SUPERNETS, IP DUPLICATE OBJECTS, USED IN POLICIES, DESCRIPTION, SUBNETS of OBJECT, SUBNET HOSTS OF OBJECT\n";
			print OBJANALYSIS "\n##===================================================================================================\n";
			print OBJANALYSIS "## CONFIG BUNDLE: $cfgfile\n";
			print OBJANALYSIS "##===================================================================================================\n";
			print OBJANALYSIS "## Object Analysis Spreadsheet output using 'print' or 'fltprint' mode in 360-FAAR\n";
			print OBJANALYSIS "##\n";
			print OBJANALYSIS "## NAME, TYPE, IP, NM, COLOUR, CIDR, SUB OR SUPERGROUP MEMBERSHIP, SUPERNETS OF OBJECT, IP DUPLICATE OBJECTS, USED IN POLICIES, DESCRIPTION, SUBNETS OF OBJECT, SUBNET HOSTS OF OBJECT, POLICY SRC RULE USAGE, POLICY DST RULE USAGE, LOG SRC RULE HITS, LOG SRC PROTO PORT USAGE, LOG DST RULE HITS, LOG DST PROTO PORT USAGE, BINARY IPS, ASSOCIATED SRC RULE ACTIONS, ASSOCIATED DST RULE ACTIONS, USED AS SRC IN RULES, USED AS DST IN RULES, SRC NATS FROM POLICY, DST NATS FROM POLICY, SRVC NATS FROM POLICY, SRC NATS FROM LOGS, DST NATS FROM LOGS, SRVC NAT DESTS FROM LOG, SRC INSTALL ONS, DST INSTALL ONS, SRC IN VPN, DST IN VPN, SRC NEG IN POLICY, DST NEG IN POLICY, SRVC NEG AS SRC, SRVC NEG AS DST, SRC RULE COMMENTS, DST RULE COMMENTS, SRC RULE SECTION HEADDER, DST RULE SECTION HEADDER\n";

#---------------------------------------------------------------------------------------------------
# PROCESS OBJECTS FOR ANALYSIS SPREADSHEET AND FILTER IF 'fltprint' MODE
#---------------------------------------------------------------------------------------------------
	
			foreach my $obj (sort keys %{$configbundles{$cfgfile}{'netobjects'}}) {

			# NOTE: set hashes and arrays for OBJECT USE in RULE details

				my %descrip;
				my %descrid;
				my %secheds;
				my %sechedd;
				my %rulegrp;
				my %rulesrvcs;
				my %ruleactions;
				my %ruleactiond;
				my %src;
				my %dst;
				my %installons;
				my %installond;
				my %vpns;
				my %vpnd;
				my %srcnegs;
				my %dstnegs;
				my %srvcnegs;
				my %srcnegd;
				my %dstnegd;
				my %srvcnegd;
				my @names;
				my @duplnames;
				my @subnames;
				my @hostnames;

			# NOTE: set variables for object 'get'

				my ($type, $ip, $nm, $colour, $cidr, $supergroups_ref, $description, $ipbins_ref, $rulesrcs_ref, $ruledsts_ref, $logsrcrules_ref, $logsrcsrvcs_ref, $logdstrules_ref, $logdstsrvcs_ref, $natsrcs_ref, $natdsts_ref, $natsrvcs_ref, $lognatsrcs_ref, $lognatdsts_ref, $lognatsrvcs_ref);

			# NOTE: get object details using get_netobj subroutine

				($type, $ip, $nm, $colour, $supergroups_ref, $cidr, $description, $ipbins_ref, $rulesrcs_ref, $ruledsts_ref, $logsrcrules_ref, $logsrcsrvcs_ref, $logdstrules_ref, $logdstsrvcs_ref, $natsrcs_ref, $natdsts_ref, $natsrvcs_ref, $lognatsrcs_ref, $lognatdsts_ref, $lognatsrvcs_ref) = get_netobj($obj, $configbundles{$cfgfile}{'netobjects'});

				if ($obj =~ /^any$|^Any$|^ANY$/) { $cidr = "0.0.0.0\/0";}
				if ($cidr eq 'none') { 
					my ($maskbin, $maskbits, $masklength)		= netmask_to_bin($nm) ;
					$cidr = "$ip\/$masklength";
				}

				my @srvcs;
				my @srvcd;

			# NOTE: pull details from each global rule number in which each object was used as a SOURCE

				foreach my $rlsrc (sort numerically @$rulesrcs_ref) {
					next if $rlsrc eq 'none';
					my $desc = ' ';
					my $seched = ' ';

					my $rlnum 	= $configbundles{$cfgfile}{'rules'}{$rlsrc}{'rbnum'};
					my $rulegroup 	= $configbundles{$cfgfile}{'rules'}{$rlsrc}{'rulegroup'};
					my $ruleaction 	= $configbundles{$cfgfile}{'rules'}{$rlsrc}{'action'};
					my $vpn 	= $configbundles{$cfgfile}{'rules'}{$rlsrc}{'vpn'};
					my $srcneg 	= $configbundles{$cfgfile}{'rules'}{$rlsrc}{'srcneg'};
					my $dstneg 	= $configbundles{$cfgfile}{'rules'}{$rlsrc}{'dstneg'};
					my $srvcneg 	= $configbundles{$cfgfile}{'rules'}{$rlsrc}{'srvcneg'};

					foreach my $installon (keys %{$configbundles{$cfgfile}{'rules'}{$rlsrc}{'installon'}}) {
						$installons{"$rulegroup Rl:$rlnum: $installon  "}++;
					}

					if (exists $configbundles{$cfgfile}{'rules'}{$rlsrc}{'header'} && $configbundles{$cfgfile}{'rules'}{$rlsrc}{'header'} ne "") {
						$seched = $configbundles{$cfgfile}{'rules'}{$rlsrc}{'header'};
					} else {
						$seched = 'none';
					}
					if (exists $configbundles{$cfgfile}{'rules'}{$rlsrc}{'comment'} && $configbundles{$cfgfile}{'rules'}{$rlsrc}{'comment'} ne "") {
						$desc = $configbundles{$cfgfile}{'rules'}{$rlsrc}{'comment'};
					} else {
						$desc = 'none';
					}
					if (exists $configbundles{$cfgfile}{'rules'}{$rlsrc}{'service'} && $configbundles{$cfgfile}{'rules'}{$rlsrc}{'service'} ne "") {
						push (@srvcs, " Rule: $rulegroup  No: $rlnum ");
						push (@srvcs, ( sort keys %{$configbundles{$cfgfile}{'rules'}{$rlsrc}{'service'}}));
					}

					$descrip{"$rulegroup Rl:$rlnum:$desc "}++;
					$secheds{"$rulegroup Rl:$rlnum: $seched  "}++;
					$ruleactions{"$rulegroup Rl:$rlnum: $ruleaction  "}++;
					$vpns{"$rulegroup Rl:$rlnum: $vpn  "}++;
					$srcnegs{"$rulegroup Rl:$rlnum: $srcneg  "}++;
					$dstnegs{"$rulegroup Rl:$rlnum: $dstneg  "}++;
					$srvcnegs{"$rulegroup Rl:$rlnum: $srvcneg  "}++;
					$src{"G_Rl_Num:$rlsrc Rb:$rulegroup Rl: $rlnum  "}++;
					$rulegrp{$rulegroup}++;
				}

			# NOTE: pull details from each global rule number in which each object was used as a DESTINATION

				foreach my $rldst (sort numerically @$ruledsts_ref) {
					next if $rldst eq 'none';
					my $des = ' ';
					my $seched = ' ';
					my $rlnum 	= $configbundles{$cfgfile}{'rules'}{$rldst}{'rbnum'};
					my $rulegroup 	= $configbundles{$cfgfile}{'rules'}{$rldst}{'rulegroup'};
					my $ruleactio 	= $configbundles{$cfgfile}{'rules'}{$rldst}{'action'};
					my $vpn 	= $configbundles{$cfgfile}{'rules'}{$rldst}{'vpn'};
					my $srcneg 	= $configbundles{$cfgfile}{'rules'}{$rldst}{'srcneg'};
					my $dstneg 	= $configbundles{$cfgfile}{'rules'}{$rldst}{'dstneg'};
					my $srvcneg 	= $configbundles{$cfgfile}{'rules'}{$rldst}{'srvcneg'};

					foreach my $installon (keys %{$configbundles{$cfgfile}{'rules'}{$rldst}{'installon'}} ) {
						$installond{"$rulegroup Rl:$rlnum: $installon  "}++;
					}
											
					if (exists $configbundles{$cfgfile}{'rules'}{$rldst}{'header'} && $configbundles{$cfgfile}{'rules'}{$rldst}{'header'} ne "") {
						$seched = $configbundles{$cfgfile}{'rules'}{$rldst}{'header'};
					} else {
						$seched = 'none';
					}

					if (exists $configbundles{$cfgfile}{'rules'}{$rldst}{'comment'} && $configbundles{$cfgfile}{'rules'}{$rldst}{'comment'} ne "") {
						$des = $configbundles{$cfgfile}{'rules'}{$rldst}{'comment'};
					} else {
						$des = 'none';
					}
					if (exists $configbundles{$cfgfile}{'rules'}{$rldst}{'service'} && $configbundles{$cfgfile}{'rules'}{$rldst}{'service'} ne "") {
						push (@srvcd, " Rule: $rulegroup  No: $rlnum ");
						push (@srvcd, ( sort keys %{$configbundles{$cfgfile}{'rules'}{$rldst}{'service'}}));
					}

					$descrid{"$rulegroup Rl:$rlnum: $des  "}++;
					$sechedd{"$rulegroup Rl:$rlnum: $seched  "}++;
					$ruleactiond{"$rulegroup Rl:$rlnum: $ruleactio  "}++;
					$vpnd{"$rulegroup Rl:$rlnum: $vpn  "}++;
					$srcnegd{"$rulegroup Rl:$rlnum: $srcneg  "}++;
					$dstnegd{"$rulegroup Rl:$rlnum: $dstneg  "}++;
					$srvcnegd{"$rulegroup Rl:$rlnum: $srvcneg  "}++;
					$dst{"G_Rl_Num:$rldst Rb:$rulegroup Rl: $rlnum  "}++;
					$rulegrp{$rulegroup}++;
				}

			# NOTE: sort hashes and output to arrays ready for printing

				my @rulegrp 	= sort keys %rulegrp;
				my @src 	= sort keys %src;
				my @descrip 	= sort keys %descrip;
				my @secheds 	= sort keys %secheds;
				my @dst 	= sort keys %dst;
				my @descrid 	= sort keys %descrid;
				my @sechedd 	= sort keys %sechedd;
				my @actions 	= sort keys %ruleactions;
				my @actiond 	= sort keys %ruleactiond;
				my @installons 	= sort keys %installons;
				my @installond 	= sort keys %installond;
				my @vpns 	= sort keys %vpns;
				my @vpnd 	= sort keys %vpnd;
				my @srcnegs 	= sort keys %srcnegs;
				my @srcnegd 	= sort keys %srcnegd;
				my @dstnegs 	= sort keys %dstnegs;
				my @dstnegd 	= sort keys %dstnegd;
				my @srvcnegs 	= sort keys %srvcnegs;
				my @srvcnegd 	= sort keys %srvcnegd;

			# NOTE: set include and exclude filter counts

				my $inc  = 0 ;
				my $exc  = 0 ;

			# NOTE: process binary IP's and compaire to each other

				foreach my $ipb (sort @$ipbins_ref) {

				# NOTE: filter output using CIDR 

					if ($typ eq 'fltprint') {
						my $inccount = scalar keys %includeips;
						my $exccount = scalar keys %excludeips;
						my $ipincbin = $ipb;
						if ($inccount > 0 ) {
							until (exists $includeips{$ipincbin} || $ipincbin eq "") {
								chop $ipincbin;
							}
							if (exists $includeips{$ipincbin}) {
								if ($exccount > 0 ) {
									my $ipexcbin = $ipb;
									until (exists $excludeips{$ipexcbin} || $ipexcbin eq "") {
										chop $ipexcbin;
									}
									if (exists $excludeips{$ipexcbin}) {
										$exc++;
									} else {
										$inc++;
									}
								} else {
									$inc++
								}
							}
						} elsif ($exccount > 0 ) {
							my $ipexcbin = $ipb;
							until (exists $excludeips{$ipexcbin} || $ipexcbin eq "") {
								chop $ipexcbin;
							}
							if (exists $excludeips{$ipexcbin}) {
								$exc++;
							} else {
								$inc++;
							}
						} else {
							$inc++
						}
					}
					my ($nam, $dupnam, $subnam, $hstnam) ;
					if (scalar(@$ipbins_ref) > 256) {

					# NOTE: SKIPPING SUBNET AND HOST PROCESSING\n";  

						($nam, $dupnam, $subnam, $hstnam) = find_supernets_and_duplicates($ipb,$configbundles{$cfgfile}{'ips'},$configbundles{$cfgfile}{'duplips'}) ;
					} else {
						($nam, $dupnam, $subnam, $hstnam) = find_supernets_duplicates_and_subnets($ipb,$configbundles{$cfgfile}{'ips'},$configbundles{$cfgfile}{'duplips'}) ;
					}
					push(@names, @$nam);
					push(@duplnames, @$dupnam);
					push(@subnames, @$subnam);
					push(@hostnames, @$hstnam);
				}
				my $incstr  = 0 ;
				my $excstr  = 0 ;

			# NOTE: filter object using STRINGS

				if ($typ eq 'fltprint') {
					my $inccount = scalar keys %includestr;
					my $exccount = scalar keys %excludestr;
					if ($inccount > 0 ) {
						foreach my $string (keys %includestr) {
							if ($obj =~ m/$string/) {
								if ($exccount > 0 ) {
									foreach my $exstring (keys %excludestr) {
										if ($obj =~ m/$exstring/) {
											$excstr++;
											$incstr = 0 ;
										} else {
											$incstr++;
										}
									}
								} else {
									$incstr++;
								}
							} else {
								#$exstr++;
							}
						}
					} elsif ($exccount > 0 ) {
						foreach my $exstring (keys %excludestr) {
							if ($obj =~ m/$exstring/) {
								$excstr++;
								$incstr = 0 ;
							} else {
								$incstr++;
							} 
						}
					} else {
						$incstr++
					}

			# NOTE: !!!!!!!!!!!!IMPORTANT!!!!!!!!!!!!!!  ...decide BOTH filters here

					unless (($inc > 0) && ($exc == 0) && ($incstr > 0) && ($excstr == 0)) {
						next;
					}
				}			

			# NOTE: assing none to output arrays if ARRAYS ARE EMPTY

				unless (@names) {
					push( @names, 'none');
				}
				unless (@duplnames) {
					push( @duplnames, 'none');
				}
				unless (@subnames) {
					push( @subnames, 'none');
				}
				unless (@hostnames) {
					push( @hostnames, 'none');
				}
				unless (@src) {
					push( @src, 'none');
				}
				unless (@descrip) {
					push( @descrip, 'none');
				}
				unless (@secheds) {
					push( @secheds, 'none');
				}
				unless (@dst) {
					push( @dst, 'none');
				}
				unless (@descrid) {
					push( @descrid, 'none');
				}
				unless (@actions) {
					push( @actions, 'none');
				}
				unless (@actiond) {
					push( @actiond, 'none');
				}
				unless (@sechedd) {
					push( @sechedd, 'none');
				}
				unless (@rulegrp) {
					push( @rulegrp, 'none');
				}
				unless (@srvcs) {
					push( @srvcs, 'none');
				}
				unless (@srvcd) {
					push( @srvcd, 'none');
				}
				unless (@$ipbins_ref) {
					push( @$ipbins_ref, 'none');
				}
				unless (defined ($description) && ($description ne "")) { 
					$description = 'none';
				}
				unless (@installons) {
					push( @installons, 'none');
				}
				unless (@installond) {
					push( @installond, 'none');
				}
				unless (@vpns) {
					push( @vpns, 'none');
				}
				unless (@vpnd) {
					push( @vpnd, 'none');
				}
				unless (@srcnegs) {
					push( @srcnegs, 'none');
				}
				unless (@srcnegd) {
					push( @srcnegd, 'none');
				}
				unless (@dstnegs) {
					push( @dstnegs, 'none');
				}
				unless (@dstnegd) {
					push( @dstnegd, 'none');
				}
				unless (@srvcnegs) {
					push( @srvcnegs, 'none');
				}
				unless (@srvcnegd) {
					push( @srvcnegd, 'none');
				}

#---------------------------------------------------------------------------------------------------
# OUTPUT ANALYSIS TO CSV AND SCREEN
#---------------------------------------------------------------------------------------------------
	
				$description =~ s/\,//;

			# NOTE: print analysis to CSV spreadsheet

				print OBJANALYSIS "$obj,$type,$ip,$nm,$colour,$cidr,@$supergroups_ref,@names,@duplnames,@rulegrp,$description,@subnames,@hostnames,@srvcs,@srvcd,@$logsrcrules_ref,@$logsrcsrvcs_ref,@$logdstrules_ref,@$logdstsrvcs_ref,@$ipbins_ref,@actions,@actiond,@src,@dst,@$natsrcs_ref,@$natdsts_ref,@$natsrvcs_ref,@$lognatsrcs_ref,@$lognatdsts_ref,@$lognatsrvcs_ref,@installons,@installond,@vpns,@vpnd,@srcnegs,@dstnegd,@srvcnegs,@srvcnegd,@descrip,@descrid,@secheds,@sechedd\n";

			# NOTE: print analysis to screen

				print  "$obj, $type, $ip, $nm, @$supergroups_ref, @names, @duplnames, @rulegrp, $description, @subnames, @hostnames\n";
			}
		}
		print "\n\n---------------------------------------------------------------------------------------------------\n";
		print "ANALYSIS FILE: $rulebase WRITTEN  		!!WEHAYY!!!\n";
		print "---------------------------------------------------------------------------------------------------\n";
		print "hit return...\n";
	}


#===================================================================================================
# READ RULES FROM FILE, IDENTIFY OBJECTS FROM PROCESSED CONFIGS, TRANSLATE AND OUTPUT TO FILE AND COMMANDS TO SCREEN
#===================================================================================================


	if ($typ eq 'bldobj') {
		print "\n\n-----------------------------------------------------------------------------------------\n";
		print " IDENTIFY OBJECTS TO BUILD RULE DEFINITIONS:\n";
		print "-----------------------------------------------------------------------------------------\n";
		print "   Enter rule definitions in odumper format to build a policy\n";
		my %srctmpbundle;

		my %netobjs	= ();
		my %groups	= ();
		my %ipbins	= ();

		my %srvcs	= ();
		my %srvcgrps	= ();
		my %ports	= ();

		my %bingroups 	= ();
		my %portgroups	= ();

		my %rashprintbase = ();

		$srctmpbundle{'netobjects'}	= \%netobjs;
		$srctmpbundle{'srvcobjects'}	= \%srvcs;
		$srctmpbundle{'netgroups'}	= \%groups;
		$srctmpbundle{'netgroupobjs'}	= \%groups;
		$srctmpbundle{'srvcgroups'}	= \%srvcgrps;
		$srctmpbundle{'srvcgroupobjs'}	= \%srvcgrps;
		$srctmpbundle{'ips'} 		= \%ipbins;
		$srctmpbundle{'ports'} 		= \%ports;
		$srctmpbundle{'bingroups'} 	= \%bingroups;
		$srctmpbundle{'portgroups'} 	= \%portgroups;

		print "\n	Enter the name of the spreadsheet you want to \n	read rules from:\n\n";
		my $rulebase = <STDIN>;
		chomp ($rulebase);
		print "\n";
		open RULEBASE, "$rulebase" or warn "Can't open $rulebase: $!\n"	;        

		print " 	Enter the type of config you would like to build [od|ns|cs]:\n\n";
		my $configout = <STDIN>;
		chomp ($configout);

		print "\n	Enter the config bundle name of the firewall you are \n	merging rules and objects from:\n\n";
		foreach my $configname (sort keys %configbundles){
			print " 		$configname\n";
		}
		print "\n";
		my $configfrom = <STDIN>;
		chomp ($configfrom);

		print "\n	Enter the secondary config bundle name of the firewall you are \n	merging rules and objects from:\n\n";
		foreach my $configname (sort keys %configbundles){
			print " 		$configname\n";
		}
		print "\n";
		my $configfrom2 = <STDIN>;
		chomp ($configfrom2);

		print "\n	Enter the config bundle name of the firewall you are \n	merging rules and objects to:\n\n";
		foreach my $configname (sort keys %configbundles){
			print " 		$configname\n";
		}
		print "\n";
		my $configto = <STDIN>;
		chomp ($configto);
		
#---------------------------------------------------------------------------------------------------
# PRINTING THE BANNER OBJECT BUILD BIT
#---------------------------------------------------------------------------------------------------

		print "\n-----------------------------------------------------------------------------------------\n";
		print " SCANNING FILE $rulebase FOR RULE DEFINITIONS:\n";
		print "-----------------------------------------------------------------------------------------\n";

	# NOTE: assigning objects to zones

		my $rulecount		= 0;
		my $objcountfrom	= 0;
		my $objcountfrom2	= 0;
		my $objcountto		= 0;
		my $grpcountfrom	= 0;
		my $grpcountfrom2	= 0;
		my $grpcountto		= 0;
		my $srvcfrom		= 0;
		my $srvcfrom2		= 0;
		my $srvcto		= 0;
		my $grpsrvcfrom		= 0;
		my $grpsrvcfrom2	= 0;
		my $grpsrvcto		= 0;
		
		while (<RULEBASE>) {

	# NOTE: skip objects

			next unless /^security_rule|^Rule: \d+/;
			chomp($_);
			$_  =~ s/\n//g;
			$_  =~ s/\r//g;

			$_ =~ s/\, /\,/g ;

			my ($rbnum, $type, $srcs, @srcs, $dsts, @dsts, $vpn, $services, @services, $action, $track, $installon, $time, $comment, $sectionhead) ;
			my (%srcipbins, %dstipbins, %srcgroups, %dstgroups, %rlsrvcs, %rlsrvcgrps);
			my (@srcsout, @dstsout, @srvcsout, %srvcsout);

		# NOTE: identify rule text format and break up objects accordingly

			if (/^Rule: \d+/) {

			# NOTE: readable format of odumper made with numberrules helper script

				$rulecount++;
				($rbnum, $type, $srcs, $dsts, $vpn, $services, $action, $track, $installon, $time, $comment, $sectionhead) = split (/\,/, $_);
				$rbnum =~ s/Rule: //;
				unless (defined($sectionhead)) { $sectionhead = ' ';}
				$srcs =~ s/^\s+//;
				$dsts =~ s/^\s+//;
				$services =~ s/^\s+//;
				@srcs = split (/\s+/, $srcs);
				@dsts = split (/\s+/, $dsts);
				@services = split (/\s+/, $services);
			} elsif (/^security_rule/) {

			# NOTE: odumper format file, objects seperated by ";"

				$rulecount++;
				$sectionhead = ' ';
				($type, $srcs, $dsts, $vpn, $services, $action, $track, $installon, $time, $comment) = split (/\,/, $_);
				$rbnum = $rulecount;
				$srcs =~ s/^\s+//;
				$dsts =~ s/^\s+//;
				$services =~ s/^\s+//;
				@srcs = split (/\;/, $srcs);
				@dsts = split (/\;/, $dsts);
				@services = split (/\;/, $services);
			}
			
			$rashprintbase{$rbnum} = "@srcs,@dsts,@services,$comment$sectionhead";
			
		# NOTE: the next section builds a new config bundle from objects listed in the rules from the two config bundles supplied

		# NOTE: identify rule SOURCE objects from the two sorce configs supplied

			foreach my $src (@srcs) {
				if (exists $configbundles{$configfrom}{'netobjects'}{$src}) {
					$objcountfrom++;
					$netobjs{$src} = $configbundles{$configfrom}{'netobjects'}{$src};
				} elsif (exists $configbundles{$configfrom}{'netgroupobjs'}{$src}) {
					$grpcountfrom++;
					$groups{$src} = $configbundles{$configfrom}{'netgroupobjs'}{$src};
					$bingroups{$src} = $configbundles{$configfrom}{'bingroups'}{$src};
					foreach my $netobj (keys %{$configbundles{$configfrom}{'netgroupobjs'}{$src}}) {
						$objcountfrom++;
						$netobjs{$netobj} = $configbundles{$configfrom}{'netobjects'}{$netobj};
					}
				} elsif (exists $configbundles{$configto}{'netobjects'}{$src}) {
					$objcountto++;
					$netobjs{$src} = $configbundles{$configto}{'netobjects'}{$src};
				} elsif (exists $configbundles{$configfrom2}{'netobjects'}{$src}) {
					$objcountfrom2++;
					$netobjs{$src} = $configbundles{$configfrom2}{'netobjects'}{$src};
				} elsif (exists $configbundles{$configto}{'netgroupobjs'}{$src}) {
					$grpcountto++;
					$groups{$src} = $configbundles{$configto}{'netgroupobjs'}{$src};
					$bingroups{$src} = $configbundles{$configto}{'bingroups'}{$src};
					foreach my $netobj (keys %{$configbundles{$configto}{'netgroupobjs'}{$src}}) {
						$objcountto++;
						$netobjs{$netobj} = $configbundles{$configto}{'netobjects'}{$netobj};
					}
				} elsif (exists $configbundles{$configfrom2}{'netgroupobjs'}{$src}) {
					$grpcountfrom2++;
					$groups{$src} = $configbundles{$configfrom2}{'netgroupobjs'}{$src};
					$bingroups{$src} = $configbundles{$configfrom2}{'bingroups'}{$src};
					foreach my $netobj (keys %{$configbundles{$configfrom2}{'netgroupobjs'}{$src}}) {
						$objcountfrom2++;
						$netobjs{$netobj} = $configbundles{$configfrom2}{'netobjects'}{$netobj};
					}
				} else {
					print " MISSED SRC: $src\n";
				} 
			}

		# NOTE: identify rule DESTINATION objects from the two sorce configs supplied

			foreach my $dst (@dsts) {
				if (exists $configbundles{$configfrom}{'netobjects'}{$dst}) {
					$objcountfrom++;
					$netobjs{$dst} = $configbundles{$configfrom}{'netobjects'}{$dst};
				} elsif (exists $configbundles{$configfrom}{'netgroupobjs'}{$dst}) {
					$grpcountfrom++;
					$groups{$dst} = $configbundles{$configfrom}{'netgroupobjs'}{$dst};
					$bingroups{$dst} = $configbundles{$configfrom}{'bingroups'}{$dst};
					foreach my $netobj (keys %{$configbundles{$configfrom}{'netgroupobjs'}{$dst}}) {
						$objcountfrom++;
						$netobjs{$netobj} = $configbundles{$configfrom}{'netobjects'}{$netobj};
					}
				} elsif (exists $configbundles{$configto}{'netobjects'}{$dst}) {
					$objcountto++;
					$netobjs{$dst} = $configbundles{$configto}{'netobjects'}{$dst};
				} elsif (exists $configbundles{$configfrom2}{'netobjects'}{$dst}) {
					$objcountfrom2++;
					$netobjs{$dst} = $configbundles{$configfrom2}{'netobjects'}{$dst};
				} elsif (exists $configbundles{$configto}{'netgroupobjs'}{$dst}) {
					$grpcountto++;
					$groups{$dst} = $configbundles{$configto}{'netgroupobjs'}{$dst};
					$bingroups{$dst} = $configbundles{$configto}{'bingroups'}{$dst};
					foreach my $netobj (keys %{$configbundles{$configto}{'netgroupobjs'}{$dst}}) {
						$objcountto++;
						$netobjs{$netobj} = $configbundles{$configto}{'netobjects'}{$netobj};
					}
				} elsif (exists $configbundles{$configfrom2}{'netgroupobjs'}{$dst}) {
					$grpcountfrom2++;
					$groups{$dst} = $configbundles{$configfrom2}{'netgroupobjs'}{$dst};
					$bingroups{$dst} = $configbundles{$configfrom2}{'bingroups'}{$dst};
					foreach my $netobj (keys %{$configbundles{$configfrom2}{'netgroupobjs'}{$dst}}) {
						$objcountfrom2++;
						$netobjs{$netobj} = $configbundles{$configfrom2}{'netobjects'}{$netobj};
					}
				} else {
					print " MISSED DST: $dst\n";
				} 
			}

		# NOTE: identify rule SERVICE objects from the two sorce configs supplied

			foreach my $service (@services) {
				if (exists $configbundles{$configfrom}{'srvcobjects'}{$service}) {
					$srvcfrom++;
					$srvcs{$service} = $configbundles{$configfrom}{'srvcobjects'}{$service};
				} elsif (exists $configbundles{$configfrom}{'srvcgroupobjs'}{$service}) {
					$grpsrvcfrom++;
					$srvcgrps{$service} = $configbundles{$configfrom}{'srvcgroupobjs'}{$service};
					$portgroups{$service} = $configbundles{$configfrom}{'portgroups'}{$service};
					foreach my $srvcobj (keys %{$configbundles{$configfrom}{'srvcgroupobjs'}{$service}}) {
						$srvcfrom++;
						$srvcs{$srvcobj} = $configbundles{$configfrom}{'srvcobjects'}{$srvcobj};
					}
				} elsif (exists $configbundles{$configto}{'srvcobjects'}{$service}) {
					$srvcto++;
					$srvcs{$service} = $configbundles{$configto}{'srvcobjects'}{$service};
				} elsif (exists $configbundles{$configfrom2}{'srvcobjects'}{$service}) {
					$srvcfrom2++;
					$srvcs{$service} = $configbundles{$configfrom2}{'srvcobjects'}{$service};
				} elsif (exists $configbundles{$configto}{'srvcgroupobjs'}{$service}) {
					$grpsrvcto++;
					$srvcgrps{$service} = $configbundles{$configto}{'srvcgroupobjs'}{$service};
					$portgroups{$service} = $configbundles{$configto}{'portgroups'}{$service};
					foreach my $srvcobj (keys %{$configbundles{$configto}{'srvcgroupobjs'}{$service}}) {
						$srvcto++;
						$srvcs{$srvcobj} = $configbundles{$configto}{'srvcobjects'}{$srvcobj};
					}
				} elsif (exists $configbundles{$configfrom2}{'srvcgroupobjs'}{$service}) {
					$grpsrvcfrom2++;
					$srvcgrps{$service} = $configbundles{$configfrom2}{'srvcgroupobjs'}{$service};
					$portgroups{$service} = $configbundles{$configfrom2}{'portgroups'}{$service};
					foreach my $srvcobj (keys %{$configbundles{$configfrom2}{'srvcgroupobjs'}{$service}}) {
						$srvcfrom2++;
						$srvcs{$srvcobj} = $configbundles{$configfrom2}{'srvcobjects'}{$srvcobj};
					}
				} else {
					print " MISSED SRVC: $service\n";
				}
			}

		# NOTE: build the binary ip's tree for the new config bundle

			foreach my $netobj (keys %netobjs) {
				foreach my $ipbin (keys %{$netobjs{$netobj}{'ipbin'}}) {
					$ipbins{$ipbin}{'name'} = $netobj;
				}
			}

		# NOTE: build the ports tree for the new config bundle

			foreach my $srvc (keys %srvcs) {
				foreach my $proto (keys %{$srvcs{$srvc}{'ports'}}) {
					foreach my $port (keys %{$srvcs{$srvc}{'ports'}{$proto}}) {
						$ports{$proto}{$port}{'name'} = $srvc;
					}
				}
			}
		}

#---------------------------------------------------------------------------------------------------
# PRINTING NUMBERS OF OBJECTS PULLED FROM EACH CONFIG BUNDLE
#---------------------------------------------------------------------------------------------------

		print "   Found Rules Numbering: $rulecount\n\n";
		print "   POLICY PACK: $configfrom\n";
		print "    Objects:		$objcountfrom\n";
		print "    Obj Groups:		$grpcountfrom\n";
		print "    Services:		$srvcfrom\n";
		print "    Srvc Groups: 	$grpsrvcfrom\n";
		print "   POLICY PACK: $configfrom2\n";
		print "    Objects:		$objcountfrom2\n";
		print "    Obj Groups:		$grpcountfrom2\n";
		print "    Services:		$srvcfrom2\n";
		print "    Srvc Groups: 	$grpsrvcfrom2\n";
		print "   POLICY PACK: $configto\n";
		print "    Objects: 		$objcountto\n";
		print "    Obj Groups:		$grpcountto\n";
		print "    Services:		$srvcto\n";
		print "    Srvc Groups: 	$grpsrvcto\n";
		
		#print "\n\nDEST RULES\n#############################################################################################################################################################\n\n". Dumper(%{$configbundles{$configto}{'rules'}});

		if ($configout eq 'ns') {
			output_netscreen(\%srctmpbundle, $configbundles{$configto}, \%netobjs, \%srvcs, \%groups, \%srvcgrps, \%rashprintbase, 'keepcomments');
		} elsif ($configout eq 'od') {
			output_odumper_csv_file(\%srctmpbundle, $configbundles{$configto}, \%netobjs, \%srvcs, \%groups, \%srvcgrps, \%rashprintbase, 'keepcomments');
		} elsif ($configout eq 'cs') {
			output_cisco_and_csv_file(\%srctmpbundle, $configbundles{$configto}, \%netobjs, \%srvcs, \%groups, \%srvcgrps, \%rashprintbase, 'keepcomments');
		}
	}

#===================================================================================================
# PRINT MEMORY TABLES USING DATADUMPER
#===================================================================================================

#	if ($typ eq 'ips') {
#		print "IPS			\n########################################################################################################################\n\n". Dumper(%ips) . "\n\n"		;
#	}
#	if ($typ eq 'dip') {
#		print "Duplicate IPS		\n########################################################################################################################\n\n". Dumper(%duplips) . "\n\n"	;
#	}
#	if ($typ eq 'ng') {
#		print "NET GROUPS		\n########################################################################################################################\n\n". Dumper(%netgroups) . "\n\n"	;
#	}
#	if ($typ eq 'ngo') {
#		print "NET GROUP OBJECTS	\n########################################################################################################################\n\n". Dumper(%netgroupobjs) . "\n\n"	;
#	}
#	if ($typ eq 'cg') {
#		print "COMPLETE NETGROUPS	\n########################################################################################################################\n\n". Dumper(%networkgroups) . "\n"	;
#	}
#	if ($typ eq 'eg') {
#		print "EXCLUSION GROUPS 	\n########################################################################################################################\n\n". Dumper(%exclgroups) . "\n\n"	;
#	}
#	if ($typ eq 'bg') {
#		print "BINARY GROUPS		\n########################################################################################################################\n\n". Dumper(%bingroups) . "\n\n"	;
#	}
#	if ($typ eq 'bgs') {
#		print "BINARY GROUP SIZES	\n########################################################################################################################\n\n". Dumper(%bingroupsizes) . "\n\n"	;
#	}
#	if ($typ eq 'so') {
#		print "SERVICE OBJECTS		\n########################################################################################################################\n\n". Dumper(%srvcobjects) . "\n\n"	;
#	}
#	if ($typ eq 'sg') {
#		print "SRVC GROUPS		\n########################################################################################################################\n\n". Dumper(%srvcgroups) . "\n\n"	;
#	}
#	if ($typ eq 'lp') {
#		print "PORTS			\n########################################################################################################################\n\n". Dumper(%ports) . "\n\n"	;
#	}
#	if ($typ eq 'dp') {
#		print "DUPLICATE PORTS		\n########################################################################################################################\n\n". Dumper(%duplports) . "\n\n"	;
#	}
#	if ($typ eq 'pg') {
#		print "PORT GROUPS		\n########################################################################################################################\n\n". Dumper(%portgroups) . "\n\n"	;
#	}
#	if ($typ eq 'rl') {
#		print "RULES			\n########################################################################################################################\n\n". Dumper(%rules) . "\n\n"		;
#	}
#	if ($typ eq 'rlh') {
#		print "RULE HITS		\n########################################################################################################################\n\n". Dumper(%rulehits) . "\n\n"	;
#	}
#	if ($typ eq 'bmt') {
#		print "BINARY RULE TABLE	\n########################################################################################################################\n\n". Dumper(%binrules) . "\n\n"	;
#	}
#	if ($typ eq 'pds') {
#		print "PORT/DST/SRC RULE TABLE	\n########################################################################################################################\n\n". Dumper(%rashrules) . "\n\n"	;
#	}
#	if ($typ eq 'li') {
#		print "INTERFACE GROUPS  	\n########################################################################################################################\n\n". Dumper(%interfacebins) . "\n\n";
#	}
#	if ($typ eq 'la') {
#		print "ANTI SPOOFING GROUPS	\n########################################################################################################################\n\n". Dumper(%spoofgroups) . "\n\n";
#	}
#	if ($typ eq 'dh') {
#		print "DAYS TREE 		\n########################################################################################################################\n\n". Dumper(%daystree) . "\n\n"		;
#	}
#	if ($typ eq 'oh') {
#		print "UNIQUE IPS TREE		\n########################################################################################################################\n\n". Dumper(%uniqueiphits) . "\n\n"		;
#	}

#===================================================================================================
# RATIONALIZE RULES - FULL RATIONALIZATION HARDCORE MODE
#===================================================================================================

	if ($typ eq 'rr') {

		my $restype;
		my $sourceconfig;
		my $destconfig = ' ';
		my %srcinstallons;
		my %destinstallons;
		my $incconobjs;
		my %sourcerulegroups;
		my %srcconfigobjs;
		my %srcconfigsrvcs;
		my %srcconfiggroups;
		my %srcconfigsrvcgroups;
		my %destrulegroups;
		#my %groupsinuse; 	#	= (); 	
		my %mergerulebases;	#	= ();
		my %rashrulegroups; 	#	= ();
		my %includeips		= ();
		my %excludeips		= ();
		my %mergetorulebases;	#	= ();
		my %prevrashrulebase	= %lastrashrulebase;
		my %lastrashrulebase	= ();
		my %lastrashprintbase	= ();
		my %logtypes;
		my $difflast;
		my %incstrings;
		my %exstrings;
		my %incheaderstrings;
		my %exheaderstrings;
		my $filterwithlog;
		my $translatewithnats;
		my %transrules;
		my $matchprevrules;
		my $filterconfig = ' ';
		my %filterrulegroups;
		my %filterinstallons;

		print "-----------------------------------------------------------------------------------------\n"	;
		print " COLLECTING INFO FOR RULEBASE RATIONALIZATION:\n\n"						;
		print "   The following firewall configs have been loaded:\n\n"						;

	# NOTE: choose config bundle to pull rules from 

		foreach my $configbundle (sort keys %configbundles) {
			print " 		$configbundle\n"							;
		}

		print "\n	Choose the config you want to pull rules FROM in the rationalization?\n"		;
		print " 	Enter each config name and hit RETURN.\n"						;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$_}) {
				print " 	ERROR: \"$_\" not config name, try again\n" 				;
				next											;
			}
			$sourceconfig = $_										;	  
		}									
		print "\n	The firewall config \"$sourceconfig\" has its rules grouped by these groupnames:\n\n"	;

		foreach my $groupname (sort keys (%{$configbundles{$sourceconfig}{'rulegroups'}})) {
			print "		$groupname\n"									;
		}

		print "\n	Which Rulegroups do you want to pull rules FROM?\n"					;
		print " 	Enter each group and hit RETURN.\n"							;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$sourceconfig}{'rulegroups'}{$_}) {
				print " 	ERROR: \"$_\" not rule group, try again\n" 				;
				next											;
			}
			$sourcerulegroups{$_}++	  									;
		}

		print "\n	The firewall config \"$sourceconfig\" has its rules installed on these firewalls:\n\n"	;

		foreach my $installon (sort keys (%{$configbundles{$sourceconfig}{'installon'}})) {
			print "		$installon\n"									;
		}

		print "\n	Which firewalls do you want to pull rules FROM?\n"					;
		print " 	Enter each firewall and hit RETURN.\n"							;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$sourceconfig}{'installon'}{$_}) {
				print " 	ERROR: \"$_\" not firewall, try again\n" 				;
				next											;
			}
			$srcinstallons{$_}++	  									;
		}

	# NOTE: choose config bundle to filter rules with 

		print "\n	The following configs are available to pull encryption rules from?\n\n"			;

		foreach my $configbundle (sort keys %configbundles) {
			print " 		$configbundle\n"							;
		}

		print "\n\n	Choose the config you want to pull VPN rules from in the rationalization?\n"		;
		print "  	The selected encryption rules will be added to the MERGE TO rulebase\n"			;
		print "  	Matching access rules from the MERGE FROM rulebases will be filtered outi\n\n"		;
		print " 	Enter each config name and hit RETURN.\n"						;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$_}) {
				print " 	ERROR: \"$_\" not config name, try again\n" 				;
				next											;
			}
			$filterconfig = $_										;	  
		}									
		print "\n	The firewall config \"$filterconfig\" has its rules grouped by these groupnames:\n\n"	;

		foreach my $groupname (sort keys (%{$configbundles{$filterconfig}{'rulegroups'}})) {
			print "		$groupname\n"									;
		}

		print "\n	Which Rulegroups do you want to pull Encryption rules FROM?\n"					;
		print " 	Enter each group and hit RETURN.\n"							;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$filterconfig}{'rulegroups'}{$_}) {
				print " 	ERROR: \"$_\" not rule group, try again\n" 				;
				next											;
			}
			$filterrulegroups{$_}++	  									;
		}

		print "\n	The firewall config \"$filterconfig\" has its rules installed on these firewalls:\n\n"	;

		foreach my $installon (sort keys (%{$configbundles{$filterconfig}{'installon'}})) {
			print "		$installon\n"									;
		}

		print "\n	Which firewalls do you want to pull rules FROM?\n"					;
		print " 	Enter each firewall and hit RETURN.\n"							;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$filterconfig}{'installon'}{$_}) {
				print " 	ERROR: \"$_\" not firewall, try again\n" 				;
				next											;
			}
			$filterinstallons{$_}++	  									;
		}

	# NOTE: choose config bundle to merge rules to

		print "\n	The following configs are available for merging rules TO them?\n\n"			;

		foreach my $configbundle (sort keys %configbundles) {
			#next if exists $configbundles{$sourceconfig}							;
			print " 		$configbundle\n"							;
		}

		print "\n	Choose the config you want to merge rules TO in the rationalization?\n"			;
		print " 	Enter each config name and hit RETURN.\n"						;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$_}) {
				print " 	ERROR: \"$_\" not config name, try again\n" 				;
				next											;
			}
			$destconfig = $_										;	  
		}	
										
		print "\n	The firewall config \"$destconfig\" has rules are grouped by these groupnames:\n\n"	;

		foreach my $groupname (sort keys (%{$configbundles{$destconfig}{'rulegroups'}})) {
			print "		$groupname\n"									;
		}

		print "\n	Choose a rulebase to merge the previous rulebases with\n"				;
		print " 	Connections that exist in the rulebases you choose here will not apprear \n"		;
		print " 	in the new rules created.\n\n"								;

		print " 	Enter each group and hit RETURN.\n"							;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$destconfig}{'rulegroups'}{$_}) {
				print " 	ERROR: \"$_\" not rule group, try again\n" 				;
				next											;
			}
			$destrulegroups{$_}++	  									;
		}

		print "\n	The firewall config \"$destconfig\" has its rules installed on these firewalls:\n\n"	;

		foreach my $installon (sort keys (%{$configbundles{$destconfig}{'installon'}})) {
			print "		$installon\n"									;
		}

		print "\n	Which firewalls do you want to merge rules TO?\n"					;
		print " 	Enter each firewall and hit RETURN.\n"							;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$destconfig}{'installon'}{$_}) {
				print " 	ERROR: \"$_\" not firewall, try again\n" 				;
				next											;
			}
			$destinstallons{$_}++	  									;
		}

	# NOTE: choose the log types you want to include

		print "\n	Choose the log types of the rules you wish to include for rationalization:\n\n"		;

		foreach my $logtype (sort keys (%{$configbundles{$sourceconfig}{'logtypes'}})) {
			print "		$logtype\n"									;
		}

		print "\n	Which logging types do you want to pull rules with?\n"					;
		print " 	Enter each log type and hit RETURN.\n"							;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			unless (exists $configbundles{$sourceconfig}{'logtypes'}{$_}) {
				print " 	ERROR: \"$_\" not a log type in use, try again\n" 			;
				next											;
			}
			$logtypes{$_}++	  										;
		}

	# NOTE: add the filters that we require

		print "\n	Enter any strings you wish to INCLUDE filter each rule for\n"				;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			$incstrings{$_}++										;
			print "$_\n";
		}

		print "\n	Enter any strings you wish to INCLUDE filter each header section for\n"		;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			$incheaderstrings{$_}++										;
		}
		print "\n	Enter any strings you wish to EXCLUDE filter each rule for\n"				;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			$exstrings{$_}++										;
			print "$_\n";
		}

		print "\n	Enter any strings you wish to EXCLUDE filter each header section for\n"		;
		print " 	Enter 'end.' when done....\n\n"								;

		while (<STDIN>) {
			chomp												;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			$exheaderstrings{$_}++										;
		}

		print "\n	Enter the IP address ranges you wish to either include or exclude in the format:\n"	;
		print " 	[IN|EX] IP MASKLENGTH\n"								;
		print " 	Enter 'end.' when done\n"								;

		while (<STDIN>) {
			chomp;
			last if $_ eq 'end.'										;
			next if $_ eq ''										;
			my @incexips = split (/\s+/, $_)								;
			if ($incexips[0] !~ /^IN|^EX|^from.or$/ ) {
				print "\n	ERROR: Unknown key word \"$_\" try again!\n"				;
			} elsif ($incexips[0] eq 'IN') {
				my $ipbin = ip_to_bin($incexips[1]) 							;
				my ($maskedbits) 		= substr($ipbin, 0, $incexips[2]) 			;
				print " 	Resolved IN to Binary Match $maskedbits\n"				;
				$includeips{$maskedbits} 	= $incexips[1] 						;
			} elsif ($incexips[0] eq 'EX') {
				my $ipbin = ip_to_bin($incexips[1]) 							;
				my ($maskedbits) 		= substr($ipbin, 0, $incexips[2]) 			;
				print " 	Resolved EX to Binary Match: $maskedbits\n"				;
				$excludeips{$maskedbits} 	= $incexips[1]  					;
			} elsif ($incexips[0] eq 'from.or') {
				foreach my $ormatch (keys %resobjectshrd) {
					my @incex = split (/\s+/, $ormatch)						;
					my $ipbin = ip_to_bin($incex[1]) 						;
					my ($maskedbits) 		= substr($ipbin, 0, $incex[2]) 			;
					print " 	Resolved IN to Binary Match $maskedbits\n"			;
					$includeips{$maskedbits} 	= $incex[1] 					;
				}
			}
						 
		}
		#print "RULE GROUPS        	\n########################################################################################################################\n\n". Dumper(%rulegroups) . "\n\n";
		#print "INCLUDE GROUPS        	\n########################################################################################################################\n\n". Dumper(%includeips) . "\n\n";
		#print "EXCLUDE GROUPS        	\n########################################################################################################################\n\n". Dumper(%excludeips) . "\n\n";

	# NOTE: include objects that are within the CIDR ranges specified in the filter section

		print "\n 	Include objects from subnets resolved in filters in new rulebase?\n"				;
		print " 	[yes|no] - probably yes\n\n"									;

		while (<STDIN>) {
			chomp($_) 											;
			if ($_ =~ /^yes$|^no$/) {
				$restype = $_										;
				last 											;
			} else {
				print " 	ERROR: type 'yes' or 'no'\n"						;
			}
		}
		print "\n"												;

	# NOTE: set the filter so that it either includes only connections in which both ends of the connection match or one end of the connections matches

		print " 	Filter rules based on connections found in the log?\n"					;
		print " 	[yes|loose|loosen|no|none] - loose(n) modes require no in next question\n\n"		;

		while (<STDIN>) {
			chomp($_) 											;
			if ($_ =~ /^yes$|^loose$|^loosen$|^none$|^no$/) {
				$filterwithlog = $_									;
				last 											;
			} else {
				print " 	ERROR: type 'yes', 'no', 'loose', or 'loosen' or 'none'\n"		;
			}
		}

		print " 	Include objects that connect to the objects resolved, by the filters?\n"				;
		print " 	[yes|no] - probably no\n\n"										;
		while (<STDIN>) {
			chomp($_) 											;
			if ($_ =~ /^yes$|^no$/) {
				$incconobjs = $_									;
				last 											;
			} else {
				print " 	ERROR: type 'yes' or 'no'\n"						;
			}
		}

		print " 	Translate log connections ips using dest nats while filtering for IN EX CIDRs?\n"	;
		print "  	These translations are only for the IN EX filters to match using.\n"	;
		print " 	[yes|no]\n\n"										;

		while (<STDIN>) {
			chomp($_) 											;
			if ($_ =~ /^yes$|^no$/) {
				$translatewithnats = $_									;
				last 											;
			} else {
				print " 	ERROR: type 'yes' or 'no'\n"						;
			}
		}

		print " 	Match previous rules and supernets in prev rules?\n"					;
		print " 	Check each rule as its being expanded against alrady expanded rules\n"			; 
		print " 	[yes|no] - probably no\n\n"								;

		while (<STDIN>) {
			chomp($_) 											;
			if ($_ =~ /^yes$|^no$/) {
				$matchprevrules = $_									;
				last 											;
			} else {
				print " 	ERROR: type 'yes' or 'no'\n"						;
			}
		}


		print "\n"												;
		print "\n-----------------------------------------------------------------------------------------\n"	;
		print " BUILDING NAT MATCH TREE:\n"									;

		my %nats;
		if ($translatewithnats eq 'yes') {
			foreach my $natrule (keys %{$configbundles{$sourceconfig}{'nats'}}) {
				foreach my $srcnatbin (keys %{$configbundles{$sourceconfig}{'nats'}{$natrule}{'origsrcbins'}}) {
					foreach my $dstnatbin (keys %{$configbundles{$sourceconfig}{'nats'}{$natrule}{'origdstbins'}}) {
						foreach my $origproto (keys %{$configbundles{$sourceconfig}{'nats'}{$natrule}{'origsrvcports'}}) {
							foreach my $origport (keys %{$configbundles{$sourceconfig}{'nats'}{$natrule}{'origsrvcports'}{$origproto}}) {
								$nats{$dstnatbin}{$srcnatbin}{$origproto}{$origport}{$natrule}++;
							}
						}
					}
				}
			}
		}

		#print "NATS			\n######################################################################################################################\n\n". Dumper(%nats) . "\n\n"	;

		print "\n"												;
		print "\n-----------------------------------------------------------------------------------------\n"	;
		print " STARTING FILTER MATCH ANALYSYS:\n"								;

		my $rulebincount 	= 0										;
		my $rulebincountholder 	= 0										;
		my $rulebincountquick = 0										;
		my %rashlogfilter											;

		# my @mergegroupsfirst = keys %mergerulebases								;
		# push ( @mergegroupsfirst, ( keys %groupsinuse))							;

		foreach my $rulegp (keys %destrulegroups) {
			my %mergetodrops;
			foreach my $rulenum (sort numerically keys (%{$configbundles{$destconfig}{'rulegroups'}{$rulegp}})) {
				unless (exists $configbundles{$destconfig}{'rules'}{$rulenum}{'type'} ) { 
					print "  WARNING:  UNKNOWN TYPE of RULE found in Rule Group:  $rulegp, Number:  $rulenum  - SKIPPED\n";
					next;
				}
				unless (exists $configbundles{$destconfig}{'rules'}{$rulenum}{'action'} ) { 
					print "  WARNING:  UNKNOWN ACTION of RULE found in Rule Group:  $rulegp, Number:  $rulenum  - SKIPPED\n";
					next;
				}
				next if $configbundles{$destconfig}{'rules'}{$rulenum}{'type'} 		eq 'disabled_sec_rule'	;
				next if $configbundles{$destconfig}{'rules'}{$rulenum}{'type'} 		eq 'disabled_sec_nat_rule'	;
				#next if $configbundles{$destconfig}{'rules'}{$rulenum}{'type'}  	eq 'sec_nat_rule'	;
				next if $configbundles{$destconfig}{'rules'}{$rulenum}{'action'} 	eq 'ClientAuth'		;
				next if $configbundles{$destconfig}{'rules'}{$rulenum}{'action'} 	eq 'Encrypt'		;
			 	if (exists $configbundles{$destconfig}{'rules'}{$rulenum}{'srcneg'} 	&& $configbundles{$destconfig}{'rules'}{$rulenum}{'srcneg'} 	eq 'yes') { next ;}
				if (exists $configbundles{$destconfig}{'rules'}{$rulenum}{'dstneg'} 	&& $configbundles{$destconfig}{'rules'}{$rulenum}{'dstneg'} 	eq 'yes') { next ;}
				if (exists $configbundles{$destconfig}{'rules'}{$rulenum}{'srvcneg'} 	&& $configbundles{$destconfig}{'rules'}{$rulenum}{'srvcneg'} 	eq 'yes') { next ;}
				if (exists $configbundles{$destconfig}{'rules'}{$rulenum}{'vpn'} 	&& $configbundles{$destconfig}{'rules'}{$rulenum}{'vpn'} 	ne 'Any') { next ;}		;
				foreach my $installon (keys %destinstallons) {
					unless (exists $configbundles{$destconfig}{'rules'}{$rulenum}{'installon'}{$installon}	|| 
						exists $configbundles{$destconfig}{'rules'}{$rulenum}{'installon'}{'Any'} 	|| 
						exists $configbundles{$destconfig}{'rules'}{$rulenum}{'installon'}{'any'}) 	{
						next ;
					}

					my @rulesrcs  = filter_rule_net_obj_ungrouper($rulenum, 'src', $configbundles{$destconfig}{'netobjects'}, $configbundles{$destconfig}{'netgroupobjs'}, $configbundles{$destconfig}{'rules'})	;
					foreach my $rulesrc (@rulesrcs) {
						foreach my $srcbin (keys (%{$configbundles{$destconfig}{'netobjects'}{$rulesrc}{'ipbin'}})) {
							my @ruledsts  = filter_rule_net_obj_ungrouper($rulenum, 'dst', $configbundles{$destconfig}{'netobjects'}, $configbundles{$destconfig}{'netgroupobjs'}, $configbundles{$destconfig}{'rules'})	;
							foreach my $ruledst (@ruledsts) {
								foreach my $dstbin (keys (%{$configbundles{$destconfig}{'netobjects'}{$ruledst}{'ipbin'}})) {
									my @rulesrvcs = filter_rule_srvc_obj_ungrouper($rulenum, $configbundles{$destconfig}{'srvcobjects'}, $configbundles{$destconfig}{'srvcgroupobjs'}, $configbundles{$destconfig}{'rules'});
									foreach my $rulesrvc (@rulesrvcs) {
										if (exists ($configbundles{$destconfig}{'srvcexceptions'}{$rulesrvc})) {
											foreach my $ruleproto (keys (%{$configbundles{$destconfig}{'srvcobjects'}{$rulesrvc}{'port'}})) {
												my $ruleproto = "srvcexception_$ruleproto"; 
												my $ruleport  = $rulesrvc;
												build_merge_to_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,
															$configbundles{$destconfig}{'rules'},\%rashrulegroups,\%mergetodrops,\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
											}
										} elsif (exists ($configbundles{$destconfig}{'srvcobjects'}{$rulesrvc})) {
											foreach my $ruleproto (keys (%{$configbundles{$destconfig}{'srvcobjects'}{$rulesrvc}{'ports'}})) {
												foreach my $ruleport (keys (%{$configbundles{$destconfig}{'srvcobjects'}{$rulesrvc}{'ports'}{$ruleproto}})) {
													build_merge_to_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,
																$configbundles{$destconfig}{'rules'},\%rashrulegroups,\%mergetodrops,\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
												}
											}
										} else {
											my $ruleproto = 'portunknown'	;
											my $ruleport  =  $rulesrvc   	;
											build_merge_to_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,  
														$configbundles{$destconfig}{'rules'},\%rashrulegroups,\%mergetodrops,\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
										}
									}
								}
							}
						}
					}
				}
			}
		}
		print "\n---------------------------------------------------$rulebincount	MERGE BASE DONE\n";

		$rulebincount 		= 0										;
		$rulebincountholder 	= 0										;
		$rulebincountquick 	= 0										;

		foreach my $rulegp (keys %filterrulegroups) {
			my %mergetodrops;
			foreach my $rulenum (sort numerically keys (%{$configbundles{$filterconfig}{'rulegroups'}{$rulegp}})) {
				unless (exists $configbundles{$filterconfig}{'rules'}{$rulenum}{'type'} ) { 
					print "  WARNING:  UNKNOWN TYPE of RULE found in Rule Group:  $rulegp, Number:  $rulenum  - SKIPPED\n";
					next;
				}
				unless (exists $configbundles{$filterconfig}{'rules'}{$rulenum}{'action'} ) { 
					print "  WARNING:  UNKNOWN ACTION of RULE found in Rule Group:  $rulegp, Number:  $rulenum  - SKIPPED\n";
					next;
				}
				next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'type'} 	eq 'disabled_sec_rule'	;
				next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'type'} 	eq 'disabled_sec_nat_rule'	;
				#next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'type'}  	eq 'sec_nat_rule'	;
				next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'action'} 	eq 'ClientAuth'		;
				next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'srcneg'} 	eq 'yes'		;
				next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'dstneg'} 	eq 'yes'		;
				next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'srvcneg'} 	eq 'yes'		;
				next if $configbundles{$filterconfig}{'rules'}{$rulenum}{'vpn'} 	ne 'Any'		;
				#unless (($configbundles{$filterconfig}{'rules'}{$rulenum}{'action'} =~ m/^Encrypt$|^Drop$|^drop$|^Reject$|^reject$/) || ($configbundles{$filterconfig}{'rules'}{$rulenum}{'vpn'} ne 'Any')) {
				#	#print "FECK\n";
				#	next	;
				#}
				foreach my $installon (keys %filterinstallons) {
					unless (exists $configbundles{$filterconfig}{'rules'}{$rulenum}{'installon'}{$installon}||
						exists $configbundles{$filterconfig}{'rules'}{$rulenum}{'installon'}{'Any'} 	||
						exists $configbundles{$filterconfig}{'rules'}{$rulenum}{'installon'}{'any'})	{
						next 	;
					}

					my @rulesrcs  = filter_rule_net_obj_ungrouper($rulenum, 'src', $configbundles{$filterconfig}{'netobjects'}, $configbundles{$filterconfig}{'netgroupobjs'}, $configbundles{$filterconfig}{'rules'})	;
					foreach my $rulesrc (@rulesrcs) {
						foreach my $srcbin (keys (%{$configbundles{$filterconfig}{'netobjects'}{$rulesrc}{'ipbin'}})) {
							my @ruledsts  = filter_rule_net_obj_ungrouper($rulenum, 'dst', $configbundles{$filterconfig}{'netobjects'}, $configbundles{$filterconfig}{'netgroupobjs'}, $configbundles{$filterconfig}{'rules'})	;
							foreach my $ruledst (@ruledsts) {
								foreach my $dstbin (keys (%{$configbundles{$filterconfig}{'netobjects'}{$ruledst}{'ipbin'}})) {
									my @rulesrvcs = filter_rule_srvc_obj_ungrouper($rulenum, $configbundles{$filterconfig}{'srvcobjects'}, $configbundles{$filterconfig}{'srvcgroupobjs'}, $configbundles{$filterconfig}{'rules'});
									foreach my $rulesrvc (@rulesrvcs) {
										if (exists ($configbundles{$filterconfig}{'srvcexceptions'}{$rulesrvc})) {
											foreach my $ruleproto (keys (%{$configbundles{$filterconfig}{'srvcobjects'}{$rulesrvc}{'port'}})) {
												my $ruleproto = "srvcexception_$ruleproto"; 
												my $ruleport  = $rulesrvc;
												build_merge_to_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,
															$configbundles{$filterconfig}{'rules'},\%rashrulegroups,\%mergetodrops,\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
											}
										} elsif (exists ($configbundles{$filterconfig}{'srvcobjects'}{$rulesrvc})) {
											foreach my $ruleproto (keys (%{$configbundles{$filterconfig}{'srvcobjects'}{$rulesrvc}{'ports'}})) {
												foreach my $ruleport (keys (%{$configbundles{$filterconfig}{'srvcobjects'}{$rulesrvc}{'ports'}{$ruleproto}})) {
													build_merge_to_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,
																$configbundles{$filterconfig}{'rules'},\%rashrulegroups,\%mergetodrops,\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
												}
											}
										} else {
											my $ruleproto = 'portunknown'	;
											my $ruleport  =  $rulesrvc   	;
											build_merge_to_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,  
														$configbundles{$filterconfig}{'rules'},\%rashrulegroups,\%mergetodrops,\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
										}
									}
								}
							}
						}
					}
				}
			}
		}
		print "\n---------------------------------------------------$rulebincount	FILTER BASE DONE\n";

		#print "MERGE TO RULES         	\n########################################################################################################################\n\n". Dumper(%mergetorulebases) . "\n\n";

		$rulebincount 		= 0										;
		$rulebincountholder 	= 0										;
		$rulebincountquick 	= 0										;

# NOTE: 	!!IMPORTANT!!
#		Encryption rules and client encryption rules are exempt from the analysis by default because they need both ends of a vpn to change to reconnect
#		You can enable it if you want to see how best you could simplify your VPN rules but you will need to speak to the 3rd parties at the other end 
#		before making changes, the same applies to NAT rules

		my %pulledrules;
		foreach my $rulegp (keys %sourcerulegroups) {
			my %drops;
			RULE:
			foreach my $rulenum (sort numerically keys (%{$configbundles{$sourceconfig}{'rulegroups'}{$rulegp}})) {
				unless (exists $configbundles{$sourceconfig}{'rules'}{$rulenum}{'type'} ) { 
					print "  WARNING:  UNKNOWN TYPE of RULE found in Rule Group:  $rulegp, Number:  $rulenum  - SKIPPED\n";
					next;
				}
				unless (exists $configbundles{$sourceconfig}{'rules'}{$rulenum}{'action'} ) { 
					print "  WARNING:  UNKNOWN ACTION of RULE found in Rule Group:  $rulegp, Number:  $rulenum  - SKIPPED\n";
					next;
				}
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'type'} 	eq 'disabled_sec_rule'	;
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'type'} 	eq 'disabled_nat_sec_rule'	;
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'type'} 	eq 'sec_nat_rule'	;
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'action'} 	eq 'ClientAuth'		;

			# NOTE: if you have an ald style checkpoint policy that needed accept rules under the encrypt rules comment out this next line
			#	this will cause the encrypt rules to be caught during the rule unwrap and added to the merge to rules, which will in turn
			#	remove the following matching accept rules

				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'action'} 	eq 'Encrypt'		;
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'srcneg'} 	eq 'yes'		;
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'dstneg'} 	eq 'yes'		;
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'srvcneg'} 	eq 'yes'		;
				next if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'vpn'} 	ne 'Any'		;

			# NOTE: exclude the drop and reject rules from the filters because they are all needed to ensure nothing that was dropped is now allowed

				if ($configbundles{$sourceconfig}{'rules'}{$rulenum}{'action'} !~ m/^drop$|^Drop$|^deny$|^Deny$|^reject$|^Reject$/) {

				# NOTE: string filters to INCLUDE rules that match the strings

					if ((scalar keys %incstrings) > 0) {
						my $includehit	= 0;
						foreach my $incfilter (keys %incstrings) {
							if ($configbundles{$sourceconfig}{'rulecsvs'}{$rulenum} =~ m/$incfilter/) {
								$includehit++;
							}
						}
						next RULE if $includehit == 0;
					}
					if ((scalar keys %incheaderstrings) > 0) {
						my $includehit	= 0;
						foreach my $inchedfilter (keys %incheaderstrings) {
							if ($configbundles{$sourceconfig}{'rules'}{$rulenum}{'header'} =~ m/$inchedfilter/) {
								$includehit++;
							}
						}
						next RULE if $includehit == 0;
					}
					if ((scalar keys %logtypes) > 0) {
						my %printwarnings;
						my $includehit	= 0;
						foreach my $logtracktype (keys %logtypes) {
							if (defined ($configbundles{$sourceconfig}{'rules'}{$rulenum}{'track'})) {
								if ($configbundles{$sourceconfig}{'rules'}{$rulenum}{'track'} =~ m/$logtracktype/) {
									$includehit++;
								}
							} else {
								$printwarnings{"  NO LOG TYPE IN RULE $rulenum - RULE TREATED AS UNLOGGED"}++;
								$includehit++;
							}
						}
						next RULE if $includehit == 0;
						foreach my $printwarning (sort keys %printwarnings) {
							print "\n$printwarning";
						}
					}
	
				# NOTE: string filters to EXCLUDE rules that match the strings
	
					foreach my $exstfilt (keys %exstrings) {
						next RULE if $configbundles{$sourceconfig}{'rulecsvs'}{$rulenum} =~ m/$exstfilt/;
					}
					foreach my $exhedstfilt (keys %exheaderstrings) {
						next RULE if $configbundles{$sourceconfig}{'rules'}{$rulenum}{'header'} =~ m/$exhedstfilt/ ;
					}
				}
	
				foreach my $installon (keys %srcinstallons) {
					unless (exists $configbundles{$sourceconfig}{'rules'}{$rulenum}{'installon'}{$installon} ||
						exists $configbundles{$sourceconfig}{'rules'}{$rulenum}{'installon'}{'Any'}  	 ||
						exists $configbundles{$sourceconfig}{'rules'}{$rulenum}{'installon'}{'any'}) 	 {
						next;
					}

					$pulledrules{$rulenum}++;
					my @rulesrcs  = filter_rule_net_obj_ungrouper($rulenum, 'src', $configbundles{$sourceconfig}{'netobjects'}, $configbundles{$sourceconfig}{'netgroupobjs'}, $configbundles{$sourceconfig}{'rules'});
					foreach my $rulesrc (@rulesrcs) {
						foreach my $srcbin (keys (%{$configbundles{$sourceconfig}{'netobjects'}{$rulesrc}{'ipbin'}})) {
							my @ruledsts  = filter_rule_net_obj_ungrouper($rulenum, 'dst', $configbundles{$sourceconfig}{'netobjects'}, $configbundles{$sourceconfig}{'netgroupobjs'}, $configbundles{$sourceconfig}{'rules'});
							foreach my $ruledst (@ruledsts) {
								foreach my $dstbin (keys (%{$configbundles{$sourceconfig}{'netobjects'}{$ruledst}{'ipbin'}})) {
									my @rulesrvcs = filter_rule_srvc_obj_ungrouper($rulenum, $configbundles{$sourceconfig}{'srvcobjects'}, $configbundles{$sourceconfig}{'srvcgroupobjs'}, $configbundles{$sourceconfig}{'rules'})	;
									foreach my $rulesrvc (@rulesrvcs) {
										if (exists ($configbundles{$sourceconfig}{'srvcexceptions'}{$rulesrvc})) {
											foreach my $ruleproto (keys (%{$configbundles{$sourceconfig}{'srvcobjects'}{$rulesrvc}{'port'}})) {
												my $ruleproto = "srvcexception_$ruleproto"; 
												my $ruleport  = $rulesrvc;
												if ($configbundles{$sourceconfig}{'rules'}{$rulenum}{'action'} 	eq 'Encrypt') {
													add_encrypt_to_mergeto_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,
																$configbundles{$sourceconfig}{'rules'},\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
												} else {
													if ($restype eq 'yes') {
														rulegroup_bin_and_subnet_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$incconobjs,
														$configbundles{$sourceconfig}{'rules'},$configbundles{$sourceconfig}{'netobjects'},$configbundles{$sourceconfig}{'srvcstree'},\%includeips,\%excludeips,\%rashrulegroups,\%rashlogfilter,\%drops,\%mergetorulebases,\%nats,$configbundles{$sourceconfig}{'nats'},\%transrules,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\$filterwithlog,\$matchprevrules);
													} elsif ($restype eq 'no') {
														rulegroup_bin_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$incconobjs,
														$configbundles{$sourceconfig}{'rules'},$configbundles{$sourceconfig}{'netobjects'},$configbundles{$sourceconfig}{'srvcstree'},\%includeips,\%excludeips,\%rashrulegroups,\%rashlogfilter,\%drops,\%mergetorulebases,\%nats,$configbundles{$sourceconfig}{'nats'},\%transrules,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\$filterwithlog,\$translatewithnats,\$matchprevrules);
													}
												}
											}
										} elsif (exists ($configbundles{$sourceconfig}{'srvcobjects'}{$rulesrvc})) {
											foreach my $ruleproto (keys (%{$configbundles{$sourceconfig}{'srvcobjects'}{$rulesrvc}{'ports'}})) {
												foreach my $ruleport (keys (%{$configbundles{$sourceconfig}{'srvcobjects'}{$rulesrvc}{'ports'}{$ruleproto}})) {
													if ($configbundles{$sourceconfig}{'rules'}{$rulenum}{'action'} 	eq 'Encrypt') {
														add_encrypt_to_mergeto_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,
																	$configbundles{$sourceconfig}{'rules'},\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
													} else {
														if ($restype eq 'yes') {
															rulegroup_bin_and_subnet_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$incconobjs,
																$configbundles{$sourceconfig}{'rules'},$configbundles{$sourceconfig}{'netobjects'},$configbundles{$sourceconfig}{'srvcstree'},\%includeips,\%excludeips,\%rashrulegroups,\%rashlogfilter,\%drops,\%mergetorulebases,\%nats,$configbundles{$sourceconfig}{'nats'},\%transrules,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\$filterwithlog,\$translatewithnats,\$matchprevrules);
														} elsif ($restype eq 'no') {
															rulegroup_bin_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$incconobjs,
																$configbundles{$sourceconfig}{'rules'},$configbundles{$sourceconfig}{'netobjects'},$configbundles{$sourceconfig}{'srvcstree'},\%includeips,\%excludeips,\%rashrulegroups,\%rashlogfilter,\%drops,\%mergetorulebases,\%nats,$configbundles{$sourceconfig}{'nats'},\%transrules,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\$filterwithlog,\$translatewithnats,\$matchprevrules);
														}
													}
												}
											}
										} else {
											my $ruleproto = 'portunknown'												;
											my $ruleport  =  $rulesrvc   												;
											if ($configbundles{$sourceconfig}{'rules'}{$rulenum}{'action'} 	eq 'Encrypt') {
												add_encrypt_to_mergeto_rulebase($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,
															$configbundles{$sourceconfig}{'rules'},\%mergetorulebases,\$rulebincount,\$rulebincountquick,\$rulebincountholder)  ;
											} else {
												if ($restype eq 'yes') {
													rulegroup_bin_and_subnet_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$incconobjs,
																	$configbundles{$sourceconfig}{'rules'},$configbundles{$sourceconfig}{'netobjects'},$configbundles{$sourceconfig}{'srvcstree'},\%includeips,\%excludeips,\%rashrulegroups,\%rashlogfilter,\%drops,\%mergetorulebases,\%nats,$configbundles{$sourceconfig}{'nats'},\%transrules,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\$filterwithlog,\$translatewithnats,\$matchprevrules)	;
												} elsif ($restype eq 'no') {
													rulegroup_bin_proc_add($rulenum,$rulesrc,$srcbin,$ruledst,$dstbin,$ruleproto,$rulesrvc,$ruleport,$incconobjs,
																$configbundles{$sourceconfig}{'rules'},$configbundles{$sourceconfig}{'netobjects'},$configbundles{$sourceconfig}{'srvcstree'},\%includeips,\%excludeips,\%rashrulegroups,\%rashlogfilter,\%drops,\%mergetorulebases,\%nats,$configbundles{$sourceconfig}{'nats'},\%transrules,\$rulebincount,\$rulebincountquick,\$rulebincountholder,\$filterwithlog,\$translatewithnats,\$matchprevrules);
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}
		print "\n---------------------------------------------------$rulebincount	RULE BASE DONE\n";
		#print "\n\nTRANS RULES\n#############################################################################################################################################################\n\n". Dumper(%transrules)				;

		print "\n\nTRANSLATION RULES IN USE:\n";
		print "-----------------------------------------------------------------------------------------\n";
		print "NAT Rule Num, Orig Source, Orig Dest, Orig Service, Associated Security Rule,\n";
		foreach my $natnum (keys %transrules) {
			my @natsrc = keys %{$transrules{$natnum}{'src'}} ;
			my @natdst = keys %{$transrules{$natnum}{'dst'}} ;
			my @natsrvc = keys %{$transrules{$natnum}{'srvc'}} ;
			my @natglobalsecrule = keys %{$transrules{$natnum}{'secrule'}} ;
			my @natsecrule;
			foreach my $secrule (@natglobalsecrule) {
				my $natsecrule = $configbundles{$sourceconfig}{'rules'}{$secrule}{'rbnum'};
				push (@natsecrule, $natsecrule) ;
			}
			print "NAT Rule: $natnum, @natsrc, @natdst, @natsrvc, @natsecrule\n";
		}

		print "\n\n-----------------------------------------------------------------------------------------\n";
		print " ORIGINAL RULES INCLUDED IN RATIONALIZATION:\n";
		print "   These are the original rules that were evaulated:\n\n";

		foreach my $pulledrules (sort numerically keys %pulledrules) {
			my $printorigrule = $configbundles{$sourceconfig}{'rulecsvs'}{$pulledrules};
			$printorigrule =~ tr/;/ /;
			print "Global $pulledrules, Rule: $configbundles{$sourceconfig}{'rules'}{$pulledrules}{'rbnum'},$printorigrule\n";
		}

		print "\n\n-----------------------------------------------------------------------------------------\n";
		print " RULE FILTER SECTION COMPLETE:\n";
		print "   These are the original objects and rules that matched the filters:\n\n";

		#print "RATIONALIZED RULE GROUPS        	\n########################################################################################################################\n\n". Dumper(%rashrulegroups) . "\n\n";
		
		my %filteredorigirules;
		foreach my $logdst (keys %rashrulegroups) {
			foreach my $logsrc (keys %{$rashrulegroups{$logdst}}) {
				foreach my $logproto (keys %{$rashrulegroups{$logdst}{$logsrc}}) {
					foreach my $logport (keys %{$rashrulegroups{$logdst}{$logsrc}{$logproto}}) {
						foreach my $filterrule (keys %{$rashrulegroups{$logdst}{$logsrc}{$logproto}{$logport}}) {
							if (exists $configbundles{$sourceconfig}{'ports'}{$logproto} && exists $configbundles{$sourceconfig}{'ports'}{$logproto}{$logport}) {
								$filteredorigirules{$filterrule}{'services'}{$configbundles{$sourceconfig}{'ports'}{$logproto}{$logport}{'name'}}++;
							} else { 
								print "EMPTY SERVICE FOR: $logproto, $logport.  ADDING $logport AS SERVICE NAME\n";
								$filteredorigirules{$filterrule}{'services'}{$logport}++;
							}
							$filteredorigirules{$filterrule}{'src'}{$configbundles{$sourceconfig}{'ips'}{$logsrc}{'name'}}++;
							$filteredorigirules{$filterrule}{'dst'}{$configbundles{$sourceconfig}{'ips'}{$logdst}{'name'}}++;
						}
					}
				}
			}
		}
		print "ORIG RULE, SRC, DST, SERVICE, ACTION, DESCRIPTION\n";
		foreach my $filternum (sort numerically keys %filteredorigirules) {
			my @services = sort keys %{$filteredorigirules{$filternum}{'services'}};
			my @sources  = sort keys %{$filteredorigirules{$filternum}{'src'}};
			my @destins  = sort keys %{$filteredorigirules{$filternum}{'dst'}};
			my $action   = $configbundles{$sourceconfig}{'rules'}{$filternum}{'action'};
			my $rbnum    = $configbundles{$sourceconfig}{'rules'}{$filternum}{'rbnum'};
			my $descrip  = 'FILTERED RULE';
			if (exists $configbundles{$sourceconfig}{'rules'}{$filternum}{'comment'}) {
				my $descrip  = $configbundles{$sourceconfig}{'rules'}{$filternum}{'comment'};
			}
			print "$rbnum,@sources,@destins,@services,$action,$descrip\n";
		}

		print "\n\n-----------------------------------------------------------------------------------------\n";
		print " STARTING LOG TO RULE COMPARISON:\n";

# NOTE: log filter section
# Expand the binary log file and compair it to the expanded rules hash
# Rules in the rashed rule groups are filtered and put into the rashlogfilter hash
			
		my %rashlogmisses;
		my %rashlogfiltermiss;
		if ($filterwithlog =~ /^yes$|^loose$/) {
			my $srvcexceps = $configbundles{$sourceconfig}{'srvcexceptions'};
	
			my $logtorulehitcount	= 0;
			my $logconncount	= 0;
			my $logconnplaceholder	= 0;
			foreach my $logdstorig (keys %{$configbundles{$sourceconfig}{'logbins'}}) {
				foreach my $logsrcorig (keys %{$configbundles{$sourceconfig}{'logbins'}{$logdstorig}}) {
					foreach my $logproto (keys %{$configbundles{$sourceconfig}{'logbins'}{$logdstorig}{$logsrcorig}}) {
						foreach my $logport (keys %{$configbundles{$sourceconfig}{'logbins'}{$logdstorig}{$logsrcorig}{$logproto}}) {
							$logconncount++;
							my @origrules = sort numerically keys %{$configbundles{$sourceconfig}{'logbins'}{$logdstorig}{$logsrcorig}{$logproto}{$logport}};
							my $logdst = $logdstorig;
							my $hitcount = 0;
							for (my $i = 32 ; $i >= 0 ; $i--) {
								if (exists $rashrulegroups{$logdst}) {
									my $logsrc = $logsrcorig;
									for (my $i = 32 ; $i >= 0 ; $i--) {
										if (exists $rashrulegroups{$logdst}{$logsrc}) {
											if (exists $rashrulegroups{$logdst}{$logsrc}{"srvcexception_$logproto"}) {
												$logproto =~ s/^srvcexception_//;
												foreach my $srvcobj (keys %{$rashrulegroups{$logdst}{$logsrc}{"srvcexception_$logproto"}}) {
													if (exists $configbundles{$sourceconfig}{'srvcobjects'}{$srvcobj}{'ports'}{$logproto}) {
														if (exists $configbundles{$sourceconfig}{'srvcobjects'}{$srvcobj}{'ports'}{$logproto}{$logport}) {
															foreach my $rashrulenum (keys %{$rashrulegroups{$logdst}{$logsrc}{"srvcexception_$logproto"}{$srvcobj}}) {
																$rashlogfilter{"srvcexception_$logproto~$srvcobj"}{$logdst}{$logsrc}{$rashrulenum}++;
																$hitcount++;
																$logtorulehitcount++;
															}
														}
													}
												}
											}

											if (exists $rashrulegroups{$logdst}{$logsrc}{$logproto}) {
												if (exists $rashrulegroups{$logdst}{$logsrc}{$logproto}{$logport}) {
													foreach my $rashrulenum (keys %{$rashrulegroups{$logdst}{$logsrc}{$logproto}{$logport}}) {
														$rashlogfilter{"$logproto~$logport"}{$logdst}{$logsrc}{$rashrulenum}++;
														$hitcount++;
														$logtorulehitcount++;
													}
												}
											} elsif ((exists $rashrulegroups{$logdst}{$logsrc}{'any'}) && ((exists $rashrulegroups{$logdst}{$logsrc}{'any'}{'Any'}) || (exists $rashrulegroups{$logdst}{$logsrc}{'any'}{'any'}))) {
												foreach my $rashrulenum (keys %{$rashrulegroups{$logdst}{$logsrc}{'any'}{'any'}}) {
													$rashlogfilter{"any.any"}{$logdst}{$logsrc}{$rashrulenum}++;
													$hitcount++;
													$logtorulehitcount++;
												}
											}
										}
										chop($logsrc);
									}
								}
								chop($logdst);
							}
							if ($logconncount >= ($logconnplaceholder + 200)) {
								print "....................................................$logconncount	connections processed\n"		;
								$logconnplaceholder = $logconncount;
							}

						# NOTE: check to see if the log matched and print details

							if ($hitcount > 0) {
								my %dummy;
								my @dstnames = find_net_object_and_supernets_and_duplicates($logdstorig,$configbundles{$sourceconfig}{'ips'},\%dummy) ;
								my @srcnames = find_net_object_and_supernets_and_duplicates($logsrcorig,$configbundles{$sourceconfig}{'ips'},\%dummy) ;
								print "   hit, src (@srcnames), dst (@dstnames), $logproto, $logport, rules:@origrules\n";
							} else {
								my %dummy;
								my @dstnames = find_net_object_and_supernets_and_duplicates($logdstorig,$configbundles{$sourceconfig}{'ips'},\%dummy) ;
								my @srcnames = find_net_object_and_supernets_and_duplicates($logsrcorig,$configbundles{$sourceconfig}{'ips'},\%dummy) ;
								print "MISSED, SRC (@srcnames), DST (@dstnames), $logproto, $logport, RULES:@origrules\n";
								#foreach my $rulenumorig (@origrules) {
									#$rashlogfiltermiss{$logsrcorig}{$logdstorig}{$logproto}{$logport}{$rulenumorig}++;
								#}
							}
						}
					}
				}
			}	
			print "-----------------------------------------------------------------------------------------\n";
			print "  LOG TO RULE COMPARISON COMPLETE:\n";
			print "    Number of log connections processed	= $logconncount\n"; 
			print "    Number of rules matched by conns 	= $logtorulehitcount\n";
		}


#		print "-----------------------------------------------------------------------------------------\n";
#		print "  STARTING MISSED CONNECTIVITY DST SRC PRIORITY RULE BUILD:\n";
#
#	# NOTE: all connectivity from the pulled rulles that didnt make it through the string and ip filters or that was not matched in the logs
#	# NOTE: this is not completely reliable some connectivity that is listed as missed has not been.  Tuning defaults will fix some of this.
#
#		foreach my $dst (keys %rashlogfiltermiss) {
#			foreach my $src (keys %{$rashlogfiltermiss{$dst}}) {
#				foreach my $proto (keys %{$rashlogfiltermiss{$dst}{$src}}) {
#					foreach my $port (keys %{$rashlogfiltermiss{$dst}{$src}{$proto}}) {
#						foreach my $rule (keys %{$rashlogfiltermiss{$dst}{$src}{$proto}{$port}}) {
#							my $protoport = "$proto~$port";
#							unless (exists $rashlogfilter{$protoport} && exists $rashlogfilter{$protoport}{$dst} && exists $rashlogfilter{$protoport}{$dst}{$src}) {
#								$rashlogmisses{$dst}{$src}{$protoport}{$rule}++;
#							}
#						}
#					}
#				}
#			}
#		}
#
#		print "\n-----------------------------------------------------------------------------------------\n";
#		print "  Rules Built From Missed Connections\n";
#		print"    NOTE: all connectivity from the pulled rulles that didnt make it through the string and ip filters or that was not matched in the logs\n";
#		print "   NOTE: this is not completely reliable some connectivity that is listed as missed probably has not been.\n";
#		my ($rulebasemiss_ref, $printbasemiss_ref, $objsmiss_ref, $srvcsmiss_ref, $groupsmiss_ref, $srvcgroupsmiss_ref) = build_dst_src_rules(\%rashlogmisses, $configbundles{$sourceconfig}, $configbundles{$destconfig}) ;
#		output_odumper_csv_file($configbundles{$sourceconfig}, $configbundles{$destconfig}, $objsmiss_ref, $srvcsmiss_ref, $groupsmiss_ref, $srvcgroupsmiss_ref, $printbasemiss_ref, $ruleoutswitch);
#
#		my ($rulebasemiss1_ref, $printbasemiss1_ref, $objsmiss1_ref, $srvcsmiss1_ref, $groupsmiss1_ref, $srvcgroupsmiss1_ref) = build_rules(\%rashlogmisses, $configbundles{$sourceconfig}, $configbundles{$destconfig}) ;
#		print "\n-----------------------------------------------------------------------------------------\n";
#		print "  Rules Built From Missed Connections NOT TRANSLATED\n";
#		output_odumper_csv_file($configbundles{$sourceconfig}, \%dummy, $objsmiss1_ref, $srvcsmiss1_ref, $groupsmiss1_ref, $srvcgroupsmiss1_ref, $printbasemiss1_ref, $ruleoutswitch);
#		output_netscreen($configbundles{$sourceconfig}, \%dummy, $objsmiss1_ref, $srvcsmiss1_ref, $groupsmiss1_ref, $srvcgroupsmiss1_ref, $printbasemiss1_ref, $ruleoutswitch);



		print "-----------------------------------------------------------------------------------------\n";
		print "  STARTING SERVICE PRIORITY RULE BUILD: \n";
		print "   This builds the rules using a secondary method - useful for comparison\n";

		my ($rulebaseout_ref, $printbaseout_ref, $objsout_ref, $srvcsout_ref, $groupsout_ref, $srvcgroupsout_ref) = build_rules(\%rashlogfilter, $configbundles{$sourceconfig}, $configbundles{$destconfig}) ;


		print "-----------------------------------------------------------------------------------------\n";
		print "  STARTING DST SRC PRIORITY RULE BUILD: - primary rule building mode\n";
		my %dstsrcrash;
		foreach my $service (keys %rashlogfilter) {
			foreach my $rdst (keys %{$rashlogfilter{$service}}) {
				foreach my $rsrc (keys %{$rashlogfilter{$service}{$rdst}}) {
					foreach my $rnum (keys %{$rashlogfilter{$service}{$rdst}{$rsrc}}) {
						$dstsrcrash{$rdst}{$rsrc}{$service}{$rnum}++;
					}
				}
			}
		}
		my ($sdrulebaseout_ref, $sdprintbaseout_ref, $sdobjsout_ref, $sdsrvcsout_ref, $sdgroupsout_ref, $sdsrvcgroupsout_ref) = build_dst_src_rules(\%dstsrcrash, $configbundles{$sourceconfig}, $configbundles{$destconfig}) ;



		print "\n\n-----------------------------------------------------------------------------------------\n";
		print " RASH RULE COMPARISON COMPLETE:\n\n";
		print " 	Would you like to print the most recent rulebase to file\n";
		print " 	[no|od|ns|cs]\n\n";
		print " 	Choose: ";
		my $printquest;
		my $destrulebase;

		while (<STDIN>) {
			chomp($_) 								;
			if ($_ =~ /^od$|^no$|^ns$|^cs$|^dbedit$/) {
				$printquest = $_						;
				last 								;
			} else {
				print " 	ERROR: type 'od', 'ns', 'cs'  or  'no''\n"	;
			}
		}
		print "\n";
		if ($printquest eq 'od') {
			print "\n-----------------------------------------------------------------------------------------\n";
			print "  Rules Built From Hit Connetions output in Odumper format\n";

			my $ruleoutswitch = 'STANDARD';

			output_odumper_csv_file($configbundles{$sourceconfig}, $configbundles{$destconfig}, $sdobjsout_ref, $sdsrvcsout_ref, $sdgroupsout_ref, $sdsrvcgroupsout_ref, $sdprintbaseout_ref, $ruleoutswitch);

		} elsif ($printquest eq 'cs') {
			print "\n-----------------------------------------------------------------------------------------\n";
			print "  Rules Built From Hit Connetions output in Cisco ASA and Odumper CSV format\n";

			my $ruleoutswitch = 'STANDARD';

			output_cisco_and_csv_file($configbundles{$sourceconfig}, $configbundles{$destconfig}, $sdobjsout_ref, $sdsrvcsout_ref, $sdgroupsout_ref, $sdsrvcgroupsout_ref, $sdprintbaseout_ref, $ruleoutswitch);

		} elsif ($printquest eq 'ns') {
			print "\n-----------------------------------------------------------------------------------------\n";
			print "  Rules Built From Hit Connetions output in Netscreen ScreenOS format\n";

			my $ruleoutswitch = 'STANDARD';

			output_netscreen($configbundles{$sourceconfig}, $configbundles{$destconfig}, $sdobjsout_ref, $sdsrvcsout_ref, $sdgroupsout_ref, $sdsrvcgroupsout_ref, $sdprintbaseout_ref, $ruleoutswitch);

		}
	}
}
				

#---------------------------------------------------------------------------------------------
# Build Subroutines
#---------------------------------------------------------------------------------------------

# NOTE: build the groups and subgroups

sub net_builder {
        my ($group, $netobjects_ref, $netgroups_ref, $networkgroups_ref, $netgroupobjs_ref, $netsubgroupcount, $subgroup) = @_	;
	my $subgrpcount												;
	my @subgroups												;

	if (defined $subgroup) {
	        foreach my $groupmembr ( keys %{ $netgroups_ref->{$subgroup} } ) {
			$subgrpcount++															;
			$$netsubgroupcount++														;
			if ($groupmembr eq $group) {
				print "   WARNING:  CIRCULAR group DETECTED in $group - THIS GROUP WAS REFERENCED IN ITS $subgroup\n";
				next;
			} elsif ($groupmembr eq $subgroup) {
				print "   WARNING:  CIRCULAR group DETECTED in $subgroup - THIS GROUP REFERENCED ITS SELF AND IS INCLUDED IN $group\n";
				next;

			} elsif (exists($netgroups_ref->{$groupmembr})) {
       	       		        $networkgroups_ref->{$group}{$groupmembr}{'count'}++									;
				$networkgroups_ref->{$group}{$groupmembr}{'type'} 				= "subgroup.$subgrpcount"		;
				push (@subgroups								, $group) 				;
				push (@{$networkgroups_ref->{$groupmembr}{'supergroups'}}			, $group)				;

       	 			foreach my $subgroupmembr ( keys %{ $netgroups_ref->{$groupmembr} } ) {
					if (exists ($netgroups_ref->{$subgroupmembr})) {
						$subgrpcount++												;
						$$netsubgroupcount++											;
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subgroup.$subgrpcount"		;
						push (@subgroups						, $groupmembr) 				;
						push (@{$networkgroups_ref->{$subgroupmembr}{'supergroups'}}	, $group) 				;

						net_builder($group, $netobjects_ref, $netgroups_ref, $networkgroups_ref, $netgroupobjs_ref, $netsubgroupcount, $subgroupmembr);

					} elsif (exists ($netobjects_ref->{$subgroupmembr})) {
       	                 			$netgroupobjs_ref->{$group}{$subgroupmembr}{'type'} 		= $netobjects_ref->{$subgroupmembr}{'type'};		
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subobj.$subgrpcount"			;
						push (@{$netobjects_ref->{$subgroupmembr}{'supergroups'}}	, $group) 				;
					}
				}
	
			} elsif (exists ($netobjects_ref->{$groupmembr})) {
       	                 	$netgroupobjs_ref->{$group}{$groupmembr}{'type'} 		= $netobjects_ref->{$groupmembr}{'type'}		;		
				$networkgroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$networkgroups_ref->{$group}{$groupmembr}{'type'} 		= "subobj.$subgrpcount"					;
				push (@{$netobjects_ref->{$groupmembr}{'supergroups'}}		, $group) 						;
       		       	} else {
       	                 	$netgroupobjs_ref->{$group}{$groupmembr}{'type'} 		= 'default'						;		
				$networkgroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$networkgroups_ref->{$group}{$groupmembr}{'type'} 		= "default.subobj.$subgrpcount"				;
       			       	print "WHAT THE FUCK!??? $group $groupmembr\n"										;
			}
       	         } 
	} else {
	        foreach my $groupmembr ( keys %{ $netgroups_ref->{$group} } ) {
			if ($groupmembr eq $group) {
				print "   WARNING:  CIRCULAR group DETECTED in $group - THIS GROUP REFERENCED ITS SELF\n";
				next;
				 
			} elsif (exists($netgroups_ref->{$groupmembr})) {
				$subgrpcount++														;
				$$netsubgroupcount++													;
       	                 	$networkgroups_ref->{$group}{$groupmembr}{'count'}++									;
       	                 	$networkgroups_ref->{$group}{$groupmembr}{'type'} 				= 'group'				;
				push (@subgroups								, $group) 				;
				push (@{$networkgroups_ref->{$groupmembr}{'supergroups'}}			, $group)				;

       	 			foreach my $subgroupmembr ( keys %{ $netgroups_ref->{$groupmembr} } ) {
					if (exists ($netgroups_ref->{$subgroupmembr})) {
						$subgrpcount++												;
						$$netsubgroupcount++											;
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subgroup.$subgrpcount"		;
						push (@subgroups, $group) 										;
						push (@{$networkgroups_ref->{$subgroupmembr}{'supergroups'}}	, $group)				;

						net_builder($group, $netobjects_ref, $netgroups_ref, $networkgroups_ref, $netgroupobjs_ref, $netsubgroupcount, $subgroupmembr);

					} elsif (exists ($netobjects_ref->{$subgroupmembr})) {
       	                 			$netgroupobjs_ref->{$group}{$subgroupmembr}{'type'} 		= $netobjects_ref->{$subgroupmembr}{'type'};		
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$networkgroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subobj.$subgrpcount"			;
						push (@{$netobjects_ref->{$subgroupmembr}{'supergroups'}}	, $group) 				;
					}
				}
				$subgrpcount--														;	
	
			} elsif (exists ($netobjects_ref->{$groupmembr})) {
       	                 	$netgroupobjs_ref->{$group}{$groupmembr}{'type'} 		= $netobjects_ref->{$groupmembr}{'type'}		;		
				$networkgroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$networkgroups_ref->{$group}{$groupmembr}{'type'} 		= 'object' 						;
				push (@{$netobjects_ref->{$groupmembr}{'supergroups'}}		, $group) 						;
       		       	} else {
       	                 	$netgroupobjs_ref->{$group}{$groupmembr}{'type'} 		='default'						;		
				$networkgroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$networkgroups_ref->{$group}{$groupmembr}{'type'} 		= "default.object"					;
       			       	#print "WHAT THE FUCK!??? $group $groupmembr\n"										;
       		 	}
       		 }
	}
}

# NOTE: building the service groups

sub service_builder {
        my ($group, $srvcobjects_ref, $srvcgroups_ref, $servicegroups_ref, $srvcgroupobjs_ref, $srvcsubgroupcount, $subgroup) = @_	;
	my $subgrpcount												;
	my @subgroups												;

	if (defined $subgroup) {
	        foreach my $groupmembr ( keys %{ $srvcgroups_ref->{$subgroup} } ) {
			$subgrpcount++															;
			$$srvcsubgroupcount++														;
			if ($groupmembr eq $group) {
				print "   WARNING:  CIRCULAR group DETECTED in $group - THIS GROUP WAS REFERENCED IN ITS $subgroup\n";
				next;
			} elsif ($groupmembr eq $subgroup) {
				print "   WARNING:  CIRCULAR group DETECTED in $subgroup - THIS GROUP REFERENCED ITS SELF AND IS INCLUDED IN $group\n";
				next;

			} elsif (exists($srvcgroups_ref->{$groupmembr})) {
       	       		        $servicegroups_ref->{$group}{$groupmembr}{'count'}++									;
				$servicegroups_ref->{$group}{$groupmembr}{'type'} 				= "subgroup.$subgrpcount"		;
				push (@subgroups								, $group) 				;
				push (@{$servicegroups_ref->{$groupmembr}{'supergroups'}}			, $group)				;

       	 			foreach my $subgroupmembr ( keys %{ $srvcgroups_ref->{$groupmembr} } ) {
					if (exists ($srvcgroups_ref->{$subgroupmembr})) {
						$subgrpcount++												;
						$$srvcsubgroupcount++											;
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subgroup.$subgrpcount"		;
						push (@subgroups						, $groupmembr) 				;
						push (@{$servicegroups_ref->{$subgroupmembr}{'supergroups'}}	, $group) 				;

						service_builder($group, $srvcobjects_ref, $srvcgroups_ref, $servicegroups_ref, $srvcgroupobjs_ref, $srvcsubgroupcount, $subgroupmembr);

					} elsif (exists ($srvcobjects_ref->{$subgroupmembr})) {
       	                 			$srvcgroupobjs_ref->{$group}{$subgroupmembr}{'type'} 		= $srvcobjects_ref->{$subgroupmembr}{'type'};		
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subobj.$subgrpcount"			;
						push (@{$srvcobjects_ref->{$subgroupmembr}{'supergroups'}}	, $group) 				;
					}
				}
	
			} elsif (exists ($srvcobjects_ref->{$groupmembr})) {
       	                 	$srvcgroupobjs_ref->{$group}{$groupmembr}{'type'} 		= $srvcobjects_ref->{$groupmembr}{'type'}		;		
				$servicegroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$servicegroups_ref->{$group}{$groupmembr}{'type'} 		= "subobj.$subgrpcount"					;
				push (@{$srvcobjects_ref->{$groupmembr}{'supergroups'}}		, $group) 						;
       		       	} else {
       	                 	$srvcgroupobjs_ref->{$group}{$groupmembr}{'type'} 		= 'default'						;
				$servicegroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$servicegroups_ref->{$group}{$groupmembr}{'type'} 		= "default.subobj.$subgrpcount"				;
       			       	#print "WHAT THE FUCK!??? $group $groupmembr\n"										;
			}
       	         } 
	} else {
	        foreach my $groupmembr ( keys %{ $srvcgroups_ref->{$group} } ) {
			if ($groupmembr eq $group) {
				print "   WARNING:  CIRCULAR SERVICE group DETECTED in $group - THIS GROUP REFERENCED ITS SELF\n";
				next;
				 
			} elsif (exists($srvcgroups_ref->{$groupmembr})) {
				$subgrpcount++														;	
				$$srvcsubgroupcount++													;
       	                 	$servicegroups_ref->{$group}{$groupmembr}{'count'}++									;
       	                 	$servicegroups_ref->{$group}{$groupmembr}{'type'} 				= 'group'				;
				push (@subgroups								, $group) 				;
				push (@{$servicegroups_ref->{$groupmembr}{'supergroups'}}			, $group)				;

       	 			foreach my $subgroupmembr ( keys %{ $srvcgroups_ref->{$groupmembr} } ) {
					if (exists ($srvcgroups_ref->{$subgroupmembr})) {
						$subgrpcount++												;
						$$srvcsubgroupcount++											;
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subgroup.$subgrpcount"		;
						push (@subgroups						, $group) 				;
						push (@{$servicegroups_ref->{$subgroupmembr}{'supergroups'}}	, $group)				;

						service_builder($group, $srvcobjects_ref, $srvcgroups_ref, $servicegroups_ref, $srvcgroupobjs_ref, $srvcsubgroupcount, $subgroupmembr) ;

					} elsif (exists ($srvcobjects_ref->{$subgroupmembr})) {
       	                 			$srvcgroupobjs_ref->{$group}{$subgroupmembr}{'type'} 		= $srvcobjects_ref->{$subgroupmembr}{'type'};		
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'count'}++							;
       	                 			$servicegroups_ref->{$group}{$subgroupmembr}{'type'} 		= "subobj.$subgrpcount"			;
						push (@{$srvcobjects_ref->{$subgroupmembr}{'supergroups'}}	, $group) 				;
					}
				}
				$subgrpcount--														;	
			} elsif (exists ($srvcobjects_ref->{$groupmembr})) {
       	                 	$srvcgroupobjs_ref->{$group}{$groupmembr}{'type'} 		= $srvcobjects_ref->{$groupmembr}{'type'}		;		
				$servicegroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$servicegroups_ref->{$group}{$groupmembr}{'type'} 		= 'object' 						;
				push (@{$srvcobjects_ref->{$groupmembr}{'supergroups'}}		, $group) 						;
       		       	} else {
       	                 	$srvcgroupobjs_ref->{$group}{$groupmembr}{'type'} 		= 'default'						;		
				$servicegroups_ref->{$group}{$groupmembr}{'count'}++ 									;
				$servicegroups_ref->{$group}{$groupmembr}{'type'} 		= "default.object"					;
       			       	#print "WHAT THE FUCK!??? $group $groupmembr\n"										;
       		 	}
                }
        }
}


# NOTE: Build Filtered Binary Match Table

sub rule_net_obj_ungrouper {
	my ($snrulenum, $snsrcdst, $netobjects_ref, $netgroupobjs_ref, $rules_ref) = @_	;
	my (@snallobjs)									;
	my (@snruleobj) = keys %{$rules_ref->{$snrulenum}{$snsrcdst}}			;
	#print "NUM $snrulenum $snsrcdst\n"						;
	foreach my $snrlobj (@snruleobj) {
		if (exists ($netgroupobjs_ref->{$snrlobj})) {
			foreach my $snsubrlobj (keys (%{$netgroupobjs_ref->{$snrlobj}})) {
				push (@snallobjs, $snsubrlobj) 				;
			}
		} elsif (exists ($netobjects_ref->{$snrlobj})) {
			push (@snallobjs, $snrlobj) 					;
		} else {
			push (@snallobjs, $snrlobj) 					;
			#print "GROAPER $snrlobj\n"					;
		}
	}
	#print "ALL OBJS @snallobjs\n"							;
	return @snallobjs								;
}

sub rule_srvc_obj_ungrouper {
	my ($ssrulenum, $srvcobjects_ref, $srvcgroupobjs_ref, $rules_ref) = @_		;
	my (@ssallobjs)									;
	my (@ssruleobj) = keys %{$rules_ref->{$ssrulenum}{'service'}}			;
	#print "SNUM $ssrulenum\n"							;
	foreach my $ssrlobj (@ssruleobj) {
		if (exists ($srvcgroupobjs_ref->{$ssrlobj})) {
			foreach my $sssubrlobj (keys (%{$srvcgroupobjs_ref->{$ssrlobj}})) {
				push (@ssallobjs, $sssubrlobj) 				;
			}
		} elsif (exists ($srvcobjects_ref->{$ssrlobj})) {
			push (@ssallobjs, $ssrlobj) 					;
		} else {
			push (@ssallobjs, $ssrlobj) 					;
			#print "SROAPER $ssrlobj\n"					;
		}
	}
	#print "SALL OBJS @ssallobjs\n"							;
	return @ssallobjs								;
}

sub rule_bin_proc_add {
	my ($srrulenum,$srrulesrc,$srsrcbin,$srruledst,$srdstbin,$srruleproto,$srrulesrvc,$srruleport,$natrulecount,$rulebincount_ref,$rulebincountquick_ref,$rulebincountholder_ref,$netobjects_ref,$srvcobjects_ref,$rules_ref,$nats_ref,$rashrules_ref,$binrules_ref) = @_		;
	#$rashrules_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}++							;
	#$binrules_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++					;
	$netobjects_ref->{$srrulesrc}{'rulesrcs'}{$srrulenum}++								;
	$netobjects_ref->{$srruledst}{'ruledsts'}{$srrulenum}++								;
	$srvcobjects_ref->{$srrulesrvc}{'rule'}{$srrulenum}++									;
	$rules_ref->{$srrulenum}{'rulesrcs'}{$srrulesrc}++									;
	$rules_ref->{$srrulenum}{'ruledsts'}{$srruledst}++									;
	$rules_ref->{$srrulenum}{'srcbins'}{$srsrcbin}++									;
	$rules_ref->{$srrulenum}{'dstbins'}{$srdstbin}++									;
	$rules_ref->{$srrulenum}{'allsrvcobjs'}{$srrulesrvc}++								;
	$rules_ref->{$srrulenum}{'allsrvcports'}{"$srruleproto~$srruleport"}++						;
	if ($rules_ref->{$srrulenum}{'type'} =~ /sec_nat_rule/) {
		$nats_ref->{$srrulenum + $natrulecount}{'enabled'} = 'yes';
		$nats_ref->{$srrulenum + $natrulecount}{'installon'} = 'Any';
		$nats_ref->{$srrulenum + $natrulecount}{'comment'} = "NAT RULE defined from POLICY NAT rule: $srrulenum";
		$nats_ref->{$srrulenum + $natrulecount}{'origsrc'}{$srrulesrc}++;
		$nats_ref->{$srrulenum + $natrulecount}{'origdst'}{$srruledst}++;
		$nats_ref->{$srrulenum + $natrulecount}{'origsrvc'}{$srrulesrvc}++;
		$nats_ref->{$srrulenum + $natrulecount}{'origsrcbins'}{$srsrcbin}++;
		$nats_ref->{$srrulenum + $natrulecount}{'origdstbins'}{$srdstbin}++;
		$nats_ref->{$srrulenum + $natrulecount}{'origsrvcports'}{$srruleproto}{$srruleport}++;
		if (exists $rules_ref->{$srrulenum}{'natdstip'}) {
			$nats_ref->{$srrulenum + $natrulecount}{'natdst'}  = $rules_ref->{$srrulenum}{'natdstip'};
			$netobjects_ref->{$srruledst}{'natdst'}{$rules_ref->{$srrulenum}{'natdstip'}} = $srrulenum ;
		}
		if (exists $rules_ref->{$srrulenum}{'natdstdip'}) {
			$nats_ref->{$srrulenum + $natrulecount}{'natdst'}  = $rules_ref->{$srrulenum}{'natdstdip'};
			$netobjects_ref->{$srruledst}{'natdst'}{$rules_ref->{$srrulenum}{'natdstdip'}} = $srrulenum ;
		}
		if (exists $rules_ref->{$srrulenum}{'natsrc'}) {
			$nats_ref->{$srrulenum + $natrulecount}{'natsrc'}  = 'SRC_INT';
			$netobjects_ref->{$srrulesrc}{'natsrc'}{"SRC_INT"} = $srrulenum	;
		}
		if (exists $rules_ref->{$srrulenum}{'natsrcdip'}) {
			$nats_ref->{$srrulenum + $natrulecount}{'natsrc'}  = 'SRC_DIP';
			$netobjects_ref->{$srrulesrc}{'natsrc'}{"SRC_DIP"} = $srrulenum	;
		}

		unless (exists $nats_ref->{$srrulenum + $natrulecount}{'natsrc'}) {
			$nats_ref->{$srrulenum + $natrulecount}{'natsrc'}  = 'ORIGINAL';
			$netobjects_ref->{$srrulesrc}{'natsrc'}{"ORIGINAL"} = $srrulenum	;
		}
		unless (exists $nats_ref->{$srrulenum + $natrulecount}{'natdst'}) {
			$nats_ref->{$srrulenum + $natrulecount}{'natdst'}  = 'ORIGINAL';
			$netobjects_ref->{$srruledst}{'natdst'}{"ORIGINAL"} = $srrulenum	;
		}
		unless (exists $nats_ref->{$srrulenum + $natrulecount}{'natsrvc'}) {
			$nats_ref->{$srrulenum + $natrulecount}{'natsrvc'} = 'ORIGINAL';
			$netobjects_ref->{$srrulesrc}{'natsrvc'}{"ORIGINAL"} = $srrulenum	;
			$netobjects_ref->{$srruledst}{'natsrvc'}{"ORIGINAL"} = $srrulenum	;
		}
	} 
	
	$$rulebincount_ref++												;
	if ($$rulebincount_ref == ($$rulebincountquick_ref + 5000)) {
		printf "."	;
		$$rulebincountquick_ref = $$rulebincount_ref									;
	}
	if ($$rulebincount_ref == ($$rulebincountholder_ref + 250000)) {
		print ".$$rulebincount_ref	matches processed\n"	;
		$$rulebincountholder_ref = $$rulebincount_ref									;
	}
}

sub filter_rule_net_obj_ungrouper {
	my ($snrulenum, $snsrcdst, $netobjects_ref, $netgroupobjs_ref, $rules_ref) = @_							;
	my (@snallobjs)									;
	my (@snruleobj) = keys %{$rules_ref->{$snrulenum}{$snsrcdst}}				;
	#print "NUM $snrulenum $snsrcdst\n"						;
	foreach my $snrlobj (@snruleobj) {
		if (exists ($netgroupobjs_ref->{$snrlobj})) {
			foreach my $snsubrlobj (keys (%{$netgroupobjs_ref->{$snrlobj}})) {
				push (@snallobjs, $snsubrlobj) 				;
			}
		} elsif (exists ($netobjects_ref->{$snrlobj})) {
			push (@snallobjs, $snrlobj) 					;
		} else {
			push (@snallobjs, $snrlobj) 					;
			print "GROAPER $snrlobj\n"					;
		}
	}
	#print "ALL OBJS @snallobjs\n"							;
	return @snallobjs								;
}

sub filter_rule_srvc_obj_ungrouper {
	my ($ssrulenum, $srvcobjects_ref, $srvcgroupobjs_ref, $rules_ref) = @_								;
	my (@ssallobjs)									;
	my (@ssruleobj) = keys %{$rules_ref->{$ssrulenum}{'service'}}				;
	#print "SNUM $ssrulenum\n"							;
	foreach my $ssrlobj (@ssruleobj) {
		if (exists ($srvcgroupobjs_ref->{$ssrlobj})) {
			foreach my $sssubrlobj (keys (%{$srvcgroupobjs_ref->{$ssrlobj}})) {
				push (@ssallobjs, $sssubrlobj) 				;
			}
		} elsif (exists ($srvcobjects_ref->{$ssrlobj})) {
			push (@ssallobjs, $ssrlobj) 					;
		} else {
			push (@ssallobjs, $ssrlobj) 					;
			print "SROAPER $ssrlobj\n"					;
		}
	}
	#print "SALL OBJS @ssallobjs\n"							;
	return @ssallobjs								;
}

sub build_merge_to_rulebase {
	my ($srrulenum,$srrulesrc,$srsrcbin,$srruledst,$srdstbin,$srruleproto,$srrulesrvc,$srruleport,$rules_ref,$rashrulegroups_ref,$mergetodrops_ref,$mergetorulebases_ref,$rulebincount,$rulebincountquick_ref,$rulebincountholder) = @_	;

	#if ($rules_ref->{$srrulenum}{'srcneg'} eq 'yes') {
	#	#$rules{$srrulenum}{'action'} =~ /^drop$|^Drop$|^reject$|^Reject$/ ;
	#}
#	if (($rules_ref->{$srrulenum}{'action'} =~ /^drop$|^Drop$|^reject$|^Reject$/) && (($rules_ref->{$srrulenum}{'srcneg'} eq 'yes') || ($rules_ref->{$srrulenum}{'dstneg'} eq 'yes') || ($rules_ref->{$srrulenum}{'srvcneg'} eq 'yes')) {
#		my ($hitmatch) = (0);
#		if (exists $rashrulegroups_ref->{"$srruleproto~$srruleport"}) {
#			my $checkdst = $srdstbin;
#			until ($checkdst eq '') {
#				if (exists $rashrulegroups_ref->{"$srruleproto~$srruleport"}{$checkdst}) {
#					my $checksrc = $srsrcbin;
#					until ($checksrc eq '') {
#						if (exists $rashrulegroups_ref->{"$srruleproto~$srruleport"}{$checkdst}{$checksrc}) {
#							$hitmatch++;
#						}
#		 				chop $checksrc;
#					}
#				}
#	 			chop $checkdst;
#			}
#		}
#		if ($hitmatch > 0) {
#			return '';
#		} else {
#			$mergetodrops_ref->{"$srrulesrvc~$srruleport"}{$srdstbin}{$srsrcbin}++ ;
#			return '';
#		}

# NOTE: handle drop rules - first check that the drop rule traffic is not allowed already

	if ($rules_ref->{$srrulenum}{'action'} =~ m/^drop$|^Drop$|^reject$|^Reject$/) {
		my ($hitmatch) = (0);
		my $checkdst = $srdstbin;
		for (my $i = 32 ; $i >= 0 ; $i--) {
			if (exists $mergetorulebases_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 32 ; $ix >= 0 ; $ix--) {
					if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}) {
						if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								$hitmatch++;
								print "DROP MATCHED PREV ACCEPT RULE: src $checksrc dst $checkdst proto $srruleproto port $srruleport\n";
							} elsif (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}) {
								if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
									$hitmatch++;
									print "DROP MATCHED PREV ACCEPT RULE: src $checksrc dst $checkdst proto Any port Any\n";
								}
							}
						}
					}
		 			chop $checksrc;
				}
			}
	 		chop $checkdst;
		}
		if ($hitmatch > 0) {
			print "MERGE TO DROPS:			{$srdstbin}{$srsrcbin}{$srrulesrvc}{$srruleport}\n";
			return '';
		} else {
			#print "MERGE TO added --- DROPS:	{$srdstbin}{$srsrcbin}{$srrulesrvc}{$srruleport}\n";
			$mergetodrops_ref->{$srdstbin}{$srsrcbin}{$srrulesrvc}{$srruleport}++ ;
			return '';
		}
	} else {

	# NOTE: check if rules other than drop rules matche previously expanded drop rules

		my $dropmatch = 0;
		my $checkdst = $srdstbin;
		for (my $i = 32 ; $i >= 0 ; $i--) {
			if (exists $mergetodrops_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 32 ; $ix >= 0 ; $ix--) {
					if (exists $mergetodrops_ref->{$checkdst}{$checksrc}) {
						if (exists $mergetodrops_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $mergetodrops_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								$dropmatch++;
								print "DROP MATCHED: src $checksrc dst $checkdst proto $srruleproto port $srruleport\n";
							}
						} elsif (exists $mergetodrops_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $mergetodrops_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $mergetodrops_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								$dropmatch++;
								print "DROP MATCHED: src $checksrc dst $checkdst proto Any port Any\n";
							}
						}
					}
		 			chop $checksrc;
				}
			}
 			chop $checkdst;
		}
		if ($dropmatch > 0 ) {
			print "DROP RULE MATCH:		$srrulenum\n";
			return '';
		}
	}
	#print "SRC YES $srcaddyes, SRC NO $srcaddno, DST YES $dstaddyes, DST NO $dstaddno\n";

	#if (($srrulesrc || $srruledst || $srrulesrvc) =~ /^Any$|^any$/) { 
	#if (($srruledst || $srrulesrvc) =~ /^Any$|^any$/) { 
		#print "ANY ARRIVED $srrulenum, $srrulesrc, $srsrcbin, $srruledst, $srdstbin, $srrulesrvc\n";

	#}

# NOTE: add rules to merge to rulebase

	if ($rules_ref->{$srrulenum}{'action'} !~ m/^drop$|^Drop$|^reject$|^Reject$/) {
		$mergetorulebases_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++			;
		#print "ADDED 	".$rules_ref->{$srrulenum}{'action'}."	SRC: $srsrcbin, 		DST: $srdstbin,   	SERVC: $srruleproto~$srruleport\n";
	} else {
		print "DROPPED 	".$rules_ref->{$srrulenum}{'action'}."	SRC: $srsrcbin, 		DST: $srdstbin,   	SERVC: $srruleproto~$srruleport\n";
	}

# print dots

	$$rulebincount++														;
	if ($$rulebincount == ($$rulebincountquick_ref + 1000)) {
		print "."	;
		$$rulebincountquick_ref = $$rulebincount									;
	}
	if ($$rulebincount == ($$rulebincountholder + 50000)) {
		print ".$$rulebincount	Merge to Rbase matches built\n"		;
		$$rulebincountholder = $$rulebincount										;
	}
}

sub add_encrypt_to_mergeto_rulebase {
	my ($srrulenum,$srrulesrc,$srsrcbin,$srruledst,$srdstbin,$srruleproto,$srrulesrvc,$srruleport,$rules_ref,$mergetorulebases_ref,$rulebincount,$rulebincountquick_ref,$rulebincountholder) = @_	;

	$mergetorulebases_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;

	$$rulebincount++									;
	if ($$rulebincount == ($$rulebincountquick_ref + 1000)) {
		print "."	;
		$$rulebincountquick_ref = $$rulebincount									;
	}
	if ($$rulebincount == ($$rulebincountholder + 50000)) {
		print ".$$rulebincount	Merge to VPNBase matches built\n";
		$$rulebincountholder = $$rulebincount	;
	}
}

sub rulegroup_bin_proc_add {
	my ($srrulenum,$srrulesrc,$srsrcbin,$srruledst,$srdstbin,$srruleproto,$srrulesrvc,$srruleport,$incconobjs,
		$rules_ref,$netobjects_ref,$srvcstree_ref,$includeips_ref,$excludeips_ref,$rashrulegroups_ref,$rashlogfilter_ref,$drops_ref,$mergetorulebases_ref,$nats_ref,$natrules_ref,$transrules_ref,$rulebincount_ref,$rulebincountquick_ref,$rulebincountholder_ref,$filterwithlog_ref,$translatewithnats_ref,$matchprevrules_ref) = @_	;
	my ($srcaddyes, $srcaddno, $dstaddyes, $dstaddno, $inccount, $excount) = (0,0,0,0,0,0);
	$inccount = keys %{$includeips_ref};
	$excount  = keys %{$excludeips_ref};
	#print "IN $inccount, 	EX $excount\n";
	#print (Dumper(%includeips).Dumper(%excludeips));  

	#if ($rules_ref->{$srrulenum}{'srcneg'} eq 'yes') {
	#	#$rules{$srrulenum}{'action'} =~ /^drop$|^Drop$|^reject$|^Reject$/ ;
	#}

# NOTE: handle drop rules - first check that the drop rule traffic is not allowed already

	if ($rules_ref->{$srrulenum}{'action'} =~ m/^deny$|^Deny$|^drop$|^Drop$|^reject$|^Reject$/) {
		my ($hitmatch) = (0);
		my $checkdst = $srdstbin;
		for (my $i = 33 ; $i >= 1 ; $i--) {
			if (exists $rashrulegroups_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}) {
						if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								#print "PREV RULE MATCH\n";
								$hitmatch++;
							}
						} elsif (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								#print "PREV RULE any MATCH\n";
								$hitmatch++;
							}
						}
					}
		 			chop $checksrc;
				}
			}
	 		chop $checkdst;
		}
		if ($hitmatch > 0) {
			print "PREVIOUS RULE MATCH: {$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}\n";
			return '';
		} else {

			# NOTE: add drop rule

			$drops_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}++ ;
			return '';
		}
	} else {

	# NOTE: check if rules other than drop rules matche previously expanded drop rules

		my $dropmatch = 0;
		my $checkdst = $srdstbin;
		for (my $i = 33 ; $i >= 1 ; $i--) {
			if (exists $drops_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $drops_ref->{$checkdst}{$checksrc}) {
						if (exists $drops_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $drops_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								#print "DROP RULEBASE MATCH\n";
								$dropmatch++;
							}
						} elsif (exists $drops_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $drops_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $drops_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								#print "DROP RULEBASE any MATCH\n";
								$dropmatch++;
							}
						}
					}
		 			chop $checksrc;
				}
			}
 			chop $checkdst;
		}
		if ($dropmatch > 0 ) {
			print "DROP RULEBASE MATCH1 $dropmatch {$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}\n";
			return '';
		}
	}

# NOTE: if no log is given check if the rule matches previous connectivity expaneded

	if ($$filterwithlog_ref eq 'none') {
		my ($hitmatch) = (0);
		my $checkdst = $srdstbin;
		for (my $i = 33 ; $i >= 1 ; $i--) {
			if (exists $rashrulegroups_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}) {
						if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								#print "PREV RULE MATCH\n";
								$hitmatch++;
							}
						} elsif (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								#print "PREV RULE any MATCH\n";
								$hitmatch++;
							}
						}
					}
		 			chop $checksrc;
				}
			}
	 		chop $checkdst;
		}
		if ($hitmatch > 0) {
			print "ACCEPT MATCHED PREV RILE : $srrulenum\n";
			return '';
		}
		($hitmatch) = (0);
		if (exists $rashlogfilter_ref->{"$srruleproto~$srruleport"}) {
			my $checkdst = $srdstbin;
			for (my $i = 33 ; $i >= 1 ; $i--) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $rashlogfilter_ref->{"$srruleproto~$srruleport"}{$checkdst}) {
						if (exists $rashlogfilter_ref->{"$srruleproto~$srruleport"}{$checkdst}{$checksrc}) {
							#print "PREV RULE MATCH\n";
							$hitmatch++;
						}
					}
		 			chop $checksrc;
				}
	 			chop $checkdst;
			}
		} elsif (exists $rashlogfilter_ref->{'any.any'} || exists $rashlogfilter_ref->{'any.Any'}) {
			my $checkdst = $srdstbin;
			for (my $i = 33 ; $i >= 1 ; $i--) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $rashlogfilter_ref->{'any.any'}{$checkdst}) {
						if (exists $rashlogfilter_ref->{'any.any'}{$checkdst}{$checksrc}) {
							#print "PREV RULE MATCHi any\n";
							$hitmatch++;
						}
					}
		 			chop $checksrc;
				}
	 			chop $checkdst;
			}
		}
		if ($hitmatch > 0) {
			print "ACCEPT MATCHED PREV RILE : $srrulenum\n";
			return '';
		}

# NOTE: if no log is given check if the rule matches previous connectivity expaneded - excluding rules that could not be matched against the log

	} elsif ($$filterwithlog_ref eq 'no') {
		my ($hitmatch) = (0);
		if (exists $rashlogfilter_ref->{"$srruleproto~$srruleport"}) {
			#print "hit port: $srruleproto~$srruleport\n";
			my $checkdst = $srdstbin;
			for (my $i = 33 ; $i >= 1 ; $i--) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $rashlogfilter_ref->{"$srruleproto~$srruleport"}{$checkdst}) {
						#print "hit DST: $srruleproto~$srruleport $checkdst\n";
						if (exists $rashlogfilter_ref->{"$srruleproto~$srruleport"}{$checkdst}{$checksrc}) {
							#print "hit SRC: $srruleproto~$srruleport $checkdst, $checksrc\n";
							$hitmatch++;
							#return;
						}
					}
		 			chop $checksrc;
				}
	 			chop $checkdst;
			}
		} elsif (exists $rashlogfilter_ref->{'any.any'} || exists $rashlogfilter_ref->{'any.Any'}) {
			my $checkdst = $srdstbin;
			for (my $i = 33 ; $i >= 1 ; $i--) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $rashlogfilter_ref->{'any.any'}{$checkdst}) {
						if (exists $rashlogfilter_ref->{'any.any'}{$checkdst}{$checksrc}) {
							print "PREV RULE MATCHi any\n";
							$hitmatch++;
							#return;
						}
					}
		 			chop $checksrc;
				}
	 			chop $checkdst;
			}
		}
		if ($hitmatch > 0) {
			print "No Log ACCEPT MATCHED PREV RILE: $srrulenum\n";
			return;
		}
	}

# NOTE: all filter types - check merge from rules for match in merge to rulebase

	my ($matchtobasematch) = 0;
	my $checkdst = $srdstbin;
	for (my $i = 33 ; $i >= 1 ; $i--) {
		if (exists $mergetorulebases_ref->{$checkdst}) {
			my $checksrc = $srsrcbin;
			for (my $ix = 33 ; $ix >= 1 ; $ix--) {
				if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}) {
					if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{$srruleproto}) {
						if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
							#print "MERGETO RULEBASE MATCH		{$checkdst}{$checksrc}{$srruleproto}{$srruleport}\n";
							$matchtobasematch++;
						}
					} elsif (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}) {
						if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
							#print "MERGETO RULEBASE any MATCH	{$checkdst}{$checksrc}{$srruleproto}{$srruleport}\n";
							$matchtobasematch++;
						}
					}
				}
	 			chop $checksrc;
			}
		}
 		chop $checkdst;
	}
	if ($matchtobasematch > 0 ) {
		print "MERGETO RULEBASE MATCH  {$srsrcbin}{$srdstbin}{$srruleproto}{$srruleport}\n";
		return '';
	}

# NOTE: translate destination nats only

	my ($oldsrcbin, $olddstbin) = (0,0);
	my @natrules;
	if ($$translatewithnats_ref eq 'yes') {
		my $checkdst = $srdstbin;
		for (my $i = 33 ; $i >= 1 ; $i--) {
			if (exists $nats_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $nats_ref->{$checkdst}{$checksrc}) {
						if (exists $nats_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $nats_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								foreach my $natrule (keys %{$nats_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}}) {
									if ($natrules_ref->{$natrule}{'natdst'} ne 'ORIGINAL') {
										push(@natrules, $natrule);
										$olddstbin = $srdstbin;
										$srdstbin  = ip_to_bin($netobjects_ref->{$natrules_ref->{$natrule}{'natdst'}}{'ip'}) ;
										#print "WOOH ".$natrules_ref->{$natrule}{'natdst'}.", $srdstbin\n";
									}
								}
							}
						} elsif (exists $nats_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $nats_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $nats_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								foreach my $natrule (keys %{$nats_ref->{$checkdst}{$checksrc}{'any'}{'any'}}) {
									if ($natrules_ref->{$natrule}{'natdst'} ne 'ORIGINAL') {
										push(@natrules, $natrule);
										$olddstbin = $srdstbin;
										$srdstbin  = ip_to_bin($netobjects_ref->{$natrules_ref->{$natrule}{'natdst'}}{'ip'}) ;
										#print "WEH ".$natrules_ref->{$natrule}{'natdst'}.", $srdstbin\n";
									}
								}
							}
						}
					}
		 			chop $checksrc;
				}
			}
 			chop $checkdst;
		}
	}

# NOTE: filter only the exact binary matches of the IN EX statements entered earlier, no subnet matching here

	if ($inccount > 0 ) {
		my $workingsrcbin = $srsrcbin;
		if (exists $includeips_ref->{$workingsrcbin}) {
			if ($excount > 0 ) {
				$workingsrcbin = $srsrcbin;
				if (exists $excludeips_ref->{$workingsrcbin}) { 
					#print "SRC IN EX DONT ADD $workingsrcbin\n";
					$srcaddno++;
				} else {
					$srcaddyes++;
					#print "SRC IN EX ADD $workingsrcbin\n";
				}
			} else {
				$srcaddyes++;
				#print "SRC IN ADD $srsrcbin\n";
			}
		} else {
			# NOTE: %$%$%$%$%--IMPORTANT--$%$%$%$$%$
			# this should only be set if you want to match both source and dest for each connection permitted
			
			if ($incconobjs eq 'no') {
				$srcaddno++;
				#print "SRC IN DONT ADD $srsrcbin\n";
			}

		}
	} elsif ($excount > 0 ) {
		my $workingsrcbin = $srsrcbin;
		#print "EXC elsif $srsrcbin\n";
		if (exists $excludeips_ref->{$workingsrcbin}) { 
			$srcaddno++;
			#print "SRC EX DONT ADD $workingsrcbin\n";
		} else {
			$srcaddyes++;
			#print "SRC EX ADD $workingsrcbin\n";
		}
	} else {
		#print "SRC PLAIN OLD ADD $srruleproto~$srruleport\n";
		$srcaddyes++;
	}

	# NOTE: Check to see if the dst IP is to be included or excluded

	if ($inccount > 0 ) {
		my $workingdstbin = $srdstbin;
		#print "DST INC if $workingdstbin\n";
		if (exists $includeips_ref->{$workingdstbin}) {
			#print "DST INC if until exists $workingdstbin\n";
			$workingdstbin = $srdstbin;
			if ($excount > 0 ) {
				#print "DST INC EX if until exists $workingdstbin\n";
				if (exists $excludeips_ref->{$workingdstbin}) { 
					#print "DST INC EX if foreach if until if $workingdstbin\n DONT ADD";
					$dstaddno++;
					#print "DST IN EX DONT ADD $workingdstbin\n";
				} else {
					$dstaddyes++;
					#print "DST IN EX ADD $workingdstbin\n";
				}
			} else {
				#print "DST IN ADD $workingdstbin\n";
				$dstaddyes++;				
			}
		} else {
			# NOTE: %$%$%$%$%--IMPORTANT--$%$%$%$$%$
			# this should only be set if you want to match both source and dest for each connection permitted

			if ($incconobjs eq 'no') {
				$dstaddno++;
				#print "DST IN DONT ADD $srdstbin\n";
			}
			
		}
	} elsif ($excount > 0 ) {
		#print "DST EX $srdstbin\n";
		my $workingdstbin = $srdstbin;
		if (exists $excludeips_ref->{$workingdstbin}) { 
			#print "DST EXC elsif until unless $workingdstbin\n";
			$dstaddno++;
			#print "DST EX DONT ADD $workingdstbin\n";
		} else {
			$dstaddyes++;
			#print "DST EX ADD $workingdstbin\n";
		}
	} else {
		#print "DST PLAIN OLD ADD $srruleproto~$srruleport\n";
		$dstaddyes++;
	}
	
	if ($$translatewithnats_ref eq 'yes') {
		$srdstbin = $olddstbin;
	}
	#print "SRC YES $srcaddyes, SRC NO $srcaddno, DST YES $dstaddyes, DST NO $dstaddno\n";

# NOTE: implement the different types of filters
# The rashlogfilter hash is where rules that can be checked against logs go
# The rashrulegroups hash is where the rules set not to log - and currently the accounting rules - are put so as to avoid being filtered out

	if ($$filterwithlog_ref eq 'yes') {
		if (($srcaddyes > 0) && ($srcaddno < 1) && ($dstaddyes > 0) && ($dstaddno < 1)) {
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}

			#print "ADDED 		SRC: $srsrcbin, 		DST: $srdstbin,   	SERVC: $srruleproto~$srruleport\n";
		} else {
			#print "FILTERED OUT 	SRC: $srsrcbin, 		DST: $srdstbin, 	SERVC: $srruleproto~$srruleport\n";
		}
		if    ((($dstaddyes > 0) && ($dstaddno < 1)) && (($srcaddyes > 0) && ($srcaddno < 1)) && ($rules_ref->{$srrulenum}{'track'} eq 'None')) {
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
	} elsif ($$filterwithlog_ref eq 'loosen') {
		if (($srcaddno < 1) || ($dstaddno < 1)) {
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++ ;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
	} elsif ($$filterwithlog_ref eq 'loose') {
		if (($srcaddno < 1) || ($dstaddno < 1)) {
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
		if ((($srcaddno < 1) || ($dstaddno < 1)) && ($rules_ref->{$srrulenum}{'track'} ne 'Log')) { 
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
	} else {
		if (($srcaddyes > 0) && ($srcaddno < 1) && ($dstaddyes > 0) && ($dstaddno < 1)) {
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		} else {
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
	}

	$$rulebincount_ref++														;
	if ($$rulebincount_ref == ($$rulebincountquick_ref + 1000)) {
		print "."	;
		$$rulebincountquick_ref = $$rulebincount_ref									;
	}
	if ($$rulebincount_ref == ($$rulebincountholder_ref + 50000)) {
		print ".$$rulebincount_ref	Speciffic matches processed\n"		;
		$$rulebincountholder_ref = $$rulebincount_ref										;
	}
}

sub rulegroup_bin_and_subnet_proc_add {
	my ($srrulenum,$srrulesrc,$srsrcbin,$srruledst,$srdstbin,$srruleproto,$srrulesrvc,$srruleport,$incconobjs,
	      $rules_ref,$netobjects_ref,$srvcstree_ref,$includeips_ref,$excludeips_ref,$rashrulegroups_ref,$rashlogfilter_ref,$drops_ref,$mergetorulebases_ref,$nats_ref,$natrules_ref,$transrules_ref,$rulebincount_ref,$rulebincountquick_ref,$rulebincountholder_ref,$filterwithlog_ref,$translatewithnats_ref,$matchprevrules_ref) = @_;
	my ($srcaddyes, $srcaddno, $dstaddyes, $dstaddno, $inccount, $excount) = (0,0,0,0,0,0);
	$inccount = keys %{$includeips_ref};
	$excount  = keys %{$excludeips_ref};
	#print "IN $inccount, 	EX $excount\n";
	#print (Dumper(%includeips).Dumper(%excludeips));  

# NOTE: handle drop rules - first check that the drop rule traffic is not allowed already

	if ($rules_ref->{$srrulenum}{'action'} =~ m/^drop$|^Drop$|^reject$|^Reject$/) {
		my ($hitmatch) = (0);
		my $checkdst = $srdstbin;
		for (my $i = 33 ; $i >= 1 ; $i--) {
			if (exists $rashrulegroups_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}) {
						if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								$hitmatch++;
								print "DROP RULE MATCHED PREV RULE\n";
							}
						} elsif (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								$hitmatch++;
								print "DROP RULE MATCHED PREV ANY RULE\n";
							}
						}
					}
		 			chop $checksrc;
				}
			}
	 		chop $checkdst;
		}
		if ($hitmatch > 0) {
			print "DROP RULE MATCHED PREV ACCEPT RULE: {$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}\n";
			return '';
		} else {

			# NOTE: add drop rule

			$drops_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}++ ;
			return '';
		}
	} else {

# NOTE: check if rules other than drop rules matche previously expanded drop rules

		my $dropmatch = 0;
		my $checkdst = $srdstbin;
		for (my $i = 33 ; $i >= 1 ; $i--) {
			if (exists $drops_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $drops_ref->{$checkdst}{$checksrc}) {
						if (exists $drops_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $drops_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								$dropmatch++;
								#print "DROP RULEBASE MATCH\n";
							}
						} elsif (exists $drops_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $drops_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $drops_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								$dropmatch++;
								#print "DROP RULEBASE any MATCH\n";
							}
						}
					}
		 			chop $checksrc;
				}
			}
 			chop $checkdst;
		}
		if ($dropmatch > 0 ) {
			print "ACCEPT RULE MATCHED PREV DROP RULE: {$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}\n";
			return '';
		}
	}
#	#print "$$matchprevrules_ref\n";
#	if ($$matchprevrules_ref eq 'yes') {
#		my ($hitmatch) = (0);
#		my $checkdst = $srdstbin;
#		for (my $i = 33 ; $i >= 1 ; $i--) {
#			if (exists $rashrulegroups_ref->{$checkdst}) {
#				my $checksrc = $srsrcbin;
#				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
#					if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}) {
#						if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}) {
#							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
#								print "PREV RULE MATCH   	{$checkdst}{$checksrc}{$srruleproto}{$srruleport}\n";
#								$hitmatch++;
#							}
#						} elsif (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}) {
#							if (exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $rashrulegroups_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
#								print "PREV RULE ANY MATCH	$checkdst}{$checksrc}{$srruleproto}{$srruleport}\n";
#								$hitmatch++;
#							}
#						}
#					}
#		 			chop $checksrc;
#				}
#			}
#			chop $checkdst;
#		}
#		if ($hitmatch > 0) {
#			print "ACCEPT MATCHED PREV RILE : $srrulenum\n";
#			return '';
#		}
#	}

# NOTE: all filter types - check merge from rules for match in merge to rulebase

	my ($matchtobasematch) = 0;
	my $checkdst = $srdstbin;
	for (my $i = 33 ; $i >= 1 ; $i--) {
		if (exists $mergetorulebases_ref->{$checkdst}) {
			my $checksrc = $srsrcbin;
			for (my $ix = 33 ; $ix >= 1 ; $ix--) {
				if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}) {
					if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{$srruleproto}) {
						if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
							$matchtobasematch++;
							print "MERGETO RULEBASE MATCH		{$checkdst}{$checksrc}{$srruleproto}{$srruleport}\n";
						}
					} elsif (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}) {
						if (exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $mergetorulebases_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
							$matchtobasematch++;
							print "MERGETO RULEBASE any MATCH	{$checkdst}{$checksrc}{$srruleproto}{$srruleport}\n";
						}
					}
				}
	 			chop $checksrc;
			}
		}
 		chop $checkdst;
	}
	if ($matchtobasematch > 0 ) {
		#print "MERGE TO BASE HOT HOT $matchtobasematch\n";
		return '';
	}

# NOTE: translate destination nats only

	my ($oldsrcbin, $olddstbin) ;
	my @natrules;
	if ($$translatewithnats_ref eq 'yes') {
		my $checkdst = $srdstbin;
		for (my $i = 33 ; $i >= 1 ; $i--) {
			if (exists $nats_ref->{$checkdst}) {
				my $checksrc = $srsrcbin;
				for (my $ix = 33 ; $ix >= 1 ; $ix--) {
					if (exists $nats_ref->{$checkdst}{$checksrc}) {
						if (exists $nats_ref->{$checkdst}{$checksrc}{$srruleproto}) {
							if (exists $nats_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}) {
								foreach my $natrule (keys %{$nats_ref->{$checkdst}{$checksrc}{$srruleproto}{$srruleport}}) {
									if ($natrules_ref->{$natrule}{'natdst'} ne 'ORIGINAL') {
										push(@natrules, $natrule);
										$olddstbin = $srdstbin;
										$srdstbin  = ip_to_bin($netobjects_ref->{$natrules_ref->{$natrule}{'natdst'}}{'ip'}) ;
									}
								}
							}
						} elsif (exists $nats_ref->{$checkdst}{$checksrc}{'any'}) {
							if (exists $nats_ref->{$checkdst}{$checksrc}{'any'}{'any'} || exists $nats_ref->{$checkdst}{$checksrc}{'any'}{'Any'}) {
								foreach my $natrule (keys %{$nats_ref->{$checkdst}{$checksrc}{'any'}{'any'}}) {
									if ($natrules_ref->{$natrule}{'natdst'} ne 'ORIGINAL') {
										push(@natrules, $natrule);
										$olddstbin = $srdstbin;
										$srdstbin  = ip_to_bin($netobjects_ref->{$natrules_ref->{$natrule}{'natdst'}}{'ip'}) ;
									}
								}
							}
						}
					}
		 			chop $checksrc;
				}
			}
 			chop $checkdst;
		}
	}

# NOTE: filter binary matches of the IN EX statements entered earlier, hosts and subnets of the IP's and netmasks entered will be included

	if ($inccount > 0 ) {
		my $workingsrcbin = $srsrcbin;
		until (exists $includeips_ref->{$workingsrcbin} || $workingsrcbin eq '') {
			chop $workingsrcbin;
		} 
		if (exists $includeips_ref->{$workingsrcbin}) {
			if ($excount > 0 ) {
				$workingsrcbin = $srsrcbin;
				until (exists $excludeips_ref->{$workingsrcbin} || $workingsrcbin eq '') {
					chop $workingsrcbin;
				} 
				if (exists $excludeips_ref->{$workingsrcbin}) { 
					#print "SRC IN EX DONT ADD $workingsrcbin\n";
					$srcaddno++;
				} else {
					$srcaddyes++;
					#print "SRC IN EX ADD $workingsrcbin\n";
				}
			} else {
				$srcaddyes++;
				#print "SRC IN ADD $srsrcbin\n";
			}
		} else {
			# NOTE: %$%$%$%$%--IMPORTANT--$%$%$%$$%$
			# this should only be set if you want to match both source and dest for each connection permitted
			
			if ($incconobjs eq 'no') {
				$srcaddno++;
				#print "SRC IN DONT ADD $srsrcbin\n";
			}
		}
	} elsif ($excount > 0 ) {
		my $workingsrcbin = $srsrcbin;
		#print "EXC elsif $srsrcbin\n";
		until (exists $excludeips_ref->{$workingsrcbin} || $workingsrcbin eq '') {
			#print "SRC EXC elsif until $workingsrcbin\n";
			chop $workingsrcbin;
		} 
		if (exists $excludeips_ref->{$workingsrcbin}) { 
			$srcaddno++;
			#print "SRC EX DONT ADD $workingsrcbin\n";
		} else {
			$srcaddyes++;
			#print "SRC EX ADD $workingsrcbin\n";
		}
	} else {
		#print "SRC PLAIN OLD ADD $srruleproto~$srruleport\n";
		$srcaddyes++;
	}

	# NOTE: Check to see if the dst IP is to be included or excluded

	if ($inccount > 0 ) {
		my $workingdstbin = $srdstbin;
		#print "DST INC if $workingdstbin\n";
		until (exists $includeips_ref->{$workingdstbin} || $workingdstbin eq '') {
			#print "DST INC if until $workingdstbin\n";
			chop $workingdstbin;
		} 
		if (exists $includeips_ref->{$workingdstbin}) {
			#print "DST INC if until exists $workingdstbin\n";
			$workingdstbin = $srdstbin;
			if ($excount > 0 ) {
				#print "DST INC EX if until exists $workingdstbin\n";
				until (exists $excludeips_ref->{$workingdstbin} || $workingdstbin eq '') {
					#print "DST INC EX if until exists until $workingdstbin\n";
					chop $workingdstbin;
				} 
				if (exists $excludeips_ref->{$workingdstbin}) { 
					#print "DST INC EX if foreach if until if $workingdstbin\n DONT ADD";
					$dstaddno++;
					#print "DST IN EX DONT ADD $workingdstbin\n";
				} else {
					$dstaddyes++;
					#print "DST IN EX ADD $workingdstbin\n";
				}
			} else {
				#print "DST IN ADD $workingdstbin\n";
				$dstaddyes++;				
			}
		} else {
			# NOTE: %$%$%$%$%--IMPORTANT--$%$%$%$$%$
			# this should only be set if you want to match both source and dest for each connection permitted

			if ($incconobjs eq 'no') {
				$dstaddno++				;
				#print "DST IN DONT ADD $srdstbin\n";
			}
			
		}
	} elsif ($excount > 0 ) {
		#print "DST EX $srdstbin\n";
		my $workingdstbin = $srdstbin										;
		until (exists $excludeips_ref->{$workingdstbin} || $workingdstbin eq '') {
			#print "DST EXC elsif until $workingdstbin\n";
			chop $workingdstbin										;
		} 
		if (exists $excludeips_ref->{$workingdstbin}) { 
			#print "DST EXC elsif until unless $workingdstbin\n";
			$dstaddno++;
			#print "DST EX DONT ADD $workingdstbin\n";
		} else {
			$dstaddyes++;
			#print "DST EX ADD $workingdstbin\n";
		}
	} else {
		#print "DST PLAIN OLD ADD $srruleproto~$srruleport\n";
		$dstaddyes++;
	}

	#print "SRC YES $srcaddyes, SRC NO $srcaddno, DST YES $dstaddyes, DST NO $dstaddno\n";

# NOTE: swap back old dest bin so that objects are matched against source config

	if (($$translatewithnats_ref eq 'yes') && defined($olddstbin)) {
		#print "WEEEEK $srdstbin = $olddstbin\n";
		$srdstbin = $olddstbin;
	}


# NOTE: implement the different types of filters
# The rashlogfilter hash is where rules that can be checked against logs go
# The rashrulegroups hash is where the rules set not to log are put - THIS IS DIFFERENT TO THE SIMILAR SUB ABOVE 

	if ($$filterwithlog_ref eq 'yes') {
		if (($srcaddyes > 0) && ($srcaddno < 1) && ($dstaddyes > 0) && ($dstaddno < 1))  {
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
		if ((($dstaddyes > 0) && ($dstaddno < 1) && ($srcaddyes > 0) && ($srcaddno < 1)) && ($rules_ref->{$srrulenum}{'track'} eq 'None')) {
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
	} elsif ($$filterwithlog_ref eq 'loosen') {
		if (($srcaddno < 1) || ($dstaddno < 1)) {
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++ ;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
	} elsif ($$filterwithlog_ref eq 'loose') {
		if (($srcaddno < 1) || ($dstaddno < 1)) {
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
		if ((($srcaddno < 1) || ($dstaddno < 1)) && ($rules_ref->{$srrulenum}{'track'} eq 'None')) { 
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++	;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			}
		}
	} else {
		if (($srcaddyes > 0) && ($srcaddno < 1) && ($dstaddyes > 0) && ($dstaddno < 1)) {
			$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
			$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++ ;
			if ($$translatewithnats_ref eq 'yes') {
				foreach my $natrule (@natrules) {
					$transrules_ref->{$natrule}{'src'}{$srrulesrc}++	;
					$transrules_ref->{$natrule}{'dst'}{$srruledst}++	;
					$transrules_ref->{$natrule}{'srvc'}{$srrulesrvc}++	;
					$transrules_ref->{$natrule}{'secrule'}{$srrulenum}++	;
				}
			} else {
				$rashlogfilter_ref->{"$srruleproto~$srruleport"}{$srdstbin}{$srsrcbin}{$srrulenum}++ ;
				$rashrulegroups_ref->{$srdstbin}{$srsrcbin}{$srruleproto}{$srruleport}{$srrulenum}++ ;
			}
		}
	}

	$$rulebincount_ref++								;
	if ($$rulebincount_ref == ($$rulebincountquick_ref + 1000)) {
		print "."	;
		$$rulebincountquick_ref = $$rulebincount_ref				;
	}
	if ($$rulebincount_ref == ($$rulebincountholder_ref + 50000)) {
		print ".$$rulebincount_ref	Subnet matches processed\n"		;
		$$rulebincountholder_ref = $$rulebincount_ref				;
	}
}
sub build_dst_src_rules {
	my ($rashlogfilter_ref, $srcbundle_ref, $dstbundle_ref) = @_;
	my (%lastrashrulebase, %lastrashprintbase, %resobjects, %ressrvcs, %resobjgroups, %ressrvcgroups);
	
	print "\n-----------------------------------------------------------------------------------------\n";
	print " STARTING RULE COMPARISON: \n";
	print "   rationalizing rulebase FILTERED - RULEGROUP SPECIFFIC - SUBROUTE MODE!\n";

	my (%rationizedrules, %rashizedrules, %rashizedrules2, %rashizedrules3, %rashizedrules4, %rashizedrules5, $rrgroupcount, $rrgroupcountholder, $rrcount, $rrcountholder);
	($rrgroupcount, $rrgroupcountholder, $rrcount, $rrcountholder) = (0,0,0,0);

	foreach my $rashdst (keys %{$rashlogfilter_ref}) {
		foreach my $rashsrc (keys %{$rashlogfilter_ref->{$rashdst}}) {
			my @seengroups;
			
			foreach my $groupname (keys %{$srcbundle_ref->{'portgroups'}}) {
				my ($match, $miss) = (0,0);
				my (%match, %miss) ;
				
				foreach my $gport (keys %{$srcbundle_ref->{'portgroups'}{$groupname}}) {
					$rrgroupcount++;
					if (exists $rashlogfilter_ref->{$rashdst}{$rashsrc}{$gport}) {
						$match++ ;	 
						$match{$gport}++ ;
					} else {
						$miss++ ;	 
						$miss{$gport}++ ;
					}
				}
				if ($miss < 1 ) {
					push (@seengroups, $groupname) ;
				}
			}
			if ($rrgroupcount >= ($rrgroupcountholder + 1000000)) {
				print "....................................................$rrgroupcount	port group comparisons made\n"	;
				$rrgroupcountholder = $rrgroupcount;
			}
			my %matchgroupports;
			for (@seengroups) {
				$ressrvcgroups{$_}++;
				foreach my $grpport (keys %{$srcbundle_ref->{'portgroups'}{$_}}) {
					$matchgroupports{$grpport} = $_;
				}
			}

			foreach my $rashport (keys %{$rashlogfilter_ref->{$rashdst}{$rashsrc}}) {
				foreach my $rulenum (keys %{$rashlogfilter_ref->{$rashdst}{$rashsrc}{$rashport}}) {
					$rrcount++;
					my ($protoc, $porty) = split (/\~/, $rashport) ;

					if (exists $matchgroupports{$rashport}) {
						$rashizedrules{$rashsrc}{$matchgroupports{$rashport}}{$rashdst}{$rulenum}++;
					} elsif (exists $srcbundle_ref->{'ports'}{$protoc}) {
						if (exists $srcbundle_ref->{'ports'}{$protoc}{$porty}) {
							$rashizedrules{$rashsrc}{$srcbundle_ref->{'ports'}{$protoc}{$porty}{'name'}}{$rashdst}{$rulenum}++;
							$ressrvcs{$srcbundle_ref->{'ports'}{$protoc}{$porty}{'name'}}++;
						} else {
							$rashizedrules{$rashsrc}{$porty}{$rashdst}{$rulenum}++;
							print "MOMOMOMOMO $porty\n";
						}
					} else {
						$rashizedrules{$rashsrc}{$porty}{$rashdst}{$rulenum}++;
						print "WOWOWOWOWOW $porty\n";
					}
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	rule ports simplified\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	#print "RATIONALIZED RULES         	\n########################################################################################################################\n\n". Dumper(%rashizedrules) . "\n\n";
	print "   ports rationalized...............................DONE!\n"						;
	($rrcount, $rrcountholder, $rrgroupcount, $rrgroupcountholder) = (0,0,0,0)					;

	foreach my $rashsrc (keys %rashizedrules) {
		foreach my $rashport (keys %{$rashizedrules{$rashsrc}}) {
			my @seengroups;
			
			foreach my $groupname (keys %{$srcbundle_ref->{'bingroups'}}) {
				my ($match, $miss) = (0,0);
				my (%match, %miss) ;
				
				foreach my $gbin (keys %{$srcbundle_ref->{'bingroups'}{$groupname}}) {
					$rrgroupcount++;
					if (exists $rashizedrules{$rashsrc}{$rashport}{$gbin}) {
						$match++ ;	 
						$match{$gbin}++ ;
					} else {
						$miss++ ;	 
						$miss{$gbin}++ ;
					}
				}
				if ($miss < 1 ) {
					push (@seengroups, $groupname) ;
				}
			}
			if ($rrgroupcount >= ($rrgroupcountholder + 1000000)) {
				print "....................................................$rrgroupcount	dst group comparisons made\n"	;
				$rrgroupcountholder = $rrgroupcount;
			}
			my %matchgroupbins;
			for (@seengroups) {
				$resobjgroups{$_}++;
				foreach my $grpbin (keys %{$srcbundle_ref->{'bingroups'}{$_}}) {
					$matchgroupbins{$grpbin} = $_;
				}
			}

			foreach my $rashdst (keys %{$rashizedrules{$rashsrc}{$rashport}}) {
				foreach my $rulenum (keys %{$rashizedrules{$rashsrc}{$rashport}{$rashdst}}) {
					$rrcount++;
					if (exists $matchgroupbins{$rashdst}) {
						$rashizedrules2{$matchgroupbins{$rashdst}}{$rashport}{$rashsrc}{$rulenum}++;
					#} elsif (exists $destbundle_ref->{'ips'}{$rashsrc}) {
					#	$rashizedrules{$rashport}{$destbundle_ref->{'ips'}{$rashsrc}{'name'}}{$rashdst}{$rulenum}++;
					} elsif (exists $srcbundle_ref->{'ips'}{$rashdst}) {
						$rashizedrules2{$srcbundle_ref->{'ips'}{$rashdst}{'name'}}{$rashport}{$rashsrc}{$rulenum}++;
						$resobjects{$srcbundle_ref->{'ips'}{$rashdst}{'name'}}++;
					} else {
						print "OOOOWHAKAOOOOWHAKA $rashdst\n";
					}
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	rule dests simplified\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	print "   destinations rationalized........................DONE!\n"			;
	($rrcount, $rrcountholder, $rrgroupcount, $rrgroupcountholder) = (0,0,0,0)	;
	%rashizedrules = ();

	foreach my $rashdst (keys %rashizedrules2) {
		foreach my $rashport (keys %{$rashizedrules2{$rashdst}}) {
			my @seengroups;
			
			foreach my $groupname (keys %{$srcbundle_ref->{'bingroups'}}) {
				my ($match, $miss) = (0,0);
				my (%match, %miss) ;
				
				foreach my $gbin (keys %{$srcbundle_ref->{'bingroups'}{$groupname}}) {
					$rrgroupcount++;
					if (exists $rashizedrules2{$rashdst}{$rashport}{$gbin}) {
						$match++ ;	 
						$match{$gbin}++ ;
					} else {
						$miss++ ;	 
						$miss{$gbin}++ ;
					}
				}
				if ($miss < 1 ) {
					push (@seengroups, $groupname) ;
				}
			}
			if ($rrgroupcount >= ($rrgroupcountholder + 1000000)) {
				print "....................................................$rrgroupcount	src group comparisons made\n"	;
				$rrgroupcountholder = $rrgroupcount;
			}
			my %matchgroupbins;
			for (@seengroups) {
				$resobjgroups{$_}++;
				foreach my $grpbin (keys %{$srcbundle_ref->{'bingroups'}{$_}}) {
					$matchgroupbins{$grpbin} = $_;
				}
			}

			foreach my $rashsrc (keys %{$rashizedrules2{$rashdst}{$rashport}}) {
				foreach my $rulenum (keys %{$rashizedrules2{$rashdst}{$rashport}{$rashsrc}}) {
					$rrcount++;
					if (exists $matchgroupbins{$rashsrc}) {
						$rashizedrules3{$matchgroupbins{$rashsrc}}{$rashdst}{$rashport}{$rulenum}++;
					} elsif (exists $srcbundle_ref->{'ips'}{$rashsrc}) {
						$rashizedrules3{$srcbundle_ref->{'ips'}{$rashsrc}{'name'}}{$rashdst}{$rashport}{$rulenum}++;
						$resobjects{$srcbundle_ref->{'ips'}{$rashsrc}{'name'}}++;
					} else {
						print "OOOOWHAKAOOOOWHAKA $rashsrc\n";
					}
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	rule sources simplified\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	#print "RATIONALIZED RULES PRE        	\n########################################################################################################################\n\n". Dumper(%rashizedrules3) . "\n\n";
	print "   sources rationalized.............................DONE!\n"			;
	foreach my $rashsrc (keys %rashizedrules3) {
		foreach my $rashdst (keys %{$rashizedrules3{$rashsrc}}) {
			my (@rulenums, @dstsgrouped, @portsgrouped)							;
			my $portgrouphit = 0 										;
			foreach my $rashport (sort keys %{$rashizedrules3{$rashsrc}{$rashdst}}) {
				push (@portsgrouped, $rashport)								;
				foreach my $rulenum (sort keys %{$rashizedrules3{$rashsrc}{$rashdst}{$rashport}}) {
					push (@rulenums, $rulenum) 							;
				}
			}
			foreach my $rulecomp (keys %{$rashizedrules3{$rashsrc}}) {
				my @rulenumscomp = ()									;
				my @portscomp 	 = ()									;
				foreach my $portscomp (sort keys %{$rashizedrules3{$rashsrc}{$rulecomp}}) {
					push (@portscomp, $portscomp)							;
					foreach my $rulenumcomp (sort keys %{$rashizedrules3{$rashsrc}{$rulecomp}{$portscomp}}) {
						push (@rulenumscomp, $rulenumcomp) 					;
					}
				}
				next if $rashdst eq $rulecomp								;
				if (compare_arrays(\@portsgrouped, \@portscomp)) {
					$portgrouphit++									;
					push (@dstsgrouped, $rulecomp) 							;
					push (@rulenums, @rulenumscomp) 						;
				}
			}
			if ($portgrouphit >= 1 ) {
				push (@dstsgrouped, $rashdst) 								;
				my @dstssorted = sort @dstsgrouped							;
				foreach my $rulenumber (@rulenums) {
					$rashizedrules4{"@dstssorted"}{"@portsgrouped"}{$rashsrc}{$rulenumber}++ 	;
				}
			} else {
				foreach my $rulenumber (@rulenums) {
					$rashizedrules4{$rashdst}{"@portsgrouped"}{$rashsrc}{$rulenumber}++		;
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	ports grouped\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	#print "RATIONALIZED RULES 4        	\n########################################################################################################################\n\n". Dumper(%rashizedrules4) . "\n\n";
	%rashizedrules3 = (0,0)												;
	($rrcount, $rrcountholder, $rrgroupcount, $rrgroupcountholder) = (0,0,0,0)					;

	foreach my $rashdst (keys %rashizedrules4) {
		foreach my $rashport (keys %{$rashizedrules4{$rashdst}}) {
			my (@srcgroups, %rulenums)									;
			foreach my $srcgroup (sort keys %{$rashizedrules4{$rashdst}{$rashport}}) {
				push (@srcgroups, $srcgroup)								;
				foreach my $rulenum (sort keys %{$rashizedrules4{$rashdst}{$rashport}{$srcgroup}}) {
					$rulenums{$rulenum}++								;
				}
			}
			my @rulenums = sort numerically keys %rulenums							;
			$rashizedrules5{$rashport}{$rashdst}{"@srcgroups"}{"@rulenums"}++ 				;
		}
	}
	#print "RATIONALIZED RULES 5        	\n########################################################################################################################\n\n". Dumper(%rashizedrules5) . "\n\n";
	%rashizedrules4 = (0,0)										;
	my $rulenumber = 0										;
	print "\n   RATIONALIZED RULES:\n\n"								;
	foreach my $rashport (sort keys %rashizedrules5) {
		foreach my $rashdst (sort keys %{$rashizedrules5{$rashport}}) {
			foreach my $rashsrc (sort keys %{$rashizedrules5{$rashport}{$rashdst}}) {
				foreach my $rashnum (sort keys %{$rashizedrules5{$rashport}{$rashdst}{$rashsrc}}) {
					$rulenumber++								;
					print "Rule: $rulenumber, $rashsrc, $rashdst, $rashport, $rashnum\n"		;	
					$lastrashrulebase{"$rashsrc,$rashdst,$rashport,$rashnum"} = $rulenumber	;
					$lastrashprintbase{$rulenumber} = "$rashsrc,$rashdst,$rashport,$rashnum"	;
				}
			}
		}
	}
	foreach my $configgroup (keys %resobjgroups) {
		foreach my $grpobj (keys %{$srcbundle_ref->{'netgroupobjs'}{$configgroup}}) {
			$resobjects{$grpobj}++;
		}
	}
	foreach my $configsrvcgroup (keys %ressrvcgroups) {
		foreach my $grpobj (keys %{$srcbundle_ref->{'srvcgroupobjs'}{$configsrvcgroup}}) {
			$ressrvcs{$grpobj}++;
		}
	}
	return (\%lastrashrulebase, \%lastrashprintbase, \%resobjects, \%ressrvcs, \%resobjgroups, \%ressrvcgroups);
}

sub build_rules {
	my ($rashlogfilter_ref, $srcbundle_ref, $dstbundle_ref) = @_;
	my (%lastrashrulebase, %lastrashprintbase, %resobjects, %ressrvcs, %resobjgroups, %ressrvcgroups);
	
	print "-----------------------------------------------------------------------------------------\n";
	print " STARTING RULE COMPARISON: \n";
	print "   rationalizing rulebase FILTERED - RULEGROUP SPECIFFIC - SUBROUTE MODE!\n";

	my (%rationizedrules, %rashizedrules, %rashizedrules2, %rashizedrules3, %rashizedrules4, %rashizedrules5, $rrgroupcount, $rrgroupcountholder, $rrcount, $rrcountholder);
	($rrgroupcount, $rrgroupcountholder, $rrcount, $rrcountholder) = (0,0,0,0);

	foreach my $rashport (keys %{$rashlogfilter_ref}) {
		foreach my $rashdst (keys %{$rashlogfilter_ref->{$rashport}}) {
			my @seengroups;
			
			foreach my $groupname (keys %{$srcbundle_ref->{'bingroups'}}) {
				my ($match, $miss) = (0,0);
				my (%match, %miss) ;
				
				foreach my $gbin (keys %{$srcbundle_ref->{'bingroups'}{$groupname}}) {
					$rrgroupcount++;
					if (exists $rashlogfilter_ref->{$rashport}{$rashdst}{$gbin}) {
						$match++ ;	 
						$match{$gbin}++ ;
					} else {
						$miss++ ;	 
						$miss{$gbin}++ ;
					}
				}
				if ($miss < 1 ) {
					push (@seengroups, $groupname) ;
				}
			}
			if ($rrgroupcount >= ($rrgroupcountholder + 1000000)) {
				print "....................................................$rrgroupcount	src group comparisons made\n"	;
				$rrgroupcountholder = $rrgroupcount;
			}
			my %matchgroupbins;
			for (@seengroups) {
				$resobjgroups{$_}++;
				foreach my $grpbin (keys %{$srcbundle_ref->{'bingroups'}{$_}}) {
					$matchgroupbins{$grpbin} = $_;
				}
			}

			foreach my $rashsrc (keys %{$rashlogfilter_ref->{$rashport}{$rashdst}}) {
				foreach my $rulenum (keys %{$rashlogfilter_ref->{$rashport}{$rashdst}{$rashsrc}}) {
					$rrcount++;
					if (exists $matchgroupbins{$rashsrc}) {
						$rashizedrules{$rashport}{$matchgroupbins{$rashsrc}}{$rashdst}{$rulenum}++;
					#} elsif (exists $destbundle_ref->{'ips'}{$rashsrc}) {
					#	$rashizedrules{$rashport}{$destbundle_ref->{'ips'}{$rashsrc}{'name'}}{$rashdst}{$rulenum}++;
					} elsif (exists $srcbundle_ref->{'ips'}{$rashsrc}) {
						$rashizedrules{$rashport}{$srcbundle_ref->{'ips'}{$rashsrc}{'name'}}{$rashdst}{$rulenum}++;
						$resobjects{$srcbundle_ref->{'ips'}{$rashsrc}{'name'}}++;
					} else {
						print "OOOOWHAKAOOOOWHAKA\n";
					}
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	rule sources simplified\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	#print "RATIONALIZED RULES         	\n########################################################################################################################\n\n". Dumper(%rashizedrules) . "\n\n";
	print "   sources rationalized.............................DONE!\n"			;
	($rrcount, $rrcountholder, $rrgroupcount, $rrgroupcountholder) = (0,0,0,0)	;
	#%rashrulegroups = ();

	foreach my $rashport2 (keys %rashizedrules) {
		foreach my $rashsrc2 (keys %{$rashizedrules{$rashport2}}) {
			my @seengroups;
			
			foreach my $groupname (keys %{$srcbundle_ref->{'bingroups'}}) {
				my ($match, $miss) = (0,0);
				my (%match, %miss) ;
				
				foreach my $gbin (keys %{$srcbundle_ref->{'bingroups'}{$groupname}}) {
					$rrgroupcount++;
					if (exists $rashizedrules{$rashport2}{$rashsrc2}{$gbin}) {
						$match++ ;	 
						$match{$gbin}++ ;
					} else {
						$miss++ ;	 
						$miss{$gbin}++ ;
					}
				}
				if ($miss < 1 ) {
					push (@seengroups, $groupname) ;
				}
			}
			if ($rrgroupcount >= ($rrgroupcountholder + 1000000)) {
				print "....................................................$rrgroupcount	dst group comparisons made\n"	;
				$rrgroupcountholder = $rrgroupcount;
			}
			my %matchgroupbins;
			for (@seengroups) {
				$resobjgroups{$_}++;
				foreach my $grpbin (keys %{$srcbundle_ref->{'bingroups'}{$_}}) {
					$matchgroupbins{$grpbin} = $_;
				}
			}

			foreach my $rashdst2 (keys %{$rashizedrules{$rashport2}{$rashsrc2}}) {
				foreach my $rulenum2 (keys %{$rashizedrules{$rashport2}{$rashsrc2}{$rashdst2}}) {
					$rrcount++;
					if (exists $matchgroupbins{$rashdst2}) {
						$rashizedrules2{$matchgroupbins{$rashdst2}}{$rashsrc2}{$rashport2}{$rulenum2}++;
					#} elsif (exists $destbundle_ref->{'ips'}{$rashdst2}) {
					#	$rashizedrules2{$destbundle_ref->{'ips'}{$rashdst2}{'name'}}{$rashsrc2}{$rashport2}{$rulenum2}++;
					} elsif (exists $srcbundle_ref->{'ips'}{$rashdst2}) {
						$rashizedrules2{$srcbundle_ref->{'ips'}{$rashdst2}{'name'}}{$rashsrc2}{$rashport2}{$rulenum2}++;
						$resobjects{$srcbundle_ref->{'ips'}{$rashdst2}{'name'}}++;
					} else {
						print "NNOOOWONG\n";
					}
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	rule destinations simplified\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	#print "RATIONALIZED RULES         	\n########################################################################################################################\n\n". Dumper(%rashizedrules2) . "\n\n";
	print "   dests rationalized...............................DONE!\n"			;
	%rashizedrules = ()								;
	($rrcount, $rrcountholder, $rrgroupcount, $rrgroupcountholder) = (0,0,0,0)	;

	foreach my $rashdst3 (keys %rashizedrules2) {
		foreach my $rashsrc3 (keys %{$rashizedrules2{$rashdst3}}) {
			my @seengroups;
			
			foreach my $groupname (keys %{$srcbundle_ref->{'portgroups'}}) {
				my ($match, $miss) = (0,0);
				my (%match, %miss) ;
				
				foreach my $gport (keys %{$srcbundle_ref->{'portgroups'}{$groupname}}) {
					$rrgroupcount++;
					if (exists $rashizedrules2{$rashdst3}{$rashsrc3}{$gport}) {
						$match++ ;	 
						$match{$gport}++ ;
					} else {
						$miss++ ;	 
						$miss{$gport}++ ;
					}
				}
				if ($miss < 1 ) {
					push (@seengroups, $groupname) ;
				}
			}
			if ($rrgroupcount >= ($rrgroupcountholder + 1000000)) {
				print "....................................................$rrgroupcount	port group comparisons made\n"	;
				$rrgroupcountholder = $rrgroupcount;
			}
			my %matchgroupports;
			for (@seengroups) {
				$ressrvcgroups{$_}++;
				foreach my $grpport (keys %{$srcbundle_ref->{'portgroups'}{$_}}) {
					$matchgroupports{$grpport} = $_;
				}
			}

			foreach my $rashport3 (keys %{$rashizedrules2{$rashdst3}{$rashsrc3}}) {
				foreach my $rulenum3 (keys %{$rashizedrules2{$rashdst3}{$rashsrc3}{$rashport3}}) {
					$rrcount++;
					my ($protoc, $porty) = split (/\~/, $rashport3) ;

					if (exists $matchgroupports{$rashport3}) {
						$rashizedrules3{$matchgroupports{$rashport3}}{$rashdst3}{$rashsrc3}{$rulenum3}++;
					} elsif (exists $srcbundle_ref->{'ports'}{$protoc}) {
						if (exists $srcbundle_ref->{'ports'}{$protoc}{$porty}) {
							$rashizedrules3{$srcbundle_ref->{'ports'}{$protoc}{$porty}{'name'}}{$rashdst3}{$rashsrc3}{$rulenum3}++;
							$ressrvcs{$srcbundle_ref->{'ports'}{$protoc}{$porty}{'name'}}++;
						} else {
							$rashizedrules3{$porty}{$rashdst3}{$rashsrc3}{$rulenum3}++;
							print "MOMOMOMOMO $protoc, $porty\n";
						}
					} else {
						$rashizedrules3{$porty}{$rashdst3}{$rashsrc3}{$rulenum3}++;
						print "WOWOWOWOWOW $protoc, $porty\n";
					}
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	rule ports simplified\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	#print "RATIONALIZED RULES PRE        	\n########################################################################################################################\n\n". Dumper(%rashizedrules3) . "\n\n";
	print "   ports rationalized...............................DONE!\n"						;
	%rashizedrules2 = ()												;
	($rrcount, $rrcountholder, $rrgroupcount, $rrgroupcountholder) = (0,0,0,0)					;

	foreach my $rashport4 (keys %rashizedrules3) {
		foreach my $rashdst4 (keys %{$rashizedrules3{$rashport4}}) {
			my (@rulenums, @srcsgrouped, @dstsgrouped)							;
			my $dstgrouphit = 0 										;
			foreach my $rashsrc4 (sort keys %{$rashizedrules3{$rashport4}{$rashdst4}}) {
				push (@srcsgrouped, $rashsrc4)								;
				foreach my $rulenum4 (sort keys %{$rashizedrules3{$rashport4}{$rashdst4}{$rashsrc4}}) {
					push (@rulenums, $rulenum4) 							;
				}
			}
			foreach my $rulecomp (keys %{$rashizedrules3{$rashport4}}) {
				my @rulenumscomp = ()									;
				my @srcscomp 	 = ()									;
				foreach my $srcscomp (sort keys %{$rashizedrules3{$rashport4}{$rulecomp}}) {
					push (@srcscomp, $srcscomp)							;
					foreach my $rulenumcomp4 (sort keys %{$rashizedrules3{$rashport4}{$rulecomp}{$srcscomp}}) {
						push (@rulenumscomp, $rulenumcomp4) 					;
					}
				}
				next if $rashdst4 eq $rulecomp								;
				if (compare_arrays(\@srcsgrouped, \@srcscomp)) {
					$dstgrouphit++									;
					push (@dstsgrouped, $rulecomp) 							;
					push (@rulenums, @rulenumscomp) 						;
				}
			}
			if ($dstgrouphit >= 1 ) {
				push (@dstsgrouped, $rashdst4) 								;
				my @dstssorted = sort @dstsgrouped							;
				foreach my $rulenumber (@rulenums) {
					$rashizedrules4{"@srcsgrouped"}{"@dstssorted"}{$rashport4}{$rulenumber}++ 	;
				}
			} else {
				foreach my $rulenumber (@rulenums) {
					$rashizedrules4{"@srcsgrouped"}{$rashdst4}{$rashport4}{$rulenumber}++		;
				}
			}
			if ($rrcount >= ($rrcountholder + 25000)) {
				print "....................................................$rrcount	ports grouped\n"	;
				$rrcountholder = $rrcount;
			}
		}
	}
	#print "RATIONALIZED RULES 4        	\n########################################################################################################################\n\n". Dumper(%rashizedrules4) . "\n\n";
	%rashizedrules3 = (0,0)												;
	($rrcount, $rrcountholder, $rrgroupcount, $rrgroupcountholder) = (0,0,0,0)					;

	foreach my $rashsrc5 (keys %rashizedrules4) {
		foreach my $rashdst5 (keys %{$rashizedrules4{$rashsrc5}}) {
			my (@portgroups, %rulenums)									;
			foreach my $portgroup (sort keys %{$rashizedrules4{$rashsrc5}{$rashdst5}}) {
				push (@portgroups, $portgroup)								;
				foreach my $rulenum5 (sort keys %{$rashizedrules4{$rashsrc5}{$rashdst5}{$portgroup}}) {
					$rulenums{$rulenum5}++								;
				}
			}
			my @rulenums = sort numerically keys %rulenums							;
			$rashizedrules5{"@portgroups"}{$rashdst5}{$rashsrc5}{"@rulenums"}++ 				;
		}
	}
	#print "RATIONALIZED RULES 5        	\n########################################################################################################################\n\n". Dumper(%rashizedrules5) . "\n\n";
	%rashizedrules4 = (0,0)										;
	my $rulenumber = 0										;
	print "\n   RATIONALIZED RULES:\n\n"								;
	foreach my $rashport6 (sort keys %rashizedrules5) {
		foreach my $rashdst6 (sort keys %{$rashizedrules5{$rashport6}}) {
			foreach my $rashsrc6 (sort keys %{$rashizedrules5{$rashport6}{$rashdst6}}) {
				foreach my $rashnum6 (sort keys %{$rashizedrules5{$rashport6}{$rashdst6}{$rashsrc6}}) {
					$rulenumber++								;
					print "Rule: $rulenumber, $rashsrc6, $rashdst6, $rashport6, $rashnum6\n"		;	
					$lastrashrulebase{"$rashsrc6,$rashdst6,$rashport6,$rashnum6"} = $rulenumber	;
					$lastrashprintbase{$rulenumber} = "$rashsrc6,$rashdst6,$rashport6,$rashnum6"	;
				}
			}
		}
	}
	foreach my $configgroup (keys %resobjgroups) {
		foreach my $grpobj (keys %{$srcbundle_ref->{'netgroupobjs'}{$configgroup}}) {
			$resobjects{$grpobj}++;
		}
	}
	foreach my $configsrvcgroup (keys %ressrvcgroups) {
		foreach my $grpobj (keys %{$srcbundle_ref->{'srvcgroupobjs'}{$configsrvcgroup}}) {
			$ressrvcs{$grpobj}++;
		}
	}
	return (\%lastrashrulebase, \%lastrashprintbase, \%resobjects, \%ressrvcs, \%resobjgroups, \%ressrvcgroups);
}
sub output_cisco_and_csv_file {
	my ($srcbundle_ref, $dstbundle_ref, $srcconfigobjs_ref, $srcconfigsrvcs_ref, $srcconfiggroups_ref, $srcconfigsrvcgroups_ref, $lastrashprintbase_ref, $ruleoutswitch) = @_;
	my $filename								;
	my $rulefile = 'cisco.cisco'						;
	my $destrulebase							;
	my %netobjxlates							;
	my %multinetobjs							;
	my %srvcobjxlates							;
	print "-----------------------------------------------------------------------------------------\n";
	print " OUTPUT ODUMPER CSV AND CISCO ASA CMD TEXT TO SCREEN:\n";

	print "\n	Enter the name of the file to be saved: "		;
	while (<STDIN>) {
		chomp($_) 							;
		if ($_ eq '') {
			print "\n 	ERROR: type a filename\n"		;
		} elsif (-e "$_") {
			print "\n	ERROR: file exists\n"			;
		} else {
			$filename = $_						;
			last							;
		}
	}
	print "\n	Enter the name of the access-list to write rules to: "	;
	while (<STDIN>) {
		chomp								;
		next if $_ eq ''						;
		$destrulebase = $_						;
		last;
	}
	print "\n\n"								;

	open (LASTRASH, ">$filename")						;

	my %sourceobjprint = ()							;
	my %ciscoobjprint = ()							;
	my %ciscosrvcprint = ()							;
	foreach my $ruleobj (sort keys %{$srcconfigobjs_ref}) {
		foreach my $ipbin (sort keys %{$srcbundle_ref->{'netobjects'}{$ruleobj}{'ipbin'}}) {
			my $ruleobjout;
			my $destobjstring = ' ';
			my $description = ' ';
			my $colour = 'blue';

		# NOTE: check if the object name exists in the destination config and note it if the ip matches, no transation needed objects is the same

		# NOTE: check if its a range or translate and print

			if ($srcbundle_ref->{'netobjects'}{$ruleobj}{'type'} eq 'range') {
				my $rangecount = 0;
				my $ipstart 		= $srcbundle_ref->{'netobjects'}{$ruleobj}{'rangestart'};
				my $ipend 		= $srcbundle_ref->{'netobjects'}{$ruleobj}{'rangeend'};
				if (exists $dstbundle_ref->{'netobjects'}{$ruleobj} && ($dstbundle_ref->{'netobjects'}{$ruleobj}{'type'} eq 'range')) {
					if (($srcbundle_ref->{'netobjects'}{$ruleobj}{'rangestart'} eq $dstbundle_ref->{'netobjects'}{$ruleobj}{'rangestart'}) && 
					    ($srcbundle_ref->{'netobjects'}{$ruleobj}{'rangeend'}   eq $dstbundle_ref->{'netobjects'}{$ruleobj}{'rangeend'}  )) {
						$destobjstring = "$destobjstring TRANSLATED Range Object: $ruleobj matches the RANGE of $dstbundle_ref->{'netobjects'}{$ruleobj}{'type'} $ruleobj EXACTLY";
					} 
				}
				if (exists $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'} && defined($srcbundle_ref->{'netobjects'}{$ruleobj}{'description'})) {
					$description = $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'};
					$description =~ s'"''g;
					$description =~ s',''g;
				}
				$ciscoobjprint{"object network $ruleobj\n range $ipstart $ipend\n description $description $colour $destobjstring"}++;
				$sourceobjprint{"$ruleobj,$srcbundle_ref->{'netobjects'}{$ruleobj}{'type'},$ipstart,$ipend,$srcbundle_ref->{'netobjects'}{$ruleobj}{'colour'},,,,$description $destobjstring"}++; 
				next;

			} elsif (exists $dstbundle_ref->{'netobjects'}{$ruleobj}) {
				$destobjstring = "Matching object name in dest config: $ruleobj";
				unless ($srcbundle_ref->{'netobjects'}{$ruleobj}{'type'} eq $dstbundle_ref->{'netobjects'}{$ruleobj}{'type'}) {
					$destobjstring = "$destobjstring TYPE MISMATCH: src $srcbundle_ref->{'netobjects'}{$ruleobj}{'type'} dst $dstbundle_ref->{'netobjects'}{$ruleobj}{'type'}";
				}
				unless (exists $dstbundle_ref->{'netobjects'}{$ruleobj}{'ipbin'}{$ipbin}) {
					$destobjstring = "$destobjstring IP MISMATCH: src $srcbundle_ref->{'netobjects'}{$ruleobj}{'ip'} dst $dstbundle_ref->{'netobjects'}{$ruleobj}{'ip'}";
				}

		# NOTE: translation  based on IP

			} elsif ((exists $dstbundle_ref->{'ips'}{$ipbin}) && ($ruleobj ne $dstbundle_ref->{'ips'}{$ipbin}{'name'})) {
				my $destobjname = $dstbundle_ref->{'ips'}{$ipbin}{'name'};
				$netobjxlates{$ruleobj}{'xlate'} = $destobjname;
				$destobjstring = "$destobjstring TRANSLATED Object: $ruleobj matches the IP of $dstbundle_ref->{'netobjects'}{$destobjname}{'type'} $destobjname";
			} elsif (exists $dstbundle_ref->{'ips'}{$ipbin}) {
				my $destobjname = $dstbundle_ref->{'ips'}{$ipbin}{'name'};
				$netobjxlates{$ruleobj}{'xlate'} = $destobjname;
				$destobjstring = "$destobjstring TRANSLATED LOOSE Object: $ruleobj matches the IP of $dstbundle_ref->{'netobjects'}{$destobjname}{'type'} $destobjname";
			}

			if (exists $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'} && defined($srcbundle_ref->{'netobjects'}{$ruleobj}{'description'})) {
				$description = $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'};
				$description =~ s'"''g;
				$description =~ s',''g;
			}
			if (exists $srcbundle_ref->{'netobjects'}{$ruleobj}{'colour'}) {
				$colour = $srcbundle_ref->{'netobjects'}{$ruleobj}{'colour'};
			}
			if (exists $netobjxlates{$ruleobj}) {
				$ruleobjout = $netobjxlates{$ruleobj}{'xlate'};
			} else {
				$ruleobjout = $ruleobj;
			}
			$sourceobjprint{"$ruleobjout,$srcbundle_ref->{'netobjects'}{$ruleobj}{'type'},$srcbundle_ref->{'netobjects'}{$ruleobj}{'ip'},$srcbundle_ref->{'netobjects'}{$ruleobj}{'nm'},$colour,,,,$description $destobjstring"}++;
			if ($srcbundle_ref->{'netobjects'}{$ruleobj}{'nm'} eq '255.255.255.255') {
				$ciscoobjprint{"name $srcbundle_ref->{'netobjects'}{$ruleobj}{'ip'} $ruleobjout description $description $colour $destobjstring"}++;
				$ciscoobjprint{"object network $ruleobjout\n host $srcbundle_ref->{'netobjects'}{$ruleobj}{'ip'}\n description $description $colour $destobjstring"}++;
			} else {
				$ciscoobjprint{"object network $ruleobjout\n subnet $srcbundle_ref->{'netobjects'}{$ruleobj}{'ip'} $srcbundle_ref->{'netobjects'}{$ruleobj}{'nm'}\n description $description $colour $destobjstring"}++;
				#$multinetobjs{$ruleobjout}{'translated'}++;
#			} else {
#				print "   WARNING: Object $ruleobj has been missed by the Cisco ASA object writer\n";
			}
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
	} 
	foreach my $printline (sort keys %ciscoobjprint) {
		print "$printline\n";
	} 
	foreach my $multiobj (sort keys %multinetobjs) {
		if (exists $multinetobjs{$multiobj}{'netobjs'}) {
			print "object-group network $multiobj\n";
			my $description = 'Migrated';
			if (exists $srcbundle_ref->{'netobjects'}{$multiobj}{'description'} && $srcbundle_ref->{'netobjects'}{$multiobj}{'description'} ne "") {
				$description = $srcbundle_ref->{'netobjects'}{$multiobj}{'description'};
				$description =~ s/\"//g;
				$description =~ s',''g;
				print "!! Description: $description\"\n"; 
			}
			foreach my $netobj (sort keys %{$multinetobjs{$multiobj}{'netobjs'}}) {
				print " network-object host $netobj\n"; 
			}
		}
	}

	%sourceobjprint = ();
	my %multisrvcobjs;
	foreach my $srvcname (sort keys %{$srcconfigsrvcs_ref}) {
		if ($srvcname =~ /^any$|^Any$/) { next ;}
		if ($srvcname eq "") { print "   ## WARNING: EMPTY SERVICE FOUND\n";}
		unless (defined($srvcname)) { print "   ## WARNING: EMPTY SERVICE UNDEFINED\n"; next;}
		foreach my $proto (sort keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}}) {
			foreach my $port (sort keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}}) {
				my $srvcnameout;
				my $destobjstring = ' ';
				my $description   = 'Migrated';
				my $colour   	  = 'black';

			# NOTE: check if this service name exists in the destination config bundle, and weather its type and ports exist in the object with the same name

				if (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}) {
					$destobjstring = "Matching object name in dest config: $srvcname";
					unless ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} eq $dstbundle_ref->{'srvcobjects'}{$srvcname}{'type'}) {
						$destobjstring = "$destobjstring TYPE MISMATCH: src $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} dst $dstbundle_ref->{'srvcobjects'}{$srvcname}{'type'}";
					}
					unless ((exists $dstbundle_ref->{'srvcobjects'}{$srvcname}) && (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}) && (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}{$port})) {
						$destobjstring = "$destobjstring PORT MISMATCH: src $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} dst $dstbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto}";
					}
				}

			# NOTE: translate port based on proto and port as well as checking that the destination object has the same number of ports

				if ((exists $dstbundle_ref->{'ports'}{$proto}) && (exists $dstbundle_ref->{'ports'}{$proto}{$port}) && ($srvcname ne $dstbundle_ref->{'ports'}{$proto}{$port}{'name'})) {
					my $destobjname = $dstbundle_ref->{'ports'}{$proto}{$port}{'name'} ;
					if ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} eq $dstbundle_ref->{'srvcobjects'}{$destobjname}{'port'}{$proto}) {
						$srvcobjxlates{$srvcname}{'xlate'} = $destobjname; 
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname and has been EXACTLY TRANSLATED";
					} elsif ((scalar keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}}) == (scalar keys %{$dstbundle_ref->{'srvcobjects'}{$destobjname}{'ports'}{$proto}})) {
						$srvcobjxlates{$srvcname}{'xlate'} = $destobjname; 
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname and has been TRANSLATED";
					} else {
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname not xlated ";
					}
				} elsif ((exists $dstbundle_ref->{'ports'}{$proto}) && (exists $dstbundle_ref->{'ports'}{$proto}{$port}) && ($srvcname eq $dstbundle_ref->{'ports'}{$proto}{$port}{'name'})) {
					$destobjstring = "$destobjstring EXACTLY";
				}

			# NOTE: copy description and colour

				if (exists $srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'} && defined($srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'})) {
					$description = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'};
					$description =~ s'"''g;
					$description =~ s',''g;
				}
				if (exists $srcbundle_ref->{'srvcobjects'}{$srvcname}{'colour'}) {
					$colour = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'colour'};
				}
			# NOTE: translate object if it was matched sufficiently in the destination config

				if (exists $srvcobjxlates{$srvcname}) {
					$srvcnameout = $srvcobjxlates{$srvcname}{'xlate'};
				} else {
					$srvcnameout = $srvcname;
				}
				if ($srvcnameout eq "") { print "   ## WARNING: EMPTY SSERVICE OUT ORIG SERVICE: $srvcname\n"; }
				unless (defined($srvcnameout)) { print "   ## WARNING: UNDEFINED SSERVICE OUT ORIG SERVICE: $srvcname\n"; next; }
				$sourceobjprint{"$srvcnameout,$srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'},$srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto},,$colour,,,,$description $destobjstring"}++;
				if ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} =~ m/^\d+\-\d+$/) {
					my ($rangestart, $rangeend) = split ('-', $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto});
					$ciscosrvcprint{"object service $srvcnameout\n service $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} destination range $rangestart $rangeend\n description $description $colour $destobjstring"}++;
					#$multisrvcobjs{$srvcnameout}{'translated'}++;
				} elsif ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} =~ m/^\<\d+$/) {
					my ($dummy, $origport) = split ('<', $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto});
					$ciscosrvcprint{"object service $srvcnameout \n service $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} destination lt $origport\n description $description $colour $destobjstring"}++;
					#$multisrvcobjs{$srvcnameout}{'translated'}++;
				} elsif ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} =~ m/^\>\d+$/) {
					my ($dummy, $origport) = split ('>', $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto});
					$ciscosrvcprint{"object service $srvcnameout\n service $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} destination gt $origport\n description $description $colour $destobjstring"}++;
					#$multisrvcobjs{$srvcnameout}{'translated'}++;
				} elsif ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} =~ m/^\d+$/) {
					my $portout = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto};
					$ciscosrvcprint{"object service $srvcnameout\n service $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} destination eq $portout\n description $description $colour $destobjstring"}++;
					#$multisrvcobjs{$srvcnameout}{'translated'}++;
					#next;
				} else {
					my $portout = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto};
					$ciscosrvcprint{"object service $srvcnameout $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'}\n port-object eq $portout\n description $description $colour $destobjstring"}++;
					$multisrvcobjs{$srvcnameout}{'translated'}++;
				}
			}
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
	} 
	foreach my $printline (sort keys %ciscosrvcprint) {
		print "$printline\n";
	} 

	%sourceobjprint = ();
	foreach my $ruleobj (sort keys %{$srcconfiggroups_ref}) {
		my $destobjstring = ' ';
		if (exists $srcbundle_ref->{'netgroups'}{$ruleobj}) {
			my $groupmiss = 0;
			my $grouphit  = 0;
			if (exists $dstbundle_ref->{'netgroups'}{$ruleobj}) {

				# NOTE: check if group with the same name exists 

				$destobjstring = "Matching group name in dest config: $ruleobj";
				my @srcnetgroup = keys %{$srcbundle_ref->{'netgroupobjs'}{$ruleobj}};
				my @dstnetgroup = keys %{$dstbundle_ref->{'netgroupobjs'}{$ruleobj}} ;

				if (compare_arrays(\@srcnetgroup, \@dstnetgroup)) {

					# NOTE: check if the all the objects are the same names and if the objects ips are the same

					my @srcbingroup = sort keys %{$srcbundle_ref->{'bingroups'}{$ruleobj}} ;                                                
					my @dstbingroup = sort keys %{$dstbundle_ref->{'bingroups'}{$ruleobj}} ;
					 
					#print "FOO FOO: @srcbingroup \nMOO MOO: @dstbingroup\n";

					if (compare_arrays(\@srcbingroup, \@dstbingroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: object names and IPs correct";
						#print "$destobjstring WOOOOWOOOWOOO!!!\n";
						$grouphit++;
					} else {
						$destobjstring = "$destobjstring GROUP MATCH: all object names exactly correct but IPs differ";
						$groupmiss++;
					}
				} else {
					# NOTE: else find out whats missing, src and dst being configs not traffic
				}
			} else {
				# NOTE: get the source config group binary ips and check it against each of the destination configs groups

				my @srcbingroup = sort keys %{$srcbundle_ref->{'bingroups'}{$ruleobj}} ;                                                

				foreach my $dstgrp (keys %{$dstbundle_ref->{'bingroups'}}) {
					next if $dstgrp eq $ruleobj;
					my @dstbingroup = sort keys %{$dstbundle_ref->{'bingroups'}{$dstgrp}} ;
					if (compare_arrays(\@srcbingroup, \@dstbingroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: IPs correct but object names differ $ruleobj TRANSLATED";
						#print "$destobjstring FFFFFFFFFFFFFZIP!!!\n";
						$netobjxlates{$ruleobj}{'xlate'} = $dstgrp;
						$grouphit++;
					} else {
						#print "AAAAAAAAAAAAAWWWWWWWW: $dstgrp\n";
					}
				}

			}
			
			my $objcount = scalar keys %{$srcbundle_ref->{'netgroups'}{$ruleobj}};
			my @groupobjs = sort keys %{$srcbundle_ref->{'netgroupobjs'}{$ruleobj}};

			# NOTE: translate the group name if a match was found

			my $ruleobjx = $ruleobj;

			if (exists $netobjxlates{$ruleobj}) {
				$ruleobjx = $netobjxlates{$ruleobj}{'xlate'};
			} 

			print "object-group network $ruleobjx\n";
			print "!! GROUP DESCRIPTION: $destobjstring\n";

			foreach my $groupobj (@groupobjs) {

			# NOTE: translate the group MEMBER name if a match was found and ready output

				if (exists $netobjxlates{$groupobj}) {
					$groupobj = $netobjxlates{$groupobj}{'xlate'};

					if (exists $multinetobjs{$groupobj}) {
						print " group-object $groupobj\t\t!! Description: GROUPNET TRANS\n";
					} else {
						print " network-object host $groupobj\t\t!! Description: TRANSLATED\n";
					}

					$sourceobjprint{"$ruleobjx,group,$groupobj,,red,,,,TRANSLATED $destobjstring"}++;
				} else {
					if (exists $multinetobjs{$groupobj}) {
						print " group-object $groupobj\t\t!! Description: GROUPNET\n";
					} else {
						print " network-object host $groupobj\n";
					}

					$sourceobjprint{"$ruleobjx,group,$groupobj,,blue,,,,$destobjstring"}++;
				}
			}
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
	} 

	%sourceobjprint = ();
	foreach my $ruleobj (sort keys %{$srcconfigsrvcgroups_ref}) {
		my $destobjstring = ' ';
		if (exists $srcbundle_ref->{'srvcgroups'}{$ruleobj}) {
			if (exists $dstbundle_ref->{'srvcgroups'}{$ruleobj}) {

				# NOTE: check if group with the same name exists 

				$destobjstring = "Matching service group name in dest config: $ruleobj";
				my @srcnamegroup = keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
				my @dstnamegroup = keys %{$dstbundle_ref->{'srvcgroupobjs'}{$ruleobj}} ;

				if (compare_arrays(\@srcnamegroup, \@dstnamegroup)) {

					# NOTE: check if the all the objects are the same names and if the objects port and protocols are the same

					my @srcportgroup = sort keys %{$srcbundle_ref->{'portgroups'}{$ruleobj}} ;                                                
					my @dstportgroup = sort keys %{$dstbundle_ref->{'portgroups'}{$ruleobj}} ;

					if (compare_arrays(\@srcportgroup, \@dstportgroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: object names correct but IPs differ";
					} else {
						$destobjstring = "$destobjstring GROUP MISMATCH: object names correct but IPs differ";
					}
				} else {

					# NOTE: else find out whats missing, src and dst being configs not traffic
				}
			} else {
				# NOTE: get the source config group binary ips and check it against each of the destination configs groups

				foreach my $dstgrp (keys %{$dstbundle_ref->{'portgroups'}}) {
					my $srvcgrouphit  = 0;
					my $srvcgroupmiss = 0;
					next if $dstgrp eq $ruleobj;
					my @srcprotogroups = sort keys %{$srcbundle_ref->{'portgroups'}{$ruleobj}} ;                                                
					my @dstprotogroups = sort keys %{$dstbundle_ref->{'portgroups'}{$dstgrp}} ;
					if (compare_arrays(\@srcprotogroups, \@dstprotogroups)) {
						$srvcgrouphit++;
					} else { 
						$srvcgroupmiss++;
					}

					if (($srvcgrouphit > 0) && ($srvcgroupmiss < 1)) {

						$destobjstring = "$destobjstring SERVICE GROUP MATCH: Protocols and Ports correct but object names differ $ruleobj TRANSLATED";
						$srvcobjxlates{$ruleobj}{'xlate'} = $dstgrp;

					} else {
						#print "AAAAAAAAAAAAAWWWWWWWW: $dstgrp\n";
					}
				}

			}
			my ($objt) = keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
			my @grpprotos = sort keys %{$srcbundle_ref->{'srvcobjects'}{$objt}{'port'}}; 
			my $grpprotos = join('-',@grpprotos);


			my @groupobjs = sort keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
			my $ruleobjx  = $ruleobj;
			if (exists $srvcobjxlates{$ruleobj}) {
				$ruleobjx = $srvcobjxlates{$ruleobj}{'xlate'};
			}
			print "object-group service $ruleobjx $grpprotos\n";
			print "!! SERVICE GROUP DESCRIPTION: $destobjstring\n";

			foreach my $groupobj (@groupobjs) {
				if (exists $srvcobjxlates{$groupobj}) {
					$groupobj = $srvcobjxlates{$groupobj}{'xlate'};

					if (exists $multisrvcobjs{$groupobj}) {
						print " group-object $groupobj\t\t!! Description: GROUPSRVC TRANS\n";
					} else {
						print " port-object eq $groupobj\t\t!! Description: TRANSLATED\n";
					}
					$sourceobjprint{"$ruleobjx,srvgroup,$groupobj,,red,,,,TRANSLATED $destobjstring"}++;
				} else {
					if (exists $multisrvcobjs{$groupobj}) {
						print " group-object $groupobj\t\t!! Description: GROUPSRVC\n";
					} else {
						print " port-object eq $groupobj\n";
					}
					$sourceobjprint{"$ruleobjx,srvgroup,$groupobj,,forrest green,,,,$destobjstring"}++;
				}
			}
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
	} 

	#print "NET XLATE OBJECTS		\n######################################################################################################################\n\n". Dumper(%netobjxlates) . "\n\n"	;

	foreach my $num (sort numerically keys %{$lastrashprintbase_ref}) {
		my ($rsrc, $rdst, $rport, $origrnum) = split (/\,/, $lastrashprintbase_ref->{$num}) ;
		my (@srcs) 		= split (/\s+/, $rsrc) ;
		my (@dsts) 		= split (/\s+/, $rdst) ;
		my (@services) 	= split (/\s+/, $rport) ;
		my @origrulecomments	;
		my @origruleheaders 	;
		my @origrulenums	;

		if ($ruleoutswitch eq 'STANDARD') {
			@origrulenums 		= sort numerically split (/\s+/, $origrnum) ;
			foreach my $rlnum (@origrulenums) {
				push (@origrulecomments, "Rulebase $srcbundle_ref->{'rules'}{$rlnum}{'rulegroup'}: Rule $srcbundle_ref->{'rules'}{$rlnum}{'rbnum'}: $srcbundle_ref->{'rules'}{$rlnum}{'comment'} ");
				push (@origruleheaders, "Rulebase $srcbundle_ref->{'rules'}{$rlnum}{'rulegroup'}: Rule $srcbundle_ref->{'rules'}{$rlnum}{'rbnum'}: Section Title: $srcbundle_ref->{'rules'}{$rlnum}{'header'} ");
			}
		} elsif ($ruleoutswitch eq 'keepcomments') {
			push (@origrulecomments, $origrnum);
			push (@origruleheaders, ' ');
		}

		print "access-list $destrulebase remark @origrulecomments @origruleheaders\n";

		foreach my $src (sort @srcs) {
			foreach my $dst (sort @dsts) {
				foreach my $service (sort @services) {

					my $srcout = $src;

					if (exists $netobjxlates{$src} ) {
						$srcout = $netobjxlates{$src}{'xlate'};
					}
					if (exists $srcbundle_ref->{'netgroupobjs'}{$src}) {
						my ($objt) = keys %{$srcbundle_ref->{'netgroupobjs'}{$src}};
						$srcout = "object-group $srcout";
					} elsif ((exists $srcbundle_ref->{'netobjects'}{$src}) && (exists $srcbundle_ref->{'netobjects'}{$src}{'nm'}) && ($srcbundle_ref->{'netobjects'}{$src}{'nm'} eq '255.255.255.255')) {
						$srcout = "host $srcout";
					} elsif ((exists $srcbundle_ref->{'netobjects'}{$src}) && (exists $srcbundle_ref->{'netobjects'}{$src}{'nm'}) && (is_netmask($srcbundle_ref->{'netobjects'}{$src}{'nm'}))) {
						$srcout = "$srcout $srcbundle_ref->{'netobjects'}{$src}{'nm'}";
					} elsif (exists $srcbundle_ref->{'netobjects'}{$src}) {
						$srcout = "object $srcout";
					} elsif (exists $multinetobjs{$src}) {
						$srcout = "object-group $srcout";
					} elsif ($src =~ /^Any$|^any$|^ANY$/) {
						$srcout = "any";
					}

					my $dstout = $dst;

					if (exists $netobjxlates{$dst} ) {
						$dstout = $netobjxlates{$dst}{'xlate'};
					}
					if (exists $srcbundle_ref->{'netgroupobjs'}{$dst}) {
						my ($objt) = keys %{$srcbundle_ref->{'netgroupobjs'}{$dst}};
						$dstout = "object-group $dstout";
					} elsif ((exists $srcbundle_ref->{'netobjects'}{$dst}) && (exists $srcbundle_ref->{'netobjects'}{$dst}{'nm'}) && ($srcbundle_ref->{'netobjects'}{$dst}{'nm'} eq '255.255.255.255')) {
						$dstout = "host $dstout";
					} elsif ((exists $srcbundle_ref->{'netobjects'}{$dst}) && (exists $srcbundle_ref->{'netobjects'}{$dst}{'nm'}) && (is_netmask($srcbundle_ref->{'netobjects'}{$dst}{'nm'}))) {
						$dstout = "$dstout $srcbundle_ref->{'netobjects'}{$dst}{'nm'}";
					} elsif (exists $srcbundle_ref->{'netobjects'}{$dst}) {
						$dstout = "object $dstout";
					} elsif (exists $multinetobjs{$dst}) {
						$dstout = "object-group $dstout";
					} elsif ($dst =~ /^Any$|^any$|^ANY$/) {
						$dstout = "any";
					}

					my $grpprotos;
					my $port;
					my $srvcout = $service;

					if (exists $multisrvcobjs{$service}) {
						my @grpprotos = sort keys %{$srcbundle_ref->{'srvcobjects'}{$service}{'port'}}; 
						foreach my $prt (@grpprotos) {
							$port = $srcbundle_ref->{'srvcobjects'}{$service}{'port'}{$prt};
						} 
						$grpprotos = join('-',@grpprotos);
						$srvcout = "object-group $srvcout";

					} elsif (exists $srcbundle_ref->{'srvcgroupobjs'}{$service}) {
						my ($objt) = keys %{$srcbundle_ref->{'srvcgroupobjs'}{$service}};
						my @grpprotos = sort keys %{$srcbundle_ref->{'srvcobjects'}{$objt}{'port'}}; 
						$grpprotos    = join('-',@grpprotos);
						if (exists $srvcobjxlates{$service}) {
							$srvcout = $srvcobjxlates{$service}{'xlate'};
						}
						$srvcout = "object-group $srvcout";
					} elsif (exists $srcbundle_ref->{'srvcobjects'}{$service}) {
						my @grpprotos = sort keys %{$srcbundle_ref->{'srvcobjects'}{$service}{'port'}}; 
						foreach my $prt (@grpprotos) {
							$port = $srcbundle_ref->{'srvcobjects'}{$service}{'port'}{$prt};
						} 
						if (exists $srvcobjxlates{$service}) {
							$srvcout = $srvcobjxlates{$service}{'xlate'};
						}
						$grpprotos = join('-',@grpprotos);
						$srvcout = "eq $srvcout";
					}

					print "access-list $destrulebase extended permit $grpprotos $srcout $dstout $srvcout log\n";
				}
			}
		}
	}
	close LASTRASH	;
	print "\n\n-----------------------------------------------------------------------------------------\n";
	print "  	FILE: $filename WRITTEN  !!*%*%*-WAHOO-*%*%*!!\n";
	print "-----------------------------------------------------------------------------------------\n\n";
}
sub output_odumper_csv_file {
	my ($srcbundle_ref, $dstbundle_ref, $srcconfigobjs_ref, $srcconfigsrvcs_ref, $srcconfiggroups_ref, $srcconfigsrvcgroups_ref, $lastrashprintbase_ref, $ruleoutswitch) = @_;
	my $filename								;
	my $rulefile = 'dbedit.dbedit'					;
	my $destrulebase							;
	my %netobjxlates							;
	my %srvcobjxlates							;
	print "-----------------------------------------------------------------------------------------\n";
	print " OUTPUT ODUMPER AND DBEDIT TEXT:\n";

	print "\n	Enter the name of the CSV file to be saved: "		;
	while (<STDIN>) {
		chomp($_) 							;
		if ($_ eq '') {
			print "\n 	ERROR: type a filename\n"		;
		} elsif (-e "$_") {
			print "\n	ERROR: file exists\n"			;
		} else {
			$filename = $_						;
			last							;
		}
	}
	print "\n	Enter the name of the dbedit file to be saved: "	;
	while (<STDIN>) {
		chomp($_) 							;
		if ($_ eq '') {
			print "\n 	ERROR: type a filename\n"		;
		} elsif (-e "$_") {
			print "\n	ERROR: file exists\n"			;
		} else {
			$rulefile = $_						;
			last							;
		}
	}
	print "\n	Enter the name of the Checkpoint FW-1 RULEBASE to write rules to: "	;
	while (<STDIN>) {
		chomp								;
		next if $_ eq ''						;
		$destrulebase = $_						;
		last;
	}
	print "\n\n"								;

	open (LASTRASH, ">$filename")						;
	open (DBEDIT, ">$rulefile")						;

	my %sourceobjprint = ()							;
	foreach my $ruleobj (sort keys %{$srcconfigobjs_ref}) {
		foreach my $ipbin (sort keys %{$srcbundle_ref->{'netobjects'}{$ruleobj}{'ipbin'}}) {
			my $ruleobjout;
			my $destobjstring = ' ';
			my $description = ' ';
			my $colour = 'blue';
			my $transout = 'no';

		# NOTE: check if the object name exists in the destination config and note it if the ip matches, no transation needed objects is the same

			if (exists $dstbundle_ref->{'netobjects'}{$ruleobj}) {
				$destobjstring = "Matching object name in dest config: $ruleobj";
				#unless (exists $dstbundle_ref->{'netobjects'}{$ruleobj}{'type'}) {
				#	print "$ruleobj}{'type'}\n";
				#}
				unless ($srcbundle_ref->{'netobjects'}{$ruleobj}{'type'} eq $dstbundle_ref->{'netobjects'}{$ruleobj}{'type'}) {
					$destobjstring = "$destobjstring TYPE MISMATCH: src $srcbundle_ref->{'netobjects'}{$ruleobj}{'type'} dst $dstbundle_ref->{'netobjects'}{$ruleobj}{'type'}";
				}
				unless (exists $dstbundle_ref->{'netobjects'}{$ruleobj}{'ipbin'}{$ipbin}) {
					$destobjstring = "$destobjstring IP MISMATCH: src $srcbundle_ref->{'netobjects'}{$ruleobj}{'ip'} dst $dstbundle_ref->{'netobjects'}{$ruleobj}{'ip'}";
				}
			}

		# NOTE: translation  based on IP

			if ((exists $dstbundle_ref->{'ips'}{$ipbin}) && ($ruleobj ne $dstbundle_ref->{'ips'}{$ipbin}{'name'})) {
				my $destobjname = $dstbundle_ref->{'ips'}{$ipbin}{'name'};
				$netobjxlates{$ruleobj}{'xlate'} = $destobjname;
				$destobjstring = "$destobjstring TRANSLATED Object: $ruleobj matches the IP of $dstbundle_ref->{'netobjects'}{$destobjname}{'type'} $destobjname";
			} elsif (exists $dstbundle_ref->{'ips'}{$ipbin}) {
				my $destobjname = $dstbundle_ref->{'ips'}{$ipbin}{'name'};
				$netobjxlates{$ruleobj}{'xlate'} = $destobjname;
				$destobjstring = "$destobjstring TRANSLATED LOOSE Object: $ruleobj matches the IP of $dstbundle_ref->{'netobjects'}{$destobjname}{'type'} $destobjname";
			}
		# NOTE: check if its a range or translate and print

			if ($srcbundle_ref->{'netobjects'}{$ruleobj}{'type'} eq 'range') {
				if (exists $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'} && defined($srcbundle_ref->{'netobjects'}{$ruleobj}{'description'})) {
					$description = $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'};
					$description =~ s'"''g;
					$description =~ s',''g;
				}
				if (exists $srcbundle_ref->{'netobjects'}{$ruleobj}{'colour'}) {
					$colour = $srcbundle_ref->{'netobjects'}{$ruleobj}{'colour'};
				}
				if (exists $netobjxlates{$ruleobj}) {
					$ruleobjout = $netobjxlates{$ruleobj}{'xlate'};
					$transout   = 'yes';
				} else {
					$ruleobjout = $ruleobj;
					$transout   = 'no';
				}
				$sourceobjprint{"$ruleobjout,$srcbundle_ref->{'netobjects'}{$ruleobj}{'type'},$srcbundle_ref->{'netobjects'}{$ruleobj}{'rangestart'},$srcbundle_ref->{'netobjects'}{$ruleobj}{'rangeend'},$colour,,,,$description $destobjstring"} = $transout; 
			} else {
				if (exists $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'} && defined($srcbundle_ref->{'netobjects'}{$ruleobj}{'description'})) {
					$description = $srcbundle_ref->{'netobjects'}{$ruleobj}{'description'};
					$description =~ s'"''g;
					$description =~ s',''g;
				}
				if (exists $srcbundle_ref->{'netobjects'}{$ruleobj}{'colour'}) {
					$colour = $srcbundle_ref->{'netobjects'}{$ruleobj}{'colour'};
				}
				if (exists $netobjxlates{$ruleobj}) {
					$ruleobjout = $netobjxlates{$ruleobj}{'xlate'};
					$transout   = 'yes';
				} else {
					$ruleobjout = $ruleobj;
					$transout   = 'no';
				}
				$sourceobjprint{"$ruleobjout,$srcbundle_ref->{'netobjects'}{$ruleobj}{'type'},$srcbundle_ref->{'netobjects'}{$ruleobj}{'ip'},$srcbundle_ref->{'netobjects'}{$ruleobj}{'nm'},$colour,,,,$description $destobjstring"} = $transout;
			}
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
		my $transout = $sourceobjprint{$printline};
		if ($transout eq 'no') {
			my ($netobject, $type, $ip, $nm, $colour, $peram1, $peram2, $peram3, $description) = split(/\,/, $printline);
			if ($type eq 'host') {
				print DBEDIT "create host_plain $netobject\n";
				print DBEDIT "modify network_objects $netobject ipaddr $ip\n";
				print DBEDIT "modify network_objects $netobject comments \"$description\"\n";
				print DBEDIT "modify network_objects $netobject color $colour\n";
				print DBEDIT "update network_objects $netobject\n";
			} elsif ($type eq 'net') {
				print DBEDIT "create network $netobject\n";
				print DBEDIT "modify network_objects $netobject ipaddr $ip\n";
				print DBEDIT "modify network_objects $netobject netmask $nm\n";
				print DBEDIT "modify network_objects $netobject comments \"$description\"\n";
				print DBEDIT "modify network_objects $netobject color $colour\n";
				print DBEDIT "update network_objects $netobject\n";
			} elsif ($type eq 'range') {
				print DBEDIT "create address_range $netobject\n";
				print DBEDIT "modify network_objects $netobject ipaddr_first $ip\n";
				print DBEDIT "modify network_objects $netobject ipaddr_last $nm\n";
				print DBEDIT "modify network_objects $netobject comments \"$description\"\n";
				print DBEDIT "modify network_objects $netobject color $colour\n";
				print DBEDIT "update network_objects $netobject\n";
			} elsif ($type eq 'plaingw') {
				print DBEDIT "create gateway_plain $netobject\n";
				print DBEDIT "modify network_objects $netobject ipaddr $ip\n";
				print DBEDIT "modify network_objects $netobject comments \"$description\"\n";
				print DBEDIT "modify network_objects $netobject color $colour\n";
				print DBEDIT "update network_objects $netobject\n";
			} elsif ($type eq 'cluster') {
				print DBEDIT "create gateway_cluster $netobject\n";
				print DBEDIT "modify network_objects $netobject ipaddr $ip\n";
				print DBEDIT "modify network_objects $netobject comments \"$description\"\n";
				print DBEDIT "modify network_objects $netobject color $colour\n";
				print DBEDIT "update network_objects $netobject\n";
			} elsif ($type eq 'member') {
				print DBEDIT "create cluster_member $netobject\n";
				print DBEDIT "modify network_objects $netobject ipaddr $ip\n";
				print DBEDIT "modify network_objects $netobject comments \"$description\"\n";
				print DBEDIT "modify network_objects $netobject color $colour\n";
				print DBEDIT "update network_objects $netobject\n";
			} else {
				print "	MISSED OBJECT: $netobject, $type, $ip, $nm, $colour, $peram1, $peram2, $peram3, $description\n";
			} 
		}
	} 
	%sourceobjprint = ();
	foreach my $srvcname (sort keys %{$srcconfigsrvcs_ref}) {
		if ($srvcname eq "") { print "   ## WARNING: EMPTY SERVICE FOUND\n";}
		foreach my $proto (sort keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}}) {
			foreach my $port (sort keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}}) {
				my $srvcnameout;
				my $destobjstring = ' ';
				my $description   = 'Migrated';
				my $colour   	  = 'black';
				my $transout 	  = 'no';

			# NOTE: check if this service name exists in the destination config bundle, and weather its type and ports exist in the object with the same name

				if (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}) {
					$destobjstring = "Matching object name in dest config: $srvcname";
					unless ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} eq $dstbundle_ref->{'srvcobjects'}{$srvcname}{'type'}) {
						$destobjstring = "$destobjstring TYPE MISMATCH: src $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} dst $dstbundle_ref->{'srvcobjects'}{$srvcname}{'type'}";
					}
					unless ((exists $dstbundle_ref->{'srvcobjects'}{$srvcname}) && (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}) && (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}{$port})) {
						$destobjstring = "$destobjstring PORT MISMATCH: src $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} dst $dstbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto}";
					}
				}

			# NOTE: translate port based on proto and port as well as checking that the destination object has the same number of ports

				if ((exists $dstbundle_ref->{'ports'}{$proto}) && (exists $dstbundle_ref->{'ports'}{$proto}{$port}) && ($srvcname ne $dstbundle_ref->{'ports'}{$proto}{$port}{'name'})) {
					my $destobjname = $dstbundle_ref->{'ports'}{$proto}{$port}{'name'} ;
					if ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} eq $dstbundle_ref->{'srvcobjects'}{$destobjname}{'port'}{$proto}) {
						$srvcobjxlates{$srvcname}{'xlate'} = $destobjname; 
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname and has been EXACTLY TRANSLATED";
					} elsif ((scalar keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}}) == (scalar keys %{$dstbundle_ref->{'srvcobjects'}{$destobjname}{'ports'}{$proto}})) {
						$srvcobjxlates{$srvcname}{'xlate'} = $destobjname; 
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname and has been TRANSLATED";
					} else {
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname not xlated ";
					}
				} elsif ((exists $dstbundle_ref->{'ports'}{$proto}) && (exists $dstbundle_ref->{'ports'}{$proto}{$port}) && ($srvcname eq $dstbundle_ref->{'ports'}{$proto}{$port}{'name'})) {
					$destobjstring = "$destobjstring EXACTLY";
				}

			# NOTE: copy description and colour

				if (exists $srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'} && defined($srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'})) {
					$description = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'};
					$description =~ s'"''g;
					$description =~ s',''g;
				}
				if (exists $srcbundle_ref->{'srvcobjects'}{$srvcname}{'colour'}) {
					$colour = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'colour'};
				}
			# NOTE: translate object if it was matched sufficiently in the destination config

				if (exists $srvcobjxlates{$srvcname}) {
					$srvcnameout = $srvcobjxlates{$srvcname}{'xlate'};
					$transout    = 'yes';
				} else {
					$srvcnameout = $srvcname;
					$transout    = 'no';
				}
				if ($srvcnameout eq "") { print "   ## WARNING: EMPTY SSERVICE OUT ORIG SERVICE: $srvcname\n"; }
				$sourceobjprint{"$srvcnameout,$srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'},$srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto},,$colour,,,,$description $destobjstring"} = $transout;
			}
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
		my $transout = $sourceobjprint{$printline};
		if ($transout eq 'no') {
			my ($srvcobject, $proto, $port, $blank, $colour, $peram1, $peram2, $peram3, $description) = split(/\,/, $printline);
			print DBEDIT "create $proto"."_service $srvcobject\n"; 
			print DBEDIT "modify services $srvcobject color  $colour\n"; 
			print DBEDIT "modify services $srvcobject comments \"$description\"\n"; 
			print DBEDIT "modify services $srvcobject protocol $proto\n"; 
			print DBEDIT "modify services $srvcobject exp \"dport = $port\"\n"; 
			print DBEDIT "modify services $srvcobject include_in_any true\n"; 
			print DBEDIT "modify services $srvcobject timeout 3600\n"; 
			print DBEDIT "update services $srvcobject\n";
		}
	} 

	%sourceobjprint = ();
	foreach my $ruleobj (sort keys %{$srcconfiggroups_ref}) {
		my $destobjstring = ' ';
		if (exists $srcbundle_ref->{'netgroups'}{$ruleobj}) {
			my $groupmiss = 0;
			my $grouphit  = 0;
			if (exists $dstbundle_ref->{'netgroups'}{$ruleobj}) {

				# NOTE: check if group with the same name exists 

				$destobjstring = "Matching group name in dest config: $ruleobj";
				my @srcnetgroup = keys %{$srcbundle_ref->{'netgroupobjs'}{$ruleobj}};
				my @dstnetgroup = keys %{$dstbundle_ref->{'netgroupobjs'}{$ruleobj}} ;

				if (compare_arrays(\@srcnetgroup, \@dstnetgroup)) {

					# NOTE: check if the all the objects are the same names and if the objects ips are the same

					my @srcbingroup = sort keys %{$srcbundle_ref->{'bingroups'}{$ruleobj}} ;                                                
					my @dstbingroup = sort keys %{$dstbundle_ref->{'bingroups'}{$ruleobj}} ;
					 
					#print "FOO FOO: @srcbingroup \nMOO MOO: @dstbingroup\n";

					if (compare_arrays(\@srcbingroup, \@dstbingroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: object names and IPs correct";
						#print "$destobjstring WOOOOWOOOWOOO!!!\n";
						$grouphit++;
					} else {
						$destobjstring = "$destobjstring GROUP MATCH: all object names exactly correct but IPs differ";
						$groupmiss++;
					}
				} else {
					# NOTE: else find out whats missing, src and dst being configs not traffic
				}
			} else {
				# NOTE: get the source config group binary ips and check it against each of the destination configs groups

				my @srcbingroup = sort keys %{$srcbundle_ref->{'bingroups'}{$ruleobj}} ;                                                

				foreach my $dstgrp (keys %{$dstbundle_ref->{'bingroups'}}) {
					next if $dstgrp eq $ruleobj;
					my @dstbingroup = sort keys %{$dstbundle_ref->{'bingroups'}{$dstgrp}} ;
					if (compare_arrays(\@srcbingroup, \@dstbingroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: IPs correct but object names differ $ruleobj TRANSLATED";
						#print "$destobjstring FFFFFFFFFFFFFZIP!!!\n";
						$netobjxlates{$ruleobj}{'xlate'} = $dstgrp;
						$grouphit++;
					} else {
						#print "AAAAAAAAAAAAAWWWWWWWW: $dstgrp\n";
					}
				}

			}
			
			my $objcount = scalar keys %{$srcbundle_ref->{'netgroups'}{$ruleobj}};
			my @groupobjs = keys %{$srcbundle_ref->{'netgroupobjs'}{$ruleobj}};

			# NOTE: translate the group name if a match was found

			my $ruleobjx = $ruleobj;
			if (exists $netobjxlates{$ruleobj}) {
				$ruleobjx = $netobjxlates{$ruleobj}{'xlate'};
			} 

			print DBEDIT "create network_object_group $ruleobjx\n";
			print DBEDIT "modify network_objects $ruleobjx color \"dark orchid\"\n";
			print DBEDIT "modify network_objects $ruleobjx comments \"$destobjstring\"\n";
			print DBEDIT "update network_object_group $ruleobjx\n";


			foreach my $groupobj (@groupobjs) {

			# NOTE: translate the group MEMBER name if a match was found and ready output

				if (exists $netobjxlates{$groupobj}) {
					$groupobj = $netobjxlates{$groupobj}{'xlate'};
					print DBEDIT "addelement network_objects $ruleobjx '' network_objects:$groupobj\n";
					$sourceobjprint{"$ruleobjx,group,$groupobj,,red,,,,TRANSLATED $destobjstring"}++;
				} else {
					print DBEDIT "addelement network_objects $ruleobjx '' network_objects:$groupobj\n";
					$sourceobjprint{"$ruleobjx,group,$groupobj,,blue,,,,$destobjstring"}++;
				}
			}
			print DBEDIT "update network_object_group $ruleobjx\n";
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
	} 

	%sourceobjprint = ();
	foreach my $ruleobj (sort keys %{$srcconfigsrvcgroups_ref}) {
		my $destobjstring = ' ';
		if (exists $srcbundle_ref->{'srvcgroups'}{$ruleobj}) {
			if (exists $dstbundle_ref->{'srvcgroups'}{$ruleobj}) {

				# NOTE: check if group with the same name exists 

				$destobjstring = "Matching service group name in dest config: $ruleobj";
				my @srcnamegroup = keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
				my @dstnamegroup = keys %{$dstbundle_ref->{'srvcgroupobjs'}{$ruleobj}} ;

				if (compare_arrays(\@srcnamegroup, \@dstnamegroup)) {

					# NOTE: check if the all the objects are the same names and if the objects port and protocols are the same

					my @srcportgroup = sort keys %{$srcbundle_ref->{'portgroups'}{$ruleobj}} ;                                                
					my @dstportgroup = sort keys %{$dstbundle_ref->{'portgroups'}{$ruleobj}} ;

					if (compare_arrays(\@srcportgroup, \@dstportgroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: object names correct but IPs differ";
					} else {
						$destobjstring = "$destobjstring GROUP MISMATCH: object names correct but IPs differ";
					}
				} else {

					# NOTE: else find out whats missing, src and dst being configs not traffic
				}
			} else {
				# NOTE: get the source config group binary ips and check it against each of the destination configs groups

				foreach my $dstgrp (keys %{$dstbundle_ref->{'portgroups'}}) {
					my $srvcgrouphit  = 0;
					my $srvcgroupmiss = 0;
					next if $dstgrp eq $ruleobj;
					my @srcprotogroups = sort keys %{$srcbundle_ref->{'portgroups'}{$ruleobj}} ;                                                
					my @dstprotogroups = sort keys %{$dstbundle_ref->{'portgroups'}{$dstgrp}} ;
					if (compare_arrays(\@srcprotogroups, \@dstprotogroups)) {
						$srvcgrouphit++;
					} else { 
						$srvcgroupmiss++;
					}

					if (($srvcgrouphit > 0) && ($srvcgroupmiss < 1)) {

						$destobjstring = "$destobjstring SERVICE GROUP MATCH: Protocols and Ports correct but object names differ $ruleobj TRANSLATED";
						$srvcobjxlates{$ruleobj}{'xlate'} = $dstgrp;

					} else {
						#print "AAAAAAAAAAAAAWWWWWWWW: $dstgrp\n";
					}
				}

			}
			my $objcount = scalar keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
			my @groupobjs = keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
			my $ruleobjx  = $ruleobj;
			if (exists $srvcobjxlates{$ruleobj}) {
				$ruleobjx = $srvcobjxlates{$ruleobj}{'xlate'};
			}

			print DBEDIT "create service_group $ruleobjx\n";
			print DBEDIT "modify services $ruleobjx color \"cyan\"\n";
			print DBEDIT "modify services $ruleobjx comments \"$destobjstring\"\n";
			print DBEDIT "update service_group $ruleobjx\n";
			foreach my $groupobj (@groupobjs) {
				if (exists $srvcobjxlates{$groupobj}) {
					$groupobj = $srvcobjxlates{$groupobj}{'xlate'};
					$sourceobjprint{"$ruleobjx,srvgroup,$groupobj,,red,,,,TRANSLATED $destobjstring"}++;
					print DBEDIT "addelement services $ruleobjx '' services:$groupobj\n";
				} else {
					$sourceobjprint{"$ruleobjx,srvgroup,$groupobj,,forrest green,,,,$destobjstring"}++;
					print DBEDIT "addelement services $ruleobjx '' services:$groupobj\n";
				}
			}
			print DBEDIT "update service_group $ruleobjx\n";
		}
	}
	foreach my $printline (sort keys %sourceobjprint) {
		print LASTRASH "$printline\n";
	} 

	#print "NET XLATE OBJECTS		\n######################################################################################################################\n\n". Dumper(%netobjxlates) . "\n\n"	;

	print LASTRASH "##RULE_TYPE,SOURCE,DESTINATION,VPN,SERVICE,ACTION,TRACK,INSTALL_ON,TIME,COMMENT\n";
	print LASTRASH "rulebase_header,$destrulebase\n";
	my $newnum = 0;
	print DBEDIT "update_all\n";
	print DBEDIT "create policies_collection $destrulebase\n";
	print DBEDIT "modify policies_collections $destrulebase comments Created_by_Dan_Martin_With_360-FAAR\n";
	print DBEDIT "update policies_collections $destrulebase\n";
	print DBEDIT "create firewall_policy ##$destrulebase\n";
	print DBEDIT "modify fw_policies ##$destrulebase collection policies_collections:$destrulebase\n";

	foreach my $lastnum (sort numerically keys %{$lastrashprintbase_ref}) {
		my ($rsrc, $rdst, $rport, $origrnum) = split (/\,/, $lastrashprintbase_ref->{$lastnum}) ;
		my $lastnum = $lastnum - 1;
		my @origrulenums	;
		my @origrulecomments	;
		my @origruleheaders 	;
		my @srcouts		;
		my @dstouts		;
		my @srvcouts		;
		print DBEDIT "addelement fw_policies ##$destrulebase rule security_rule\n";

		my @srcs = split (/\s+/, $rsrc); 
		foreach my $srctest (@srcs) { 
			next if $srctest =~ /^Any$|^any$|^ANY$/;
			if (exists $netobjxlates{$srctest}) {
				#print "TEST SRC: $srctest $netobjxlates{$srctest}{'xlate'}\n";
				push(@srcouts, $netobjxlates{$srctest}{'xlate'});
				#print "SRC ARRAY @srcouts\n";
				print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:src:'' network_objects:$netobjxlates{$srctest}{'xlate'}\n";
			} else {
				push(@srcouts, $srctest);
				print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:src:'' network_objects:$srctest\n";
			}

		}
		my $src = join (';', @srcouts);

		my @dsts = split (/\s+/, $rdst);
		foreach my $dsttest (@dsts) { 
			next if $dsttest =~ /^Any$|^any$|^ANY$/;
			if (exists $netobjxlates{$dsttest}) {
				#print "TEST DST: $dsttest $netobjxlates{$dsttest}{'xlate'}\n";
				push(@dstouts, $netobjxlates{$dsttest}{'xlate'});
				#print "DST ARRAY @dstouts\n";
				print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:dst:'' network_objects:$netobjxlates{$dsttest}{'xlate'}\n";
			} else {
				push(@dstouts, $dsttest);
				print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:dst:'' network_objects:$dsttest\n";
			}
		}
		my $dst = join (';', @dstouts);
		print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:through:'' globals:Any\n";

		my @ports = split (/\s+/, $rport); 	
		foreach my $porttest (@ports) {
			next if $porttest =~ /^Any$|^any$|^ANY$/;
			if ($porttest eq "") {
				print "  ## WARNING:  EMPTY SERVICE FOUND IN NEW RULE $newnum ORIG NUM $lastnum\n";
			} elsif (exists $srvcobjxlates{$porttest}) {
				#print "TEST SRVC: $porttest $srvcobjxlates{$porttest}{'xlate'}\n";
				push(@srvcouts, $srvcobjxlates{$porttest}{'xlate'});
				#print "SRVC ARRAY @srvcouts\n";
				print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:services:'' services:$srvcobjxlates{$porttest}{'xlate'}\n";
			} else {
				print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:services:'' services:$porttest\n";
				push(@srvcouts, $porttest);
			}
		}
		my $ports = join (';', @srvcouts);
		print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:action accept_action:accept\n";
		print DBEDIT "rmbyindex fw_policies ##$destrulebase rule:$newnum:track 0\n";
		print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:track tracks:Log\n";
		print DBEDIT "addelement fw_policies ##$destrulebase rule:$newnum:install:'' globals:Any\n";

		if ($ruleoutswitch eq 'STANDARD') {
			my $description;
			my $sectionhead;
			@origrulenums = split (/\s+/, $origrnum) ;
			foreach my $rlnum (sort @origrulenums) {

				if (exists $srcbundle_ref->{'rules'}{$rlnum}{'comment'}) {
					$description = $srcbundle_ref->{'rules'}{$rlnum}{'comment'};
					$description =~ s'"''g;
					$description =~ s',''g;
				} else {
					$description = ' ';
				}
				if (exists $srcbundle_ref->{'rules'}{$rlnum}{'header'}) {
					$sectionhead = $srcbundle_ref->{'rules'}{$rlnum}{'header'};
					$sectionhead =~ s'"''g;
					$sectionhead =~ s',''g;
				} else {
					$sectionhead = ' ';
				}
				push (@origrulecomments, "OrigRuleDesc:$srcbundle_ref->{'rules'}{$rlnum}{'rbnum'}:$description ");
				push (@origruleheaders, "OrigSecHed:$srcbundle_ref->{'rules'}{$rlnum}{'rbnum'}:$sectionhead ");
			}
		} elsif ($ruleoutswitch eq 'keepcomments') {
			push (@origrulecomments, $origrnum);
			push (@origruleheaders, ' ');
		}
		print LASTRASH "security_rule,$src,$dst,Any,$ports,Accept,Log,Any,Any,@origrulecomments@origruleheaders\n";
		print DBEDIT "modify fw_policies ##$destrulebase rule:$newnum:comments \"@origrulecomments@origruleheaders\"\n";
		print DBEDIT "update fw_policies ##$destrulebase\n";
		$newnum++;
	}
	print "\n\n-----------------------------------------------------------------------------------------\n";
	print "  	FILE: $filename WRITTEN  !!*%*%*-HURRAY-*%*%*!!\n";
	print "-----------------------------------------------------------------------------------------\n";
	print "-----------------------------------------------------------------------------------------\n";
	print "  DBEDIT FILE: $filename WRITTEN  !!*%*%*-SWEEET-*%*%*!!\n";
	print "-----------------------------------------------------------------------------------------\n\n";
	close LASTRASH	;
	close DBEDIT	;
}
sub output_netscreen {
	my ($srcbundle_ref, $dstbundle_ref, $srcconfigobjs_ref, $srcconfigsrvcs_ref, $srcconfiggroups_ref, $srcconfigsrvcgroups_ref, $lastrashprintbase_ref, $ruleoutswitch) = @_;
	my %zonemappings;
	my %rangemappings;
	my %netobjxlates;
	my %srvcobjxlates;
	my %multinetobjs;
	my %netobjzones;
	my %sourceobjprint = ();
	#$zonemappings{''}{'zone'} = 'Untrusted';

	print "-----------------------------------------------------------------------------------------\n";
	print " NETSCREEN CONVERSION:\n\n";
	print "   Define route to zone mappings in the format: \n";
	print "   ZONE IP MASKLENGTH\n\n";
	print "   type 'end.' to finish zone input\n\n";
	while (<STDIN>) {
		last if $_ =~ /^end\./ ;
		my ($zone, $ip, $masklength) 	= split (/\s+/, $_);
		my $ipbin 			= ip_to_bin($ip) ;
		my ($maskedbits) 		= substr($ipbin, 0, $masklength) ;
		$zonemappings{$maskedbits}{'zone'} = $zone;
	}

	print "\n\n	Enter the name of the file to be saved: "		;

	while (<STDIN>) {
		chomp($_) 							;
		my $nsfilename = $_						;
		if ($nsfilename eq '') {
			print "\n 	ERROR: type a filename\n"		;
		} elsif (-e "$nsfilename") {
			print "\n	ERROR: file exists\n"			;
		} else {
			#open (CONVNSOUT, ">$nsfilename")			;
			last							;
		}
	}
	print "\n";
	
	my @rbnums;
	foreach my $globalrule (keys %{$dstbundle_ref->{'rules'}}) {
		push (@rbnums, $dstbundle_ref->{'rules'}{$globalrule}{'rbnum'});
	}
	my $maxrbnum = 0;
	$maxrbnum    = pop(@rbnums);
	foreach my $testnum (@rbnums) {
		$maxrbnum = $testnum if $testnum > $maxrbnum;
	}

	print "\n	MAX EXISTING RULE NUM: $maxrbnum\n";
	print "\n	Enter a number to override the above rule count or press enter to accept: ";
	my $override = <STDIN>;
	if ($override =~ /^\d+$/) {
		$maxrbnum = $override;
	}

	print "\n-----------------------------------------------------------------------------------------\n";
	print " BUILDING OBJECT ZONES FROM DEST CONFIG INFO:\n\n";

# NOTE: Working out best zones to put objects into
	
	my $zonecount       = 0;
	my $zonecountholder = 0;
	foreach my $objn (keys %{$srcbundle_ref->{'netobjects'}}) {
		foreach my $srcipbin (keys %{$srcbundle_ref->{'netobjects'}{$objn}{'ipbin'}}) {

		# NOTE: assign zone from object details

			my $workingsrcbin = $srcipbin;
			until (exists $dstbundle_ref->{'ips'}{$workingsrcbin} || $workingsrcbin eq "") {
				chop $workingsrcbin;
			}
			if ($workingsrcbin ne "" && exists $dstbundle_ref->{'ips'}{$workingsrcbin} && exists $dstbundle_ref->{'ips'}{$workingsrcbin}{'zone'}) {
				if (exists $netobjzones{$objn} && exists $netobjzones{$objn}{'zone'} && ($netobjzones{$objn}{'zone'} ne $dstbundle_ref->{'ips'}{$workingsrcbin}{'zone'})) {
					print "MULTIPLE OBJECT ZONES FOUND FOR: $objn, USING: $netobjzones{$objn}{'zone'}, DISCARDING: $dstbundle_ref->{'ips'}{$workingsrcbin}{'zone'}\n";
				} else {
					print "ASSIGNED ZONE $dstbundle_ref->{'ips'}{$workingsrcbin}{'zone'} TO OBJ $objn FROM NET OBJECTS DEFFINITION\n";
					$netobjzones{$objn}{'zone'} = $dstbundle_ref->{'ips'}{$workingsrcbin}{'zone'};
				}
			} else {

			# NOTE: assign zone from zone details in destination configuration

				my $workingzonebin = $srcipbin;
				until (exists $dstbundle_ref->{'zones'}{$workingzonebin} || $workingzonebin eq "") {
					chop $workingzonebin;
				}
				if (($workingzonebin ne "") && exists $netobjzones{$objn} && exists $netobjzones{$objn}{'zone'} && ($netobjzones{$objn}{'zone'} ne $dstbundle_ref->{'zones'}{$workingzonebin}{'zone'})) {
					print "MULTIPLE OBJECT ZONES FOUND FOR: $objn, USING: $netobjzones{$objn}{'zone'}, DISCARDING ROUTE ZONE: $dstbundle_ref->{'zones'}{$workingsrcbin}{'zone'}\n";

			# NOTE: assign zone from zone details here if not default route - else use zone mappings - and finally if no zone mappings were entered use the default

				} elsif (($workingzonebin ne "") && exists $dstbundle_ref->{'zones'}{$workingzonebin}) {
					print "ASSIGNED ZONE $dstbundle_ref->{'zones'}{$workingzonebin}{'zone'} TO OBJ $objn FROM ROUTE DEFFINITION, ANY EXCLUDED\n";
					$netobjzones{$objn}{'zone'} = $dstbundle_ref->{'zones'}{$workingzonebin}{'zone'};
				} elsif (1 <= (scalar keys %zonemappings)) {

				# NOTE: assign zone from zone details in destination configuration

					my $workingmapbin = $srcipbin;
					until (exists $zonemappings{$workingmapbin} || $workingmapbin eq "") {
						chop $workingmapbin;
					}
					if (exists $netobjzones{$objn} && exists $netobjzones{$objn}{'zone'} && ($netobjzones{$objn}{'zone'} ne $zonemappings{$workingmapbin}{'zone'})) {
						print "MULTIPLE OBJECT ZONES FOUND FOR: $objn, USING: $netobjzones{$objn}{'zone'}, DISCARDING MANUAL MAP ZONE: $zonemappings{$workingmapbin}{'zone'}\n";
					} elsif (exists $netobjzones{$objn} && exists $netobjzones{$objn}{'zone'}) {

						# NOTE do nothing object has the same zone as already noted

					} elsif (exists $zonemappings{$workingmapbin} && exists $zonemappings{$workingmapbin}{'zone'} && ($workingmapbin ne "")) {
						print "ASSIGNED ZONE $zonemappings{$workingmapbin}{'zone'} TO OBJ $objn FROM MANUAL DEFFINITION\n";
						$netobjzones{$objn}{'zone'} = $zonemappings{$workingmapbin}{'zone'};
					} elsif (exists $dstbundle_ref->{'zones'}{$workingmapbin}) {
						print "ASSIGNED ZONE $dstbundle_ref->{'zones'}{$workingmapbin}{'zone'} TO OBJ $objn FROM ROUTE DEFFINITION, FROM DEFAULT ZONE IN CONFIG\n";
						$netobjzones{$objn}{'zone'} = $dstbundle_ref->{'zones'}{$workingmapbin}{'zone'};
					} elsif (exists $zonemappings{$workingmapbin} && exists $zonemappings{$workingmapbin}{'zone'}) {
						print "ASSIGNED ZONE $zonemappings{$workingmapbin}{'zone'} TO OBJ $objn FROM DEFAULT ZONE IN MANUAL DEFFINITION\n";
						$netobjzones{$objn}{'zone'} = $zonemappings{$workingmapbin}{'zone'};
					} else {
						print "FAILED TO ASSIGN A ZONE TO OBJECT, from config or mapppings: $objn\n";
					}
				} elsif (exists $dstbundle_ref->{'zones'}{$workingzonebin}) {
					print "ASSIGNED ZONE $dstbundle_ref->{'zones'}{$workingzonebin}{'zone'} TO OBJ $objn FROM ROUTE DEFFINITION, FROM DEFAULT ZONE\n";
					$netobjzones{$objn}{'zone'} = $dstbundle_ref->{'zones'}{$workingzonebin}{'zone'};
				} else {
					print "FAILED TO ASSIGN A ZONE TO OBJECT, try adding mappings: $objn\n";
				}
			}

		# NOTE: print dots

			#$zonecount++;
			#if ($zonecount == ($zonecountholder + 10)) {
			#	print "."			;
			#	$zonecount = $zonecountholder	;
			#}
			#if ($zonecount == ($zonecountholder + 500)) {
			#	print ".$zonecount	zones assigned to objects\n";
			#	$zonecount = $zonecountholder	;
			#}
		}
	}

# NOTE: output ip objects

	print "\n-----------------------------------------------------------------------------------------\n";
	print " NETSCREEN NETWORK OBJECTS:\n\n";
	
	$netobjzones{'Any'}{'zone'} = 'Global';
	$netobjzones{'any'}{'zone'} = 'Global';
	foreach my $netobject (sort keys %{$srcconfigobjs_ref}) {

		if ($srcbundle_ref->{'netobjects'}{$netobject}{'type'} =~ /^net$|^host$|^member$|^ss$|^idevice$|^plaingw$|^dynamic$|^cpgw$|^default$|^empty$|^cluster$/ ) {
			my $intcount = 0;
			my $description = 'Migrated';
			foreach my $objbin (keys %{$srcbundle_ref->{'netobjects'}{$netobject}{'ipbin'}}) {
				if (exists $dstbundle_ref->{'ips'}{$objbin}) {
					my $ip = $srcbundle_ref->{'netobjects'}{$netobject}{'ip'};
					my $nm = $srcbundle_ref->{'netobjects'}{$netobject}{'nm'};
					my $destnetobj = $dstbundle_ref->{'ips'}{$objbin}{'name'};
					if (exists $srcbundle_ref->{'netobjects'}{$netobject}{'description'} && defined($srcbundle_ref->{'netobjects'}{$netobject}{'description'})) {
						$description = $srcbundle_ref->{'netobjects'}{$netobject}{'description'};
						$description =~ s/\"//g;
					}
					$netobjxlates{$netobject}{'xlate'} = $destnetobj;
					print "set address \"$netobjzones{$netobject}{'zone'}\" \"$destnetobj\" $ip $nm \"DEST CONFIG OBJ USED, ORIG SRC $netobject, DESC: $description\"\n";
				} else {
					my $ip = $srcbundle_ref->{'netobjects'}{$netobject}{'ip'};
					my $nm = $srcbundle_ref->{'netobjects'}{$netobject}{'nm'};
					if (exists $srcbundle_ref->{'netobjects'}{$netobject}{'description'} && defined($srcbundle_ref->{'netobjects'}{$netobject}{'description'})) {
						$description = $srcbundle_ref->{'netobjects'}{$netobject}{'description'};
						$description =~ s/\"//g;
					}
					print "set address \"$netobjzones{$netobject}{'zone'}\" \"$netobject\" $ip $nm \"$description\"\n";
				}
			}

		} elsif ($srcbundle_ref->{'netobjects'}{$netobject}{'type'} =~ /^range$/ ) {
			my $description = 'Migrated';
			my $rangecount = 0;
			my $ipstart 		= $srcbundle_ref->{'netobjects'}{$netobject}{'rangestart'};
			my $ipend 		= $srcbundle_ref->{'netobjects'}{$netobject}{'rangeend'};
			my @ipstart 		= split (/\./, $ipstart) ;
			my @ipend 		= split (/\./, $ipend)   ;
#			my $rngcount1		= $ipend[0] - $ipstart[0];
#			my $rngcount2		= $ipend[1] - $ipstart[1];
#			my $rngcount3		= $ipend[2] - $ipstart[2];
#			my $rngcount4		= $ipend[3] - $ipstart[3];
									
			for (my $i = $ipstart[0]; $i <= $ipend[0]; $i++) {							# first  octet
				for (my $i1 = $ipstart[1]; $i1 <= $ipend[1]; $i1++) {						# second octet
					for (my $i2 = $ipstart[2]; $i2 <= $ipend[2]; $i2++) {					# third  octet
						for (my $i3 = $ipstart[3]; $i3 <= $ipend[3]; $i3++) {				# fourth octet
							$rangecount++;
							my $iptoadd 		= join (".", $i, $i1, $i2, $i3)		;
							my $ipbin 		= ip_to_bin($iptoadd) 			;

							if (exists $dstbundle_ref->{'ips'}{$ipbin}) {
								my $destnetobj = $dstbundle_ref->{'ips'}{$ipbin}{'name'};
								if (exists $srcbundle_ref->{'netobjects'}{$netobject}{'description'} && $srcbundle_ref->{'netobjects'}{$netobject}{'description'} ne "") {
									$description = $srcbundle_ref->{'netobjects'}{$netobject}{'description'};
									$description =~ s/\"//g;
								}
								print "set address \"$netobjzones{$netobject}{'zone'}\" \"$destnetobj\" $iptoadd 255.255.255.255 \"DEST CONFIG OBJ MATCHED BY RANGE, SRC: $netobject, DESC: $description\"\n";
								$multinetobjs{$netobject}{'netobjs'}{$destnetobj}++;
							} else {
								if (exists $srcbundle_ref->{'netobjects'}{$netobject}{'description'} && $srcbundle_ref->{'netobjects'}{$netobject}{'description'} ne "") {
									$description = $srcbundle_ref->{'netobjects'}{$netobject}{'description'};
									$description =~ s/\"//g;
								}
								print "set address \"$netobjzones{$netobject}{'zone'}\" \"$netobject.$rangecount\" $iptoadd 255.255.255.255 \"RANGE ADDED TO GROUP, $description\"\n";
								$multinetobjs{$netobject}{'netobjs'}{"$netobject.$rangecount"}++;
							}
						}
					}
				}
			}
		}
	}

	print "\n-----------------------------------------------------------------------------------------\n";
	print " NETSCREEN MULTIPLE IP ADDRESS OBJECT TRANSLATION TO GROUPS:\n\n";

	foreach my $multiobj (keys %multinetobjs) {
		my $description = 'Migrated';
		if (exists $srcbundle_ref->{'netobjects'}{$multiobj}{'description'} && $srcbundle_ref->{'netobjects'}{$multiobj}{'description'} ne "") {
			$description = $srcbundle_ref->{'netobjects'}{$multiobj}{'description'};
			$description =~ s/\"//g;
		}
		print "set group address \"$netobjzones{$multiobj}{'zone'}\" \"$multiobj\" comment \"MULTIPLE IP OBJECT TRANSLATED TO GROUP: $description\"\n"; 
		foreach my $netobj (keys %{$multinetobjs{$multiobj}{'netobjs'}}) {
			print "set group address \"$netobjzones{$multiobj}{'zone'}\" \"$multiobj\" add \"$netobj\"\n"; 
		}
	}

# NOTE: output service objects

	print "\n-----------------------------------------------------------------------------------------\n";
	print " NETSCREEN SERVICE OBJECTS:\n\n";
	
	my %serviceouts;
	foreach my $srvcname (sort keys %{$srcconfigsrvcs_ref}) {
		foreach my $proto (sort keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}}) {
			foreach my $port (sort keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}}) {
				my $srvcnameout;
				my $destobjstring = ' ';
				my $description   = 'Migrated';
				my $colour   	  = 'black';
				if (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}) {
					$destobjstring = "Matching object name in dest config: $srvcname";
					unless ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} eq $dstbundle_ref->{'srvcobjects'}{$srvcname}{'type'}) {
						$destobjstring = "$destobjstring TYPE MISMATCH: src $srcbundle_ref->{'srvcobjects'}{$srvcname}{'type'} dst $dstbundle_ref->{'srvcobjects'}{$srvcname}{'type'}";
					}
					unless ((exists $dstbundle_ref->{'srvcobjects'}{$srvcname}) && (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}) && (exists $dstbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}{$port})) {
						$destobjstring = "$destobjstring PORT MISMATCH: src $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} dst $dstbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto}";
					}
				#} else {
				#	$destobjstring = " ";
				}
				if ((exists $dstbundle_ref->{'ports'}{$proto}) && (exists $dstbundle_ref->{'ports'}{$proto}{$port}) && ($srvcname ne $dstbundle_ref->{'ports'}{$proto}{$port}{'name'})) {
					my $destobjname = $dstbundle_ref->{'ports'}{$proto}{$port}{'name'} ;
					if ($srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto} eq $dstbundle_ref->{'srvcobjects'}{$destobjname}{'port'}{$proto}) {
						$srvcobjxlates{$srvcname}{'xlate'} = $destobjname; 
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname and has been EXACTLY TRANSLATED";
					} elsif ((scalar keys %{$srcbundle_ref->{'srvcobjects'}{$srvcname}{'ports'}{$proto}}) == (scalar keys %{$dstbundle_ref->{'srvcobjects'}{$destobjname}{'ports'}{$proto}})) {
						$srvcobjxlates{$srvcname}{'xlate'} = $destobjname; 
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname and has been TRANSLATED";
					} else {
						$destobjstring = "$destobjstring Object: $srvcname matches the PORT of $dstbundle_ref->{'srvcobjects'}{$destobjname}{'type'} $destobjname not xlated ";
					}
				} elsif ((exists $dstbundle_ref->{'ports'}{$proto}) && (exists $dstbundle_ref->{'ports'}{$proto}{$port}) && ($srvcname eq $dstbundle_ref->{'ports'}{$proto}{$port}{'name'})) {
					$destobjstring = "$destobjstring EXACTLY";
				}
				if (exists $srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'}) {
					$description = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'description'};
					$description =~ s'"''g;
					$description =~ s',''g;
				}
				if (exists $srcbundle_ref->{'srvcobjects'}{$srvcname}{'colour'}) {
					$colour = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'colour'};
				}
				if (exists $srvcobjxlates{$srvcname}) {
					$srvcnameout = $srvcobjxlates{$srvcname}{'xlate'};
				} else {
					$srvcnameout = $srvcname;
				}
				my $portout = $srcbundle_ref->{'srvcobjects'}{$srvcname}{'port'}{$proto};

				unless (defined($portout)) { print "Service:  $srvcname  - has a bad PROTO definition in $proto - SERVICE TRANSLATION USING Proto: $proto SKIPPED\n"; next; }

				if ($portout =~ /^\<\d+$/) {
					$portout =~ tr'<'';;
					$portout = "0\-$portout";
				} elsif ($portout =~ /^\>\d+$/) {
					$portout =~ tr'>'';
					$portout = "$portout\-65535";
				} elsif ($portout =~ /^\d+$/) {
					$portout = "$portout\-$portout";
				} elsif ($portout =~ /^\d+\-\d+$/) {
					# DO NOTHING
				} else { 
					#print "OUTPORT BAD $portout\n";
				}
				$serviceouts{"set service \"$srvcnameout\" protocol $proto src-port 0-65535 dst-port $portout"}{"## $destobjstring $description"}++;
			}
		}
	}
	foreach my $outservice (sort keys %serviceouts) {
		foreach my $outstring (sort keys %{$serviceouts{$outservice}}) {
			print "$outstring\n";
		}
		print "$outservice\n";
	}

# NOTE: output ip groups

	
	print "\n-----------------------------------------------------------------------------------------\n";
	print " NETSCREEN ADDRESS GROUPS:\n\n";

	%sourceobjprint = ();
	foreach my $ruleobj (sort keys %{$srcconfiggroups_ref}) {
		my $destobjstring = ' ';
		if (exists $srcbundle_ref->{'netgroups'}{$ruleobj}) {

			my $groupmiss = 0;
			my $grouphit  = 0;
			if (exists $dstbundle_ref->{'netgroups'}{$ruleobj}) {

				# NOTE: check if group with the same name exists 

				$destobjstring = "Matching group name in dest config: $ruleobj";
				my @srcnetgroup = keys %{$srcbundle_ref->{'netgroupobjs'}{$ruleobj}};
				my @dstnetgroup = keys %{$dstbundle_ref->{'netgroupobjs'}{$ruleobj}} ;

				if (compare_arrays(\@srcnetgroup, \@dstnetgroup)) {

					# NOTE: check if the all the objects are the same names and if the objects ips are the same

					my @srcbingroup = sort keys %{$srcbundle_ref->{'bingroups'}{$ruleobj}} ;                                                
					my @dstbingroup = sort keys %{$dstbundle_ref->{'bingroups'}{$ruleobj}} ;
					 

					if (compare_arrays(\@srcbingroup, \@dstbingroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: object names and IPs correct";
						$grouphit++;
					} else {
						$destobjstring = "$destobjstring GROUP MATCH: all object names exactly correct but IPs differ";
						$groupmiss++;
					}
				} else {
					#print "@srcnetgroup TINNNNNNGS: @dstnetgroup\n";

				}
			} else {
				# NOTE: get the source config group binary ips and check it against each of the destination configs groups

				my @srcbingroup = sort keys %{$srcbundle_ref->{'bingroups'}{$ruleobj}} ;                                                

				foreach my $dstgrp (keys %{$dstbundle_ref->{'bingroups'}}) {
					next if $dstgrp eq $ruleobj;
					my @dstbingroup = sort keys %{$dstbundle_ref->{'bingroups'}{$dstgrp}} ;
					if (compare_arrays(\@srcbingroup, \@dstbingroup)) {
						$destobjstring = "$destobjstring GROUP MATCH: IPs correct but object names differ $ruleobj TRANSLATED";
						$netobjxlates{$ruleobj}{'xlate'} = $dstgrp;
						$grouphit++;
					} else {
					}
				}

			}
			
			my $objcount	= scalar keys %{$srcbundle_ref->{'netgroups'}{$ruleobj}};
			my @groupobjs	= keys %{$srcbundle_ref->{'netgroupobjs'}{$ruleobj}};
			my ($grpobj) 	= keys %{$srcbundle_ref->{'netgroupobjs'}{$ruleobj}};
			my $zone 	= $netobjzones{$grpobj}{'zone'};

			$netobjzones{$ruleobj}{'zone'} = $zone;
			print "set group address \"$zone\" \"$ruleobj\" comment \"$destobjstring\"\n";

			foreach my $groupobj (@groupobjs) {
				my $ruleobjx = $ruleobj;

			# NOTE: translate the group name if a match was found

				if (exists $netobjxlates{$ruleobj}) {
					$ruleobjx = $netobjxlates{$ruleobj}{'xlate'};
				} 

			# NOTE: translate the group MEMBER name if a match was found and ready output

				if (exists $netobjxlates{$groupobj}) {
					$groupobj = $netobjxlates{$groupobj}{'xlate'};
					$sourceobjprint{"set group address \"$zone\" \"$ruleobjx\" add \"$groupobj\""}++;
				} else {
					$sourceobjprint{"set group address \"$zone\" \"$ruleobjx\" add \"$groupobj\""}++;
				}
			}
			foreach my $printline (sort keys %sourceobjprint) {
				print "$printline\n";
			} 

			%sourceobjprint = ();

		} else {
			print "GROUP GONE ARRY!! $ruleobj\n";
		}
	}

# NOTE: output service groups
			
	print "\n-----------------------------------------------------------------------------------------\n";
	print " NETSCREEN SERVICE GROUPS:\n\n";
	
	foreach my $ruleobj (sort keys %{$srcconfigsrvcgroups_ref}) {
		my $destobjstring = ' ';
		if (exists $srcbundle_ref->{'srvcgroups'}{$ruleobj}) {
			if (exists $dstbundle_ref->{'srvcgroups'}{$ruleobj}) {

				# NOTE: check if group with the same name exists 

				$destobjstring = "Matching service group name in dest config: $ruleobj";
				my @srcportgroup = keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
				my @dstportgroup = keys %{$dstbundle_ref->{'srvcgroupobjs'}{$ruleobj}} ;

				if (compare_arrays(\@srcportgroup, \@dstportgroup)) {

					# NOTE: check if the all the objects are the same names and if the objects port and protocols are the same

					my @srcgroupobjs = sort keys %{$srcbundle_ref->{'portgroups'}{$ruleobj}} ;                                                
					my @dstgroupobjs = sort keys %{$dstbundle_ref->{'portgroups'}{$ruleobj}} ;

					if (compare_arrays(\@srcgroupobjs, \@dstgroupobjs)) {
						$destobjstring = "$destobjstring GROUP MATCH: object names correct but IPs differ";
					} else {
						$destobjstring = "$destobjstring GROUP MISMATCH: object names correct but IPs differ";
					}
				} else {

					# NOTE: else find out whats missing, src and dst being configs not traffic
				}
			} else {
				# NOTE: get the source config group binary ips and check it against each of the destination configs groups

				foreach my $dstgrp (keys %{$dstbundle_ref->{'portgroups'}}) {
					my $srvcgrouphit  = 0;
					my $srvcgroupmiss = 0;
					next if $dstgrp eq $ruleobj;
					my @srcprotogroups = sort keys %{$srcbundle_ref->{'portgroups'}{$ruleobj}} ;                                                
					my @dstprotogroups = sort keys %{$dstbundle_ref->{'portgroups'}{$dstgrp}} ;
					if (compare_arrays(\@srcprotogroups, \@dstprotogroups)) {
						$srvcgrouphit++;
					} else { 
						$srvcgroupmiss++;
					}

					if (($srvcgrouphit > 0) && ($srvcgroupmiss < 1)) {

						$destobjstring = "$destobjstring SERVICE GROUP MATCH: Protocols and Ports correct but object names differ $ruleobj TRANSLATED";
						$srvcobjxlates{$ruleobj}{'xlate'} = $dstgrp;

					} else {
						#print "AAAAAAAAAAAAAWWWWWWWW: $dstgrp\n";
					}
				}

			}
			my $objcount = scalar keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
			my @groupobjs = keys %{$srcbundle_ref->{'srvcgroupobjs'}{$ruleobj}};
			my $ruleobjx  = $ruleobj;
			if (exists $srvcobjxlates{$ruleobj}) {
				$ruleobjx = $srvcobjxlates{$ruleobj}{'xlate'};
			}

			print "set group service \"$ruleobjx\" comment \"$destobjstring\"\n";

			foreach my $groupobj (@groupobjs) {
				if (exists $srvcobjxlates{$groupobj}) {
					$groupobj = $srvcobjxlates{$groupobj}{'xlate'};
					$sourceobjprint{"set group service \"$ruleobjx\" add $groupobj"}++;
				} else {
					$sourceobjprint{"set group service \"$ruleobjx\" add $groupobj"}++;
				}
			}
			foreach my $printline (sort keys %sourceobjprint) {
				print "$printline\n";
			} 

			%sourceobjprint = ();

		} else {
			print "   SRVC GROUP GONE ARRY!! $ruleobj\n";
		}
	}

	#print "NET XLATE OBJECTS		\n######################################################################################################################\n\n". Dumper(%netobjxlates) . "\n\n"	;

# NOTE: output rules

	print "\n-----------------------------------------------------------------------------------------\n";
	print " NETSCREEN RULE DEFINITIONS:\n\n";

	foreach my $num (sort numerically keys %{$lastrashprintbase_ref}) {
		my ($rsrc, $rdst, $rport, $origrnum) = split (/\,/, $lastrashprintbase_ref->{$num}) ;
		my ($firstsrc, @srcs) 		= split (/\s+/, $rsrc) ;
		my ($firstdst, @dsts) 		= split (/\s+/, $rdst) ;
		my ($firstsrvc, @services) 	= split (/\s+/, $rport) ;
		my ($firstsrcout, $firstdstout);
		my @origrulecomments	;
		my @origruleheaders 	;
		my @origrulenums	;

		if ($ruleoutswitch eq 'STANDARD') {
			@origrulenums 		= sort numerically split (/\s+/, $origrnum) ;
			foreach my $rlnum (@origrulenums) {
				push (@origrulecomments, "Rulebase $srcbundle_ref->{'rules'}{$rlnum}{'rulegroup'}: Rule $srcbundle_ref->{'rules'}{$rlnum}{'rbnum'}: $srcbundle_ref->{'rules'}{$rlnum}{'comment'} ");
				push (@origruleheaders, "Rulebase $srcbundle_ref->{'rules'}{$rlnum}{'rulegroup'}: Rule $srcbundle_ref->{'rules'}{$rlnum}{'rbnum'}: Section Title: $srcbundle_ref->{'rules'}{$rlnum}{'header'} ");
			}
		} elsif ($ruleoutswitch eq 'keepcomments') {
			push (@origrulecomments, $origrnum);
			push (@origruleheaders, ' ');
		}


		if (exists $netobjxlates{$firstsrc} ) {
			$firstsrcout = $netobjxlates{$firstsrc}{'xlate'};
		} else {
			$firstsrcout = $firstsrc;
		}

		if (exists $netobjxlates{$firstdst} ) {
			$firstdstout = $netobjxlates{$firstdst}{'xlate'};
		} else {
			$firstdstout = $firstdst;
		}

		if (exists $srvcobjxlates{$firstsrvc}) {
			$firstsrvc = $srvcobjxlates{$firstsrvc}{'xlate'};
		}

		my $outnum;
		if (defined ($maxrbnum)) {
			$outnum = $num + $maxrbnum;
		} else {
			$outnum = $num;
		}

		print "set policy id $outnum from \"$netobjzones{$firstsrc}{'zone'}\" to \"$netobjzones{$firstdst}{'zone'}\" \"$firstsrcout\" \"$firstdstout\" \"$firstsrvc\" permit log\n";     #@origrulecomments,@origruleheaders\n";
		print "set policy id $outnum\n";

		foreach my $src (sort @srcs) {
			my $srcout = $src;
			if (exists $netobjxlates{$src} ) {
				$srcout = $netobjxlates{$src}{'xlate'};
			}
			print "set src-address \"$srcout\"\n"; 
			#print "set src-address \"$srcout\" zone $netobjzones{$src}{'zone'}\n";
		}
		foreach my $dst (sort @dsts) {
			my $dstout = $dst;
			if (exists $netobjxlates{$dst} ) {
				$dstout = $netobjxlates{$dst}{'xlate'};
			}
			print "set dst-address \"$dstout\"\n"; 
			#print "set dst-address \"$dstout\" zone $netobjzones{$dst}{'zone'}\n";
		}
		foreach my $service (sort @services) {
			if (exists $srvcobjxlates{$service}) {
				$service = $srvcobjxlates{$service}{'xlate'};
			}
			print "set service \"$service\"\n";
		}
		print "set log session-init\n";
		print "exit\n";
	}
}


# NOTE: Subroutines for sort

sub numerically    { $a <=> $b }
sub alphabetically { lc $a cmp lc $b }

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to compair speciffic things 
#---------------------------------------------------------------------------------------------

sub compare_arrays {
	my ($first, $second) = @_				;
	return 0 unless @$first == @$second			;
	for (my $i = 0; $i < @$first; $i++) {
		return 0 if $first->[$i] ne $second->[$i]	;
	}
	return 1						;
}
#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to convert speciffic things 
#---------------------------------------------------------------------------------------------

sub ip_to_bin {
        my (@ip) = split (/\./, "$_[0]")  						;
        my ($ipbin) = unpack ( "B32", pack ("CCCC", $ip[0], $ip[1], $ip[2], $ip[3]))	;
        return $ipbin									;
}
sub netmask_to_bin {
	my ($masklength)				;
        my ($maskbin) = ip_to_bin($_[0])		;
        my ($maskbits) = $maskbin 			;
	if ($maskbin =~ /0+/) {
        	$masklength = index("$maskbin", 0 )	;
	} else {
		$masklength = 32			;
	}
        return ($maskbin, $maskbits, $masklength)	;
}

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to convert from names or IP addresses and netmasks to ip's or ip mask pairs or binary ips
#---------------------------------------------------------------------------------------------

# NOTE: used only for single HOST entires where all 32 bits are required (in cisco mostly)

sub name_or_ip_to_ip {
	my ($nameorip, $netobjects_ref, $ips_ref) = @_	;

	if (is_ip($nameorip) && address_is_known($nameorip, $ips_ref)) {

		return $nameorip; 		# is a known ip

	} elsif (is_netobj_name($nameorip, $netobjects_ref)) {

		my $ip = $netobjects_ref->{$nameorip}{'ip'};

		return $ip; 			# is a name translated to just its ip

	} elsif (is_ip($nameorip)) {

		#print "  WARNING: Unknown IP: $nameorip used in name_or_ip_to_ip\n";

		return $nameorip; 		# is an unknown ip
	
	} else {	
		print "  WARNING: $nameorip, used in NAME_OR_IP_TO_IP is not an IP or a known name\n";
		return $nameorip;
	}
}
sub name_or_ip_to_ipbin {
	my ($nameorip, $netobjects_ref, $ips_ref) = @_;
	my $ip 		= name_or_ip_to_ip($nameorip, $netobjects_ref, $ips_ref);
	my $ipbin 	= ip_to_bin($ip);
	return $ipbin;
}

# NOTE: used for networks  -  name_or_ip,netmask pairs

sub name_or_net_to_ip_nm {
	my ($nameornet, $nm, $netobjects_ref, $ips_ref) = @_	;

	if (is_ip($nameornet) && is_netmask($nm) && network_is_known($nameornet, $nm, $ips_ref)) {

		return ($nameornet, $nm); 				# is a known net

	} elsif (is_netobj_name($nameornet, $netobjects_ref)) {

		my $ip = $netobjects_ref->{$nameornet}{'ip'};
		#   $nm = $netobjects_ref->{$nameornet}{'nm'};		# NOTE: this should be disabled at the moment as its only being used in the cisco build section

		return ($ip, $nm); 					# is a name translated to its ip with the netmask supplied

	} elsif (is_ip($nameornet) && is_netmask($nm)) {

		#print "  WARNING: Unknown Net: $nameornet $nm used in name_or_net_to_ip_nm, this is usually ok though\n";

		return ($nameornet, $nm); 				# is an unknown net
	
	} else {	
		print "  WARNING: $nameornet , $nm , used in NAME_OR_NET_TO_IP_NM is NOT a known network, ip or name\n";
		return $nameornet;
	}
}
sub name_or_net_to_ipbin {
	my ($nameornet, $nm_in, $netobjects_ref, $ips_ref) = @_;

	my ($ip, $nm) 				= name_or_net_to_ip_nm($nameornet, $nm_in, $netobjects_ref, $ips_ref)	;
	my $ipbin 				= ip_to_bin($ip)			;
	my ($maskbin, $maskbits, $masklength)	= netmask_to_bin($nm)			;
	my ($maskedipbin) 			= substr($ipbin, 0, $masklength)	;

	return $maskedipbin;
}
sub name_or_net_to_ipbin_nmln {
	my ($nameornet, $nm_in, $netobjects_ref, $ips_ref) = @_;

	my ($ip, $nm) 				= name_or_net_to_ip_nm($nameornet, $nm_in, $netobjects_ref, $ips_ref)	;
	my $ipbin 				= ip_to_bin($ip)			;
	my ($maskbin, $maskbits, $masklength)	= netmask_to_bin($nm)			;
	my ($maskedipbin) 			= substr($ipbin, 0, $masklength)	;

	return ($maskedipbin, $masklength);
}

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to convert from names or IP addresses and netmasks to ip's or ip mask pairs or binary ips
#---------------------------------------------------------------------------------------------

sub ipbin_to_name {
	my ($ipbin, $ips_ref) = @_				;
	if (exists $ips_ref->{$ipbin}) {
		if (exists ($ips_ref->{$ipbin}{'name'})) {
			my $name = $ips_ref->{$ipbin}{'name'}	;
			return $name				;
		} else {
			print "   WARNING: no name found for $ipbin in IPBIN_TO_NAME, returned TEXTBIN IP use hbin to ranslate output back to name\n";
			return $ipbin				;
		}
	} else {
		print "   WARNING: $ipbin not found in IPBIN_TO_NAME, returned TEXTBIN IP use hbin to ranslate output back to name\n";
		return $ipbin					;
	}
}
sub net_to_name {
	my ($netip, $nm, $netobjects_ref, $ips_ref) = @_	;

	if (is_ip($netip) && is_netmask($nm) && network_is_known($netip, $nm, $ips_ref)) {
		my $maskedipbin 	= name_or_net_to_ipbin($netip, $nm, $netobjects_ref, $ips_ref)	;
		my $name 		= ipbin_to_name($maskedipbin, $ips_ref)				;
		return $name; 							# is a known net

	} elsif (is_netobj_name($netip, $netobjects_ref)) {

		return $netip; 							# is a name already

	} elsif (is_ip($netip) && is_netmask($nm)) {

		#print "  WARNING: Unknown Net: $netip $nm used in net_to_name\n";

		return $netip; 				
		
		# NOTE: is an unknown net using its IP as a name - potentially this could cause name conflicts with networks - so I'm considering adding a mask length
	
	} else {	
		print "  WARNING: $netip , $nm , used in NAT_TO_NAME is NOT a known network, ip or hostname\n";
	
		return $netip;
	}
}
sub ip_to_name {
	my ($ip, $netobjects_ref, $ips_ref) = @_;
	my $nm	 = '255.255.255.255'		;
	my $name = net_to_name($ip, $nm, $netobjects_ref, $ips_ref)  ;
	return $name				;
}
sub proto_port_to_srvc_name {
	my ($proto, $port, $ports_ref) = @_;
	if (port_is_known($proto,$port,$ports_ref)) {
		my $srvcname = $ports_ref->{$proto}{$port}{'name'};
		return $srvcname;
	} else {
		return $port;
	}
}

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to add networks - the build stage for checkpoint and the binip processing bit add further details 
#---------------------------------------------------------------------------------------------

sub add_host {
	my ($name, $ip, $orderednetobj_ref, $netobjects_ref, $ips_ref) = @_;
	my $type 	= 'host'		;
	my $nm 		= '255.255.255.255'	;
	my $descrip 	= 'Simple Host'		;
	my $colour 	= 'blue'		;
	add_netobject($type,$name,$ip,$nm,$descrip,$colour, $orderednetobj_ref, $netobjects_ref, $ips_ref);
}
sub add_net {
	my ($name,$ip,$nm, $orderednetobj_ref, $netobjects_ref, $ips_ref) = @_;
	my $type 	= 'net'			;
	my $descrip	= 'Simple Network'	;
	my $colour 	= 'green'		;
	add_netobject($type,$name,$ip,$nm,$descrip,$colour, $orderednetobj_ref, $netobjects_ref, $ips_ref);
}
sub add_range {
	my ($name,$rangestart,$rangeend, $orderednetobj_ref, $netobjects_ref, $ips_ref) = @_;
	my $type 	= 'range'			;
	my $descrip	= 'Simple Range'	;
	my $colour 	= 'black'		;
	add_rangeobject($type,$name,$rangestart,$rangeend,$descrip,$colour, $orderednetobj_ref, $netobjects_ref, $ips_ref);
}
sub add_netobject {
	my ($type,$name,$ip,$nm,$descrip,$colour, $orderednetobj_ref, $netobjects_ref, $ips_ref) = @_;
	my $ipbin 				= ip_to_bin($ip)			;
	my ($maskbin, $maskbits, $masklength)	= netmask_to_bin($nm)			;
	my ($maskedipbin) 			= substr($ipbin, 0, $masklength)	;
	my $cidr 				= "$ip\/$masklength"			;
	$netobjects_ref->{$name}{'type'} 	= $type			;
	$netobjects_ref->{$name}{'ip'} 		= $ip			;
	$netobjects_ref->{$name}{'nm'} 		= $nm			;
	$netobjects_ref->{$name}{'colour'} 	= $colour		;
	$netobjects_ref->{$name}{'cidr'} 	= $cidr			;
	$netobjects_ref->{$name}{'description'} = $descrip		;
	$netobjects_ref->{$name}{'ipbin'}{$maskedipbin}++ 		;
	$ips_ref->{$maskedipbin}{'name'} 	= $name     		;
	push(	@{$orderednetobj_ref},		  $name)		;

	# NOTE: cluster object stuff 

	#my ($type,$name,$ip,$nm,$descrip,$colour,$member,$interface, $netobjects_ref, $ips_ref) = @_;
	#$netobjects_ref->{$name}{'member'} 	= $member		;
	#$netobjects_ref->{$name}{'interface'} = $interface		;
}
sub add_rangeobject {
	my ($type,$name,$rangestart,$rangeend,$descrip,$colour, $orderednetobj_ref, $netobjects_ref, $ips_ref) = @_;
	my $cidr 				= "$rangestart\/$rangeend";
	$netobjects_ref->{$name}{'type'} 	= $type			;
	$netobjects_ref->{$name}{'rangestart'} 	= $rangestart		;
	$netobjects_ref->{$name}{'rangeend'} 	= $rangeend		;
	$netobjects_ref->{$name}{'colour'} 	= $colour		;
	$netobjects_ref->{$name}{'cidr'} 	= $cidr			;
	$netobjects_ref->{$name}{'description'} = $descrip		;
	push(	@{$orderednetobj_ref},		  $name)		;
}

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to add services - the build stage for checkpoint and the port proto processing bit add further details 
#---------------------------------------------------------------------------------------------

sub add_srvc {
	my ($name,$proto,$port, $orderedports_ref, $srvcobjects_ref, $ports_ref) = @_;
	my $type = $proto;
	my $descrip = 'Simple Service';
	my $colour = 'green';
	if ($proto =~ /\w+\-\w+/) {
		my @protos = split (/\-/, $proto);
		foreach my $protos (@protos) {
			add_srvcobject ($type,$name,$protos,$port,$descrip,$colour, $orderedports_ref, $srvcobjects_ref, $ports_ref);
		}
	} else {
		add_srvcobject ($type,$name,$proto,$port,$descrip,$colour, $orderedports_ref, $srvcobjects_ref, $ports_ref);
	}
}

sub add_srvcobject {
	my ($type,$name,$proto,$port,$descrip,$colour, $orderedports_ref, $srvcobjects_ref, $ports_ref) = @_;
	$srvcobjects_ref->{$name}{'port'}{$proto} 	= $port		;
	$srvcobjects_ref->{$name}{'type'} 		= $proto	;
	$ports_ref->{$proto}{$port}{'name'} 		= $name		;
	$srvcobjects_ref->{$name}{'description'} 	= $descrip		;
	$srvcobjects_ref->{$name}{'colour'} 		= $colour		;
	push(		@{$orderedports_ref}, 		  $name)		;
}

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to GET speciffic things 
#---------------------------------------------------------------------------------------------

sub get_netobj {
	my ($netobj, $netobjects_ref) = @_;
	my ($name, $ip, $nm, $colour, $cidr, $type, $description, @ipbins, @rulesrcs, @ruledsts, @supergroups, @logsrcrules, @logsrcsrvcs, @logdstrules, @logdstsrvcs, @natsrcs, @natdsts, @natsrvcs, @lognatsrcs, @lognatdsts, @lognatsrvcs);
 
	if (exists $netobjects_ref->{$netobj}{'ip'}) {
		$ip = $netobjects_ref->{$netobj}{'ip'};
	} elsif (exists $netobjects_ref->{$netobj}{'rangestart'}) {
		$ip = $netobjects_ref->{$netobj}{'rangestart'};
	} else { 
		$ip = 'none';
	}
	if (exists $netobjects_ref->{$netobj}{'nm'}) {
		$nm = $netobjects_ref->{$netobj}{'nm'};
	} elsif (exists $netobjects_ref->{$netobj}{'rangeend'}) {
		$nm = $netobjects_ref->{$netobj}{'rangeend'};
	} else {
		$nm = 'none';
	}
	if (exists $netobjects_ref->{$netobj}{'colour'}) {
		$colour = $netobjects_ref->{$netobj}{'colour'};
	} else {
		$colour = 'none';
	} 
	if (exists $netobjects_ref->{$netobj}{'supergroups'}) {
		@supergroups = @{$netobjects_ref->{$netobj}{'supergroups'}};
	} else {
		@supergroups = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'cidr'}) {
		$cidr = $netobjects_ref->{$netobj}{'cidr'};
	} else {
		$cidr = 'none';
	} 
	if (exists $netobjects_ref->{$netobj}{'type'}) {
		$type = $netobjects_ref->{$netobj}{'type'};
	} else {
		$type = 'none';
	} 
	if (exists $netobjects_ref->{$netobj}{'description'}) {
		$description = $netobjects_ref->{$netobj}{'description'};
	} else {
		$description = 'none';
	} 
	if (exists $netobjects_ref->{$netobj}{'ipbin'}) {
		@ipbins = sort keys %{$netobjects_ref->{$netobj}{'ipbin'}};
	} else {
		@ipbins = ('none')
	}
	if (exists $netobjects_ref->{$netobj}{'rulesrcs'}) {
		@rulesrcs = sort keys %{$netobjects_ref->{$netobj}{'rulesrcs'}};
	} else {
		@rulesrcs = ('none'); 
	}
	if (exists $netobjects_ref->{$netobj}{'ruledsts'}) {
		@ruledsts = sort keys %{$netobjects_ref->{$netobj}{'ruledsts'}};
	} else {
		@ruledsts = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'logsrcrules'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'logsrcrules'}}) {
			push (@logsrcrules, "Log Rule: $key  Hits: $value ");
		}
	} else {
		@logsrcrules = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'logsrcsrvcs'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'logsrcsrvcs'}}) {
			push (@logsrcsrvcs, "Service: $key  Hits: $value ");
		}
	} else {
		@logsrcsrvcs = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'logdstrules'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'logdstrules'}}) {
			push (@logdstrules, "Log Rule: $key  Hits: $value ");
		}
	} else {
		@logdstrules = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'logdstsrvcs'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'logdstsrvcs'}}) {
			push (@logdstsrvcs, "Service: $key  Hits: $value ");
		}
	} else {
		@logdstsrvcs = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'lognatsrc'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'lognatsrc'}}) {
			push (@lognatsrcs, "Log Rule: $value NAT SRC: $key ");
		}
	} else {
		@lognatsrcs = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'lognatdst'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'lognatdst'}}) {
			push (@lognatdsts, "Log Rule: $value NAT DST: $key ");
		}
	} else {
		@lognatdsts = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'lognatsrvc'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'lognatsrvc'}}) {
			push (@lognatsrvcs, "Log Rule: $value NAT SRVC: $key ");
		}
	} else {
		@lognatsrvcs = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'natsrc'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'natsrc'}}) {
			push (@natsrcs, "Rule: $value NAT SRC: $key ");
		}
	} else {
		@natsrcs = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'natdst'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'natdst'}}) {
			push (@natdsts, "Rule: $value NAT DST: $key ");
		}
	} else {
		@natdsts = ('none');
	}
	if (exists $netobjects_ref->{$netobj}{'natsrvc'}) {
		while (my ($key, $value) = each %{$netobjects_ref->{$netobj}{'natsrvc'}}) {
			push (@natsrvcs, "Rule: $value NAT SRVC: $key ");
		}
	} else {
		@natsrvcs = ('none');
	}
	@logsrcrules = sort @logsrcrules ;
	@logsrcsrvcs = sort @logsrcsrvcs ;
	@logdstrules = sort @logdstrules ;
	@logdstsrvcs = sort @logdstsrvcs ;
	@lognatsrcs  = sort @lognatsrcs  ;
	@lognatdsts  = sort @lognatdsts  ;
	@lognatsrvcs = sort @lognatsrvcs ;
	@natsrcs  = sort @natsrcs  ;
	@natdsts  = sort @natdsts  ;
	@natsrvcs = sort @natsrvcs ;

	return ($type, $ip, $nm, $colour, \@supergroups, $cidr, $description, \@ipbins, \@rulesrcs, \@ruledsts, \@logsrcrules, \@logsrcsrvcs, \@logdstrules, \@logdstsrvcs, \@natsrcs, \@natdsts, \@natsrvcs, \@lognatsrcs, \@lognatdsts, \@lognatsrvcs);
}

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to identify speciffic things 
#---------------------------------------------------------------------------------------------

sub is_ip {
	if ( $_[0] =~ /^(\d{1,3}).(\d{1,3}).(\d{1,3}).(\d{1,3})$/ ) {
		my ($yesno)				;
		my ($byte)				;
		$yesno = 0				;
		my (@ip) = split (/\./, "$_[0]")  	;
		foreach $byte (@ip) {
			if (256 > $byte) {
				$yesno++		;
			}
		}
		if ($yesno == 4) {
			#print "YEH, LETS FUCK $_[0]\n"	;
			return 1			;
		} else 	{
			return 0			;
		}
	} else {
		return 0;
	}
}
sub isnt_ip {
	if ( $_[0] =~ /^(\d{1,3}).(\d{1,3}).(\d{1,3}).(\d{1,3})$/ ) {
		my ($yesno)				;
		my ($byte)				;
		$yesno = 0				;
		my (@ip) = split (/\./, "$_[0]")  	;
		foreach $byte (@ip) {
			if (256 > $byte) {
				$yesno++		;
			}
		}
		if ($yesno == 4) {
			#print "YEH, LETS FUCK $_[0]\n"	;
			return 0			;
		} else 	{
			return 1			;
		}
	} else {
		return 1;
	}
}
sub is_netmask {
	if (is_ip($_[0])) {
		my ($maskbin) = ip_to_bin($_[0]);
		if ($maskbin =~ /"01"/ ) {
			return 0		;
		} else {
			return 1		;
		}
	} else {
		return 0			;
		#print "FISH FACED COCK END $_[0]\n";
	}
}
sub is_netobj_name {
	my ($name, $netobjects_ref) = @_;
	if (exists $netobjects_ref->{$name}) {
		return 1				;
	} else {
		return 0				;
	}
}
sub is_srvcobj_name {
	my ($name, $srvcobjects_ref) = @_;
	if (exists $srvcobjects_ref->{$name}) {
		return 1				;
	} else {
		return 0				;
	}
}
sub isnt_netobj_name {
	my ($name, $netobjects_ref) = @_;
	if (exists $netobjects_ref->{$name}) {
		return 0				;
	} else {
		return 1				;
	}
}
sub isnt_srvcobj_name {
	my ($name, $srvcobjects_ref) = @_;
	if (exists $srvcobjects_ref->{$name}) {
		return 0				;
	} else {
		return 1				;
	}
}
sub is_name {
	my ($name, $netobjects_ref, $srvcobjects_ref, $netgroups_ref, $srvcgroups_ref) = @_;
	if (exists $netobjects_ref->{$name}) {
		return 1				;
	} elsif (exists $netgroups_ref->{$name}) {
		return 1				;
	} elsif (exists $srvcobjects_ref->{$name}) {
		return 1				;
	} elsif (exists $srvcgroups_ref->{$name}) {
		return 1				;
	} else {
		return 0				;
	}
}
sub isnt_name {
	my ($name, $netobjects_ref, $srvcobjects_ref, $netgroups_ref, $srvcgroups_ref) = @_ ;
	if (exists $netobjects_ref->{$name}) {
		return 0				;
	} elsif (exists $netgroups_ref->{$name}) {
		return 0				;
	} elsif (exists $srvcobjects_ref->{$name}) {
		return 0				;
	} elsif (exists $srvcgroups_ref->{$name}) {
		return 0				;
	} else {
		return 1				;
	}
}
#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to check if things are known - more comprehensive (or different) checking
#---------------------------------------------------------------------------------------------

sub address_is_known { 
	my ($ip, $ips_ref) = @_	;
	if (is_ip($ip)) {
		my ($ipbin) 	= ip_to_bin($ip)	;
		if (exists ($ips_ref->{$ipbin})) {
			return 1			;
		} else {
			return 0			;
		}
	} else {
		return 0;
	}
}
sub address_isnt_known { 
	my ($ip, $ips_ref) = @_	;
	if (is_ip($ip)) {
		my ($ipbin) 	= ip_to_bin($ip)	;
		if (exists ($ips_ref->{$ipbin})) {
			return 0			;
		} else {
			return 1			;
		}
	} else {
		return 0;
	}
}
sub network_is_known { 
	my ($ip, $nm, $ips_ref) = @_;
	if (is_ip($ip) && is_netmask($nm)) {
		my ($ipbin) 	= ip_to_bin($_[0])				;
		my ($maskbin, $maskbits, $masklength) = netmask_to_bin($_[1])	;
		my ($maskedbits) = substr($ipbin, 0, $masklength)		;
		#print "ML $masklength\n";
		if (exists($ips_ref->{$maskedbits})) {
			return 1						;
		} else {
			return 0						;
		}
	} else {
		return 0;
	}
}
sub network_isnt_known { 
	my ($ip, $nm, $ips_ref) = @_;
	if (is_ip($ip) && is_netmask($nm)) {
		my ($ipbin) 	= ip_to_bin($_[0])				;
		my ($maskbin, $maskbits, $masklength) = netmask_to_bin($_[1])	;
		my ($maskedbits) = substr($ipbin, 0, $masklength)		;
		#print "ML $masklength\n";
		if (exists($ips_ref->{$maskedbits})) {
			return 0						;
		} else {
			return 1						;
		}
	} else {
		return 0;
	}
}
sub proto_is_known {
	my ($proto, $ports_ref) = @_;
	if (exists $ports_ref->{$proto}) {
		return 1;
	} else {
		return 0;
	}
}
sub port_is_known {
	my ($proto, $port, $ports_ref) = @_;
	if (exists $ports_ref->{$proto}) {
		if (exists $ports_ref->{$proto}{$port}) {
			return 1;
		} else {
			return 0;
		}
	} else {
		return 0;
	}
}
sub proto_isnt_known {
	my ($proto, $ports_ref) = @_;
	if (exists $ports_ref->{$proto}) {
		return 0;
	} else {
		return 1;
	}
}
sub port_isnt_known {
	my ($proto, $port, $ports_ref) = @_;
	if (exists $ports_ref->{$proto}) {
		if (exists $ports_ref->{$proto}{$port}) {
			return 0;
		} else {
			return 1;
		}
	} else {
		return 1;
	}
}


sub net_group_is_known {
	my ($group,$netgroups_ref) = @_ ;
	if ( exists $netgroups_ref->{$group} ) {
		return 1			;
	} else {
		return 0			;
	}
}
sub service_group_is_known {
	my ($group,$srvcgroups_ref) = @_	;
	if ( exists $srvcgroups_ref->{$group} ) {
		#print " KNOWN GROUP: $group\n";
		return 1			;
	} else {
		return 0			;
	}
}
sub net_or_service_group_is_known {
	my ($grouptype,$group,$netgroups_ref,$srvcgroups_ref) 	= @_	;
	if ($grouptype 		=~ /service/ ) {
		if (service_group_is_known($group,$srvcgroups_ref)) {
			return 1			;
		} else {
			return 0			;
		}
	} elsif ($grouptype 	=~ /network/ ) {
		if (net_group_is_known($group,$netgroups_ref)) {
			return 1			;
		} else {
			return 0			;
		}
	}
}

#---------------------------------------------------------------------------------------------
# NOTE: Subroutines to find things and their supernets
#---------------------------------------------------------------------------------------------

sub find_net_object {
	my ($object,$netobjects_ref,$ips_ref) = @_ 				;
        if (exists ($netobjects_ref->{$object})) {
                return ($object)			;
        } else {
                my ($ipbin) = ip_to_bin($object)	;
		until (exists ($ips_ref->{$ipbin}) || $ipbin eq "") {
                        chop ($ipbin)			;
                }
                return ($ips_ref->{$ipbin}{'name'}) 		;
        }
}
sub find_supernets_and_duplicates {
	my @names;
	my @duplnames;
	my @subnames;
	my @hostnames;
	my ($ipbin, $ips_ref, $duplips_ref) = @_;
	my $workbin = $ipbin;
	until ($workbin eq "") {
		chop ($workbin);
		if (exists $ips_ref->{$workbin}) {
			my $obname = $ips_ref->{$workbin}{'name'};
			next if $obname eq 'Any';
			next if $obname eq 'any';
			next if $obname eq 'ANY';
			push (@names, $obname);
		}
	}
	my $dupworkbin = $ipbin;
	if (exists $duplips_ref->{$dupworkbin}) {
		foreach my $dupli (sort keys %{$duplips_ref->{$dupworkbin}}) {
			push (@duplnames, $dupli);
		}
	}
	#@hostnames = ('Range_To_Large_For_Meaningful_Host_List');
	#@subnames = ('Range_To_Large_To_Process_Timely_Supernet_List');

	return (\@names, \@duplnames, \@subnames, \@hostnames);
}
sub find_supernets_duplicates_and_subnets {
	my @names;
	my @duplnames;
	my @subnames;
	my @hostnames;
	my ($ipbin, $ips_ref, $duplips_ref) = @_;
	my $workbin = $ipbin;
	until ($workbin eq "") {
		chop ($workbin);
		if (exists $ips_ref->{$workbin}) {
			my $obname = $ips_ref->{$workbin}{'name'};
			next if $obname eq 'Any';
			next if $obname eq 'any';
			next if $obname eq 'ANY';
			push (@names, $obname);
		}
	}
	my $dupworkbin = $ipbin;
	if (exists $duplips_ref->{$dupworkbin}) {
		foreach my $dupli (sort keys %{$duplips_ref->{$dupworkbin}}) {
			push (@duplnames, $dupli);
		}
	}
	my $binlen = length($ipbin);
	my $subworkbin = $ipbin;
	foreach my $testbin (keys %{$ips_ref}) {
		next if $testbin eq $subworkbin;
		my $testlen = length($testbin);
		my $testlenorig = length($testbin);
		my $testworkbin = $testbin;
		if ($testlen > $binlen) {
			#print "FIRST TEST: $testlen, $binlen, $testworkbin\n";
			until ( $testlen < $binlen) {
				last if $binlen == 0 ;
				#print "UNTIL TEST: $testlen, $binlen, $testworkbin\n";
				if ($testworkbin eq $subworkbin) {
					if (($testlenorig == 32) && ($binlen < 18)) { 
						@hostnames = ('Net_To_Large_For_Meaningful_Host_List');
					} elsif (($testlenorig == 32)) { 
						my $hostobname = $ips_ref->{$testbin}{'name'};
						#print "MADEIT HOST TEST: $testlen, $binlen, $testworkbin, $subobname\n";
						push (@hostnames, $hostobname);
					} else {
						my $subobname = $ips_ref->{$testbin}{'name'};
						#print "MADEIT NET TEST: $testlen, $binlen, $testworkbin, $subobname\n";
						push (@subnames, $subobname);
					}
				}
				chop ($testworkbin);
				$testlen = length($testworkbin);
			}
		}
	}
	return (\@names, \@duplnames, \@subnames, \@hostnames);
}
sub find_net_object_and_supernets_and_duplicates {
	my @names;
	my ($ipbin, $ips_ref, $duplips_ref) = @_;
	my $workbin = $ipbin;
	for (my $i = 0; $i <= 32; $i++) {
		if (exists $ips_ref->{$workbin}) {
			my $obname = $ips_ref->{$workbin}{'name'};
			next if $obname eq 'Any';
			push (@names, $obname);
		}
		chop ($workbin);
	}
	my $dupworkbin = $ipbin;
	for (my $i = 0; $i <= 32; $i++) {
		if (exists $duplips_ref->{$dupworkbin}) {
			foreach my $dupli (sort keys %{$duplips_ref->{$dupworkbin}}) {
				next if $dupli eq 'Any';
				push (@names, $dupli);
			}
		}
		chop ($dupworkbin);
	}
	return @names;
}

#---------------------------------------------------------------------------------------------
# CONFIG dumpers
#---------------------------------------------------------------------------------------------

#$Data::Dumper::Indent = 3;

#print "CONFIG BUNDLES TREE         	\n########################################################################################################################\n\n". Dumper(%configbundles) . "\n\n"		;

#---------------------------------------------------------------------------------------------
# Define Defaults Subroutines
#---------------------------------------------------------------------------------------------

sub set_osx_defaults {
	my ($srvcobjects_ref, $ports_ref) = @_;

## NOTE: OSX /etc/services ports
#
#	$srvcobjects_ref->{'gmrupdateserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gmrupdateserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gmrupdateserv'}{'port'}{'udp'} = '1070'	; 
#	$srvcobjects_ref->{'gmrupdateserv'}{'ports'}{'udp'}{'1070'}++	; 
#	$ports_ref->{'udp'}{'1070'}{'name'} = 'gmrupdateserv'		; 
#	$srvcobjects_ref->{'gmrupdateserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gmrupdateserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gmrupdateserv'}{'port'}{'tcp'} = '1070'	; 
#	$srvcobjects_ref->{'gmrupdateserv'}{'ports'}{'tcp'}{'1070'}++	; 
#	$ports_ref->{'tcp'}{'1070'}{'name'} = 'gmrupdateserv'		; 
#	$srvcobjects_ref->{'circle-x'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'circle-x'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'circle-x'}{'port'}{'udp'} = '2931'	; 
#	$srvcobjects_ref->{'circle-x'}{'ports'}{'udp'}{'2931'}++	; 
#	$ports_ref->{'udp'}{'2931'}{'name'} = 'circle-x'		; 
#	$srvcobjects_ref->{'circle-x'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'circle-x'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'circle-x'}{'port'}{'tcp'} = '2931'	; 
#	$srvcobjects_ref->{'circle-x'}{'ports'}{'tcp'}{'2931'}++	; 
#	$ports_ref->{'tcp'}{'2931'}{'name'} = 'circle-x'		; 
#	$srvcobjects_ref->{'smartsdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smartsdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smartsdp'}{'port'}{'udp'} = '426'	; 
#	$srvcobjects_ref->{'smartsdp'}{'ports'}{'udp'}{'426'}++	; 
#	$ports_ref->{'udp'}{'426'}{'name'} = 'smartsdp'		; 
#	$srvcobjects_ref->{'smartsdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smartsdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smartsdp'}{'port'}{'tcp'} = '426'	; 
#	$srvcobjects_ref->{'smartsdp'}{'ports'}{'tcp'}{'426'}++	; 
#	$ports_ref->{'tcp'}{'426'}{'name'} = 'smartsdp'		; 
#	$srvcobjects_ref->{'harp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'harp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'harp'}{'port'}{'udp'} = '1816'	; 
#	$srvcobjects_ref->{'harp'}{'ports'}{'udp'}{'1816'}++	; 
#	$ports_ref->{'udp'}{'1816'}{'name'} = 'harp'		; 
#	$srvcobjects_ref->{'harp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'harp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'harp'}{'port'}{'tcp'} = '1816'	; 
#	$srvcobjects_ref->{'harp'}{'ports'}{'tcp'}{'1816'}++	; 
#	$ports_ref->{'tcp'}{'1816'}{'name'} = 'harp'		; 
#	$srvcobjects_ref->{'tsspmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tsspmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsspmap'}{'port'}{'udp'} = '1568'	; 
#	$srvcobjects_ref->{'tsspmap'}{'ports'}{'udp'}{'1568'}++	; 
#	$ports_ref->{'udp'}{'1568'}{'name'} = 'tsspmap'		; 
#	$srvcobjects_ref->{'tsspmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tsspmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsspmap'}{'port'}{'tcp'} = '1568'	; 
#	$srvcobjects_ref->{'tsspmap'}{'ports'}{'tcp'}{'1568'}++	; 
#	$ports_ref->{'tcp'}{'1568'}{'name'} = 'tsspmap'		; 
#	$srvcobjects_ref->{'a1-msc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'a1-msc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a1-msc'}{'port'}{'udp'} = '5602'	; 
#	$srvcobjects_ref->{'a1-msc'}{'ports'}{'udp'}{'5602'}++	; 
#	$ports_ref->{'udp'}{'5602'}{'name'} = 'a1-msc'		; 
#	$srvcobjects_ref->{'a1-msc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'a1-msc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a1-msc'}{'port'}{'tcp'} = '5602'	; 
#	$srvcobjects_ref->{'a1-msc'}{'ports'}{'tcp'}{'5602'}++	; 
#	$ports_ref->{'tcp'}{'5602'}{'name'} = 'a1-msc'		; 
#	$srvcobjects_ref->{'ufastro-instr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ufastro-instr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ufastro-instr'}{'port'}{'udp'} = '3720'	; 
#	$srvcobjects_ref->{'ufastro-instr'}{'ports'}{'udp'}{'3720'}++	; 
#	$ports_ref->{'udp'}{'3720'}{'name'} = 'ufastro-instr'		; 
#	$srvcobjects_ref->{'ufastro-instr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ufastro-instr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ufastro-instr'}{'port'}{'tcp'} = '3720'	; 
#	$srvcobjects_ref->{'ufastro-instr'}{'ports'}{'tcp'}{'3720'}++	; 
#	$ports_ref->{'tcp'}{'3720'}{'name'} = 'ufastro-instr'		; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'port'}{'udp'} = '2297'	; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'ports'}{'udp'}{'2297'}++	; 
#	$ports_ref->{'udp'}{'2297'}{'name'} = 'd2k-datamover1'		; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'port'}{'tcp'} = '2297'	; 
#	$srvcobjects_ref->{'d2k-datamover1'}{'ports'}{'tcp'}{'2297'}++	; 
#	$ports_ref->{'tcp'}{'2297'}{'name'} = 'd2k-datamover1'		; 
#	$srvcobjects_ref->{'intellistor-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intellistor-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intellistor-lm'}{'port'}{'udp'} = '1539'	; 
#	$srvcobjects_ref->{'intellistor-lm'}{'ports'}{'udp'}{'1539'}++	; 
#	$ports_ref->{'udp'}{'1539'}{'name'} = 'intellistor-lm'		; 
#	$srvcobjects_ref->{'intellistor-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intellistor-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intellistor-lm'}{'port'}{'tcp'} = '1539'	; 
#	$srvcobjects_ref->{'intellistor-lm'}{'ports'}{'tcp'}{'1539'}++	; 
#	$ports_ref->{'tcp'}{'1539'}{'name'} = 'intellistor-lm'		; 
#	$srvcobjects_ref->{'cryptoadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cryptoadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cryptoadmin'}{'port'}{'udp'} = '624'	; 
#	$srvcobjects_ref->{'cryptoadmin'}{'ports'}{'udp'}{'624'}++	; 
#	$ports_ref->{'udp'}{'624'}{'name'} = 'cryptoadmin'		; 
#	$srvcobjects_ref->{'cryptoadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cryptoadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cryptoadmin'}{'port'}{'tcp'} = '624'	; 
#	$srvcobjects_ref->{'cryptoadmin'}{'ports'}{'tcp'}{'624'}++	; 
#	$ports_ref->{'tcp'}{'624'}{'name'} = 'cryptoadmin'		; 
#	$srvcobjects_ref->{'pcsync-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcsync-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcsync-http'}{'port'}{'udp'} = '8444'	; 
#	$srvcobjects_ref->{'pcsync-http'}{'ports'}{'udp'}{'8444'}++	; 
#	$ports_ref->{'udp'}{'8444'}{'name'} = 'pcsync-http'		; 
#	$srvcobjects_ref->{'pcsync-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcsync-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcsync-http'}{'port'}{'tcp'} = '8444'	; 
#	$srvcobjects_ref->{'pcsync-http'}{'ports'}{'tcp'}{'8444'}++	; 
#	$ports_ref->{'tcp'}{'8444'}{'name'} = 'pcsync-http'		; 
#	$srvcobjects_ref->{'infoexch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infoexch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infoexch'}{'port'}{'udp'} = '3667'	; 
#	$srvcobjects_ref->{'infoexch'}{'ports'}{'udp'}{'3667'}++	; 
#	$ports_ref->{'udp'}{'3667'}{'name'} = 'infoexch'		; 
#	$srvcobjects_ref->{'infoexch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infoexch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infoexch'}{'port'}{'tcp'} = '3667'	; 
#	$srvcobjects_ref->{'infoexch'}{'ports'}{'tcp'}{'3667'}++	; 
#	$ports_ref->{'tcp'}{'3667'}{'name'} = 'infoexch'		; 
#	$srvcobjects_ref->{'prat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prat'}{'port'}{'udp'} = '1264'	; 
#	$srvcobjects_ref->{'prat'}{'ports'}{'udp'}{'1264'}++	; 
#	$ports_ref->{'udp'}{'1264'}{'name'} = 'prat'		; 
#	$srvcobjects_ref->{'prat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prat'}{'port'}{'tcp'} = '1264'	; 
#	$srvcobjects_ref->{'prat'}{'ports'}{'tcp'}{'1264'}++	; 
#	$ports_ref->{'tcp'}{'1264'}{'name'} = 'prat'		; 
#	$srvcobjects_ref->{'imap4-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imap4-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imap4-ssl'}{'port'}{'udp'} = '585'	; 
#	$srvcobjects_ref->{'imap4-ssl'}{'ports'}{'udp'}{'585'}++	; 
#	$ports_ref->{'udp'}{'585'}{'name'} = 'imap4-ssl'		; 
#	$srvcobjects_ref->{'imap4-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imap4-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imap4-ssl'}{'port'}{'tcp'} = '585'	; 
#	$srvcobjects_ref->{'imap4-ssl'}{'ports'}{'tcp'}{'585'}++	; 
#	$ports_ref->{'tcp'}{'585'}{'name'} = 'imap4-ssl'		; 
#	$srvcobjects_ref->{'guibase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'guibase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'guibase'}{'port'}{'udp'} = '9321'	; 
#	$srvcobjects_ref->{'guibase'}{'ports'}{'udp'}{'9321'}++	; 
#	$ports_ref->{'udp'}{'9321'}{'name'} = 'guibase'		; 
#	$srvcobjects_ref->{'guibase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'guibase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'guibase'}{'port'}{'tcp'} = '9321'	; 
#	$srvcobjects_ref->{'guibase'}{'ports'}{'tcp'}{'9321'}++	; 
#	$ports_ref->{'tcp'}{'9321'}{'name'} = 'guibase'		; 
#	$srvcobjects_ref->{'redwood-chat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'redwood-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redwood-chat'}{'port'}{'udp'} = '3032'	; 
#	$srvcobjects_ref->{'redwood-chat'}{'ports'}{'udp'}{'3032'}++	; 
#	$ports_ref->{'udp'}{'3032'}{'name'} = 'redwood-chat'		; 
#	$srvcobjects_ref->{'redwood-chat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'redwood-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redwood-chat'}{'port'}{'tcp'} = '3032'	; 
#	$srvcobjects_ref->{'redwood-chat'}{'ports'}{'tcp'}{'3032'}++	; 
#	$ports_ref->{'tcp'}{'3032'}{'name'} = 'redwood-chat'		; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'port'}{'udp'} = '2525'	; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'ports'}{'udp'}{'2525'}++	; 
#	$ports_ref->{'udp'}{'2525'}{'name'} = 'ms-v-worlds'		; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'port'}{'tcp'} = '2525'	; 
#	$srvcobjects_ref->{'ms-v-worlds'}{'ports'}{'tcp'}{'2525'}++	; 
#	$ports_ref->{'tcp'}{'2525'}{'name'} = 'ms-v-worlds'		; 
#	$srvcobjects_ref->{'jaleosnd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jaleosnd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jaleosnd'}{'port'}{'udp'} = '1623'	; 
#	$srvcobjects_ref->{'jaleosnd'}{'ports'}{'udp'}{'1623'}++	; 
#	$ports_ref->{'udp'}{'1623'}{'name'} = 'jaleosnd'		; 
#	$srvcobjects_ref->{'jaleosnd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jaleosnd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jaleosnd'}{'port'}{'tcp'} = '1623'	; 
#	$srvcobjects_ref->{'jaleosnd'}{'ports'}{'tcp'}{'1623'}++	; 
#	$ports_ref->{'tcp'}{'1623'}{'name'} = 'jaleosnd'		; 
#	$srvcobjects_ref->{'netangel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netangel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netangel'}{'port'}{'udp'} = '2442'	; 
#	$srvcobjects_ref->{'netangel'}{'ports'}{'udp'}{'2442'}++	; 
#	$ports_ref->{'udp'}{'2442'}{'name'} = 'netangel'		; 
#	$srvcobjects_ref->{'netangel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netangel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netangel'}{'port'}{'tcp'} = '2442'	; 
#	$srvcobjects_ref->{'netangel'}{'ports'}{'tcp'}{'2442'}++	; 
#	$ports_ref->{'tcp'}{'2442'}{'name'} = 'netangel'		; 
#	$srvcobjects_ref->{'statsci2-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'statsci2-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statsci2-lm'}{'port'}{'udp'} = '6145'	; 
#	$srvcobjects_ref->{'statsci2-lm'}{'ports'}{'udp'}{'6145'}++	; 
#	$ports_ref->{'udp'}{'6145'}{'name'} = 'statsci2-lm'		; 
#	$srvcobjects_ref->{'statsci2-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'statsci2-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statsci2-lm'}{'port'}{'tcp'} = '6145'	; 
#	$srvcobjects_ref->{'statsci2-lm'}{'ports'}{'tcp'}{'6145'}++	; 
#	$ports_ref->{'tcp'}{'6145'}{'name'} = 'statsci2-lm'		; 
#	$srvcobjects_ref->{'ep-nsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ep-nsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ep-nsp'}{'port'}{'udp'} = '3621'	; 
#	$srvcobjects_ref->{'ep-nsp'}{'ports'}{'udp'}{'3621'}++	; 
#	$ports_ref->{'udp'}{'3621'}{'name'} = 'ep-nsp'		; 
#	$srvcobjects_ref->{'ep-nsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ep-nsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ep-nsp'}{'port'}{'tcp'} = '3621'	; 
#	$srvcobjects_ref->{'ep-nsp'}{'ports'}{'tcp'}{'3621'}++	; 
#	$ports_ref->{'tcp'}{'3621'}{'name'} = 'ep-nsp'		; 
#	$srvcobjects_ref->{'tns-adv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tns-adv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tns-adv'}{'port'}{'udp'} = '3309'	; 
#	$srvcobjects_ref->{'tns-adv'}{'ports'}{'udp'}{'3309'}++	; 
#	$ports_ref->{'udp'}{'3309'}{'name'} = 'tns-adv'		; 
#	$srvcobjects_ref->{'tns-adv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tns-adv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tns-adv'}{'port'}{'tcp'} = '3309'	; 
#	$srvcobjects_ref->{'tns-adv'}{'ports'}{'tcp'}{'3309'}++	; 
#	$ports_ref->{'tcp'}{'3309'}{'name'} = 'tns-adv'		; 
#	$srvcobjects_ref->{'jmact6'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmact6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmact6'}{'port'}{'udp'} = '2958'	; 
#	$srvcobjects_ref->{'jmact6'}{'ports'}{'udp'}{'2958'}++	; 
#	$ports_ref->{'udp'}{'2958'}{'name'} = 'jmact6'		; 
#	$srvcobjects_ref->{'jmact6'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmact6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmact6'}{'port'}{'tcp'} = '2958'	; 
#	$srvcobjects_ref->{'jmact6'}{'ports'}{'tcp'}{'2958'}++	; 
#	$ports_ref->{'tcp'}{'2958'}{'name'} = 'jmact6'		; 
#	$srvcobjects_ref->{'eoss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eoss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eoss'}{'port'}{'udp'} = '1210'	; 
#	$srvcobjects_ref->{'eoss'}{'ports'}{'udp'}{'1210'}++	; 
#	$ports_ref->{'udp'}{'1210'}{'name'} = 'eoss'		; 
#	$srvcobjects_ref->{'eoss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eoss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eoss'}{'port'}{'tcp'} = '1210'	; 
#	$srvcobjects_ref->{'eoss'}{'ports'}{'tcp'}{'1210'}++	; 
#	$ports_ref->{'tcp'}{'1210'}{'name'} = 'eoss'		; 
#	$srvcobjects_ref->{'opsec-cvp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsec-cvp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-cvp'}{'port'}{'udp'} = '18181'	; 
#	$srvcobjects_ref->{'opsec-cvp'}{'ports'}{'udp'}{'18181'}++	; 
#	$ports_ref->{'udp'}{'18181'}{'name'} = 'opsec-cvp'		; 
#	$srvcobjects_ref->{'opsec-cvp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsec-cvp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-cvp'}{'port'}{'tcp'} = '18181'	; 
#	$srvcobjects_ref->{'opsec-cvp'}{'ports'}{'tcp'}{'18181'}++	; 
#	$ports_ref->{'tcp'}{'18181'}{'name'} = 'opsec-cvp'		; 
#	$srvcobjects_ref->{'rxe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rxe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rxe'}{'port'}{'udp'} = '761'	; 
#	$srvcobjects_ref->{'rxe'}{'ports'}{'udp'}{'761'}++	; 
#	$ports_ref->{'udp'}{'761'}{'name'} = 'rxe'		; 
#	$srvcobjects_ref->{'rxe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rxe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rxe'}{'port'}{'tcp'} = '761'	; 
#	$srvcobjects_ref->{'rxe'}{'ports'}{'tcp'}{'761'}++	; 
#	$ports_ref->{'tcp'}{'761'}{'name'} = 'rxe'		; 
#	$srvcobjects_ref->{'banyan-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'banyan-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'banyan-net'}{'port'}{'udp'} = '2708'	; 
#	$srvcobjects_ref->{'banyan-net'}{'ports'}{'udp'}{'2708'}++	; 
#	$ports_ref->{'udp'}{'2708'}{'name'} = 'banyan-net'		; 
#	$srvcobjects_ref->{'banyan-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'banyan-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'banyan-net'}{'port'}{'tcp'} = '2708'	; 
#	$srvcobjects_ref->{'banyan-net'}{'ports'}{'tcp'}{'2708'}++	; 
#	$ports_ref->{'tcp'}{'2708'}{'name'} = 'banyan-net'		; 
#	$srvcobjects_ref->{'osu-nms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'osu-nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'osu-nms'}{'port'}{'udp'} = '192'	; 
#	$srvcobjects_ref->{'osu-nms'}{'ports'}{'udp'}{'192'}++	; 
#	$ports_ref->{'udp'}{'192'}{'name'} = 'osu-nms'		; 
#	$srvcobjects_ref->{'osu-nms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'osu-nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'osu-nms'}{'port'}{'tcp'} = '192'	; 
#	$srvcobjects_ref->{'osu-nms'}{'ports'}{'tcp'}{'192'}++	; 
#	$ports_ref->{'tcp'}{'192'}{'name'} = 'osu-nms'		; 
#	$srvcobjects_ref->{'padl2sim'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'padl2sim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'padl2sim'}{'port'}{'udp'} = '5236'	; 
#	$srvcobjects_ref->{'padl2sim'}{'ports'}{'udp'}{'5236'}++	; 
#	$ports_ref->{'udp'}{'5236'}{'name'} = 'padl2sim'		; 
#	$srvcobjects_ref->{'padl2sim'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'padl2sim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'padl2sim'}{'port'}{'tcp'} = '5236'	; 
#	$srvcobjects_ref->{'padl2sim'}{'ports'}{'tcp'}{'5236'}++	; 
#	$ports_ref->{'tcp'}{'5236'}{'name'} = 'padl2sim'		; 
#	$srvcobjects_ref->{'tns-cml'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tns-cml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tns-cml'}{'port'}{'udp'} = '590'	; 
#	$srvcobjects_ref->{'tns-cml'}{'ports'}{'udp'}{'590'}++	; 
#	$ports_ref->{'udp'}{'590'}{'name'} = 'tns-cml'		; 
#	$srvcobjects_ref->{'tns-cml'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tns-cml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tns-cml'}{'port'}{'tcp'} = '590'	; 
#	$srvcobjects_ref->{'tns-cml'}{'ports'}{'tcp'}{'590'}++	; 
#	$ports_ref->{'tcp'}{'590'}{'name'} = 'tns-cml'		; 
#	$srvcobjects_ref->{'nbx-dir'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nbx-dir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-dir'}{'port'}{'udp'} = '2096'	; 
#	$srvcobjects_ref->{'nbx-dir'}{'ports'}{'udp'}{'2096'}++	; 
#	$ports_ref->{'udp'}{'2096'}{'name'} = 'nbx-dir'		; 
#	$srvcobjects_ref->{'nbx-dir'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nbx-dir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-dir'}{'port'}{'tcp'} = '2096'	; 
#	$srvcobjects_ref->{'nbx-dir'}{'ports'}{'tcp'}{'2096'}++	; 
#	$ports_ref->{'tcp'}{'2096'}{'name'} = 'nbx-dir'		; 
#	$srvcobjects_ref->{'dpkeyserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dpkeyserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpkeyserv'}{'port'}{'udp'} = '1780'	; 
#	$srvcobjects_ref->{'dpkeyserv'}{'ports'}{'udp'}{'1780'}++	; 
#	$ports_ref->{'udp'}{'1780'}{'name'} = 'dpkeyserv'		; 
#	$srvcobjects_ref->{'dpkeyserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dpkeyserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpkeyserv'}{'port'}{'tcp'} = '1780'	; 
#	$srvcobjects_ref->{'dpkeyserv'}{'ports'}{'tcp'}{'1780'}++	; 
#	$ports_ref->{'tcp'}{'1780'}{'name'} = 'dpkeyserv'		; 
#	$srvcobjects_ref->{'nmsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsd'}{'port'}{'udp'} = '1239'	; 
#	$srvcobjects_ref->{'nmsd'}{'ports'}{'udp'}{'1239'}++	; 
#	$ports_ref->{'udp'}{'1239'}{'name'} = 'nmsd'		; 
#	$srvcobjects_ref->{'nmsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsd'}{'port'}{'tcp'} = '1239'	; 
#	$srvcobjects_ref->{'nmsd'}{'ports'}{'tcp'}{'1239'}++	; 
#	$ports_ref->{'tcp'}{'1239'}{'name'} = 'nmsd'		; 
#	$srvcobjects_ref->{'pssc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pssc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pssc'}{'port'}{'udp'} = '645'	; 
#	$srvcobjects_ref->{'pssc'}{'ports'}{'udp'}{'645'}++	; 
#	$ports_ref->{'udp'}{'645'}{'name'} = 'pssc'		; 
#	$srvcobjects_ref->{'pssc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pssc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pssc'}{'port'}{'tcp'} = '645'	; 
#	$srvcobjects_ref->{'pssc'}{'ports'}{'tcp'}{'645'}++	; 
#	$ports_ref->{'tcp'}{'645'}{'name'} = 'pssc'		; 
#	$srvcobjects_ref->{'sdserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdserver'}{'port'}{'udp'} = '2309'	; 
#	$srvcobjects_ref->{'sdserver'}{'ports'}{'udp'}{'2309'}++	; 
#	$ports_ref->{'udp'}{'2309'}{'name'} = 'sdserver'		; 
#	$srvcobjects_ref->{'sdserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdserver'}{'port'}{'tcp'} = '2309'	; 
#	$srvcobjects_ref->{'sdserver'}{'ports'}{'tcp'}{'2309'}++	; 
#	$ports_ref->{'tcp'}{'2309'}{'name'} = 'sdserver'		; 
#	$srvcobjects_ref->{'nimreg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nimreg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimreg'}{'port'}{'udp'} = '1059'	; 
#	$srvcobjects_ref->{'nimreg'}{'ports'}{'udp'}{'1059'}++	; 
#	$ports_ref->{'udp'}{'1059'}{'name'} = 'nimreg'		; 
#	$srvcobjects_ref->{'nimreg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nimreg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimreg'}{'port'}{'tcp'} = '1059'	; 
#	$srvcobjects_ref->{'nimreg'}{'ports'}{'tcp'}{'1059'}++	; 
#	$ports_ref->{'tcp'}{'1059'}{'name'} = 'nimreg'		; 
#	$srvcobjects_ref->{'ps-ams'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ps-ams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ps-ams'}{'port'}{'udp'} = '3658'	; 
#	$srvcobjects_ref->{'ps-ams'}{'ports'}{'udp'}{'3658'}++	; 
#	$ports_ref->{'udp'}{'3658'}{'name'} = 'ps-ams'		; 
#	$srvcobjects_ref->{'ps-ams'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ps-ams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ps-ams'}{'port'}{'tcp'} = '3658'	; 
#	$srvcobjects_ref->{'ps-ams'}{'ports'}{'tcp'}{'3658'}++	; 
#	$ports_ref->{'tcp'}{'3658'}{'name'} = 'ps-ams'		; 
#	$srvcobjects_ref->{'aminet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aminet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aminet'}{'port'}{'udp'} = '2639'	; 
#	$srvcobjects_ref->{'aminet'}{'ports'}{'udp'}{'2639'}++	; 
#	$ports_ref->{'udp'}{'2639'}{'name'} = 'aminet'		; 
#	$srvcobjects_ref->{'aminet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aminet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aminet'}{'port'}{'tcp'} = '2639'	; 
#	$srvcobjects_ref->{'aminet'}{'ports'}{'tcp'}{'2639'}++	; 
#	$ports_ref->{'tcp'}{'2639'}{'name'} = 'aminet'		; 
#	$srvcobjects_ref->{'printer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'printer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'printer'}{'port'}{'udp'} = '515'	; 
#	$srvcobjects_ref->{'printer'}{'ports'}{'udp'}{'515'}++	; 
#	$ports_ref->{'udp'}{'515'}{'name'} = 'printer'		; 
#	$srvcobjects_ref->{'printer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'printer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'printer'}{'port'}{'tcp'} = '515'	; 
#	$srvcobjects_ref->{'printer'}{'ports'}{'tcp'}{'515'}++	; 
#	$ports_ref->{'tcp'}{'515'}{'name'} = 'printer'		; 
#	$srvcobjects_ref->{'gds_db'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gds_db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gds_db'}{'port'}{'udp'} = '3050'	; 
#	$srvcobjects_ref->{'gds_db'}{'ports'}{'udp'}{'3050'}++	; 
#	$ports_ref->{'udp'}{'3050'}{'name'} = 'gds_db'		; 
#	$srvcobjects_ref->{'gds_db'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gds_db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gds_db'}{'port'}{'tcp'} = '3050'	; 
#	$srvcobjects_ref->{'gds_db'}{'ports'}{'tcp'}{'3050'}++	; 
#	$ports_ref->{'tcp'}{'3050'}{'name'} = 'gds_db'		; 
#	$srvcobjects_ref->{'af'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'af'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'af'}{'port'}{'udp'} = '1411'	; 
#	$srvcobjects_ref->{'af'}{'ports'}{'udp'}{'1411'}++	; 
#	$ports_ref->{'udp'}{'1411'}{'name'} = 'af'		; 
#	$srvcobjects_ref->{'af'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'af'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'af'}{'port'}{'tcp'} = '1411'	; 
#	$srvcobjects_ref->{'af'}{'ports'}{'tcp'}{'1411'}++	; 
#	$ports_ref->{'tcp'}{'1411'}{'name'} = 'af'		; 
#	$srvcobjects_ref->{'loadav'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'loadav'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'loadav'}{'port'}{'udp'} = '750'	; 
#	$srvcobjects_ref->{'loadav'}{'ports'}{'udp'}{'750'}++	; 
#	$ports_ref->{'udp'}{'750'}{'name'} = 'loadav'		; 
#	$srvcobjects_ref->{'sua'}{'type'} = 'sctp'	; 
#	$srvcobjects_ref->{'sua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sua'}{'port'}{'sctp'} = '14001'	; 
#	$srvcobjects_ref->{'sua'}{'ports'}{'sctp'}{'14001'}++	; 
#	$ports_ref->{'sctp'}{'14001'}{'name'} = 'sua'		; 
#	$srvcobjects_ref->{'sua'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sua'}{'port'}{'udp'} = '14001'	; 
#	$srvcobjects_ref->{'sua'}{'ports'}{'udp'}{'14001'}++	; 
#	$ports_ref->{'udp'}{'14001'}{'name'} = 'sua'		; 
#	$srvcobjects_ref->{'sua'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sua'}{'port'}{'tcp'} = '14001'	; 
#	$srvcobjects_ref->{'sua'}{'ports'}{'tcp'}{'14001'}++	; 
#	$ports_ref->{'tcp'}{'14001'}{'name'} = 'sua'		; 
#	$srvcobjects_ref->{'jwclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jwclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jwclient'}{'port'}{'udp'} = '1938'	; 
#	$srvcobjects_ref->{'jwclient'}{'ports'}{'udp'}{'1938'}++	; 
#	$ports_ref->{'udp'}{'1938'}{'name'} = 'jwclient'		; 
#	$srvcobjects_ref->{'jwclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jwclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jwclient'}{'port'}{'tcp'} = '1938'	; 
#	$srvcobjects_ref->{'jwclient'}{'ports'}{'tcp'}{'1938'}++	; 
#	$ports_ref->{'tcp'}{'1938'}{'name'} = 'jwclient'		; 
#	$srvcobjects_ref->{'rtsclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtsclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsclient'}{'port'}{'udp'} = '2501'	; 
#	$srvcobjects_ref->{'rtsclient'}{'ports'}{'udp'}{'2501'}++	; 
#	$ports_ref->{'udp'}{'2501'}{'name'} = 'rtsclient'		; 
#	$srvcobjects_ref->{'rtsclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtsclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsclient'}{'port'}{'tcp'} = '2501'	; 
#	$srvcobjects_ref->{'rtsclient'}{'ports'}{'tcp'}{'2501'}++	; 
#	$ports_ref->{'tcp'}{'2501'}{'name'} = 'rtsclient'		; 
#	$srvcobjects_ref->{'as-servermap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'as-servermap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'as-servermap'}{'port'}{'udp'} = '449'	; 
#	$srvcobjects_ref->{'as-servermap'}{'ports'}{'udp'}{'449'}++	; 
#	$ports_ref->{'udp'}{'449'}{'name'} = 'as-servermap'		; 
#	$srvcobjects_ref->{'as-servermap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'as-servermap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'as-servermap'}{'port'}{'tcp'} = '449'	; 
#	$srvcobjects_ref->{'as-servermap'}{'ports'}{'tcp'}{'449'}++	; 
#	$ports_ref->{'tcp'}{'449'}{'name'} = 'as-servermap'		; 
#	$srvcobjects_ref->{'qnts-orb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qnts-orb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qnts-orb'}{'port'}{'udp'} = '1262'	; 
#	$srvcobjects_ref->{'qnts-orb'}{'ports'}{'udp'}{'1262'}++	; 
#	$ports_ref->{'udp'}{'1262'}{'name'} = 'qnts-orb'		; 
#	$srvcobjects_ref->{'qnts-orb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qnts-orb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qnts-orb'}{'port'}{'tcp'} = '1262'	; 
#	$srvcobjects_ref->{'qnts-orb'}{'ports'}{'tcp'}{'1262'}++	; 
#	$ports_ref->{'tcp'}{'1262'}{'name'} = 'qnts-orb'		; 
#	$srvcobjects_ref->{'mbus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mbus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mbus'}{'port'}{'udp'} = '47000'	; 
#	$srvcobjects_ref->{'mbus'}{'ports'}{'udp'}{'47000'}++	; 
#	$ports_ref->{'udp'}{'47000'}{'name'} = 'mbus'		; 
#	$srvcobjects_ref->{'mbus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mbus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mbus'}{'port'}{'tcp'} = '47000'	; 
#	$srvcobjects_ref->{'mbus'}{'ports'}{'tcp'}{'47000'}++	; 
#	$ports_ref->{'tcp'}{'47000'}{'name'} = 'mbus'		; 
#	$srvcobjects_ref->{'9pfs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'9pfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'9pfs'}{'port'}{'udp'} = '564'	; 
#	$srvcobjects_ref->{'9pfs'}{'ports'}{'udp'}{'564'}++	; 
#	$ports_ref->{'udp'}{'564'}{'name'} = '9pfs'		; 
#	$srvcobjects_ref->{'9pfs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'9pfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'9pfs'}{'port'}{'tcp'} = '564'	; 
#	$srvcobjects_ref->{'9pfs'}{'ports'}{'tcp'}{'564'}++	; 
#	$ports_ref->{'tcp'}{'564'}{'name'} = '9pfs'		; 
#	$srvcobjects_ref->{'idmaps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idmaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idmaps'}{'port'}{'udp'} = '1884'	; 
#	$srvcobjects_ref->{'idmaps'}{'ports'}{'udp'}{'1884'}++	; 
#	$ports_ref->{'udp'}{'1884'}{'name'} = 'idmaps'		; 
#	$srvcobjects_ref->{'idmaps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idmaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idmaps'}{'port'}{'tcp'} = '1884'	; 
#	$srvcobjects_ref->{'idmaps'}{'ports'}{'tcp'}{'1884'}++	; 
#	$ports_ref->{'tcp'}{'1884'}{'name'} = 'idmaps'		; 
#	$srvcobjects_ref->{'pdnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdnet'}{'port'}{'udp'} = '2843'	; 
#	$srvcobjects_ref->{'pdnet'}{'ports'}{'udp'}{'2843'}++	; 
#	$ports_ref->{'udp'}{'2843'}{'name'} = 'pdnet'		; 
#	$srvcobjects_ref->{'pdnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdnet'}{'port'}{'tcp'} = '2843'	; 
#	$srvcobjects_ref->{'pdnet'}{'ports'}{'tcp'}{'2843'}++	; 
#	$ports_ref->{'tcp'}{'2843'}{'name'} = 'pdnet'		; 
#	$srvcobjects_ref->{'proxy-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proxy-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proxy-gateway'}{'port'}{'udp'} = '2303'	; 
#	$srvcobjects_ref->{'proxy-gateway'}{'ports'}{'udp'}{'2303'}++	; 
#	$ports_ref->{'udp'}{'2303'}{'name'} = 'proxy-gateway'		; 
#	$srvcobjects_ref->{'proxy-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proxy-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proxy-gateway'}{'port'}{'tcp'} = '2303'	; 
#	$srvcobjects_ref->{'proxy-gateway'}{'ports'}{'tcp'}{'2303'}++	; 
#	$ports_ref->{'tcp'}{'2303'}{'name'} = 'proxy-gateway'		; 
#	$srvcobjects_ref->{'citynl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'citynl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citynl'}{'port'}{'udp'} = '1729'	; 
#	$srvcobjects_ref->{'citynl'}{'ports'}{'udp'}{'1729'}++	; 
#	$ports_ref->{'udp'}{'1729'}{'name'} = 'citynl'		; 
#	$srvcobjects_ref->{'citynl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'citynl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citynl'}{'port'}{'tcp'} = '1729'	; 
#	$srvcobjects_ref->{'citynl'}{'ports'}{'tcp'}{'1729'}++	; 
#	$ports_ref->{'tcp'}{'1729'}{'name'} = 'citynl'		; 
#	$srvcobjects_ref->{'lazy-ptop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lazy-ptop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lazy-ptop'}{'port'}{'udp'} = '7099'	; 
#	$srvcobjects_ref->{'lazy-ptop'}{'ports'}{'udp'}{'7099'}++	; 
#	$ports_ref->{'udp'}{'7099'}{'name'} = 'lazy-ptop'		; 
#	$srvcobjects_ref->{'lazy-ptop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lazy-ptop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lazy-ptop'}{'port'}{'tcp'} = '7099'	; 
#	$srvcobjects_ref->{'lazy-ptop'}{'ports'}{'tcp'}{'7099'}++	; 
#	$ports_ref->{'tcp'}{'7099'}{'name'} = 'lazy-ptop'		; 
#	$srvcobjects_ref->{'unite'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unite'}{'port'}{'udp'} = '3217'	; 
#	$srvcobjects_ref->{'unite'}{'ports'}{'udp'}{'3217'}++	; 
#	$ports_ref->{'udp'}{'3217'}{'name'} = 'unite'		; 
#	$srvcobjects_ref->{'unite'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unite'}{'port'}{'tcp'} = '3217'	; 
#	$srvcobjects_ref->{'unite'}{'ports'}{'tcp'}{'3217'}++	; 
#	$ports_ref->{'tcp'}{'3217'}{'name'} = 'unite'		; 
#	$srvcobjects_ref->{'netlabs-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netlabs-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlabs-lm'}{'port'}{'udp'} = '1406'	; 
#	$srvcobjects_ref->{'netlabs-lm'}{'ports'}{'udp'}{'1406'}++	; 
#	$ports_ref->{'udp'}{'1406'}{'name'} = 'netlabs-lm'		; 
#	$srvcobjects_ref->{'netlabs-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netlabs-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlabs-lm'}{'port'}{'tcp'} = '1406'	; 
#	$srvcobjects_ref->{'netlabs-lm'}{'ports'}{'tcp'}{'1406'}++	; 
#	$ports_ref->{'tcp'}{'1406'}{'name'} = 'netlabs-lm'		; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'port'}{'udp'} = '1278'	; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'ports'}{'udp'}{'1278'}++	; 
#	$ports_ref->{'udp'}{'1278'}{'name'} = 'dellwebadmin-1'		; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'port'}{'tcp'} = '1278'	; 
#	$srvcobjects_ref->{'dellwebadmin-1'}{'ports'}{'tcp'}{'1278'}++	; 
#	$ports_ref->{'tcp'}{'1278'}{'name'} = 'dellwebadmin-1'		; 
#	$srvcobjects_ref->{'cpq-wbem'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cpq-wbem'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpq-wbem'}{'port'}{'udp'} = '2301'	; 
#	$srvcobjects_ref->{'cpq-wbem'}{'ports'}{'udp'}{'2301'}++	; 
#	$ports_ref->{'udp'}{'2301'}{'name'} = 'cpq-wbem'		; 
#	$srvcobjects_ref->{'cpq-wbem'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cpq-wbem'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpq-wbem'}{'port'}{'tcp'} = '2301'	; 
#	$srvcobjects_ref->{'cpq-wbem'}{'ports'}{'tcp'}{'2301'}++	; 
#	$ports_ref->{'tcp'}{'2301'}{'name'} = 'cpq-wbem'		; 
#	$srvcobjects_ref->{'lontalk-norm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lontalk-norm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lontalk-norm'}{'port'}{'udp'} = '1628'	; 
#	$srvcobjects_ref->{'lontalk-norm'}{'ports'}{'udp'}{'1628'}++	; 
#	$ports_ref->{'udp'}{'1628'}{'name'} = 'lontalk-norm'		; 
#	$srvcobjects_ref->{'lontalk-norm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lontalk-norm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lontalk-norm'}{'port'}{'tcp'} = '1628'	; 
#	$srvcobjects_ref->{'lontalk-norm'}{'ports'}{'tcp'}{'1628'}++	; 
#	$ports_ref->{'tcp'}{'1628'}{'name'} = 'lontalk-norm'		; 
#	$srvcobjects_ref->{'ms-olap4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-olap4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap4'}{'port'}{'udp'} = '2383'	; 
#	$srvcobjects_ref->{'ms-olap4'}{'ports'}{'udp'}{'2383'}++	; 
#	$ports_ref->{'udp'}{'2383'}{'name'} = 'ms-olap4'		; 
#	$srvcobjects_ref->{'ms-olap4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-olap4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap4'}{'port'}{'tcp'} = '2383'	; 
#	$srvcobjects_ref->{'ms-olap4'}{'ports'}{'tcp'}{'2383'}++	; 
#	$ports_ref->{'tcp'}{'2383'}{'name'} = 'ms-olap4'		; 
#	$srvcobjects_ref->{'hyper-g'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hyper-g'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hyper-g'}{'port'}{'udp'} = '418'	; 
#	$srvcobjects_ref->{'hyper-g'}{'ports'}{'udp'}{'418'}++	; 
#	$ports_ref->{'udp'}{'418'}{'name'} = 'hyper-g'		; 
#	$srvcobjects_ref->{'hyper-g'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hyper-g'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hyper-g'}{'port'}{'tcp'} = '418'	; 
#	$srvcobjects_ref->{'hyper-g'}{'ports'}{'tcp'}{'418'}++	; 
#	$ports_ref->{'tcp'}{'418'}{'name'} = 'hyper-g'		; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'port'}{'udp'} = '3764'	; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'ports'}{'udp'}{'3764'}++	; 
#	$ports_ref->{'udp'}{'3764'}{'name'} = 'mni-prot-rout'		; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'port'}{'tcp'} = '3764'	; 
#	$srvcobjects_ref->{'mni-prot-rout'}{'ports'}{'tcp'}{'3764'}++	; 
#	$ports_ref->{'tcp'}{'3764'}{'name'} = 'mni-prot-rout'		; 
#	$srvcobjects_ref->{'qadmifoper'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qadmifoper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qadmifoper'}{'port'}{'udp'} = '2461'	; 
#	$srvcobjects_ref->{'qadmifoper'}{'ports'}{'udp'}{'2461'}++	; 
#	$ports_ref->{'udp'}{'2461'}{'name'} = 'qadmifoper'		; 
#	$srvcobjects_ref->{'qadmifoper'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qadmifoper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qadmifoper'}{'port'}{'tcp'} = '2461'	; 
#	$srvcobjects_ref->{'qadmifoper'}{'ports'}{'tcp'}{'2461'}++	; 
#	$ports_ref->{'tcp'}{'2461'}{'name'} = 'qadmifoper'		; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'port'}{'udp'} = '902'	; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'ports'}{'udp'}{'902'}++	; 
#	$ports_ref->{'udp'}{'902'}{'name'} = 'ideafarm-chat'		; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'port'}{'tcp'} = '902'	; 
#	$srvcobjects_ref->{'ideafarm-chat'}{'ports'}{'tcp'}{'902'}++	; 
#	$ports_ref->{'tcp'}{'902'}{'name'} = 'ideafarm-chat'		; 
#	$srvcobjects_ref->{'dist-upgrade'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dist-upgrade'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dist-upgrade'}{'port'}{'udp'} = '3624'	; 
#	$srvcobjects_ref->{'dist-upgrade'}{'ports'}{'udp'}{'3624'}++	; 
#	$ports_ref->{'udp'}{'3624'}{'name'} = 'dist-upgrade'		; 
#	$srvcobjects_ref->{'dist-upgrade'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dist-upgrade'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dist-upgrade'}{'port'}{'tcp'} = '3624'	; 
#	$srvcobjects_ref->{'dist-upgrade'}{'ports'}{'tcp'}{'3624'}++	; 
#	$ports_ref->{'tcp'}{'3624'}{'name'} = 'dist-upgrade'		; 
#	$srvcobjects_ref->{'ingres-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ingres-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ingres-net'}{'port'}{'udp'} = '134'	; 
#	$srvcobjects_ref->{'ingres-net'}{'ports'}{'udp'}{'134'}++	; 
#	$ports_ref->{'udp'}{'134'}{'name'} = 'ingres-net'		; 
#	$srvcobjects_ref->{'ingres-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ingres-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ingres-net'}{'port'}{'tcp'} = '134'	; 
#	$srvcobjects_ref->{'ingres-net'}{'ports'}{'tcp'}{'134'}++	; 
#	$ports_ref->{'tcp'}{'134'}{'name'} = 'ingres-net'		; 
#	$srvcobjects_ref->{'cumulus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cumulus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cumulus'}{'port'}{'udp'} = '9287'	; 
#	$srvcobjects_ref->{'cumulus'}{'ports'}{'udp'}{'9287'}++	; 
#	$ports_ref->{'udp'}{'9287'}{'name'} = 'cumulus'		; 
#	$srvcobjects_ref->{'cumulus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cumulus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cumulus'}{'port'}{'tcp'} = '9287'	; 
#	$srvcobjects_ref->{'cumulus'}{'ports'}{'tcp'}{'9287'}++	; 
#	$ports_ref->{'tcp'}{'9287'}{'name'} = 'cumulus'		; 
#	$srvcobjects_ref->{'idmgratm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idmgratm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idmgratm'}{'port'}{'udp'} = '32896'	; 
#	$srvcobjects_ref->{'idmgratm'}{'ports'}{'udp'}{'32896'}++	; 
#	$ports_ref->{'udp'}{'32896'}{'name'} = 'idmgratm'		; 
#	$srvcobjects_ref->{'idmgratm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idmgratm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idmgratm'}{'port'}{'tcp'} = '32896'	; 
#	$srvcobjects_ref->{'idmgratm'}{'ports'}{'tcp'}{'32896'}++	; 
#	$ports_ref->{'tcp'}{'32896'}{'name'} = 'idmgratm'		; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'port'}{'udp'} = '364'	; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'ports'}{'udp'}{'364'}++	; 
#	$ports_ref->{'udp'}{'364'}{'name'} = 'aurora-cmgr'		; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'port'}{'tcp'} = '364'	; 
#	$srvcobjects_ref->{'aurora-cmgr'}{'ports'}{'tcp'}{'364'}++	; 
#	$ports_ref->{'tcp'}{'364'}{'name'} = 'aurora-cmgr'		; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'port'}{'udp'} = '4015'	; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'ports'}{'udp'}{'4015'}++	; 
#	$ports_ref->{'udp'}{'4015'}{'name'} = 'talarian-mcast1'		; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'port'}{'tcp'} = '4015'	; 
#	$srvcobjects_ref->{'talarian-mcast1'}{'ports'}{'tcp'}{'4015'}++	; 
#	$ports_ref->{'tcp'}{'4015'}{'name'} = 'talarian-mcast1'		; 
#	$srvcobjects_ref->{'netsc-prod'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netsc-prod'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsc-prod'}{'port'}{'udp'} = '154'	; 
#	$srvcobjects_ref->{'netsc-prod'}{'ports'}{'udp'}{'154'}++	; 
#	$ports_ref->{'udp'}{'154'}{'name'} = 'netsc-prod'		; 
#	$srvcobjects_ref->{'netsc-prod'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netsc-prod'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsc-prod'}{'port'}{'tcp'} = '154'	; 
#	$srvcobjects_ref->{'netsc-prod'}{'ports'}{'tcp'}{'154'}++	; 
#	$ports_ref->{'tcp'}{'154'}{'name'} = 'netsc-prod'		; 
#	$srvcobjects_ref->{'drp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'drp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'drp'}{'port'}{'udp'} = '1974'	; 
#	$srvcobjects_ref->{'drp'}{'ports'}{'udp'}{'1974'}++	; 
#	$ports_ref->{'udp'}{'1974'}{'name'} = 'drp'		; 
#	$srvcobjects_ref->{'drp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'drp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'drp'}{'port'}{'tcp'} = '1974'	; 
#	$srvcobjects_ref->{'drp'}{'ports'}{'tcp'}{'1974'}++	; 
#	$ports_ref->{'tcp'}{'1974'}{'name'} = 'drp'		; 
#	$srvcobjects_ref->{'res'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'res'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'res'}{'port'}{'udp'} = '1942'	; 
#	$srvcobjects_ref->{'res'}{'ports'}{'udp'}{'1942'}++	; 
#	$ports_ref->{'udp'}{'1942'}{'name'} = 'res'		; 
#	$srvcobjects_ref->{'res'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'res'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'res'}{'port'}{'tcp'} = '1942'	; 
#	$srvcobjects_ref->{'res'}{'ports'}{'tcp'}{'1942'}++	; 
#	$ports_ref->{'tcp'}{'1942'}{'name'} = 'res'		; 
#	$srvcobjects_ref->{'utsftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'utsftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utsftp'}{'port'}{'udp'} = '2529'	; 
#	$srvcobjects_ref->{'utsftp'}{'ports'}{'udp'}{'2529'}++	; 
#	$ports_ref->{'udp'}{'2529'}{'name'} = 'utsftp'		; 
#	$srvcobjects_ref->{'utsftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'utsftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utsftp'}{'port'}{'tcp'} = '2529'	; 
#	$srvcobjects_ref->{'utsftp'}{'ports'}{'tcp'}{'2529'}++	; 
#	$ports_ref->{'tcp'}{'2529'}{'name'} = 'utsftp'		; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'port'}{'udp'} = '3406'	; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'ports'}{'udp'}{'3406'}++	; 
#	$ports_ref->{'udp'}{'3406'}{'name'} = 'nokia-ann-ch2'		; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'port'}{'tcp'} = '3406'	; 
#	$srvcobjects_ref->{'nokia-ann-ch2'}{'ports'}{'tcp'}{'3406'}++	; 
#	$ports_ref->{'tcp'}{'3406'}{'name'} = 'nokia-ann-ch2'		; 
#	$srvcobjects_ref->{'snip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snip'}{'port'}{'udp'} = '24922'	; 
#	$srvcobjects_ref->{'snip'}{'ports'}{'udp'}{'24922'}++	; 
#	$ports_ref->{'udp'}{'24922'}{'name'} = 'snip'		; 
#	$srvcobjects_ref->{'snip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snip'}{'port'}{'tcp'} = '24922'	; 
#	$srvcobjects_ref->{'snip'}{'ports'}{'tcp'}{'24922'}++	; 
#	$ports_ref->{'tcp'}{'24922'}{'name'} = 'snip'		; 
#	$srvcobjects_ref->{'gbs-smp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gbs-smp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gbs-smp'}{'port'}{'udp'} = '3762'	; 
#	$srvcobjects_ref->{'gbs-smp'}{'ports'}{'udp'}{'3762'}++	; 
#	$ports_ref->{'udp'}{'3762'}{'name'} = 'gbs-smp'		; 
#	$srvcobjects_ref->{'gbs-smp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gbs-smp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gbs-smp'}{'port'}{'tcp'} = '3762'	; 
#	$srvcobjects_ref->{'gbs-smp'}{'ports'}{'tcp'}{'3762'}++	; 
#	$ports_ref->{'tcp'}{'3762'}{'name'} = 'gbs-smp'		; 
#	$srvcobjects_ref->{'pns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pns'}{'port'}{'udp'} = '2487'	; 
#	$srvcobjects_ref->{'pns'}{'ports'}{'udp'}{'2487'}++	; 
#	$ports_ref->{'udp'}{'2487'}{'name'} = 'pns'		; 
#	$srvcobjects_ref->{'pns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pns'}{'port'}{'tcp'} = '2487'	; 
#	$srvcobjects_ref->{'pns'}{'ports'}{'tcp'}{'2487'}++	; 
#	$ports_ref->{'tcp'}{'2487'}{'name'} = 'pns'		; 
#	$srvcobjects_ref->{'mesavistaco'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mesavistaco'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mesavistaco'}{'port'}{'udp'} = '1249'	; 
#	$srvcobjects_ref->{'mesavistaco'}{'ports'}{'udp'}{'1249'}++	; 
#	$ports_ref->{'udp'}{'1249'}{'name'} = 'mesavistaco'		; 
#	$srvcobjects_ref->{'mesavistaco'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mesavistaco'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mesavistaco'}{'port'}{'tcp'} = '1249'	; 
#	$srvcobjects_ref->{'mesavistaco'}{'ports'}{'tcp'}{'1249'}++	; 
#	$ports_ref->{'tcp'}{'1249'}{'name'} = 'mesavistaco'		; 
#	$srvcobjects_ref->{'gamesmith-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gamesmith-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gamesmith-port'}{'port'}{'udp'} = '31765'	; 
#	$srvcobjects_ref->{'gamesmith-port'}{'ports'}{'udp'}{'31765'}++	; 
#	$ports_ref->{'udp'}{'31765'}{'name'} = 'gamesmith-port'		; 
#	$srvcobjects_ref->{'gamesmith-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gamesmith-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gamesmith-port'}{'port'}{'tcp'} = '31765'	; 
#	$srvcobjects_ref->{'gamesmith-port'}{'ports'}{'tcp'}{'31765'}++	; 
#	$ports_ref->{'tcp'}{'31765'}{'name'} = 'gamesmith-port'		; 
#	$srvcobjects_ref->{'xss-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xss-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xss-port'}{'port'}{'udp'} = '3510'	; 
#	$srvcobjects_ref->{'xss-port'}{'ports'}{'udp'}{'3510'}++	; 
#	$ports_ref->{'udp'}{'3510'}{'name'} = 'xss-port'		; 
#	$srvcobjects_ref->{'xss-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xss-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xss-port'}{'port'}{'tcp'} = '3510'	; 
#	$srvcobjects_ref->{'xss-port'}{'ports'}{'tcp'}{'3510'}++	; 
#	$ports_ref->{'tcp'}{'3510'}{'name'} = 'xss-port'		; 
#	$srvcobjects_ref->{'globmsgsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'globmsgsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'globmsgsvc'}{'port'}{'udp'} = '2519'	; 
#	$srvcobjects_ref->{'globmsgsvc'}{'ports'}{'udp'}{'2519'}++	; 
#	$ports_ref->{'udp'}{'2519'}{'name'} = 'globmsgsvc'		; 
#	$srvcobjects_ref->{'globmsgsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'globmsgsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'globmsgsvc'}{'port'}{'tcp'} = '2519'	; 
#	$srvcobjects_ref->{'globmsgsvc'}{'ports'}{'tcp'}{'2519'}++	; 
#	$ports_ref->{'tcp'}{'2519'}{'name'} = 'globmsgsvc'		; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'port'}{'udp'} = '5020'	; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'ports'}{'udp'}{'5020'}++	; 
#	$ports_ref->{'udp'}{'5020'}{'name'} = 'zenginkyo-1'		; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'port'}{'tcp'} = '5020'	; 
#	$srvcobjects_ref->{'zenginkyo-1'}{'ports'}{'tcp'}{'5020'}++	; 
#	$ports_ref->{'tcp'}{'5020'}{'name'} = 'zenginkyo-1'		; 
#	$srvcobjects_ref->{'stun-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stun-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-port'}{'port'}{'udp'} = '1994'	; 
#	$srvcobjects_ref->{'stun-port'}{'ports'}{'udp'}{'1994'}++	; 
#	$ports_ref->{'udp'}{'1994'}{'name'} = 'stun-port'		; 
#	$srvcobjects_ref->{'stun-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stun-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-port'}{'port'}{'tcp'} = '1994'	; 
#	$srvcobjects_ref->{'stun-port'}{'ports'}{'tcp'}{'1994'}++	; 
#	$ports_ref->{'tcp'}{'1994'}{'name'} = 'stun-port'		; 
#	$srvcobjects_ref->{'ats'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ats'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ats'}{'port'}{'udp'} = '2201'	; 
#	$srvcobjects_ref->{'ats'}{'ports'}{'udp'}{'2201'}++	; 
#	$ports_ref->{'udp'}{'2201'}{'name'} = 'ats'		; 
#	$srvcobjects_ref->{'ats'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ats'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ats'}{'port'}{'tcp'} = '2201'	; 
#	$srvcobjects_ref->{'ats'}{'ports'}{'tcp'}{'2201'}++	; 
#	$ports_ref->{'tcp'}{'2201'}{'name'} = 'ats'		; 
#	$srvcobjects_ref->{'newheights'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newheights'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newheights'}{'port'}{'udp'} = '2114'	; 
#	$srvcobjects_ref->{'newheights'}{'ports'}{'udp'}{'2114'}++	; 
#	$ports_ref->{'udp'}{'2114'}{'name'} = 'newheights'		; 
#	$srvcobjects_ref->{'newheights'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newheights'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newheights'}{'port'}{'tcp'} = '2114'	; 
#	$srvcobjects_ref->{'newheights'}{'ports'}{'tcp'}{'2114'}++	; 
#	$ports_ref->{'tcp'}{'2114'}{'name'} = 'newheights'		; 
#	$srvcobjects_ref->{'wsicopy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wsicopy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsicopy'}{'port'}{'udp'} = '3378'	; 
#	$srvcobjects_ref->{'wsicopy'}{'ports'}{'udp'}{'3378'}++	; 
#	$ports_ref->{'udp'}{'3378'}{'name'} = 'wsicopy'		; 
#	$srvcobjects_ref->{'wsicopy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wsicopy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsicopy'}{'port'}{'tcp'} = '3378'	; 
#	$srvcobjects_ref->{'wsicopy'}{'ports'}{'tcp'}{'3378'}++	; 
#	$ports_ref->{'tcp'}{'3378'}{'name'} = 'wsicopy'		; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'port'}{'udp'} = '3492'	; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'ports'}{'udp'}{'3492'}++	; 
#	$ports_ref->{'udp'}{'3492'}{'name'} = 'tvdumtray-port'		; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'port'}{'tcp'} = '3492'	; 
#	$srvcobjects_ref->{'tvdumtray-port'}{'ports'}{'tcp'}{'3492'}++	; 
#	$ports_ref->{'tcp'}{'3492'}{'name'} = 'tvdumtray-port'		; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'port'}{'udp'} = '1673'	; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'ports'}{'udp'}{'1673'}++	; 
#	$ports_ref->{'udp'}{'1673'}{'name'} = 'proshare-mc-1'		; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'port'}{'tcp'} = '1673'	; 
#	$srvcobjects_ref->{'proshare-mc-1'}{'ports'}{'tcp'}{'1673'}++	; 
#	$ports_ref->{'tcp'}{'1673'}{'name'} = 'proshare-mc-1'		; 
#	$srvcobjects_ref->{'admins-lms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'admins-lms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'admins-lms'}{'port'}{'udp'} = '2692'	; 
#	$srvcobjects_ref->{'admins-lms'}{'ports'}{'udp'}{'2692'}++	; 
#	$ports_ref->{'udp'}{'2692'}{'name'} = 'admins-lms'		; 
#	$srvcobjects_ref->{'admins-lms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'admins-lms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'admins-lms'}{'port'}{'tcp'} = '2692'	; 
#	$srvcobjects_ref->{'admins-lms'}{'ports'}{'tcp'}{'2692'}++	; 
#	$ports_ref->{'tcp'}{'2692'}{'name'} = 'admins-lms'		; 
#	$srvcobjects_ref->{'tragic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tragic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tragic'}{'port'}{'udp'} = '2642'	; 
#	$srvcobjects_ref->{'tragic'}{'ports'}{'udp'}{'2642'}++	; 
#	$ports_ref->{'udp'}{'2642'}{'name'} = 'tragic'		; 
#	$srvcobjects_ref->{'tragic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tragic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tragic'}{'port'}{'tcp'} = '2642'	; 
#	$srvcobjects_ref->{'tragic'}{'ports'}{'tcp'}{'2642'}++	; 
#	$ports_ref->{'tcp'}{'2642'}{'name'} = 'tragic'		; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'port'}{'udp'} = '6347'	; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'ports'}{'udp'}{'6347'}++	; 
#	$ports_ref->{'udp'}{'6347'}{'name'} = 'gnutella-rtr'		; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'port'}{'tcp'} = '6347'	; 
#	$srvcobjects_ref->{'gnutella-rtr'}{'ports'}{'tcp'}{'6347'}++	; 
#	$ports_ref->{'tcp'}{'6347'}{'name'} = 'gnutella-rtr'		; 
#	$srvcobjects_ref->{'qsnet-cond'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qsnet-cond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-cond'}{'port'}{'udp'} = '4357'	; 
#	$srvcobjects_ref->{'qsnet-cond'}{'ports'}{'udp'}{'4357'}++	; 
#	$ports_ref->{'udp'}{'4357'}{'name'} = 'qsnet-cond'		; 
#	$srvcobjects_ref->{'qsnet-cond'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qsnet-cond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-cond'}{'port'}{'tcp'} = '4357'	; 
#	$srvcobjects_ref->{'qsnet-cond'}{'ports'}{'tcp'}{'4357'}++	; 
#	$ports_ref->{'tcp'}{'4357'}{'name'} = 'qsnet-cond'		; 
#	$srvcobjects_ref->{'personal-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'personal-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personal-agent'}{'port'}{'udp'} = '5555'	; 
#	$srvcobjects_ref->{'personal-agent'}{'ports'}{'udp'}{'5555'}++	; 
#	$ports_ref->{'udp'}{'5555'}{'name'} = 'personal-agent'		; 
#	$srvcobjects_ref->{'personal-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'personal-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personal-agent'}{'port'}{'tcp'} = '5555'	; 
#	$srvcobjects_ref->{'personal-agent'}{'ports'}{'tcp'}{'5555'}++	; 
#	$ports_ref->{'tcp'}{'5555'}{'name'} = 'personal-agent'		; 
#	$srvcobjects_ref->{'webobjects'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webobjects'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webobjects'}{'port'}{'udp'} = '1085'	; 
#	$srvcobjects_ref->{'webobjects'}{'ports'}{'udp'}{'1085'}++	; 
#	$ports_ref->{'udp'}{'1085'}{'name'} = 'webobjects'		; 
#	$srvcobjects_ref->{'webobjects'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webobjects'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webobjects'}{'port'}{'tcp'} = '1085'	; 
#	$srvcobjects_ref->{'webobjects'}{'ports'}{'tcp'}{'1085'}++	; 
#	$ports_ref->{'tcp'}{'1085'}{'name'} = 'webobjects'		; 
#	$srvcobjects_ref->{'nhserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nhserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nhserver'}{'port'}{'udp'} = '2672'	; 
#	$srvcobjects_ref->{'nhserver'}{'ports'}{'udp'}{'2672'}++	; 
#	$ports_ref->{'udp'}{'2672'}{'name'} = 'nhserver'		; 
#	$srvcobjects_ref->{'nhserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nhserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nhserver'}{'port'}{'tcp'} = '2672'	; 
#	$srvcobjects_ref->{'nhserver'}{'ports'}{'tcp'}{'2672'}++	; 
#	$ports_ref->{'tcp'}{'2672'}{'name'} = 'nhserver'		; 
#	$srvcobjects_ref->{'vofr-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vofr-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vofr-gateway'}{'port'}{'udp'} = '21590'	; 
#	$srvcobjects_ref->{'vofr-gateway'}{'ports'}{'udp'}{'21590'}++	; 
#	$ports_ref->{'udp'}{'21590'}{'name'} = 'vofr-gateway'		; 
#	$srvcobjects_ref->{'vofr-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vofr-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vofr-gateway'}{'port'}{'tcp'} = '21590'	; 
#	$srvcobjects_ref->{'vofr-gateway'}{'ports'}{'tcp'}{'21590'}++	; 
#	$ports_ref->{'tcp'}{'21590'}{'name'} = 'vofr-gateway'		; 
#	$srvcobjects_ref->{'silkp3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'silkp3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp3'}{'port'}{'udp'} = '2831'	; 
#	$srvcobjects_ref->{'silkp3'}{'ports'}{'udp'}{'2831'}++	; 
#	$ports_ref->{'udp'}{'2831'}{'name'} = 'silkp3'		; 
#	$srvcobjects_ref->{'silkp3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'silkp3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp3'}{'port'}{'tcp'} = '2831'	; 
#	$srvcobjects_ref->{'silkp3'}{'ports'}{'tcp'}{'2831'}++	; 
#	$ports_ref->{'tcp'}{'2831'}{'name'} = 'silkp3'		; 
#	$srvcobjects_ref->{'ssdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssdp'}{'port'}{'udp'} = '1900'	; 
#	$srvcobjects_ref->{'ssdp'}{'ports'}{'udp'}{'1900'}++	; 
#	$ports_ref->{'udp'}{'1900'}{'name'} = 'ssdp'		; 
#	$srvcobjects_ref->{'ssdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssdp'}{'port'}{'tcp'} = '1900'	; 
#	$srvcobjects_ref->{'ssdp'}{'ports'}{'tcp'}{'1900'}++	; 
#	$ports_ref->{'tcp'}{'1900'}{'name'} = 'ssdp'		; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'port'}{'udp'} = '4016'	; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'ports'}{'udp'}{'4016'}++	; 
#	$ports_ref->{'udp'}{'4016'}{'name'} = 'talarian-mcast2'		; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'port'}{'tcp'} = '4016'	; 
#	$srvcobjects_ref->{'talarian-mcast2'}{'ports'}{'tcp'}{'4016'}++	; 
#	$ports_ref->{'tcp'}{'4016'}{'name'} = 'talarian-mcast2'		; 
#	$srvcobjects_ref->{'ipp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipp'}{'port'}{'udp'} = '631'	; 
#	$srvcobjects_ref->{'ipp'}{'ports'}{'udp'}{'631'}++	; 
#	$ports_ref->{'udp'}{'631'}{'name'} = 'ipp'		; 
#	$srvcobjects_ref->{'ipp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipp'}{'port'}{'tcp'} = '631'	; 
#	$srvcobjects_ref->{'ipp'}{'ports'}{'tcp'}{'631'}++	; 
#	$ports_ref->{'tcp'}{'631'}{'name'} = 'ipp'		; 
#	$srvcobjects_ref->{'emfis-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emfis-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emfis-data'}{'port'}{'udp'} = '140'	; 
#	$srvcobjects_ref->{'emfis-data'}{'ports'}{'udp'}{'140'}++	; 
#	$ports_ref->{'udp'}{'140'}{'name'} = 'emfis-data'		; 
#	$srvcobjects_ref->{'emfis-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emfis-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emfis-data'}{'port'}{'tcp'} = '140'	; 
#	$srvcobjects_ref->{'emfis-data'}{'ports'}{'tcp'}{'140'}++	; 
#	$ports_ref->{'tcp'}{'140'}{'name'} = 'emfis-data'		; 
#	$srvcobjects_ref->{'nssalertmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nssalertmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nssalertmgr'}{'port'}{'udp'} = '4453'	; 
#	$srvcobjects_ref->{'nssalertmgr'}{'ports'}{'udp'}{'4453'}++	; 
#	$ports_ref->{'udp'}{'4453'}{'name'} = 'nssalertmgr'		; 
#	$srvcobjects_ref->{'nssalertmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nssalertmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nssalertmgr'}{'port'}{'tcp'} = '4453'	; 
#	$srvcobjects_ref->{'nssalertmgr'}{'ports'}{'tcp'}{'4453'}++	; 
#	$ports_ref->{'tcp'}{'4453'}{'name'} = 'nssalertmgr'		; 
#	$srvcobjects_ref->{'ci3-software-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ci3-software-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ci3-software-1'}{'port'}{'udp'} = '1301'	; 
#	$srvcobjects_ref->{'ci3-software-1'}{'ports'}{'udp'}{'1301'}++	; 
#	$ports_ref->{'udp'}{'1301'}{'name'} = 'ci3-software-1'		; 
#	$srvcobjects_ref->{'ci3-software-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ci3-software-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ci3-software-1'}{'port'}{'tcp'} = '1301'	; 
#	$srvcobjects_ref->{'ci3-software-1'}{'ports'}{'tcp'}{'1301'}++	; 
#	$ports_ref->{'tcp'}{'1301'}{'name'} = 'ci3-software-1'		; 
#	$srvcobjects_ref->{'esri_sde'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esri_sde'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esri_sde'}{'port'}{'udp'} = '5151'	; 
#	$srvcobjects_ref->{'esri_sde'}{'ports'}{'udp'}{'5151'}++	; 
#	$ports_ref->{'udp'}{'5151'}{'name'} = 'esri_sde'		; 
#	$srvcobjects_ref->{'esri_sde'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esri_sde'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esri_sde'}{'port'}{'tcp'} = '5151'	; 
#	$srvcobjects_ref->{'esri_sde'}{'ports'}{'tcp'}{'5151'}++	; 
#	$ports_ref->{'tcp'}{'5151'}{'name'} = 'esri_sde'		; 
#	$srvcobjects_ref->{'sdl-ets'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdl-ets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdl-ets'}{'port'}{'udp'} = '5081'	; 
#	$srvcobjects_ref->{'sdl-ets'}{'ports'}{'udp'}{'5081'}++	; 
#	$ports_ref->{'udp'}{'5081'}{'name'} = 'sdl-ets'		; 
#	$srvcobjects_ref->{'sdl-ets'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdl-ets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdl-ets'}{'port'}{'tcp'} = '5081'	; 
#	$srvcobjects_ref->{'sdl-ets'}{'ports'}{'tcp'}{'5081'}++	; 
#	$ports_ref->{'tcp'}{'5081'}{'name'} = 'sdl-ets'		; 
#	$srvcobjects_ref->{'bacula-sd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bacula-sd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacula-sd'}{'port'}{'udp'} = '9103'	; 
#	$srvcobjects_ref->{'bacula-sd'}{'ports'}{'udp'}{'9103'}++	; 
#	$ports_ref->{'udp'}{'9103'}{'name'} = 'bacula-sd'		; 
#	$srvcobjects_ref->{'bacula-sd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bacula-sd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacula-sd'}{'port'}{'tcp'} = '9103'	; 
#	$srvcobjects_ref->{'bacula-sd'}{'ports'}{'tcp'}{'9103'}++	; 
#	$ports_ref->{'tcp'}{'9103'}{'name'} = 'bacula-sd'		; 
#	$srvcobjects_ref->{'comcam-io'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'comcam-io'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'comcam-io'}{'port'}{'udp'} = '3605'	; 
#	$srvcobjects_ref->{'comcam-io'}{'ports'}{'udp'}{'3605'}++	; 
#	$ports_ref->{'udp'}{'3605'}{'name'} = 'comcam-io'		; 
#	$srvcobjects_ref->{'comcam-io'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'comcam-io'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'comcam-io'}{'port'}{'tcp'} = '3605'	; 
#	$srvcobjects_ref->{'comcam-io'}{'ports'}{'tcp'}{'3605'}++	; 
#	$ports_ref->{'tcp'}{'3605'}{'name'} = 'comcam-io'		; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'port'}{'udp'} = '2922'	; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'ports'}{'udp'}{'2922'}++	; 
#	$ports_ref->{'udp'}{'2922'}{'name'} = 'cesdcdtrn'		; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'port'}{'tcp'} = '2922'	; 
#	$srvcobjects_ref->{'cesdcdtrn'}{'ports'}{'tcp'}{'2922'}++	; 
#	$ports_ref->{'tcp'}{'2922'}{'name'} = 'cesdcdtrn'		; 
#	$srvcobjects_ref->{'ssm-els'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssm-els'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssm-els'}{'port'}{'udp'} = '2479'	; 
#	$srvcobjects_ref->{'ssm-els'}{'ports'}{'udp'}{'2479'}++	; 
#	$ports_ref->{'udp'}{'2479'}{'name'} = 'ssm-els'		; 
#	$srvcobjects_ref->{'ssm-els'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssm-els'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssm-els'}{'port'}{'tcp'} = '2479'	; 
#	$srvcobjects_ref->{'ssm-els'}{'ports'}{'tcp'}{'2479'}++	; 
#	$ports_ref->{'tcp'}{'2479'}{'name'} = 'ssm-els'		; 
#	$srvcobjects_ref->{'swtp-port1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swtp-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swtp-port1'}{'port'}{'udp'} = '9281'	; 
#	$srvcobjects_ref->{'swtp-port1'}{'ports'}{'udp'}{'9281'}++	; 
#	$ports_ref->{'udp'}{'9281'}{'name'} = 'swtp-port1'		; 
#	$srvcobjects_ref->{'swtp-port1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swtp-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swtp-port1'}{'port'}{'tcp'} = '9281'	; 
#	$srvcobjects_ref->{'swtp-port1'}{'ports'}{'tcp'}{'9281'}++	; 
#	$ports_ref->{'tcp'}{'9281'}{'name'} = 'swtp-port1'		; 
#	$srvcobjects_ref->{'wusage'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wusage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wusage'}{'port'}{'udp'} = '2396'	; 
#	$srvcobjects_ref->{'wusage'}{'ports'}{'udp'}{'2396'}++	; 
#	$ports_ref->{'udp'}{'2396'}{'name'} = 'wusage'		; 
#	$srvcobjects_ref->{'wusage'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wusage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wusage'}{'port'}{'tcp'} = '2396'	; 
#	$srvcobjects_ref->{'wusage'}{'ports'}{'tcp'}{'2396'}++	; 
#	$ports_ref->{'tcp'}{'2396'}{'name'} = 'wusage'		; 
#	$srvcobjects_ref->{'deskshare'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'deskshare'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'deskshare'}{'port'}{'udp'} = '1702'	; 
#	$srvcobjects_ref->{'deskshare'}{'ports'}{'udp'}{'1702'}++	; 
#	$ports_ref->{'udp'}{'1702'}{'name'} = 'deskshare'		; 
#	$srvcobjects_ref->{'deskshare'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'deskshare'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'deskshare'}{'port'}{'tcp'} = '1702'	; 
#	$srvcobjects_ref->{'deskshare'}{'ports'}{'tcp'}{'1702'}++	; 
#	$ports_ref->{'tcp'}{'1702'}{'name'} = 'deskshare'		; 
#	$srvcobjects_ref->{'itinternet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itinternet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itinternet'}{'port'}{'udp'} = '2691'	; 
#	$srvcobjects_ref->{'itinternet'}{'ports'}{'udp'}{'2691'}++	; 
#	$ports_ref->{'udp'}{'2691'}{'name'} = 'itinternet'		; 
#	$srvcobjects_ref->{'itinternet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itinternet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itinternet'}{'port'}{'tcp'} = '2691'	; 
#	$srvcobjects_ref->{'itinternet'}{'ports'}{'tcp'}{'2691'}++	; 
#	$ports_ref->{'tcp'}{'2691'}{'name'} = 'itinternet'		; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'port'}{'udp'} = '615'	; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'ports'}{'udp'}{'615'}++	; 
#	$ports_ref->{'udp'}{'615'}{'name'} = 'sco-inetmgr'		; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'port'}{'tcp'} = '615'	; 
#	$srvcobjects_ref->{'sco-inetmgr'}{'ports'}{'tcp'}{'615'}++	; 
#	$ports_ref->{'tcp'}{'615'}{'name'} = 'sco-inetmgr'		; 
#	$srvcobjects_ref->{'ncpm-ft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncpm-ft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncpm-ft'}{'port'}{'udp'} = '1744'	; 
#	$srvcobjects_ref->{'ncpm-ft'}{'ports'}{'udp'}{'1744'}++	; 
#	$ports_ref->{'udp'}{'1744'}{'name'} = 'ncpm-ft'		; 
#	$srvcobjects_ref->{'ncpm-ft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncpm-ft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncpm-ft'}{'port'}{'tcp'} = '1744'	; 
#	$srvcobjects_ref->{'ncpm-ft'}{'ports'}{'tcp'}{'1744'}++	; 
#	$ports_ref->{'tcp'}{'1744'}{'name'} = 'ncpm-ft'		; 
#	$srvcobjects_ref->{'firefox'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'firefox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firefox'}{'port'}{'udp'} = '1689'	; 
#	$srvcobjects_ref->{'firefox'}{'ports'}{'udp'}{'1689'}++	; 
#	$ports_ref->{'udp'}{'1689'}{'name'} = 'firefox'		; 
#	$srvcobjects_ref->{'firefox'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'firefox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firefox'}{'port'}{'tcp'} = '1689'	; 
#	$srvcobjects_ref->{'firefox'}{'ports'}{'tcp'}{'1689'}++	; 
#	$ports_ref->{'tcp'}{'1689'}{'name'} = 'firefox'		; 
#	$srvcobjects_ref->{'opsec-uaa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsec-uaa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-uaa'}{'port'}{'udp'} = '19191'	; 
#	$srvcobjects_ref->{'opsec-uaa'}{'ports'}{'udp'}{'19191'}++	; 
#	$ports_ref->{'udp'}{'19191'}{'name'} = 'opsec-uaa'		; 
#	$srvcobjects_ref->{'opsec-uaa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsec-uaa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-uaa'}{'port'}{'tcp'} = '19191'	; 
#	$srvcobjects_ref->{'opsec-uaa'}{'ports'}{'tcp'}{'19191'}++	; 
#	$ports_ref->{'tcp'}{'19191'}{'name'} = 'opsec-uaa'		; 
#	$srvcobjects_ref->{'raid-cc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raid-cc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-cc'}{'port'}{'udp'} = '2006'	; 
#	$srvcobjects_ref->{'raid-cc'}{'ports'}{'udp'}{'2006'}++	; 
#	$ports_ref->{'udp'}{'2006'}{'name'} = 'raid-cc'		; 
#	$srvcobjects_ref->{'raid-cc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raid-cc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-cc'}{'port'}{'tcp'} = '2011'	; 
#	$srvcobjects_ref->{'raid-cc'}{'ports'}{'tcp'}{'2011'}++	; 
#	$ports_ref->{'tcp'}{'2011'}{'name'} = 'raid-cc'		; 
#	$srvcobjects_ref->{'sna-cs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sna-cs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sna-cs'}{'port'}{'udp'} = '1553'	; 
#	$srvcobjects_ref->{'sna-cs'}{'ports'}{'udp'}{'1553'}++	; 
#	$ports_ref->{'udp'}{'1553'}{'name'} = 'sna-cs'		; 
#	$srvcobjects_ref->{'sna-cs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sna-cs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sna-cs'}{'port'}{'tcp'} = '1553'	; 
#	$srvcobjects_ref->{'sna-cs'}{'ports'}{'tcp'}{'1553'}++	; 
#	$ports_ref->{'tcp'}{'1553'}{'name'} = 'sna-cs'		; 
#	$srvcobjects_ref->{'accessnetwork'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'accessnetwork'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accessnetwork'}{'port'}{'udp'} = '699'	; 
#	$srvcobjects_ref->{'accessnetwork'}{'ports'}{'udp'}{'699'}++	; 
#	$ports_ref->{'udp'}{'699'}{'name'} = 'accessnetwork'		; 
#	$srvcobjects_ref->{'accessnetwork'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'accessnetwork'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accessnetwork'}{'port'}{'tcp'} = '699'	; 
#	$srvcobjects_ref->{'accessnetwork'}{'ports'}{'tcp'}{'699'}++	; 
#	$ports_ref->{'tcp'}{'699'}{'name'} = 'accessnetwork'		; 
#	$srvcobjects_ref->{'lv-not'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lv-not'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-not'}{'port'}{'udp'} = '2146'	; 
#	$srvcobjects_ref->{'lv-not'}{'ports'}{'udp'}{'2146'}++	; 
#	$ports_ref->{'udp'}{'2146'}{'name'} = 'lv-not'		; 
#	$srvcobjects_ref->{'lv-not'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lv-not'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-not'}{'port'}{'tcp'} = '2146'	; 
#	$srvcobjects_ref->{'lv-not'}{'ports'}{'tcp'}{'2146'}++	; 
#	$ports_ref->{'tcp'}{'2146'}{'name'} = 'lv-not'		; 
#	$srvcobjects_ref->{'ftps-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftps-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftps-data'}{'port'}{'udp'} = '989'	; 
#	$srvcobjects_ref->{'ftps-data'}{'ports'}{'udp'}{'989'}++	; 
#	$ports_ref->{'udp'}{'989'}{'name'} = 'ftps-data'		; 
#	$srvcobjects_ref->{'ftps-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftps-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftps-data'}{'port'}{'tcp'} = '989'	; 
#	$srvcobjects_ref->{'ftps-data'}{'ports'}{'tcp'}{'989'}++	; 
#	$ports_ref->{'tcp'}{'989'}{'name'} = 'ftps-data'		; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'port'}{'udp'} = '5504'	; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'ports'}{'udp'}{'5504'}++	; 
#	$ports_ref->{'udp'}{'5504'}{'name'} = 'fcp-cics-gw1'		; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'port'}{'tcp'} = '5504'	; 
#	$srvcobjects_ref->{'fcp-cics-gw1'}{'ports'}{'tcp'}{'5504'}++	; 
#	$ports_ref->{'tcp'}{'5504'}{'name'} = 'fcp-cics-gw1'		; 
#	$srvcobjects_ref->{'ksysguard'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ksysguard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ksysguard'}{'port'}{'udp'} = '3112'	; 
#	$srvcobjects_ref->{'ksysguard'}{'ports'}{'udp'}{'3112'}++	; 
#	$ports_ref->{'udp'}{'3112'}{'name'} = 'ksysguard'		; 
#	$srvcobjects_ref->{'ksysguard'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ksysguard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ksysguard'}{'port'}{'tcp'} = '3112'	; 
#	$srvcobjects_ref->{'ksysguard'}{'ports'}{'tcp'}{'3112'}++	; 
#	$ports_ref->{'tcp'}{'3112'}{'name'} = 'ksysguard'		; 
#	$srvcobjects_ref->{'vpac'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpac'}{'port'}{'udp'} = '1517'	; 
#	$srvcobjects_ref->{'vpac'}{'ports'}{'udp'}{'1517'}++	; 
#	$ports_ref->{'udp'}{'1517'}{'name'} = 'vpac'		; 
#	$srvcobjects_ref->{'vpac'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpac'}{'port'}{'tcp'} = '1517'	; 
#	$srvcobjects_ref->{'vpac'}{'ports'}{'tcp'}{'1517'}++	; 
#	$ports_ref->{'tcp'}{'1517'}{'name'} = 'vpac'		; 
#	$srvcobjects_ref->{'metricadbc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metricadbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metricadbc'}{'port'}{'udp'} = '2622'	; 
#	$srvcobjects_ref->{'metricadbc'}{'ports'}{'udp'}{'2622'}++	; 
#	$ports_ref->{'udp'}{'2622'}{'name'} = 'metricadbc'		; 
#	$srvcobjects_ref->{'metricadbc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metricadbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metricadbc'}{'port'}{'tcp'} = '2622'	; 
#	$srvcobjects_ref->{'metricadbc'}{'ports'}{'tcp'}{'2622'}++	; 
#	$ports_ref->{'tcp'}{'2622'}{'name'} = 'metricadbc'		; 
#	$srvcobjects_ref->{'buddy-draw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'buddy-draw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'buddy-draw'}{'port'}{'udp'} = '1854'	; 
#	$srvcobjects_ref->{'buddy-draw'}{'ports'}{'udp'}{'1854'}++	; 
#	$ports_ref->{'udp'}{'1854'}{'name'} = 'buddy-draw'		; 
#	$srvcobjects_ref->{'buddy-draw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'buddy-draw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'buddy-draw'}{'port'}{'tcp'} = '1854'	; 
#	$srvcobjects_ref->{'buddy-draw'}{'ports'}{'tcp'}{'1854'}++	; 
#	$ports_ref->{'tcp'}{'1854'}{'name'} = 'buddy-draw'		; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'port'}{'udp'} = '2665'	; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'ports'}{'udp'}{'2665'}++	; 
#	$ports_ref->{'udp'}{'2665'}{'name'} = 'patrol-mq-nm'		; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'port'}{'tcp'} = '2665'	; 
#	$srvcobjects_ref->{'patrol-mq-nm'}{'ports'}{'tcp'}{'2665'}++	; 
#	$ports_ref->{'tcp'}{'2665'}{'name'} = 'patrol-mq-nm'		; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'port'}{'udp'} = '1987'	; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'ports'}{'udp'}{'1987'}++	; 
#	$ports_ref->{'udp'}{'1987'}{'name'} = 'tr-rsrb-p1'		; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'port'}{'tcp'} = '1987'	; 
#	$srvcobjects_ref->{'tr-rsrb-p1'}{'ports'}{'tcp'}{'1987'}++	; 
#	$ports_ref->{'tcp'}{'1987'}{'name'} = 'tr-rsrb-p1'		; 
#	$srvcobjects_ref->{'bacula-fd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bacula-fd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacula-fd'}{'port'}{'udp'} = '9102'	; 
#	$srvcobjects_ref->{'bacula-fd'}{'ports'}{'udp'}{'9102'}++	; 
#	$ports_ref->{'udp'}{'9102'}{'name'} = 'bacula-fd'		; 
#	$srvcobjects_ref->{'bacula-fd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bacula-fd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacula-fd'}{'port'}{'tcp'} = '9102'	; 
#	$srvcobjects_ref->{'bacula-fd'}{'ports'}{'tcp'}{'9102'}++	; 
#	$ports_ref->{'tcp'}{'9102'}{'name'} = 'bacula-fd'		; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'port'}{'udp'} = '1235'	; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'ports'}{'udp'}{'1235'}++	; 
#	$ports_ref->{'udp'}{'1235'}{'name'} = 'mosaicsyssvc1'		; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'port'}{'tcp'} = '1235'	; 
#	$srvcobjects_ref->{'mosaicsyssvc1'}{'ports'}{'tcp'}{'1235'}++	; 
#	$ports_ref->{'tcp'}{'1235'}{'name'} = 'mosaicsyssvc1'		; 
#	$srvcobjects_ref->{'nuts_bootp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nuts_bootp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nuts_bootp'}{'port'}{'udp'} = '4133'	; 
#	$srvcobjects_ref->{'nuts_bootp'}{'ports'}{'udp'}{'4133'}++	; 
#	$ports_ref->{'udp'}{'4133'}{'name'} = 'nuts_bootp'		; 
#	$srvcobjects_ref->{'nuts_bootp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nuts_bootp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nuts_bootp'}{'port'}{'tcp'} = '4133'	; 
#	$srvcobjects_ref->{'nuts_bootp'}{'ports'}{'tcp'}{'4133'}++	; 
#	$ports_ref->{'tcp'}{'4133'}{'name'} = 'nuts_bootp'		; 
#	$srvcobjects_ref->{'dellpwrappks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dellpwrappks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dellpwrappks'}{'port'}{'udp'} = '1266'	; 
#	$srvcobjects_ref->{'dellpwrappks'}{'ports'}{'udp'}{'1266'}++	; 
#	$ports_ref->{'udp'}{'1266'}{'name'} = 'dellpwrappks'		; 
#	$srvcobjects_ref->{'dellpwrappks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dellpwrappks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dellpwrappks'}{'port'}{'tcp'} = '1266'	; 
#	$srvcobjects_ref->{'dellpwrappks'}{'ports'}{'tcp'}{'1266'}++	; 
#	$ports_ref->{'tcp'}{'1266'}{'name'} = 'dellpwrappks'		; 
#	$srvcobjects_ref->{'shockwave2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shockwave2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shockwave2'}{'port'}{'udp'} = '1257'	; 
#	$srvcobjects_ref->{'shockwave2'}{'ports'}{'udp'}{'1257'}++	; 
#	$ports_ref->{'udp'}{'1257'}{'name'} = 'shockwave2'		; 
#	$srvcobjects_ref->{'shockwave2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shockwave2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shockwave2'}{'port'}{'tcp'} = '1257'	; 
#	$srvcobjects_ref->{'shockwave2'}{'ports'}{'tcp'}{'1257'}++	; 
#	$ports_ref->{'tcp'}{'1257'}{'name'} = 'shockwave2'		; 
#	$srvcobjects_ref->{'mpm-snd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpm-snd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpm-snd'}{'port'}{'udp'} = '46'	; 
#	$srvcobjects_ref->{'mpm-snd'}{'ports'}{'udp'}{'46'}++	; 
#	$ports_ref->{'udp'}{'46'}{'name'} = 'mpm-snd'		; 
#	$srvcobjects_ref->{'mpm-snd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpm-snd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpm-snd'}{'port'}{'tcp'} = '46'	; 
#	$srvcobjects_ref->{'mpm-snd'}{'ports'}{'tcp'}{'46'}++	; 
#	$ports_ref->{'tcp'}{'46'}{'name'} = 'mpm-snd'		; 
#	$srvcobjects_ref->{'orbix-locator'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orbix-locator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-locator'}{'port'}{'udp'} = '3075'	; 
#	$srvcobjects_ref->{'orbix-locator'}{'ports'}{'udp'}{'3075'}++	; 
#	$ports_ref->{'udp'}{'3075'}{'name'} = 'orbix-locator'		; 
#	$srvcobjects_ref->{'orbix-locator'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orbix-locator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-locator'}{'port'}{'tcp'} = '3075'	; 
#	$srvcobjects_ref->{'orbix-locator'}{'ports'}{'tcp'}{'3075'}++	; 
#	$ports_ref->{'tcp'}{'3075'}{'name'} = 'orbix-locator'		; 
#	$srvcobjects_ref->{'pdap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdap'}{'port'}{'udp'} = '344'	; 
#	$srvcobjects_ref->{'pdap'}{'ports'}{'udp'}{'344'}++	; 
#	$ports_ref->{'udp'}{'344'}{'name'} = 'pdap'		; 
#	$srvcobjects_ref->{'pdap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdap'}{'port'}{'tcp'} = '344'	; 
#	$srvcobjects_ref->{'pdap'}{'ports'}{'tcp'}{'344'}++	; 
#	$ports_ref->{'tcp'}{'344'}{'name'} = 'pdap'		; 
#	$srvcobjects_ref->{'appworxsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appworxsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appworxsrv'}{'port'}{'udp'} = '2136'	; 
#	$srvcobjects_ref->{'appworxsrv'}{'ports'}{'udp'}{'2136'}++	; 
#	$ports_ref->{'udp'}{'2136'}{'name'} = 'appworxsrv'		; 
#	$srvcobjects_ref->{'appworxsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appworxsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appworxsrv'}{'port'}{'tcp'} = '2136'	; 
#	$srvcobjects_ref->{'appworxsrv'}{'ports'}{'tcp'}{'2136'}++	; 
#	$ports_ref->{'tcp'}{'2136'}{'name'} = 'appworxsrv'		; 
#	$srvcobjects_ref->{'concomp1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'concomp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'concomp1'}{'port'}{'udp'} = '1802'	; 
#	$srvcobjects_ref->{'concomp1'}{'ports'}{'udp'}{'1802'}++	; 
#	$ports_ref->{'udp'}{'1802'}{'name'} = 'concomp1'		; 
#	$srvcobjects_ref->{'concomp1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'concomp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'concomp1'}{'port'}{'tcp'} = '1802'	; 
#	$srvcobjects_ref->{'concomp1'}{'ports'}{'tcp'}{'1802'}++	; 
#	$ports_ref->{'tcp'}{'1802'}{'name'} = 'concomp1'		; 
#	$srvcobjects_ref->{'houston'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'houston'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'houston'}{'port'}{'udp'} = '4041'	; 
#	$srvcobjects_ref->{'houston'}{'ports'}{'udp'}{'4041'}++	; 
#	$ports_ref->{'udp'}{'4041'}{'name'} = 'houston'		; 
#	$srvcobjects_ref->{'houston'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'houston'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'houston'}{'port'}{'tcp'} = '4041'	; 
#	$srvcobjects_ref->{'houston'}{'ports'}{'tcp'}{'4041'}++	; 
#	$ports_ref->{'tcp'}{'4041'}{'name'} = 'houston'		; 
#	$srvcobjects_ref->{'pcanywherestat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcanywherestat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcanywherestat'}{'port'}{'udp'} = '5632'	; 
#	$srvcobjects_ref->{'pcanywherestat'}{'ports'}{'udp'}{'5632'}++	; 
#	$ports_ref->{'udp'}{'5632'}{'name'} = 'pcanywherestat'		; 
#	$srvcobjects_ref->{'pcanywherestat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcanywherestat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcanywherestat'}{'port'}{'tcp'} = '5632'	; 
#	$srvcobjects_ref->{'pcanywherestat'}{'ports'}{'tcp'}{'5632'}++	; 
#	$ports_ref->{'tcp'}{'5632'}{'name'} = 'pcanywherestat'		; 
#	$srvcobjects_ref->{'aspentec-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aspentec-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aspentec-lm'}{'port'}{'udp'} = '6142'	; 
#	$srvcobjects_ref->{'aspentec-lm'}{'ports'}{'udp'}{'6142'}++	; 
#	$ports_ref->{'udp'}{'6142'}{'name'} = 'aspentec-lm'		; 
#	$srvcobjects_ref->{'aspentec-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aspentec-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aspentec-lm'}{'port'}{'tcp'} = '6142'	; 
#	$srvcobjects_ref->{'aspentec-lm'}{'ports'}{'tcp'}{'6142'}++	; 
#	$ports_ref->{'tcp'}{'6142'}{'name'} = 'aspentec-lm'		; 
#	$srvcobjects_ref->{'pptp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pptp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pptp'}{'port'}{'udp'} = '1723'	; 
#	$srvcobjects_ref->{'pptp'}{'ports'}{'udp'}{'1723'}++	; 
#	$ports_ref->{'udp'}{'1723'}{'name'} = 'pptp'		; 
#	$srvcobjects_ref->{'pptp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pptp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pptp'}{'port'}{'tcp'} = '1723'	; 
#	$srvcobjects_ref->{'pptp'}{'ports'}{'tcp'}{'1723'}++	; 
#	$ports_ref->{'tcp'}{'1723'}{'name'} = 'pptp'		; 
#	$srvcobjects_ref->{'h323callsigalt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h323callsigalt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323callsigalt'}{'port'}{'udp'} = '11720'	; 
#	$srvcobjects_ref->{'h323callsigalt'}{'ports'}{'udp'}{'11720'}++	; 
#	$ports_ref->{'udp'}{'11720'}{'name'} = 'h323callsigalt'		; 
#	$srvcobjects_ref->{'h323callsigalt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h323callsigalt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323callsigalt'}{'port'}{'tcp'} = '11720'	; 
#	$srvcobjects_ref->{'h323callsigalt'}{'ports'}{'tcp'}{'11720'}++	; 
#	$ports_ref->{'tcp'}{'11720'}{'name'} = 'h323callsigalt'		; 
#	$srvcobjects_ref->{'identify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'identify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'identify'}{'port'}{'udp'} = '2987'	; 
#	$srvcobjects_ref->{'identify'}{'ports'}{'udp'}{'2987'}++	; 
#	$ports_ref->{'udp'}{'2987'}{'name'} = 'identify'		; 
#	$srvcobjects_ref->{'identify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'identify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'identify'}{'port'}{'tcp'} = '2987'	; 
#	$srvcobjects_ref->{'identify'}{'ports'}{'tcp'}{'2987'}++	; 
#	$ports_ref->{'tcp'}{'2987'}{'name'} = 'identify'		; 
#	$srvcobjects_ref->{'simbaexpress'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simbaexpress'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simbaexpress'}{'port'}{'udp'} = '1583'	; 
#	$srvcobjects_ref->{'simbaexpress'}{'ports'}{'udp'}{'1583'}++	; 
#	$ports_ref->{'udp'}{'1583'}{'name'} = 'simbaexpress'		; 
#	$srvcobjects_ref->{'simbaexpress'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simbaexpress'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simbaexpress'}{'port'}{'tcp'} = '1583'	; 
#	$srvcobjects_ref->{'simbaexpress'}{'ports'}{'tcp'}{'1583'}++	; 
#	$ports_ref->{'tcp'}{'1583'}{'name'} = 'simbaexpress'		; 
#	$srvcobjects_ref->{'font-service'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'font-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'font-service'}{'port'}{'udp'} = '7100'	; 
#	$srvcobjects_ref->{'font-service'}{'ports'}{'udp'}{'7100'}++	; 
#	$ports_ref->{'udp'}{'7100'}{'name'} = 'font-service'		; 
#	$srvcobjects_ref->{'font-service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'font-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'font-service'}{'port'}{'tcp'} = '7100'	; 
#	$srvcobjects_ref->{'font-service'}{'ports'}{'tcp'}{'7100'}++	; 
#	$ports_ref->{'tcp'}{'7100'}{'name'} = 'font-service'		; 
#	$srvcobjects_ref->{'vrts-tdd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrts-tdd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-tdd'}{'port'}{'udp'} = '14149'	; 
#	$srvcobjects_ref->{'vrts-tdd'}{'ports'}{'udp'}{'14149'}++	; 
#	$ports_ref->{'udp'}{'14149'}{'name'} = 'vrts-tdd'		; 
#	$srvcobjects_ref->{'vrts-tdd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrts-tdd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-tdd'}{'port'}{'tcp'} = '14149'	; 
#	$srvcobjects_ref->{'vrts-tdd'}{'ports'}{'tcp'}{'14149'}++	; 
#	$ports_ref->{'tcp'}{'14149'}{'name'} = 'vrts-tdd'		; 
#	$srvcobjects_ref->{'nextstep'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nextstep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nextstep'}{'port'}{'udp'} = '178'	; 
#	$srvcobjects_ref->{'nextstep'}{'ports'}{'udp'}{'178'}++	; 
#	$ports_ref->{'udp'}{'178'}{'name'} = 'nextstep'		; 
#	$srvcobjects_ref->{'nextstep'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nextstep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nextstep'}{'port'}{'tcp'} = '178'	; 
#	$srvcobjects_ref->{'nextstep'}{'ports'}{'tcp'}{'178'}++	; 
#	$ports_ref->{'tcp'}{'178'}{'name'} = 'nextstep'		; 
#	$srvcobjects_ref->{'outlaws'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'outlaws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'outlaws'}{'port'}{'udp'} = '5310'	; 
#	$srvcobjects_ref->{'outlaws'}{'ports'}{'udp'}{'5310'}++	; 
#	$ports_ref->{'udp'}{'5310'}{'name'} = 'outlaws'		; 
#	$srvcobjects_ref->{'outlaws'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'outlaws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'outlaws'}{'port'}{'tcp'} = '5310'	; 
#	$srvcobjects_ref->{'outlaws'}{'ports'}{'tcp'}{'5310'}++	; 
#	$ports_ref->{'tcp'}{'5310'}{'name'} = 'outlaws'		; 
#	$srvcobjects_ref->{'3com-njack-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3com-njack-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-njack-2'}{'port'}{'udp'} = '5265'	; 
#	$srvcobjects_ref->{'3com-njack-2'}{'ports'}{'udp'}{'5265'}++	; 
#	$ports_ref->{'udp'}{'5265'}{'name'} = '3com-njack-2'		; 
#	$srvcobjects_ref->{'3com-njack-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3com-njack-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-njack-2'}{'port'}{'tcp'} = '5265'	; 
#	$srvcobjects_ref->{'3com-njack-2'}{'ports'}{'tcp'}{'5265'}++	; 
#	$ports_ref->{'tcp'}{'5265'}{'name'} = '3com-njack-2'		; 
#	$srvcobjects_ref->{'rlp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rlp'}{'port'}{'udp'} = '39'	; 
#	$srvcobjects_ref->{'rlp'}{'ports'}{'udp'}{'39'}++	; 
#	$ports_ref->{'udp'}{'39'}{'name'} = 'rlp'		; 
#	$srvcobjects_ref->{'rlp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rlp'}{'port'}{'tcp'} = '39'	; 
#	$srvcobjects_ref->{'rlp'}{'ports'}{'tcp'}{'39'}++	; 
#	$ports_ref->{'tcp'}{'39'}{'name'} = 'rlp'		; 
#	$srvcobjects_ref->{'opsec-ela'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsec-ela'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-ela'}{'port'}{'udp'} = '18187'	; 
#	$srvcobjects_ref->{'opsec-ela'}{'ports'}{'udp'}{'18187'}++	; 
#	$ports_ref->{'udp'}{'18187'}{'name'} = 'opsec-ela'		; 
#	$srvcobjects_ref->{'opsec-ela'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsec-ela'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-ela'}{'port'}{'tcp'} = '18187'	; 
#	$srvcobjects_ref->{'opsec-ela'}{'ports'}{'tcp'}{'18187'}++	; 
#	$ports_ref->{'tcp'}{'18187'}{'name'} = 'opsec-ela'		; 
#	$srvcobjects_ref->{'m-wnn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'m-wnn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m-wnn'}{'port'}{'udp'} = '3732'	; 
#	$srvcobjects_ref->{'m-wnn'}{'ports'}{'udp'}{'3732'}++	; 
#	$ports_ref->{'udp'}{'3732'}{'name'} = 'm-wnn'		; 
#	$srvcobjects_ref->{'m-wnn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'m-wnn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m-wnn'}{'port'}{'tcp'} = '3732'	; 
#	$srvcobjects_ref->{'m-wnn'}{'ports'}{'tcp'}{'3732'}++	; 
#	$ports_ref->{'tcp'}{'3732'}{'name'} = 'm-wnn'		; 
#	$srvcobjects_ref->{'cdl-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cdl-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdl-server'}{'port'}{'udp'} = '3056'	; 
#	$srvcobjects_ref->{'cdl-server'}{'ports'}{'udp'}{'3056'}++	; 
#	$ports_ref->{'udp'}{'3056'}{'name'} = 'cdl-server'		; 
#	$srvcobjects_ref->{'cdl-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cdl-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdl-server'}{'port'}{'tcp'} = '3056'	; 
#	$srvcobjects_ref->{'cdl-server'}{'ports'}{'tcp'}{'3056'}++	; 
#	$ports_ref->{'tcp'}{'3056'}{'name'} = 'cdl-server'		; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'port'}{'udp'} = '247'	; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'ports'}{'udp'}{'247'}++	; 
#	$ports_ref->{'udp'}{'247'}{'name'} = 'subntbcst_tftp'		; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'port'}{'tcp'} = '247'	; 
#	$srvcobjects_ref->{'subntbcst_tftp'}{'ports'}{'tcp'}{'247'}++	; 
#	$ports_ref->{'tcp'}{'247'}{'name'} = 'subntbcst_tftp'		; 
#	$srvcobjects_ref->{'cyc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cyc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cyc'}{'port'}{'udp'} = '3645'	; 
#	$srvcobjects_ref->{'cyc'}{'ports'}{'udp'}{'3645'}++	; 
#	$ports_ref->{'udp'}{'3645'}{'name'} = 'cyc'		; 
#	$srvcobjects_ref->{'cyc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cyc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cyc'}{'port'}{'tcp'} = '3645'	; 
#	$srvcobjects_ref->{'cyc'}{'ports'}{'tcp'}{'3645'}++	; 
#	$ports_ref->{'tcp'}{'3645'}{'name'} = 'cyc'		; 
#	$srvcobjects_ref->{'entrust-aaas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entrust-aaas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-aaas'}{'port'}{'udp'} = '680'	; 
#	$srvcobjects_ref->{'entrust-aaas'}{'ports'}{'udp'}{'680'}++	; 
#	$ports_ref->{'udp'}{'680'}{'name'} = 'entrust-aaas'		; 
#	$srvcobjects_ref->{'entrust-aaas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entrust-aaas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-aaas'}{'port'}{'tcp'} = '680'	; 
#	$srvcobjects_ref->{'entrust-aaas'}{'ports'}{'tcp'}{'680'}++	; 
#	$ports_ref->{'tcp'}{'680'}{'name'} = 'entrust-aaas'		; 
#	$srvcobjects_ref->{'mdtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mdtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdtp'}{'port'}{'udp'} = '3232'	; 
#	$srvcobjects_ref->{'mdtp'}{'ports'}{'udp'}{'3232'}++	; 
#	$ports_ref->{'udp'}{'3232'}{'name'} = 'mdtp'		; 
#	$srvcobjects_ref->{'mdtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mdtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdtp'}{'port'}{'tcp'} = '3232'	; 
#	$srvcobjects_ref->{'mdtp'}{'ports'}{'tcp'}{'3232'}++	; 
#	$ports_ref->{'tcp'}{'3232'}{'name'} = 'mdtp'		; 
#	$srvcobjects_ref->{'gtrack-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gtrack-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtrack-server'}{'port'}{'udp'} = '3591'	; 
#	$srvcobjects_ref->{'gtrack-server'}{'ports'}{'udp'}{'3591'}++	; 
#	$ports_ref->{'udp'}{'3591'}{'name'} = 'gtrack-server'		; 
#	$srvcobjects_ref->{'gtrack-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gtrack-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtrack-server'}{'port'}{'tcp'} = '3591'	; 
#	$srvcobjects_ref->{'gtrack-server'}{'ports'}{'tcp'}{'3591'}++	; 
#	$ports_ref->{'tcp'}{'3591'}{'name'} = 'gtrack-server'		; 
#	$srvcobjects_ref->{'mobilip-mn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mobilip-mn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mobilip-mn'}{'port'}{'udp'} = '435'	; 
#	$srvcobjects_ref->{'mobilip-mn'}{'ports'}{'udp'}{'435'}++	; 
#	$ports_ref->{'udp'}{'435'}{'name'} = 'mobilip-mn'		; 
#	$srvcobjects_ref->{'mobilip-mn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mobilip-mn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mobilip-mn'}{'port'}{'tcp'} = '435'	; 
#	$srvcobjects_ref->{'mobilip-mn'}{'ports'}{'tcp'}{'435'}++	; 
#	$ports_ref->{'tcp'}{'435'}{'name'} = 'mobilip-mn'		; 
#	$srvcobjects_ref->{'softcm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'softcm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softcm'}{'port'}{'udp'} = '6110'	; 
#	$srvcobjects_ref->{'softcm'}{'ports'}{'udp'}{'6110'}++	; 
#	$ports_ref->{'udp'}{'6110'}{'name'} = 'softcm'		; 
#	$srvcobjects_ref->{'softcm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'softcm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softcm'}{'port'}{'tcp'} = '6110'	; 
#	$srvcobjects_ref->{'softcm'}{'ports'}{'tcp'}{'6110'}++	; 
#	$ports_ref->{'tcp'}{'6110'}{'name'} = 'softcm'		; 
#	$srvcobjects_ref->{'netattachsdmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netattachsdmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netattachsdmp'}{'port'}{'udp'} = '3066'	; 
#	$srvcobjects_ref->{'netattachsdmp'}{'ports'}{'udp'}{'3066'}++	; 
#	$ports_ref->{'udp'}{'3066'}{'name'} = 'netattachsdmp'		; 
#	$srvcobjects_ref->{'netattachsdmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netattachsdmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netattachsdmp'}{'port'}{'tcp'} = '3066'	; 
#	$srvcobjects_ref->{'netattachsdmp'}{'ports'}{'tcp'}{'3066'}++	; 
#	$ports_ref->{'tcp'}{'3066'}{'name'} = 'netattachsdmp'		; 
#	$srvcobjects_ref->{'simplement-tie'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simplement-tie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simplement-tie'}{'port'}{'udp'} = '2756'	; 
#	$srvcobjects_ref->{'simplement-tie'}{'ports'}{'udp'}{'2756'}++	; 
#	$ports_ref->{'udp'}{'2756'}{'name'} = 'simplement-tie'		; 
#	$srvcobjects_ref->{'simplement-tie'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simplement-tie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simplement-tie'}{'port'}{'tcp'} = '2756'	; 
#	$srvcobjects_ref->{'simplement-tie'}{'ports'}{'tcp'}{'2756'}++	; 
#	$ports_ref->{'tcp'}{'2756'}{'name'} = 'simplement-tie'		; 
#	$srvcobjects_ref->{'compaq-https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'compaq-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-https'}{'port'}{'udp'} = '2381'	; 
#	$srvcobjects_ref->{'compaq-https'}{'ports'}{'udp'}{'2381'}++	; 
#	$ports_ref->{'udp'}{'2381'}{'name'} = 'compaq-https'		; 
#	$srvcobjects_ref->{'compaq-https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'compaq-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-https'}{'port'}{'tcp'} = '2381'	; 
#	$srvcobjects_ref->{'compaq-https'}{'ports'}{'tcp'}{'2381'}++	; 
#	$ports_ref->{'tcp'}{'2381'}{'name'} = 'compaq-https'		; 
#	$srvcobjects_ref->{'netrjs-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrjs-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-4'}{'port'}{'udp'} = '74'	; 
#	$srvcobjects_ref->{'netrjs-4'}{'ports'}{'udp'}{'74'}++	; 
#	$ports_ref->{'udp'}{'74'}{'name'} = 'netrjs-4'		; 
#	$srvcobjects_ref->{'netrjs-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrjs-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-4'}{'port'}{'tcp'} = '74'	; 
#	$srvcobjects_ref->{'netrjs-4'}{'ports'}{'tcp'}{'74'}++	; 
#	$ports_ref->{'tcp'}{'74'}{'name'} = 'netrjs-4'		; 
#	$srvcobjects_ref->{'magenta-logic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'magenta-logic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magenta-logic'}{'port'}{'udp'} = '313'	; 
#	$srvcobjects_ref->{'magenta-logic'}{'ports'}{'udp'}{'313'}++	; 
#	$ports_ref->{'udp'}{'313'}{'name'} = 'magenta-logic'		; 
#	$srvcobjects_ref->{'magenta-logic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'magenta-logic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magenta-logic'}{'port'}{'tcp'} = '313'	; 
#	$srvcobjects_ref->{'magenta-logic'}{'ports'}{'tcp'}{'313'}++	; 
#	$ports_ref->{'tcp'}{'313'}{'name'} = 'magenta-logic'		; 
#	$srvcobjects_ref->{'vemmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vemmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vemmi'}{'port'}{'udp'} = '575'	; 
#	$srvcobjects_ref->{'vemmi'}{'ports'}{'udp'}{'575'}++	; 
#	$ports_ref->{'udp'}{'575'}{'name'} = 'vemmi'		; 
#	$srvcobjects_ref->{'vemmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vemmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vemmi'}{'port'}{'tcp'} = '575'	; 
#	$srvcobjects_ref->{'vemmi'}{'ports'}{'tcp'}{'575'}++	; 
#	$ports_ref->{'tcp'}{'575'}{'name'} = 'vemmi'		; 
#	$srvcobjects_ref->{'snapp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snapp'}{'port'}{'udp'} = '2333'	; 
#	$srvcobjects_ref->{'snapp'}{'ports'}{'udp'}{'2333'}++	; 
#	$ports_ref->{'udp'}{'2333'}{'name'} = 'snapp'		; 
#	$srvcobjects_ref->{'snapp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snapp'}{'port'}{'tcp'} = '2333'	; 
#	$srvcobjects_ref->{'snapp'}{'ports'}{'tcp'}{'2333'}++	; 
#	$ports_ref->{'tcp'}{'2333'}{'name'} = 'snapp'		; 
#	$srvcobjects_ref->{'ace-proxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ace-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-proxy'}{'port'}{'udp'} = '2335'	; 
#	$srvcobjects_ref->{'ace-proxy'}{'ports'}{'udp'}{'2335'}++	; 
#	$ports_ref->{'udp'}{'2335'}{'name'} = 'ace-proxy'		; 
#	$srvcobjects_ref->{'ace-proxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ace-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-proxy'}{'port'}{'tcp'} = '2335'	; 
#	$srvcobjects_ref->{'ace-proxy'}{'ports'}{'tcp'}{'2335'}++	; 
#	$ports_ref->{'tcp'}{'2335'}{'name'} = 'ace-proxy'		; 
#	$srvcobjects_ref->{'comcam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'comcam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'comcam'}{'port'}{'udp'} = '2108'	; 
#	$srvcobjects_ref->{'comcam'}{'ports'}{'udp'}{'2108'}++	; 
#	$ports_ref->{'udp'}{'2108'}{'name'} = 'comcam'		; 
#	$srvcobjects_ref->{'comcam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'comcam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'comcam'}{'port'}{'tcp'} = '2108'	; 
#	$srvcobjects_ref->{'comcam'}{'ports'}{'tcp'}{'2108'}++	; 
#	$ports_ref->{'tcp'}{'2108'}{'name'} = 'comcam'		; 
#	$srvcobjects_ref->{'fatpipe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fatpipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fatpipe'}{'port'}{'udp'} = '3353'	; 
#	$srvcobjects_ref->{'fatpipe'}{'ports'}{'udp'}{'3353'}++	; 
#	$ports_ref->{'udp'}{'3353'}{'name'} = 'fatpipe'		; 
#	$srvcobjects_ref->{'fatpipe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fatpipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fatpipe'}{'port'}{'tcp'} = '3353'	; 
#	$srvcobjects_ref->{'fatpipe'}{'ports'}{'tcp'}{'3353'}++	; 
#	$ports_ref->{'tcp'}{'3353'}{'name'} = 'fatpipe'		; 
#	$srvcobjects_ref->{'cvmmon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cvmmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvmmon'}{'port'}{'udp'} = '2300'	; 
#	$srvcobjects_ref->{'cvmmon'}{'ports'}{'udp'}{'2300'}++	; 
#	$ports_ref->{'udp'}{'2300'}{'name'} = 'cvmmon'		; 
#	$srvcobjects_ref->{'cvmmon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cvmmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvmmon'}{'port'}{'tcp'} = '2300'	; 
#	$srvcobjects_ref->{'cvmmon'}{'ports'}{'tcp'}{'2300'}++	; 
#	$ports_ref->{'tcp'}{'2300'}{'name'} = 'cvmmon'		; 
#	$srvcobjects_ref->{'msl_lmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msl_lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msl_lmd'}{'port'}{'udp'} = '1464'	; 
#	$srvcobjects_ref->{'msl_lmd'}{'ports'}{'udp'}{'1464'}++	; 
#	$ports_ref->{'udp'}{'1464'}{'name'} = 'msl_lmd'		; 
#	$srvcobjects_ref->{'msl_lmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msl_lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msl_lmd'}{'port'}{'tcp'} = '1464'	; 
#	$srvcobjects_ref->{'msl_lmd'}{'ports'}{'tcp'}{'1464'}++	; 
#	$ports_ref->{'tcp'}{'1464'}{'name'} = 'msl_lmd'		; 
#	$srvcobjects_ref->{'vmpwscs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vmpwscs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vmpwscs'}{'port'}{'udp'} = '214'	; 
#	$srvcobjects_ref->{'vmpwscs'}{'ports'}{'udp'}{'214'}++	; 
#	$ports_ref->{'udp'}{'214'}{'name'} = 'vmpwscs'		; 
#	$srvcobjects_ref->{'vmpwscs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vmpwscs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vmpwscs'}{'port'}{'tcp'} = '214'	; 
#	$srvcobjects_ref->{'vmpwscs'}{'ports'}{'tcp'}{'214'}++	; 
#	$ports_ref->{'tcp'}{'214'}{'name'} = 'vmpwscs'		; 
#	$srvcobjects_ref->{'hmmp-ind'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hmmp-ind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hmmp-ind'}{'port'}{'udp'} = '612'	; 
#	$srvcobjects_ref->{'hmmp-ind'}{'ports'}{'udp'}{'612'}++	; 
#	$ports_ref->{'udp'}{'612'}{'name'} = 'hmmp-ind'		; 
#	$srvcobjects_ref->{'hmmp-ind'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hmmp-ind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hmmp-ind'}{'port'}{'tcp'} = '612'	; 
#	$srvcobjects_ref->{'hmmp-ind'}{'ports'}{'tcp'}{'612'}++	; 
#	$ports_ref->{'tcp'}{'612'}{'name'} = 'hmmp-ind'		; 
#	$srvcobjects_ref->{'nexus-portal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nexus-portal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nexus-portal'}{'port'}{'udp'} = '4021'	; 
#	$srvcobjects_ref->{'nexus-portal'}{'ports'}{'udp'}{'4021'}++	; 
#	$ports_ref->{'udp'}{'4021'}{'name'} = 'nexus-portal'		; 
#	$srvcobjects_ref->{'nexus-portal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nexus-portal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nexus-portal'}{'port'}{'tcp'} = '4021'	; 
#	$srvcobjects_ref->{'nexus-portal'}{'ports'}{'tcp'}{'4021'}++	; 
#	$ports_ref->{'tcp'}{'4021'}{'name'} = 'nexus-portal'		; 
#	$srvcobjects_ref->{'vpvd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpvd'}{'port'}{'udp'} = '1518'	; 
#	$srvcobjects_ref->{'vpvd'}{'ports'}{'udp'}{'1518'}++	; 
#	$ports_ref->{'udp'}{'1518'}{'name'} = 'vpvd'		; 
#	$srvcobjects_ref->{'vpvd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpvd'}{'port'}{'tcp'} = '1518'	; 
#	$srvcobjects_ref->{'vpvd'}{'ports'}{'tcp'}{'1518'}++	; 
#	$ports_ref->{'tcp'}{'1518'}{'name'} = 'vpvd'		; 
#	$srvcobjects_ref->{'aol-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aol-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol-3'}{'port'}{'udp'} = '5193'	; 
#	$srvcobjects_ref->{'aol-3'}{'ports'}{'udp'}{'5193'}++	; 
#	$ports_ref->{'udp'}{'5193'}{'name'} = 'aol-3'		; 
#	$srvcobjects_ref->{'aol-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aol-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol-3'}{'port'}{'tcp'} = '5193'	; 
#	$srvcobjects_ref->{'aol-3'}{'ports'}{'tcp'}{'5193'}++	; 
#	$ports_ref->{'tcp'}{'5193'}{'name'} = 'aol-3'		; 
#	$srvcobjects_ref->{'directvdata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directvdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directvdata'}{'port'}{'udp'} = '3287'	; 
#	$srvcobjects_ref->{'directvdata'}{'ports'}{'udp'}{'3287'}++	; 
#	$ports_ref->{'udp'}{'3287'}{'name'} = 'directvdata'		; 
#	$srvcobjects_ref->{'directvdata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directvdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directvdata'}{'port'}{'tcp'} = '3287'	; 
#	$srvcobjects_ref->{'directvdata'}{'ports'}{'tcp'}{'3287'}++	; 
#	$ports_ref->{'tcp'}{'3287'}{'name'} = 'directvdata'		; 
#	$srvcobjects_ref->{'zephyr-clt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zephyr-clt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zephyr-clt'}{'port'}{'udp'} = '2103'	; 
#	$srvcobjects_ref->{'zephyr-clt'}{'ports'}{'udp'}{'2103'}++	; 
#	$ports_ref->{'udp'}{'2103'}{'name'} = 'zephyr-clt'		; 
#	$srvcobjects_ref->{'zephyr-clt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zephyr-clt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zephyr-clt'}{'port'}{'tcp'} = '2103'	; 
#	$srvcobjects_ref->{'zephyr-clt'}{'ports'}{'tcp'}{'2103'}++	; 
#	$ports_ref->{'tcp'}{'2103'}{'name'} = 'zephyr-clt'		; 
#	$srvcobjects_ref->{'synoptics-trap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synoptics-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synoptics-trap'}{'port'}{'udp'} = '412'	; 
#	$srvcobjects_ref->{'synoptics-trap'}{'ports'}{'udp'}{'412'}++	; 
#	$ports_ref->{'udp'}{'412'}{'name'} = 'synoptics-trap'		; 
#	$srvcobjects_ref->{'synoptics-trap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synoptics-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synoptics-trap'}{'port'}{'tcp'} = '412'	; 
#	$srvcobjects_ref->{'synoptics-trap'}{'ports'}{'tcp'}{'412'}++	; 
#	$ports_ref->{'tcp'}{'412'}{'name'} = 'synoptics-trap'		; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'port'}{'udp'} = '2556'	; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'ports'}{'udp'}{'2556'}++	; 
#	$ports_ref->{'udp'}{'2556'}{'name'} = 'nicetec-nmsvc'		; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'port'}{'tcp'} = '2556'	; 
#	$srvcobjects_ref->{'nicetec-nmsvc'}{'ports'}{'tcp'}{'2556'}++	; 
#	$ports_ref->{'tcp'}{'2556'}{'name'} = 'nicetec-nmsvc'		; 
#	$srvcobjects_ref->{'etp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'etp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etp'}{'port'}{'udp'} = '1798'	; 
#	$srvcobjects_ref->{'etp'}{'ports'}{'udp'}{'1798'}++	; 
#	$ports_ref->{'udp'}{'1798'}{'name'} = 'etp'		; 
#	$srvcobjects_ref->{'etp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'etp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etp'}{'port'}{'tcp'} = '1798'	; 
#	$srvcobjects_ref->{'etp'}{'ports'}{'tcp'}{'1798'}++	; 
#	$ports_ref->{'tcp'}{'1798'}{'name'} = 'etp'		; 
#	$srvcobjects_ref->{'cddn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cddn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cddn'}{'port'}{'udp'} = '3447'	; 
#	$srvcobjects_ref->{'cddn'}{'ports'}{'udp'}{'3447'}++	; 
#	$ports_ref->{'udp'}{'3447'}{'name'} = 'cddn'		; 
#	$srvcobjects_ref->{'cddn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cddn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cddn'}{'port'}{'tcp'} = '3447'	; 
#	$srvcobjects_ref->{'cddn'}{'ports'}{'tcp'}{'3447'}++	; 
#	$ports_ref->{'tcp'}{'3447'}{'name'} = 'cddn'		; 
#	$srvcobjects_ref->{'yak-chat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'yak-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'yak-chat'}{'port'}{'udp'} = '258'	; 
#	$srvcobjects_ref->{'yak-chat'}{'ports'}{'udp'}{'258'}++	; 
#	$ports_ref->{'udp'}{'258'}{'name'} = 'yak-chat'		; 
#	$srvcobjects_ref->{'yak-chat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'yak-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'yak-chat'}{'port'}{'tcp'} = '258'	; 
#	$srvcobjects_ref->{'yak-chat'}{'ports'}{'tcp'}{'258'}++	; 
#	$ports_ref->{'tcp'}{'258'}{'name'} = 'yak-chat'		; 
#	$srvcobjects_ref->{'mcns-sec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcns-sec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcns-sec'}{'port'}{'udp'} = '638'	; 
#	$srvcobjects_ref->{'mcns-sec'}{'ports'}{'udp'}{'638'}++	; 
#	$ports_ref->{'udp'}{'638'}{'name'} = 'mcns-sec'		; 
#	$srvcobjects_ref->{'mcns-sec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcns-sec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcns-sec'}{'port'}{'tcp'} = '638'	; 
#	$srvcobjects_ref->{'mcns-sec'}{'ports'}{'tcp'}{'638'}++	; 
#	$ports_ref->{'tcp'}{'638'}{'name'} = 'mcns-sec'		; 
#	$srvcobjects_ref->{'courier'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'courier'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'courier'}{'port'}{'udp'} = '530'	; 
#	$srvcobjects_ref->{'courier'}{'ports'}{'udp'}{'530'}++	; 
#	$ports_ref->{'udp'}{'530'}{'name'} = 'courier'		; 
#	$srvcobjects_ref->{'courier'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'courier'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'courier'}{'port'}{'tcp'} = '530'	; 
#	$srvcobjects_ref->{'courier'}{'ports'}{'tcp'}{'530'}++	; 
#	$ports_ref->{'tcp'}{'530'}{'name'} = 'courier'		; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'port'}{'udp'} = '3266'	; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'ports'}{'udp'}{'3266'}++	; 
#	$ports_ref->{'udp'}{'3266'}{'name'} = 'ns-cfg-server'		; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'port'}{'tcp'} = '3266'	; 
#	$srvcobjects_ref->{'ns-cfg-server'}{'ports'}{'tcp'}{'3266'}++	; 
#	$ports_ref->{'tcp'}{'3266'}{'name'} = 'ns-cfg-server'		; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'port'}{'udp'} = '3389'	; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'ports'}{'udp'}{'3389'}++	; 
#	$ports_ref->{'udp'}{'3389'}{'name'} = 'ms-wbt-server'		; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'port'}{'tcp'} = '3389'	; 
#	$srvcobjects_ref->{'ms-wbt-server'}{'ports'}{'tcp'}{'3389'}++	; 
#	$ports_ref->{'tcp'}{'3389'}{'name'} = 'ms-wbt-server'		; 
#	$srvcobjects_ref->{'cadlock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadlock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadlock'}{'port'}{'udp'} = '770'	; 
#	$srvcobjects_ref->{'cadlock'}{'ports'}{'udp'}{'770'}++	; 
#	$ports_ref->{'udp'}{'770'}{'name'} = 'cadlock'		; 
#	$srvcobjects_ref->{'cadlock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadlock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadlock'}{'port'}{'tcp'} = '770'	; 
#	$srvcobjects_ref->{'cadlock'}{'ports'}{'tcp'}{'770'}++	; 
#	$ports_ref->{'tcp'}{'770'}{'name'} = 'cadlock'		; 
#	$srvcobjects_ref->{'netview-aix-8'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-8'}{'port'}{'udp'} = '1668'	; 
#	$srvcobjects_ref->{'netview-aix-8'}{'ports'}{'udp'}{'1668'}++	; 
#	$ports_ref->{'udp'}{'1668'}{'name'} = 'netview-aix-8'		; 
#	$srvcobjects_ref->{'netview-aix-8'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-8'}{'port'}{'tcp'} = '1668'	; 
#	$srvcobjects_ref->{'netview-aix-8'}{'ports'}{'tcp'}{'1668'}++	; 
#	$ports_ref->{'tcp'}{'1668'}{'name'} = 'netview-aix-8'		; 
#	$srvcobjects_ref->{'iiw-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iiw-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iiw-port'}{'port'}{'udp'} = '3186'	; 
#	$srvcobjects_ref->{'iiw-port'}{'ports'}{'udp'}{'3186'}++	; 
#	$ports_ref->{'udp'}{'3186'}{'name'} = 'iiw-port'		; 
#	$srvcobjects_ref->{'iiw-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iiw-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iiw-port'}{'port'}{'tcp'} = '3186'	; 
#	$srvcobjects_ref->{'iiw-port'}{'ports'}{'tcp'}{'3186'}++	; 
#	$ports_ref->{'tcp'}{'3186'}{'name'} = 'iiw-port'		; 
#	$srvcobjects_ref->{'disclose'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'disclose'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'disclose'}{'port'}{'udp'} = '667'	; 
#	$srvcobjects_ref->{'disclose'}{'ports'}{'udp'}{'667'}++	; 
#	$ports_ref->{'udp'}{'667'}{'name'} = 'disclose'		; 
#	$srvcobjects_ref->{'disclose'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'disclose'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'disclose'}{'port'}{'tcp'} = '667'	; 
#	$srvcobjects_ref->{'disclose'}{'ports'}{'tcp'}{'667'}++	; 
#	$ports_ref->{'tcp'}{'667'}{'name'} = 'disclose'		; 
#	$srvcobjects_ref->{'exec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'exec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exec'}{'port'}{'tcp'} = '512'	; 
#	$srvcobjects_ref->{'exec'}{'ports'}{'tcp'}{'512'}++	; 
#	$ports_ref->{'tcp'}{'512'}{'name'} = 'exec'		; 
#	$srvcobjects_ref->{'ariel2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ariel2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariel2'}{'port'}{'udp'} = '421'	; 
#	$srvcobjects_ref->{'ariel2'}{'ports'}{'udp'}{'421'}++	; 
#	$ports_ref->{'udp'}{'421'}{'name'} = 'ariel2'		; 
#	$srvcobjects_ref->{'ariel2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ariel2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariel2'}{'port'}{'tcp'} = '421'	; 
#	$srvcobjects_ref->{'ariel2'}{'ports'}{'tcp'}{'421'}++	; 
#	$ports_ref->{'tcp'}{'421'}{'name'} = 'ariel2'		; 
#	$srvcobjects_ref->{'rsh-spx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsh-spx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsh-spx'}{'port'}{'udp'} = '222'	; 
#	$srvcobjects_ref->{'rsh-spx'}{'ports'}{'udp'}{'222'}++	; 
#	$ports_ref->{'udp'}{'222'}{'name'} = 'rsh-spx'		; 
#	$srvcobjects_ref->{'rsh-spx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsh-spx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsh-spx'}{'port'}{'tcp'} = '222'	; 
#	$srvcobjects_ref->{'rsh-spx'}{'ports'}{'tcp'}{'222'}++	; 
#	$ports_ref->{'tcp'}{'222'}{'name'} = 'rsh-spx'		; 
#	$srvcobjects_ref->{'netiq-endpt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netiq-endpt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-endpt'}{'port'}{'udp'} = '10115'	; 
#	$srvcobjects_ref->{'netiq-endpt'}{'ports'}{'udp'}{'10115'}++	; 
#	$ports_ref->{'udp'}{'10115'}{'name'} = 'netiq-endpt'		; 
#	$srvcobjects_ref->{'netiq-endpt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netiq-endpt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-endpt'}{'port'}{'tcp'} = '10115'	; 
#	$srvcobjects_ref->{'netiq-endpt'}{'ports'}{'tcp'}{'10115'}++	; 
#	$ports_ref->{'tcp'}{'10115'}{'name'} = 'netiq-endpt'		; 
#	$srvcobjects_ref->{'rsip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsip'}{'port'}{'udp'} = '4555'	; 
#	$srvcobjects_ref->{'rsip'}{'ports'}{'udp'}{'4555'}++	; 
#	$ports_ref->{'udp'}{'4555'}{'name'} = 'rsip'		; 
#	$srvcobjects_ref->{'rsip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsip'}{'port'}{'tcp'} = '4555'	; 
#	$srvcobjects_ref->{'rsip'}{'ports'}{'tcp'}{'4555'}++	; 
#	$ports_ref->{'tcp'}{'4555'}{'name'} = 'rsip'		; 
#	$srvcobjects_ref->{'raid-cs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raid-cs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-cs'}{'port'}{'udp'} = '2015'	; 
#	$srvcobjects_ref->{'raid-cs'}{'ports'}{'udp'}{'2015'}++	; 
#	$ports_ref->{'udp'}{'2015'}{'name'} = 'raid-cs'		; 
#	$srvcobjects_ref->{'tht-treasure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tht-treasure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tht-treasure'}{'port'}{'udp'} = '1832'	; 
#	$srvcobjects_ref->{'tht-treasure'}{'ports'}{'udp'}{'1832'}++	; 
#	$ports_ref->{'udp'}{'1832'}{'name'} = 'tht-treasure'		; 
#	$srvcobjects_ref->{'tht-treasure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tht-treasure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tht-treasure'}{'port'}{'tcp'} = '1832'	; 
#	$srvcobjects_ref->{'tht-treasure'}{'ports'}{'tcp'}{'1832'}++	; 
#	$ports_ref->{'tcp'}{'1832'}{'name'} = 'tht-treasure'		; 
#	$srvcobjects_ref->{'utmpcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'utmpcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utmpcd'}{'port'}{'udp'} = '431'	; 
#	$srvcobjects_ref->{'utmpcd'}{'ports'}{'udp'}{'431'}++	; 
#	$ports_ref->{'udp'}{'431'}{'name'} = 'utmpcd'		; 
#	$srvcobjects_ref->{'utmpcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'utmpcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utmpcd'}{'port'}{'tcp'} = '431'	; 
#	$srvcobjects_ref->{'utmpcd'}{'ports'}{'tcp'}{'431'}++	; 
#	$ports_ref->{'tcp'}{'431'}{'name'} = 'utmpcd'		; 
#	$srvcobjects_ref->{'netserialext3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netserialext3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext3'}{'port'}{'udp'} = '16367'	; 
#	$srvcobjects_ref->{'netserialext3'}{'ports'}{'udp'}{'16367'}++	; 
#	$ports_ref->{'udp'}{'16367'}{'name'} = 'netserialext3'		; 
#	$srvcobjects_ref->{'netserialext3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netserialext3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext3'}{'port'}{'tcp'} = '16367'	; 
#	$srvcobjects_ref->{'netserialext3'}{'ports'}{'tcp'}{'16367'}++	; 
#	$ports_ref->{'tcp'}{'16367'}{'name'} = 'netserialext3'		; 
#	$srvcobjects_ref->{'intv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intv'}{'port'}{'udp'} = '1585'	; 
#	$srvcobjects_ref->{'intv'}{'ports'}{'udp'}{'1585'}++	; 
#	$ports_ref->{'udp'}{'1585'}{'name'} = 'intv'		; 
#	$srvcobjects_ref->{'intv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intv'}{'port'}{'tcp'} = '1585'	; 
#	$srvcobjects_ref->{'intv'}{'ports'}{'tcp'}{'1585'}++	; 
#	$ports_ref->{'tcp'}{'1585'}{'name'} = 'intv'		; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'port'}{'udp'} = '3590'	; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'ports'}{'udp'}{'3590'}++	; 
#	$ports_ref->{'udp'}{'3590'}{'name'} = 'wv-csp-sms'		; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'port'}{'tcp'} = '3590'	; 
#	$srvcobjects_ref->{'wv-csp-sms'}{'ports'}{'tcp'}{'3590'}++	; 
#	$ports_ref->{'tcp'}{'3590'}{'name'} = 'wv-csp-sms'		; 
#	$srvcobjects_ref->{'bmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmap'}{'port'}{'udp'} = '3421'	; 
#	$srvcobjects_ref->{'bmap'}{'ports'}{'udp'}{'3421'}++	; 
#	$ports_ref->{'udp'}{'3421'}{'name'} = 'bmap'		; 
#	$srvcobjects_ref->{'bmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmap'}{'port'}{'tcp'} = '3421'	; 
#	$srvcobjects_ref->{'bmap'}{'ports'}{'tcp'}{'3421'}++	; 
#	$ports_ref->{'tcp'}{'3421'}{'name'} = 'bmap'		; 
#	$srvcobjects_ref->{'netdb-export'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netdb-export'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netdb-export'}{'port'}{'udp'} = '1329'	; 
#	$srvcobjects_ref->{'netdb-export'}{'ports'}{'udp'}{'1329'}++	; 
#	$ports_ref->{'udp'}{'1329'}{'name'} = 'netdb-export'		; 
#	$srvcobjects_ref->{'netdb-export'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netdb-export'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netdb-export'}{'port'}{'tcp'} = '1329'	; 
#	$srvcobjects_ref->{'netdb-export'}{'ports'}{'tcp'}{'1329'}++	; 
#	$ports_ref->{'tcp'}{'1329'}{'name'} = 'netdb-export'		; 
#	$srvcobjects_ref->{'bnt-manager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bnt-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bnt-manager'}{'port'}{'udp'} = '3344'	; 
#	$srvcobjects_ref->{'bnt-manager'}{'ports'}{'udp'}{'3344'}++	; 
#	$ports_ref->{'udp'}{'3344'}{'name'} = 'bnt-manager'		; 
#	$srvcobjects_ref->{'bnt-manager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bnt-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bnt-manager'}{'port'}{'tcp'} = '3344'	; 
#	$srvcobjects_ref->{'bnt-manager'}{'ports'}{'tcp'}{'3344'}++	; 
#	$ports_ref->{'tcp'}{'3344'}{'name'} = 'bnt-manager'		; 
#	$srvcobjects_ref->{'centra'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'centra'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'centra'}{'port'}{'udp'} = '1709'	; 
#	$srvcobjects_ref->{'centra'}{'ports'}{'udp'}{'1709'}++	; 
#	$ports_ref->{'udp'}{'1709'}{'name'} = 'centra'		; 
#	$srvcobjects_ref->{'centra'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'centra'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'centra'}{'port'}{'tcp'} = '1709'	; 
#	$srvcobjects_ref->{'centra'}{'ports'}{'tcp'}{'1709'}++	; 
#	$ports_ref->{'tcp'}{'1709'}{'name'} = 'centra'		; 
#	$srvcobjects_ref->{'nbp'}{'type'} = 'ddp'	; 
#	$srvcobjects_ref->{'nbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbp'}{'port'}{'ddp'} = '2'	; 
#	$srvcobjects_ref->{'nbp'}{'ports'}{'ddp'}{'2'}++	; 
#	$ports_ref->{'ddp'}{'2'}{'name'} = 'nbp'		; 
#	$srvcobjects_ref->{'ulp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ulp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ulp'}{'port'}{'udp'} = '522'	; 
#	$srvcobjects_ref->{'ulp'}{'ports'}{'udp'}{'522'}++	; 
#	$ports_ref->{'udp'}{'522'}{'name'} = 'ulp'		; 
#	$srvcobjects_ref->{'ulp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ulp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ulp'}{'port'}{'tcp'} = '522'	; 
#	$srvcobjects_ref->{'ulp'}{'ports'}{'tcp'}{'522'}++	; 
#	$ports_ref->{'tcp'}{'522'}{'name'} = 'ulp'		; 
#	$srvcobjects_ref->{'videotex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'videotex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'videotex'}{'port'}{'udp'} = '516'	; 
#	$srvcobjects_ref->{'videotex'}{'ports'}{'udp'}{'516'}++	; 
#	$ports_ref->{'udp'}{'516'}{'name'} = 'videotex'		; 
#	$srvcobjects_ref->{'videotex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'videotex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'videotex'}{'port'}{'tcp'} = '516'	; 
#	$srvcobjects_ref->{'videotex'}{'ports'}{'tcp'}{'516'}++	; 
#	$ports_ref->{'tcp'}{'516'}{'name'} = 'videotex'		; 
#	$srvcobjects_ref->{'tinc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tinc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tinc'}{'port'}{'udp'} = '655'	; 
#	$srvcobjects_ref->{'tinc'}{'ports'}{'udp'}{'655'}++	; 
#	$ports_ref->{'udp'}{'655'}{'name'} = 'tinc'		; 
#	$srvcobjects_ref->{'tinc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tinc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tinc'}{'port'}{'tcp'} = '655'	; 
#	$srvcobjects_ref->{'tinc'}{'ports'}{'tcp'}{'655'}++	; 
#	$ports_ref->{'tcp'}{'655'}{'name'} = 'tinc'		; 
#	$srvcobjects_ref->{'symantec-sim'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'symantec-sim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'symantec-sim'}{'port'}{'udp'} = '3547'	; 
#	$srvcobjects_ref->{'symantec-sim'}{'ports'}{'udp'}{'3547'}++	; 
#	$ports_ref->{'udp'}{'3547'}{'name'} = 'symantec-sim'		; 
#	$srvcobjects_ref->{'symantec-sim'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'symantec-sim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'symantec-sim'}{'port'}{'tcp'} = '3547'	; 
#	$srvcobjects_ref->{'symantec-sim'}{'ports'}{'tcp'}{'3547'}++	; 
#	$ports_ref->{'tcp'}{'3547'}{'name'} = 'symantec-sim'		; 
#	$srvcobjects_ref->{'ftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftp'}{'port'}{'udp'} = '21'	; 
#	$srvcobjects_ref->{'ftp'}{'ports'}{'udp'}{'21'}++	; 
#	$ports_ref->{'udp'}{'21'}{'name'} = 'ftp'		; 
#	$srvcobjects_ref->{'ftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftp'}{'port'}{'tcp'} = '21'	; 
#	$srvcobjects_ref->{'ftp'}{'ports'}{'tcp'}{'21'}++	; 
#	$ports_ref->{'tcp'}{'21'}{'name'} = 'ftp'		; 
#	$srvcobjects_ref->{'sai_sentlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sai_sentlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sai_sentlm'}{'port'}{'udp'} = '2640'	; 
#	$srvcobjects_ref->{'sai_sentlm'}{'ports'}{'udp'}{'2640'}++	; 
#	$ports_ref->{'udp'}{'2640'}{'name'} = 'sai_sentlm'		; 
#	$srvcobjects_ref->{'sai_sentlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sai_sentlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sai_sentlm'}{'port'}{'tcp'} = '2640'	; 
#	$srvcobjects_ref->{'sai_sentlm'}{'ports'}{'tcp'}{'2640'}++	; 
#	$ports_ref->{'tcp'}{'2640'}{'name'} = 'sai_sentlm'		; 
#	$srvcobjects_ref->{'binderysupport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'binderysupport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'binderysupport'}{'port'}{'udp'} = '2302'	; 
#	$srvcobjects_ref->{'binderysupport'}{'ports'}{'udp'}{'2302'}++	; 
#	$ports_ref->{'udp'}{'2302'}{'name'} = 'binderysupport'		; 
#	$srvcobjects_ref->{'binderysupport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'binderysupport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'binderysupport'}{'port'}{'tcp'} = '2302'	; 
#	$srvcobjects_ref->{'binderysupport'}{'ports'}{'tcp'}{'2302'}++	; 
#	$ports_ref->{'tcp'}{'2302'}{'name'} = 'binderysupport'		; 
#	$srvcobjects_ref->{'dwnmshttp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dwnmshttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwnmshttp'}{'port'}{'udp'} = '3227'	; 
#	$srvcobjects_ref->{'dwnmshttp'}{'ports'}{'udp'}{'3227'}++	; 
#	$ports_ref->{'udp'}{'3227'}{'name'} = 'dwnmshttp'		; 
#	$srvcobjects_ref->{'dwnmshttp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dwnmshttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwnmshttp'}{'port'}{'tcp'} = '3227'	; 
#	$srvcobjects_ref->{'dwnmshttp'}{'ports'}{'tcp'}{'3227'}++	; 
#	$ports_ref->{'tcp'}{'3227'}{'name'} = 'dwnmshttp'		; 
#	$srvcobjects_ref->{'picknfs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'picknfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'picknfs'}{'port'}{'udp'} = '1598'	; 
#	$srvcobjects_ref->{'picknfs'}{'ports'}{'udp'}{'1598'}++	; 
#	$ports_ref->{'udp'}{'1598'}{'name'} = 'picknfs'		; 
#	$srvcobjects_ref->{'picknfs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'picknfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'picknfs'}{'port'}{'tcp'} = '1598'	; 
#	$srvcobjects_ref->{'picknfs'}{'ports'}{'tcp'}{'1598'}++	; 
#	$ports_ref->{'tcp'}{'1598'}{'name'} = 'picknfs'		; 
#	$srvcobjects_ref->{'cadis-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadis-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadis-1'}{'port'}{'udp'} = '1441'	; 
#	$srvcobjects_ref->{'cadis-1'}{'ports'}{'udp'}{'1441'}++	; 
#	$ports_ref->{'udp'}{'1441'}{'name'} = 'cadis-1'		; 
#	$srvcobjects_ref->{'cadis-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadis-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadis-1'}{'port'}{'tcp'} = '1441'	; 
#	$srvcobjects_ref->{'cadis-1'}{'ports'}{'tcp'}{'1441'}++	; 
#	$ports_ref->{'tcp'}{'1441'}{'name'} = 'cadis-1'		; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'port'}{'udp'} = '685'	; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'ports'}{'udp'}{'685'}++	; 
#	$ports_ref->{'udp'}{'685'}{'name'} = 'mdc-portmapper'		; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'port'}{'tcp'} = '685'	; 
#	$srvcobjects_ref->{'mdc-portmapper'}{'ports'}{'tcp'}{'685'}++	; 
#	$ports_ref->{'tcp'}{'685'}{'name'} = 'mdc-portmapper'		; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'port'}{'udp'} = '1338'	; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'ports'}{'udp'}{'1338'}++	; 
#	$ports_ref->{'udp'}{'1338'}{'name'} = 'wmc-log-svc'		; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'port'}{'tcp'} = '1338'	; 
#	$srvcobjects_ref->{'wmc-log-svc'}{'ports'}{'tcp'}{'1338'}++	; 
#	$ports_ref->{'tcp'}{'1338'}{'name'} = 'wmc-log-svc'		; 
#	$srvcobjects_ref->{'netaspi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netaspi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netaspi'}{'port'}{'udp'} = '2902'	; 
#	$srvcobjects_ref->{'netaspi'}{'ports'}{'udp'}{'2902'}++	; 
#	$ports_ref->{'udp'}{'2902'}{'name'} = 'netaspi'		; 
#	$srvcobjects_ref->{'netaspi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netaspi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netaspi'}{'port'}{'tcp'} = '2902'	; 
#	$srvcobjects_ref->{'netaspi'}{'ports'}{'tcp'}{'2902'}++	; 
#	$ports_ref->{'tcp'}{'2902'}{'name'} = 'netaspi'		; 
#	$srvcobjects_ref->{'ique'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ique'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ique'}{'port'}{'udp'} = '18769'	; 
#	$srvcobjects_ref->{'ique'}{'ports'}{'udp'}{'18769'}++	; 
#	$ports_ref->{'udp'}{'18769'}{'name'} = 'ique'		; 
#	$srvcobjects_ref->{'ique'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ique'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ique'}{'port'}{'tcp'} = '18769'	; 
#	$srvcobjects_ref->{'ique'}{'ports'}{'tcp'}{'18769'}++	; 
#	$ports_ref->{'tcp'}{'18769'}{'name'} = 'ique'		; 
#	$srvcobjects_ref->{'directv-tick'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directv-tick'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-tick'}{'port'}{'udp'} = '3336'	; 
#	$srvcobjects_ref->{'directv-tick'}{'ports'}{'udp'}{'3336'}++	; 
#	$ports_ref->{'udp'}{'3336'}{'name'} = 'directv-tick'		; 
#	$srvcobjects_ref->{'directv-tick'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directv-tick'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-tick'}{'port'}{'tcp'} = '3336'	; 
#	$srvcobjects_ref->{'directv-tick'}{'ports'}{'tcp'}{'3336'}++	; 
#	$ports_ref->{'tcp'}{'3336'}{'name'} = 'directv-tick'		; 
#	$srvcobjects_ref->{'triomotion'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'triomotion'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'triomotion'}{'port'}{'udp'} = '3240'	; 
#	$srvcobjects_ref->{'triomotion'}{'ports'}{'udp'}{'3240'}++	; 
#	$ports_ref->{'udp'}{'3240'}{'name'} = 'triomotion'		; 
#	$srvcobjects_ref->{'triomotion'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'triomotion'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'triomotion'}{'port'}{'tcp'} = '3240'	; 
#	$srvcobjects_ref->{'triomotion'}{'ports'}{'tcp'}{'3240'}++	; 
#	$ports_ref->{'tcp'}{'3240'}{'name'} = 'triomotion'		; 
#	$srvcobjects_ref->{'netlock4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netlock4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock4'}{'port'}{'udp'} = '9163'	; 
#	$srvcobjects_ref->{'netlock4'}{'ports'}{'udp'}{'9163'}++	; 
#	$ports_ref->{'udp'}{'9163'}{'name'} = 'netlock4'		; 
#	$srvcobjects_ref->{'netlock4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netlock4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock4'}{'port'}{'tcp'} = '9163'	; 
#	$srvcobjects_ref->{'netlock4'}{'ports'}{'tcp'}{'9163'}++	; 
#	$ports_ref->{'tcp'}{'9163'}{'name'} = 'netlock4'		; 
#	$srvcobjects_ref->{'redstorm_find'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'redstorm_find'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_find'}{'port'}{'udp'} = '2347'	; 
#	$srvcobjects_ref->{'redstorm_find'}{'ports'}{'udp'}{'2347'}++	; 
#	$ports_ref->{'udp'}{'2347'}{'name'} = 'redstorm_find'		; 
#	$srvcobjects_ref->{'redstorm_find'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'redstorm_find'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_find'}{'port'}{'tcp'} = '2347'	; 
#	$srvcobjects_ref->{'redstorm_find'}{'ports'}{'tcp'}{'2347'}++	; 
#	$ports_ref->{'tcp'}{'2347'}{'name'} = 'redstorm_find'		; 
#	$srvcobjects_ref->{'ccowcmr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ccowcmr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccowcmr'}{'port'}{'udp'} = '2116'	; 
#	$srvcobjects_ref->{'ccowcmr'}{'ports'}{'udp'}{'2116'}++	; 
#	$ports_ref->{'udp'}{'2116'}{'name'} = 'ccowcmr'		; 
#	$srvcobjects_ref->{'ccowcmr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ccowcmr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccowcmr'}{'port'}{'tcp'} = '2116'	; 
#	$srvcobjects_ref->{'ccowcmr'}{'ports'}{'tcp'}{'2116'}++	; 
#	$ports_ref->{'tcp'}{'2116'}{'name'} = 'ccowcmr'		; 
#	$srvcobjects_ref->{'sentinel-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sentinel-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentinel-lm'}{'port'}{'udp'} = '5093'	; 
#	$srvcobjects_ref->{'sentinel-lm'}{'ports'}{'udp'}{'5093'}++	; 
#	$ports_ref->{'udp'}{'5093'}{'name'} = 'sentinel-lm'		; 
#	$srvcobjects_ref->{'sentinel-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sentinel-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentinel-lm'}{'port'}{'tcp'} = '5093'	; 
#	$srvcobjects_ref->{'sentinel-lm'}{'ports'}{'tcp'}{'5093'}++	; 
#	$ports_ref->{'tcp'}{'5093'}{'name'} = 'sentinel-lm'		; 
#	$srvcobjects_ref->{'genie-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'genie-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genie-lm'}{'port'}{'udp'} = '1453'	; 
#	$srvcobjects_ref->{'genie-lm'}{'ports'}{'udp'}{'1453'}++	; 
#	$ports_ref->{'udp'}{'1453'}{'name'} = 'genie-lm'		; 
#	$srvcobjects_ref->{'genie-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'genie-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genie-lm'}{'port'}{'tcp'} = '1453'	; 
#	$srvcobjects_ref->{'genie-lm'}{'ports'}{'tcp'}{'1453'}++	; 
#	$ports_ref->{'tcp'}{'1453'}{'name'} = 'genie-lm'		; 
#	$srvcobjects_ref->{'ris'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ris'}{'port'}{'udp'} = '180'	; 
#	$srvcobjects_ref->{'ris'}{'ports'}{'udp'}{'180'}++	; 
#	$ports_ref->{'udp'}{'180'}{'name'} = 'ris'		; 
#	$srvcobjects_ref->{'ris'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ris'}{'port'}{'tcp'} = '180'	; 
#	$srvcobjects_ref->{'ris'}{'ports'}{'tcp'}{'180'}++	; 
#	$ports_ref->{'tcp'}{'180'}{'name'} = 'ris'		; 
#	$srvcobjects_ref->{'d3winosfi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d3winosfi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d3winosfi'}{'port'}{'udp'} = '3458'	; 
#	$srvcobjects_ref->{'d3winosfi'}{'ports'}{'udp'}{'3458'}++	; 
#	$ports_ref->{'udp'}{'3458'}{'name'} = 'd3winosfi'		; 
#	$srvcobjects_ref->{'d3winosfi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d3winosfi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d3winosfi'}{'port'}{'tcp'} = '3458'	; 
#	$srvcobjects_ref->{'d3winosfi'}{'ports'}{'tcp'}{'3458'}++	; 
#	$ports_ref->{'tcp'}{'3458'}{'name'} = 'd3winosfi'		; 
#	$srvcobjects_ref->{'mynahautostart'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mynahautostart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mynahautostart'}{'port'}{'udp'} = '2388'	; 
#	$srvcobjects_ref->{'mynahautostart'}{'ports'}{'udp'}{'2388'}++	; 
#	$ports_ref->{'udp'}{'2388'}{'name'} = 'mynahautostart'		; 
#	$srvcobjects_ref->{'mynahautostart'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mynahautostart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mynahautostart'}{'port'}{'tcp'} = '2388'	; 
#	$srvcobjects_ref->{'mynahautostart'}{'ports'}{'tcp'}{'2388'}++	; 
#	$ports_ref->{'tcp'}{'2388'}{'name'} = 'mynahautostart'		; 
#	$srvcobjects_ref->{'acmaint_dbd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acmaint_dbd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acmaint_dbd'}{'port'}{'udp'} = '774'	; 
#	$srvcobjects_ref->{'acmaint_dbd'}{'ports'}{'udp'}{'774'}++	; 
#	$ports_ref->{'udp'}{'774'}{'name'} = 'acmaint_dbd'		; 
#	$srvcobjects_ref->{'patrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'patrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol'}{'port'}{'udp'} = '8160'	; 
#	$srvcobjects_ref->{'patrol'}{'ports'}{'udp'}{'8160'}++	; 
#	$ports_ref->{'udp'}{'8160'}{'name'} = 'patrol'		; 
#	$srvcobjects_ref->{'patrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'patrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol'}{'port'}{'tcp'} = '8160'	; 
#	$srvcobjects_ref->{'patrol'}{'ports'}{'tcp'}{'8160'}++	; 
#	$ports_ref->{'tcp'}{'8160'}{'name'} = 'patrol'		; 
#	$srvcobjects_ref->{'activesync'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'activesync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'activesync'}{'port'}{'udp'} = '1034'	; 
#	$srvcobjects_ref->{'activesync'}{'ports'}{'udp'}{'1034'}++	; 
#	$ports_ref->{'udp'}{'1034'}{'name'} = 'activesync'		; 
#	$srvcobjects_ref->{'activesync'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'activesync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'activesync'}{'port'}{'tcp'} = '1034'	; 
#	$srvcobjects_ref->{'activesync'}{'ports'}{'tcp'}{'1034'}++	; 
#	$ports_ref->{'tcp'}{'1034'}{'name'} = 'activesync'		; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'port'}{'udp'} = '2736'	; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'ports'}{'udp'}{'2736'}++	; 
#	$ports_ref->{'udp'}{'2736'}{'name'} = 'radwiz-nms-srv'		; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'port'}{'tcp'} = '2736'	; 
#	$srvcobjects_ref->{'radwiz-nms-srv'}{'ports'}{'tcp'}{'2736'}++	; 
#	$ports_ref->{'tcp'}{'2736'}{'name'} = 'radwiz-nms-srv'		; 
#	$srvcobjects_ref->{'versa-tek'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'versa-tek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'versa-tek'}{'port'}{'udp'} = '2610'	; 
#	$srvcobjects_ref->{'versa-tek'}{'ports'}{'udp'}{'2610'}++	; 
#	$ports_ref->{'udp'}{'2610'}{'name'} = 'versa-tek'		; 
#	$srvcobjects_ref->{'versa-tek'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'versa-tek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'versa-tek'}{'port'}{'tcp'} = '2610'	; 
#	$srvcobjects_ref->{'versa-tek'}{'ports'}{'tcp'}{'2610'}++	; 
#	$ports_ref->{'tcp'}{'2610'}{'name'} = 'versa-tek'		; 
#	$srvcobjects_ref->{'remote-as'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remote-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-as'}{'port'}{'udp'} = '1053'	; 
#	$srvcobjects_ref->{'remote-as'}{'ports'}{'udp'}{'1053'}++	; 
#	$ports_ref->{'udp'}{'1053'}{'name'} = 'remote-as'		; 
#	$srvcobjects_ref->{'remote-as'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remote-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-as'}{'port'}{'tcp'} = '1053'	; 
#	$srvcobjects_ref->{'remote-as'}{'ports'}{'tcp'}{'1053'}++	; 
#	$ports_ref->{'tcp'}{'1053'}{'name'} = 'remote-as'		; 
#	$srvcobjects_ref->{'syslog'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'syslog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syslog'}{'port'}{'udp'} = '514'	; 
#	$srvcobjects_ref->{'syslog'}{'ports'}{'udp'}{'514'}++	; 
#	$ports_ref->{'udp'}{'514'}{'name'} = 'syslog'		; 
#	$srvcobjects_ref->{'icl-twobase1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase1'}{'port'}{'udp'} = '25000'	; 
#	$srvcobjects_ref->{'icl-twobase1'}{'ports'}{'udp'}{'25000'}++	; 
#	$ports_ref->{'udp'}{'25000'}{'name'} = 'icl-twobase1'		; 
#	$srvcobjects_ref->{'icl-twobase1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase1'}{'port'}{'tcp'} = '25000'	; 
#	$srvcobjects_ref->{'icl-twobase1'}{'ports'}{'tcp'}{'25000'}++	; 
#	$ports_ref->{'tcp'}{'25000'}{'name'} = 'icl-twobase1'		; 
#	$srvcobjects_ref->{'tambora'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tambora'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tambora'}{'port'}{'udp'} = '9020'	; 
#	$srvcobjects_ref->{'tambora'}{'ports'}{'udp'}{'9020'}++	; 
#	$ports_ref->{'udp'}{'9020'}{'name'} = 'tambora'		; 
#	$srvcobjects_ref->{'tambora'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tambora'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tambora'}{'port'}{'tcp'} = '9020'	; 
#	$srvcobjects_ref->{'tambora'}{'ports'}{'tcp'}{'9020'}++	; 
#	$ports_ref->{'tcp'}{'9020'}{'name'} = 'tambora'		; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'port'}{'udp'} = '2023'	; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'ports'}{'udp'}{'2023'}++	; 
#	$ports_ref->{'udp'}{'2023'}{'name'} = 'xinuexpansion3'		; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'port'}{'tcp'} = '2023'	; 
#	$srvcobjects_ref->{'xinuexpansion3'}{'ports'}{'tcp'}{'2023'}++	; 
#	$ports_ref->{'tcp'}{'2023'}{'name'} = 'xinuexpansion3'		; 
#	$srvcobjects_ref->{'kis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kis'}{'port'}{'udp'} = '186'	; 
#	$srvcobjects_ref->{'kis'}{'ports'}{'udp'}{'186'}++	; 
#	$ports_ref->{'udp'}{'186'}{'name'} = 'kis'		; 
#	$srvcobjects_ref->{'kis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kis'}{'port'}{'tcp'} = '186'	; 
#	$srvcobjects_ref->{'kis'}{'ports'}{'tcp'}{'186'}++	; 
#	$ports_ref->{'tcp'}{'186'}{'name'} = 'kis'		; 
#	$srvcobjects_ref->{'ni-mail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ni-mail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ni-mail'}{'port'}{'udp'} = '61'	; 
#	$srvcobjects_ref->{'ni-mail'}{'ports'}{'udp'}{'61'}++	; 
#	$ports_ref->{'udp'}{'61'}{'name'} = 'ni-mail'		; 
#	$srvcobjects_ref->{'ni-mail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ni-mail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ni-mail'}{'port'}{'tcp'} = '61'	; 
#	$srvcobjects_ref->{'ni-mail'}{'ports'}{'tcp'}{'61'}++	; 
#	$ports_ref->{'tcp'}{'61'}{'name'} = 'ni-mail'		; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'port'}{'udp'} = '265'	; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'ports'}{'udp'}{'265'}++	; 
#	$ports_ref->{'udp'}{'265'}{'name'} = 'x-bone-ctl'		; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'port'}{'tcp'} = '265'	; 
#	$srvcobjects_ref->{'x-bone-ctl'}{'ports'}{'tcp'}{'265'}++	; 
#	$ports_ref->{'tcp'}{'265'}{'name'} = 'x-bone-ctl'		; 
#	$srvcobjects_ref->{'ftrapid-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftrapid-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftrapid-2'}{'port'}{'udp'} = '1747'	; 
#	$srvcobjects_ref->{'ftrapid-2'}{'ports'}{'udp'}{'1747'}++	; 
#	$ports_ref->{'udp'}{'1747'}{'name'} = 'ftrapid-2'		; 
#	$srvcobjects_ref->{'ftrapid-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftrapid-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftrapid-2'}{'port'}{'tcp'} = '1747'	; 
#	$srvcobjects_ref->{'ftrapid-2'}{'ports'}{'tcp'}{'1747'}++	; 
#	$ports_ref->{'tcp'}{'1747'}{'name'} = 'ftrapid-2'		; 
#	$srvcobjects_ref->{'lipsinc1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lipsinc1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lipsinc1'}{'port'}{'udp'} = '1969'	; 
#	$srvcobjects_ref->{'lipsinc1'}{'ports'}{'udp'}{'1969'}++	; 
#	$ports_ref->{'udp'}{'1969'}{'name'} = 'lipsinc1'		; 
#	$srvcobjects_ref->{'lipsinc1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lipsinc1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lipsinc1'}{'port'}{'tcp'} = '1969'	; 
#	$srvcobjects_ref->{'lipsinc1'}{'ports'}{'tcp'}{'1969'}++	; 
#	$ports_ref->{'tcp'}{'1969'}{'name'} = 'lipsinc1'		; 
#	$srvcobjects_ref->{'xns-ch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xns-ch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-ch'}{'port'}{'udp'} = '54'	; 
#	$srvcobjects_ref->{'xns-ch'}{'ports'}{'udp'}{'54'}++	; 
#	$ports_ref->{'udp'}{'54'}{'name'} = 'xns-ch'		; 
#	$srvcobjects_ref->{'xns-ch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xns-ch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-ch'}{'port'}{'tcp'} = '54'	; 
#	$srvcobjects_ref->{'xns-ch'}{'ports'}{'tcp'}{'54'}++	; 
#	$ports_ref->{'tcp'}{'54'}{'name'} = 'xns-ch'		; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'port'}{'udp'} = '9100'	; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'ports'}{'udp'}{'9100'}++	; 
#	$ports_ref->{'udp'}{'9100'}{'name'} = 'hp-pdl-datastr'		; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'port'}{'tcp'} = '9100'	; 
#	$srvcobjects_ref->{'hp-pdl-datastr'}{'ports'}{'tcp'}{'9100'}++	; 
#	$ports_ref->{'tcp'}{'9100'}{'name'} = 'hp-pdl-datastr'		; 
#	$srvcobjects_ref->{'quest-vista'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quest-vista'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quest-vista'}{'port'}{'udp'} = '7980'	; 
#	$srvcobjects_ref->{'quest-vista'}{'ports'}{'udp'}{'7980'}++	; 
#	$ports_ref->{'udp'}{'7980'}{'name'} = 'quest-vista'		; 
#	$srvcobjects_ref->{'quest-vista'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quest-vista'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quest-vista'}{'port'}{'tcp'} = '7980'	; 
#	$srvcobjects_ref->{'quest-vista'}{'ports'}{'tcp'}{'7980'}++	; 
#	$ports_ref->{'tcp'}{'7980'}{'name'} = 'quest-vista'		; 
#	$srvcobjects_ref->{'hsrp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hsrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hsrp'}{'port'}{'udp'} = '1985'	; 
#	$srvcobjects_ref->{'hsrp'}{'ports'}{'udp'}{'1985'}++	; 
#	$ports_ref->{'udp'}{'1985'}{'name'} = 'hsrp'		; 
#	$srvcobjects_ref->{'hsrp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hsrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hsrp'}{'port'}{'tcp'} = '1985'	; 
#	$srvcobjects_ref->{'hsrp'}{'ports'}{'tcp'}{'1985'}++	; 
#	$ports_ref->{'tcp'}{'1985'}{'name'} = 'hsrp'		; 
#	$srvcobjects_ref->{'ms-licensing'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-licensing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-licensing'}{'port'}{'udp'} = '5720'	; 
#	$srvcobjects_ref->{'ms-licensing'}{'ports'}{'udp'}{'5720'}++	; 
#	$ports_ref->{'udp'}{'5720'}{'name'} = 'ms-licensing'		; 
#	$srvcobjects_ref->{'ms-licensing'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-licensing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-licensing'}{'port'}{'tcp'} = '5720'	; 
#	$srvcobjects_ref->{'ms-licensing'}{'ports'}{'tcp'}{'5720'}++	; 
#	$ports_ref->{'tcp'}{'5720'}{'name'} = 'ms-licensing'		; 
#	$srvcobjects_ref->{'sgmp-traps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sgmp-traps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgmp-traps'}{'port'}{'udp'} = '160'	; 
#	$srvcobjects_ref->{'sgmp-traps'}{'ports'}{'udp'}{'160'}++	; 
#	$ports_ref->{'udp'}{'160'}{'name'} = 'sgmp-traps'		; 
#	$srvcobjects_ref->{'sgmp-traps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sgmp-traps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgmp-traps'}{'port'}{'tcp'} = '160'	; 
#	$srvcobjects_ref->{'sgmp-traps'}{'ports'}{'tcp'}{'160'}++	; 
#	$ports_ref->{'tcp'}{'160'}{'name'} = 'sgmp-traps'		; 
#	$srvcobjects_ref->{'netagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netagent'}{'port'}{'udp'} = '5771'	; 
#	$srvcobjects_ref->{'netagent'}{'ports'}{'udp'}{'5771'}++	; 
#	$ports_ref->{'udp'}{'5771'}{'name'} = 'netagent'		; 
#	$srvcobjects_ref->{'netagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netagent'}{'port'}{'tcp'} = '5771'	; 
#	$srvcobjects_ref->{'netagent'}{'ports'}{'tcp'}{'5771'}++	; 
#	$ports_ref->{'tcp'}{'5771'}{'name'} = 'netagent'		; 
#	$srvcobjects_ref->{'realm-rusd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'realm-rusd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'realm-rusd'}{'port'}{'udp'} = '688'	; 
#	$srvcobjects_ref->{'realm-rusd'}{'ports'}{'udp'}{'688'}++	; 
#	$ports_ref->{'udp'}{'688'}{'name'} = 'realm-rusd'		; 
#	$srvcobjects_ref->{'realm-rusd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'realm-rusd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'realm-rusd'}{'port'}{'tcp'} = '688'	; 
#	$srvcobjects_ref->{'realm-rusd'}{'ports'}{'tcp'}{'688'}++	; 
#	$ports_ref->{'tcp'}{'688'}{'name'} = 'realm-rusd'		; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'port'}{'udp'} = '3201'	; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'ports'}{'udp'}{'3201'}++	; 
#	$ports_ref->{'udp'}{'3201'}{'name'} = 'cpq-tasksmart'		; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'port'}{'tcp'} = '3201'	; 
#	$srvcobjects_ref->{'cpq-tasksmart'}{'ports'}{'tcp'}{'3201'}++	; 
#	$ports_ref->{'tcp'}{'3201'}{'name'} = 'cpq-tasksmart'		; 
#	$srvcobjects_ref->{'filesphere'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filesphere'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filesphere'}{'port'}{'udp'} = '24242'	; 
#	$srvcobjects_ref->{'filesphere'}{'ports'}{'udp'}{'24242'}++	; 
#	$ports_ref->{'udp'}{'24242'}{'name'} = 'filesphere'		; 
#	$srvcobjects_ref->{'filesphere'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filesphere'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filesphere'}{'port'}{'tcp'} = '24242'	; 
#	$srvcobjects_ref->{'filesphere'}{'ports'}{'tcp'}{'24242'}++	; 
#	$ports_ref->{'tcp'}{'24242'}{'name'} = 'filesphere'		; 
#	$srvcobjects_ref->{'altalink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'altalink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altalink'}{'port'}{'udp'} = '1845'	; 
#	$srvcobjects_ref->{'altalink'}{'ports'}{'udp'}{'1845'}++	; 
#	$ports_ref->{'udp'}{'1845'}{'name'} = 'altalink'		; 
#	$srvcobjects_ref->{'altalink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'altalink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altalink'}{'port'}{'tcp'} = '1845'	; 
#	$srvcobjects_ref->{'altalink'}{'ports'}{'tcp'}{'1845'}++	; 
#	$ports_ref->{'tcp'}{'1845'}{'name'} = 'altalink'		; 
#	$srvcobjects_ref->{'timeflies'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timeflies'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timeflies'}{'port'}{'udp'} = '1362'	; 
#	$srvcobjects_ref->{'timeflies'}{'ports'}{'udp'}{'1362'}++	; 
#	$ports_ref->{'udp'}{'1362'}{'name'} = 'timeflies'		; 
#	$srvcobjects_ref->{'timeflies'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timeflies'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timeflies'}{'port'}{'tcp'} = '1362'	; 
#	$srvcobjects_ref->{'timeflies'}{'ports'}{'tcp'}{'1362'}++	; 
#	$ports_ref->{'tcp'}{'1362'}{'name'} = 'timeflies'		; 
#	$srvcobjects_ref->{'fjinvmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjinvmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjinvmgr'}{'port'}{'udp'} = '9396'	; 
#	$srvcobjects_ref->{'fjinvmgr'}{'ports'}{'udp'}{'9396'}++	; 
#	$ports_ref->{'udp'}{'9396'}{'name'} = 'fjinvmgr'		; 
#	$srvcobjects_ref->{'fjinvmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjinvmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjinvmgr'}{'port'}{'tcp'} = '9396'	; 
#	$srvcobjects_ref->{'fjinvmgr'}{'ports'}{'tcp'}{'9396'}++	; 
#	$ports_ref->{'tcp'}{'9396'}{'name'} = 'fjinvmgr'		; 
#	$srvcobjects_ref->{'saiscm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'saiscm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saiscm'}{'port'}{'udp'} = '1501'	; 
#	$srvcobjects_ref->{'saiscm'}{'ports'}{'udp'}{'1501'}++	; 
#	$ports_ref->{'udp'}{'1501'}{'name'} = 'saiscm'		; 
#	$srvcobjects_ref->{'saiscm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'saiscm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saiscm'}{'port'}{'tcp'} = '1501'	; 
#	$srvcobjects_ref->{'saiscm'}{'ports'}{'tcp'}{'1501'}++	; 
#	$ports_ref->{'tcp'}{'1501'}{'name'} = 'saiscm'		; 
#	$srvcobjects_ref->{'odi-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'odi-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odi-port'}{'port'}{'udp'} = '3187'	; 
#	$srvcobjects_ref->{'odi-port'}{'ports'}{'udp'}{'3187'}++	; 
#	$ports_ref->{'udp'}{'3187'}{'name'} = 'odi-port'		; 
#	$srvcobjects_ref->{'odi-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'odi-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odi-port'}{'port'}{'tcp'} = '3187'	; 
#	$srvcobjects_ref->{'odi-port'}{'ports'}{'tcp'}{'3187'}++	; 
#	$ports_ref->{'tcp'}{'3187'}{'name'} = 'odi-port'		; 
#	$srvcobjects_ref->{'dnsix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dnsix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnsix'}{'port'}{'udp'} = '90'	; 
#	$srvcobjects_ref->{'dnsix'}{'ports'}{'udp'}{'90'}++	; 
#	$ports_ref->{'udp'}{'90'}{'name'} = 'dnsix'		; 
#	$srvcobjects_ref->{'dnsix'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dnsix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnsix'}{'port'}{'tcp'} = '90'	; 
#	$srvcobjects_ref->{'dnsix'}{'ports'}{'tcp'}{'90'}++	; 
#	$ports_ref->{'tcp'}{'90'}{'name'} = 'dnsix'		; 
#	$srvcobjects_ref->{'atm-uhas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'atm-uhas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atm-uhas'}{'port'}{'udp'} = '11367'	; 
#	$srvcobjects_ref->{'atm-uhas'}{'ports'}{'udp'}{'11367'}++	; 
#	$ports_ref->{'udp'}{'11367'}{'name'} = 'atm-uhas'		; 
#	$srvcobjects_ref->{'atm-uhas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'atm-uhas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atm-uhas'}{'port'}{'tcp'} = '11367'	; 
#	$srvcobjects_ref->{'atm-uhas'}{'ports'}{'tcp'}{'11367'}++	; 
#	$ports_ref->{'tcp'}{'11367'}{'name'} = 'atm-uhas'		; 
#	$srvcobjects_ref->{'targus-getdata1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'targus-getdata1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata1'}{'port'}{'udp'} = '5201'	; 
#	$srvcobjects_ref->{'targus-getdata1'}{'ports'}{'udp'}{'5201'}++	; 
#	$ports_ref->{'udp'}{'5201'}{'name'} = 'targus-getdata1'		; 
#	$srvcobjects_ref->{'targus-getdata1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'targus-getdata1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata1'}{'port'}{'tcp'} = '5201'	; 
#	$srvcobjects_ref->{'targus-getdata1'}{'ports'}{'tcp'}{'5201'}++	; 
#	$ports_ref->{'tcp'}{'5201'}{'name'} = 'targus-getdata1'		; 
#	$srvcobjects_ref->{'techra-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'techra-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'techra-server'}{'port'}{'udp'} = '1862'	; 
#	$srvcobjects_ref->{'techra-server'}{'ports'}{'udp'}{'1862'}++	; 
#	$ports_ref->{'udp'}{'1862'}{'name'} = 'techra-server'		; 
#	$srvcobjects_ref->{'techra-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'techra-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'techra-server'}{'port'}{'tcp'} = '1862'	; 
#	$srvcobjects_ref->{'techra-server'}{'ports'}{'tcp'}{'1862'}++	; 
#	$ports_ref->{'tcp'}{'1862'}{'name'} = 'techra-server'		; 
#	$srvcobjects_ref->{'escp-ip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'escp-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'escp-ip'}{'port'}{'udp'} = '621'	; 
#	$srvcobjects_ref->{'escp-ip'}{'ports'}{'udp'}{'621'}++	; 
#	$ports_ref->{'udp'}{'621'}{'name'} = 'escp-ip'		; 
#	$srvcobjects_ref->{'escp-ip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'escp-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'escp-ip'}{'port'}{'tcp'} = '621'	; 
#	$srvcobjects_ref->{'escp-ip'}{'ports'}{'tcp'}{'621'}++	; 
#	$ports_ref->{'tcp'}{'621'}{'name'} = 'escp-ip'		; 
#	$srvcobjects_ref->{'telelpathstart'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telelpathstart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telelpathstart'}{'port'}{'udp'} = '5010'	; 
#	$srvcobjects_ref->{'telelpathstart'}{'ports'}{'udp'}{'5010'}++	; 
#	$ports_ref->{'udp'}{'5010'}{'name'} = 'telelpathstart'		; 
#	$srvcobjects_ref->{'telelpathstart'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telelpathstart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telelpathstart'}{'port'}{'tcp'} = '5010'	; 
#	$srvcobjects_ref->{'telelpathstart'}{'ports'}{'tcp'}{'5010'}++	; 
#	$ports_ref->{'tcp'}{'5010'}{'name'} = 'telelpathstart'		; 
#	$srvcobjects_ref->{'ifor-protocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ifor-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ifor-protocol'}{'port'}{'udp'} = '1515'	; 
#	$srvcobjects_ref->{'ifor-protocol'}{'ports'}{'udp'}{'1515'}++	; 
#	$ports_ref->{'udp'}{'1515'}{'name'} = 'ifor-protocol'		; 
#	$srvcobjects_ref->{'ifor-protocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ifor-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ifor-protocol'}{'port'}{'tcp'} = '1515'	; 
#	$srvcobjects_ref->{'ifor-protocol'}{'ports'}{'tcp'}{'1515'}++	; 
#	$ports_ref->{'tcp'}{'1515'}{'name'} = 'ifor-protocol'		; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'port'}{'udp'} = '2748'	; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'ports'}{'udp'}{'2748'}++	; 
#	$ports_ref->{'udp'}{'2748'}{'name'} = 'fjippol-polsvr'		; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'port'}{'tcp'} = '2748'	; 
#	$srvcobjects_ref->{'fjippol-polsvr'}{'ports'}{'tcp'}{'2748'}++	; 
#	$ports_ref->{'tcp'}{'2748'}{'name'} = 'fjippol-polsvr'		; 
#	$srvcobjects_ref->{'clearvisn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'clearvisn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clearvisn'}{'port'}{'udp'} = '2052'	; 
#	$srvcobjects_ref->{'clearvisn'}{'ports'}{'udp'}{'2052'}++	; 
#	$ports_ref->{'udp'}{'2052'}{'name'} = 'clearvisn'		; 
#	$srvcobjects_ref->{'clearvisn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'clearvisn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clearvisn'}{'port'}{'tcp'} = '2052'	; 
#	$srvcobjects_ref->{'clearvisn'}{'ports'}{'tcp'}{'2052'}++	; 
#	$ports_ref->{'tcp'}{'2052'}{'name'} = 'clearvisn'		; 
#	$srvcobjects_ref->{'ndm-requester'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndm-requester'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndm-requester'}{'port'}{'udp'} = '1363'	; 
#	$srvcobjects_ref->{'ndm-requester'}{'ports'}{'udp'}{'1363'}++	; 
#	$ports_ref->{'udp'}{'1363'}{'name'} = 'ndm-requester'		; 
#	$srvcobjects_ref->{'ndm-requester'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndm-requester'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndm-requester'}{'port'}{'tcp'} = '1363'	; 
#	$srvcobjects_ref->{'ndm-requester'}{'ports'}{'tcp'}{'1363'}++	; 
#	$ports_ref->{'tcp'}{'1363'}{'name'} = 'ndm-requester'		; 
#	$srvcobjects_ref->{'discovery-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'discovery-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discovery-port'}{'port'}{'udp'} = '1925'	; 
#	$srvcobjects_ref->{'discovery-port'}{'ports'}{'udp'}{'1925'}++	; 
#	$ports_ref->{'udp'}{'1925'}{'name'} = 'discovery-port'		; 
#	$srvcobjects_ref->{'discovery-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'discovery-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discovery-port'}{'port'}{'tcp'} = '1925'	; 
#	$srvcobjects_ref->{'discovery-port'}{'ports'}{'tcp'}{'1925'}++	; 
#	$ports_ref->{'tcp'}{'1925'}{'name'} = 'discovery-port'		; 
#	$srvcobjects_ref->{'opalis-rdv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opalis-rdv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opalis-rdv'}{'port'}{'udp'} = '536'	; 
#	$srvcobjects_ref->{'opalis-rdv'}{'ports'}{'udp'}{'536'}++	; 
#	$ports_ref->{'udp'}{'536'}{'name'} = 'opalis-rdv'		; 
#	$srvcobjects_ref->{'opalis-rdv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opalis-rdv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opalis-rdv'}{'port'}{'tcp'} = '536'	; 
#	$srvcobjects_ref->{'opalis-rdv'}{'ports'}{'tcp'}{'536'}++	; 
#	$ports_ref->{'tcp'}{'536'}{'name'} = 'opalis-rdv'		; 
#	$srvcobjects_ref->{'ddns-v3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddns-v3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddns-v3'}{'port'}{'udp'} = '2164'	; 
#	$srvcobjects_ref->{'ddns-v3'}{'ports'}{'udp'}{'2164'}++	; 
#	$ports_ref->{'udp'}{'2164'}{'name'} = 'ddns-v3'		; 
#	$srvcobjects_ref->{'ddns-v3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddns-v3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddns-v3'}{'port'}{'tcp'} = '2164'	; 
#	$srvcobjects_ref->{'ddns-v3'}{'ports'}{'tcp'}{'2164'}++	; 
#	$ports_ref->{'tcp'}{'2164'}{'name'} = 'ddns-v3'		; 
#	$srvcobjects_ref->{'ddi-udp-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddi-udp-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-udp-1'}{'port'}{'udp'} = '8888'	; 
#	$srvcobjects_ref->{'ddi-udp-1'}{'ports'}{'udp'}{'8888'}++	; 
#	$ports_ref->{'udp'}{'8888'}{'name'} = 'ddi-udp-1'		; 
#	$srvcobjects_ref->{'paradym-31port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'paradym-31port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paradym-31port'}{'port'}{'udp'} = '1864'	; 
#	$srvcobjects_ref->{'paradym-31port'}{'ports'}{'udp'}{'1864'}++	; 
#	$ports_ref->{'udp'}{'1864'}{'name'} = 'paradym-31port'		; 
#	$srvcobjects_ref->{'paradym-31port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'paradym-31port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paradym-31port'}{'port'}{'tcp'} = '1864'	; 
#	$srvcobjects_ref->{'paradym-31port'}{'ports'}{'tcp'}{'1864'}++	; 
#	$ports_ref->{'tcp'}{'1864'}{'name'} = 'paradym-31port'		; 
#	$srvcobjects_ref->{'availant-mgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'availant-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'availant-mgr'}{'port'}{'udp'} = '1122'	; 
#	$srvcobjects_ref->{'availant-mgr'}{'ports'}{'udp'}{'1122'}++	; 
#	$ports_ref->{'udp'}{'1122'}{'name'} = 'availant-mgr'		; 
#	$srvcobjects_ref->{'availant-mgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'availant-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'availant-mgr'}{'port'}{'tcp'} = '1122'	; 
#	$srvcobjects_ref->{'availant-mgr'}{'ports'}{'tcp'}{'1122'}++	; 
#	$ports_ref->{'tcp'}{'1122'}{'name'} = 'availant-mgr'		; 
#	$srvcobjects_ref->{'openmailg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openmailg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmailg'}{'port'}{'udp'} = '5755'	; 
#	$srvcobjects_ref->{'openmailg'}{'ports'}{'udp'}{'5755'}++	; 
#	$ports_ref->{'udp'}{'5755'}{'name'} = 'openmailg'		; 
#	$srvcobjects_ref->{'openmailg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openmailg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmailg'}{'port'}{'tcp'} = '5755'	; 
#	$srvcobjects_ref->{'openmailg'}{'ports'}{'tcp'}{'5755'}++	; 
#	$ports_ref->{'tcp'}{'5755'}{'name'} = 'openmailg'		; 
#	$srvcobjects_ref->{'funk-logger'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'funk-logger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'funk-logger'}{'port'}{'udp'} = '1786'	; 
#	$srvcobjects_ref->{'funk-logger'}{'ports'}{'udp'}{'1786'}++	; 
#	$ports_ref->{'udp'}{'1786'}{'name'} = 'funk-logger'		; 
#	$srvcobjects_ref->{'funk-logger'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'funk-logger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'funk-logger'}{'port'}{'tcp'} = '1786'	; 
#	$srvcobjects_ref->{'funk-logger'}{'ports'}{'tcp'}{'1786'}++	; 
#	$ports_ref->{'tcp'}{'1786'}{'name'} = 'funk-logger'		; 
#	$srvcobjects_ref->{'ggf-ncp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ggf-ncp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ggf-ncp'}{'port'}{'udp'} = '678'	; 
#	$srvcobjects_ref->{'ggf-ncp'}{'ports'}{'udp'}{'678'}++	; 
#	$ports_ref->{'udp'}{'678'}{'name'} = 'ggf-ncp'		; 
#	$srvcobjects_ref->{'ggf-ncp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ggf-ncp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ggf-ncp'}{'port'}{'tcp'} = '678'	; 
#	$srvcobjects_ref->{'ggf-ncp'}{'ports'}{'tcp'}{'678'}++	; 
#	$ports_ref->{'tcp'}{'678'}{'name'} = 'ggf-ncp'		; 
#	$srvcobjects_ref->{'ctf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctf'}{'port'}{'udp'} = '84'	; 
#	$srvcobjects_ref->{'ctf'}{'ports'}{'udp'}{'84'}++	; 
#	$ports_ref->{'udp'}{'84'}{'name'} = 'ctf'		; 
#	$srvcobjects_ref->{'ctf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctf'}{'port'}{'tcp'} = '84'	; 
#	$srvcobjects_ref->{'ctf'}{'ports'}{'tcp'}{'84'}++	; 
#	$ports_ref->{'tcp'}{'84'}{'name'} = 'ctf'		; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'port'}{'udp'} = '1892'	; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'ports'}{'udp'}{'1892'}++	; 
#	$ports_ref->{'udp'}{'1892'}{'name'} = 'childkey-ctrl'		; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'port'}{'tcp'} = '1892'	; 
#	$srvcobjects_ref->{'childkey-ctrl'}{'ports'}{'tcp'}{'1892'}++	; 
#	$ports_ref->{'tcp'}{'1892'}{'name'} = 'childkey-ctrl'		; 
#	$srvcobjects_ref->{'netview-aix-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-1'}{'port'}{'udp'} = '1661'	; 
#	$srvcobjects_ref->{'netview-aix-1'}{'ports'}{'udp'}{'1661'}++	; 
#	$ports_ref->{'udp'}{'1661'}{'name'} = 'netview-aix-1'		; 
#	$srvcobjects_ref->{'netview-aix-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-1'}{'port'}{'tcp'} = '1661'	; 
#	$srvcobjects_ref->{'netview-aix-1'}{'ports'}{'tcp'}{'1661'}++	; 
#	$ports_ref->{'tcp'}{'1661'}{'name'} = 'netview-aix-1'		; 
#	$srvcobjects_ref->{'stt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stt'}{'port'}{'udp'} = '1607'	; 
#	$srvcobjects_ref->{'stt'}{'ports'}{'udp'}{'1607'}++	; 
#	$ports_ref->{'udp'}{'1607'}{'name'} = 'stt'		; 
#	$srvcobjects_ref->{'stt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stt'}{'port'}{'tcp'} = '1607'	; 
#	$srvcobjects_ref->{'stt'}{'ports'}{'tcp'}{'1607'}++	; 
#	$ports_ref->{'tcp'}{'1607'}{'name'} = 'stt'		; 
#	$srvcobjects_ref->{'n1-fwp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'n1-fwp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n1-fwp'}{'port'}{'udp'} = '4446'	; 
#	$srvcobjects_ref->{'n1-fwp'}{'ports'}{'udp'}{'4446'}++	; 
#	$ports_ref->{'udp'}{'4446'}{'name'} = 'n1-fwp'		; 
#	$srvcobjects_ref->{'n1-fwp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'n1-fwp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n1-fwp'}{'port'}{'tcp'} = '4446'	; 
#	$srvcobjects_ref->{'n1-fwp'}{'ports'}{'tcp'}{'4446'}++	; 
#	$ports_ref->{'tcp'}{'4446'}{'name'} = 'n1-fwp'		; 
#	$srvcobjects_ref->{'hivep'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hivep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hivep'}{'port'}{'udp'} = '12172'	; 
#	$srvcobjects_ref->{'hivep'}{'ports'}{'udp'}{'12172'}++	; 
#	$ports_ref->{'udp'}{'12172'}{'name'} = 'hivep'		; 
#	$srvcobjects_ref->{'hivep'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hivep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hivep'}{'port'}{'tcp'} = '12172'	; 
#	$srvcobjects_ref->{'hivep'}{'ports'}{'tcp'}{'12172'}++	; 
#	$ports_ref->{'tcp'}{'12172'}{'name'} = 'hivep'		; 
#	$srvcobjects_ref->{'semaphore'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'semaphore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'semaphore'}{'port'}{'udp'} = '3255'	; 
#	$srvcobjects_ref->{'semaphore'}{'ports'}{'udp'}{'3255'}++	; 
#	$ports_ref->{'udp'}{'3255'}{'name'} = 'semaphore'		; 
#	$srvcobjects_ref->{'semaphore'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'semaphore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'semaphore'}{'port'}{'tcp'} = '3255'	; 
#	$srvcobjects_ref->{'semaphore'}{'ports'}{'tcp'}{'3255'}++	; 
#	$ports_ref->{'tcp'}{'3255'}{'name'} = 'semaphore'		; 
#	$srvcobjects_ref->{'vseconnector'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vseconnector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vseconnector'}{'port'}{'udp'} = '2893'	; 
#	$srvcobjects_ref->{'vseconnector'}{'ports'}{'udp'}{'2893'}++	; 
#	$ports_ref->{'udp'}{'2893'}{'name'} = 'vseconnector'		; 
#	$srvcobjects_ref->{'vseconnector'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vseconnector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vseconnector'}{'port'}{'tcp'} = '2893'	; 
#	$srvcobjects_ref->{'vseconnector'}{'ports'}{'tcp'}{'2893'}++	; 
#	$ports_ref->{'tcp'}{'2893'}{'name'} = 'vseconnector'		; 
#	$srvcobjects_ref->{'msnp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msnp'}{'port'}{'udp'} = '1863'	; 
#	$srvcobjects_ref->{'msnp'}{'ports'}{'udp'}{'1863'}++	; 
#	$ports_ref->{'udp'}{'1863'}{'name'} = 'msnp'		; 
#	$srvcobjects_ref->{'msnp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msnp'}{'port'}{'tcp'} = '1863'	; 
#	$srvcobjects_ref->{'msnp'}{'ports'}{'tcp'}{'1863'}++	; 
#	$ports_ref->{'tcp'}{'1863'}{'name'} = 'msnp'		; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'port'}{'udp'} = '1454'	; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'ports'}{'udp'}{'1454'}++	; 
#	$ports_ref->{'udp'}{'1454'}{'name'} = 'interhdl_elmd'		; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'port'}{'tcp'} = '1454'	; 
#	$srvcobjects_ref->{'interhdl_elmd'}{'ports'}{'tcp'}{'1454'}++	; 
#	$ports_ref->{'tcp'}{'1454'}{'name'} = 'interhdl_elmd'		; 
#	$srvcobjects_ref->{'mobileip-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mobileip-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mobileip-agent'}{'port'}{'udp'} = '434'	; 
#	$srvcobjects_ref->{'mobileip-agent'}{'ports'}{'udp'}{'434'}++	; 
#	$ports_ref->{'udp'}{'434'}{'name'} = 'mobileip-agent'		; 
#	$srvcobjects_ref->{'mobileip-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mobileip-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mobileip-agent'}{'port'}{'tcp'} = '434'	; 
#	$srvcobjects_ref->{'mobileip-agent'}{'ports'}{'tcp'}{'434'}++	; 
#	$ports_ref->{'tcp'}{'434'}{'name'} = 'mobileip-agent'		; 
#	$srvcobjects_ref->{'streetperfect'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'streetperfect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'streetperfect'}{'port'}{'udp'} = '1330'	; 
#	$srvcobjects_ref->{'streetperfect'}{'ports'}{'udp'}{'1330'}++	; 
#	$ports_ref->{'udp'}{'1330'}{'name'} = 'streetperfect'		; 
#	$srvcobjects_ref->{'streetperfect'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'streetperfect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'streetperfect'}{'port'}{'tcp'} = '1330'	; 
#	$srvcobjects_ref->{'streetperfect'}{'ports'}{'tcp'}{'1330'}++	; 
#	$ports_ref->{'tcp'}{'1330'}{'name'} = 'streetperfect'		; 
#	$srvcobjects_ref->{'remote-collab'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remote-collab'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-collab'}{'port'}{'udp'} = '2250'	; 
#	$srvcobjects_ref->{'remote-collab'}{'ports'}{'udp'}{'2250'}++	; 
#	$ports_ref->{'udp'}{'2250'}{'name'} = 'remote-collab'		; 
#	$srvcobjects_ref->{'remote-collab'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remote-collab'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-collab'}{'port'}{'tcp'} = '2250'	; 
#	$srvcobjects_ref->{'remote-collab'}{'ports'}{'tcp'}{'2250'}++	; 
#	$ports_ref->{'tcp'}{'2250'}{'name'} = 'remote-collab'		; 
#	$srvcobjects_ref->{'orion'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orion'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orion'}{'port'}{'udp'} = '2407'	; 
#	$srvcobjects_ref->{'orion'}{'ports'}{'udp'}{'2407'}++	; 
#	$ports_ref->{'udp'}{'2407'}{'name'} = 'orion'		; 
#	$srvcobjects_ref->{'orion'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orion'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orion'}{'port'}{'tcp'} = '2407'	; 
#	$srvcobjects_ref->{'orion'}{'ports'}{'tcp'}{'2407'}++	; 
#	$ports_ref->{'tcp'}{'2407'}{'name'} = 'orion'		; 
#	$srvcobjects_ref->{'tnETOS'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tnETOS'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tnETOS'}{'port'}{'udp'} = '377'	; 
#	$srvcobjects_ref->{'tnETOS'}{'ports'}{'udp'}{'377'}++	; 
#	$ports_ref->{'udp'}{'377'}{'name'} = 'tnETOS'		; 
#	$srvcobjects_ref->{'tnETOS'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tnETOS'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tnETOS'}{'port'}{'tcp'} = '377'	; 
#	$srvcobjects_ref->{'tnETOS'}{'ports'}{'tcp'}{'377'}++	; 
#	$ports_ref->{'tcp'}{'377'}{'name'} = 'tnETOS'		; 
#	$srvcobjects_ref->{'csoft-prev'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csoft-prev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoft-prev'}{'port'}{'udp'} = '3271'	; 
#	$srvcobjects_ref->{'csoft-prev'}{'ports'}{'udp'}{'3271'}++	; 
#	$ports_ref->{'udp'}{'3271'}{'name'} = 'csoft-prev'		; 
#	$srvcobjects_ref->{'csoft-prev'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csoft-prev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoft-prev'}{'port'}{'tcp'} = '3271'	; 
#	$srvcobjects_ref->{'csoft-prev'}{'ports'}{'tcp'}{'3271'}++	; 
#	$ports_ref->{'tcp'}{'3271'}{'name'} = 'csoft-prev'		; 
#	$srvcobjects_ref->{'ccmrmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ccmrmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmrmi'}{'port'}{'udp'} = '3154'	; 
#	$srvcobjects_ref->{'ccmrmi'}{'ports'}{'udp'}{'3154'}++	; 
#	$ports_ref->{'udp'}{'3154'}{'name'} = 'ccmrmi'		; 
#	$srvcobjects_ref->{'ccmrmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ccmrmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmrmi'}{'port'}{'tcp'} = '3154'	; 
#	$srvcobjects_ref->{'ccmrmi'}{'ports'}{'tcp'}{'3154'}++	; 
#	$ports_ref->{'tcp'}{'3154'}{'name'} = 'ccmrmi'		; 
#	$srvcobjects_ref->{'chipper'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chipper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chipper'}{'port'}{'udp'} = '17219'	; 
#	$srvcobjects_ref->{'chipper'}{'ports'}{'udp'}{'17219'}++	; 
#	$ports_ref->{'udp'}{'17219'}{'name'} = 'chipper'		; 
#	$srvcobjects_ref->{'chipper'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chipper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chipper'}{'port'}{'tcp'} = '17219'	; 
#	$srvcobjects_ref->{'chipper'}{'ports'}{'tcp'}{'17219'}++	; 
#	$ports_ref->{'tcp'}{'17219'}{'name'} = 'chipper'		; 
#	$srvcobjects_ref->{'openmailns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openmailns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmailns'}{'port'}{'udp'} = '5766'	; 
#	$srvcobjects_ref->{'openmailns'}{'ports'}{'udp'}{'5766'}++	; 
#	$ports_ref->{'udp'}{'5766'}{'name'} = 'openmailns'		; 
#	$srvcobjects_ref->{'openmailns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openmailns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmailns'}{'port'}{'tcp'} = '5766'	; 
#	$srvcobjects_ref->{'openmailns'}{'ports'}{'tcp'}{'5766'}++	; 
#	$ports_ref->{'tcp'}{'5766'}{'name'} = 'openmailns'		; 
#	$srvcobjects_ref->{'netiq-mc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netiq-mc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-mc'}{'port'}{'udp'} = '2735'	; 
#	$srvcobjects_ref->{'netiq-mc'}{'ports'}{'udp'}{'2735'}++	; 
#	$ports_ref->{'udp'}{'2735'}{'name'} = 'netiq-mc'		; 
#	$srvcobjects_ref->{'netiq-mc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netiq-mc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-mc'}{'port'}{'tcp'} = '2735'	; 
#	$srvcobjects_ref->{'netiq-mc'}{'ports'}{'tcp'}{'2735'}++	; 
#	$ports_ref->{'tcp'}{'2735'}{'name'} = 'netiq-mc'		; 
#	$srvcobjects_ref->{'aocp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aocp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aocp'}{'port'}{'udp'} = '2712'	; 
#	$srvcobjects_ref->{'aocp'}{'ports'}{'udp'}{'2712'}++	; 
#	$ports_ref->{'udp'}{'2712'}{'name'} = 'aocp'		; 
#	$srvcobjects_ref->{'aocp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aocp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aocp'}{'port'}{'tcp'} = '2712'	; 
#	$srvcobjects_ref->{'aocp'}{'ports'}{'tcp'}{'2712'}++	; 
#	$ports_ref->{'tcp'}{'2712'}{'name'} = 'aocp'		; 
#	$srvcobjects_ref->{'emce'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emce'}{'port'}{'udp'} = '2004'	; 
#	$srvcobjects_ref->{'emce'}{'ports'}{'udp'}{'2004'}++	; 
#	$ports_ref->{'udp'}{'2004'}{'name'} = 'emce'		; 
#	$srvcobjects_ref->{'pangolin-laser'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pangolin-laser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pangolin-laser'}{'port'}{'udp'} = '3348'	; 
#	$srvcobjects_ref->{'pangolin-laser'}{'ports'}{'udp'}{'3348'}++	; 
#	$ports_ref->{'udp'}{'3348'}{'name'} = 'pangolin-laser'		; 
#	$srvcobjects_ref->{'pangolin-laser'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pangolin-laser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pangolin-laser'}{'port'}{'tcp'} = '3348'	; 
#	$srvcobjects_ref->{'pangolin-laser'}{'ports'}{'tcp'}{'3348'}++	; 
#	$ports_ref->{'tcp'}{'3348'}{'name'} = 'pangolin-laser'		; 
#	$srvcobjects_ref->{'scoremgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scoremgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scoremgr'}{'port'}{'udp'} = '2034'	; 
#	$srvcobjects_ref->{'scoremgr'}{'ports'}{'udp'}{'2034'}++	; 
#	$ports_ref->{'udp'}{'2034'}{'name'} = 'scoremgr'		; 
#	$srvcobjects_ref->{'scoremgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scoremgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scoremgr'}{'port'}{'tcp'} = '2034'	; 
#	$srvcobjects_ref->{'scoremgr'}{'ports'}{'tcp'}{'2034'}++	; 
#	$ports_ref->{'tcp'}{'2034'}{'name'} = 'scoremgr'		; 
#	$srvcobjects_ref->{'corelccam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'corelccam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corelccam'}{'port'}{'udp'} = '4300'	; 
#	$srvcobjects_ref->{'corelccam'}{'ports'}{'udp'}{'4300'}++	; 
#	$ports_ref->{'udp'}{'4300'}{'name'} = 'corelccam'		; 
#	$srvcobjects_ref->{'corelccam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'corelccam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corelccam'}{'port'}{'tcp'} = '4300'	; 
#	$srvcobjects_ref->{'corelccam'}{'ports'}{'tcp'}{'4300'}++	; 
#	$ports_ref->{'tcp'}{'4300'}{'name'} = 'corelccam'		; 
#	$srvcobjects_ref->{'cdbroker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cdbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdbroker'}{'port'}{'udp'} = '3376'	; 
#	$srvcobjects_ref->{'cdbroker'}{'ports'}{'udp'}{'3376'}++	; 
#	$ports_ref->{'udp'}{'3376'}{'name'} = 'cdbroker'		; 
#	$srvcobjects_ref->{'cdbroker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cdbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdbroker'}{'port'}{'tcp'} = '3376'	; 
#	$srvcobjects_ref->{'cdbroker'}{'ports'}{'tcp'}{'3376'}++	; 
#	$ports_ref->{'tcp'}{'3376'}{'name'} = 'cdbroker'		; 
#	$srvcobjects_ref->{'nss-routing'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nss-routing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nss-routing'}{'port'}{'udp'} = '159'	; 
#	$srvcobjects_ref->{'nss-routing'}{'ports'}{'udp'}{'159'}++	; 
#	$ports_ref->{'udp'}{'159'}{'name'} = 'nss-routing'		; 
#	$srvcobjects_ref->{'nss-routing'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nss-routing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nss-routing'}{'port'}{'tcp'} = '159'	; 
#	$srvcobjects_ref->{'nss-routing'}{'ports'}{'tcp'}{'159'}++	; 
#	$ports_ref->{'tcp'}{'159'}{'name'} = 'nss-routing'		; 
#	$srvcobjects_ref->{'amt-blc-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amt-blc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amt-blc-port'}{'port'}{'udp'} = '2848'	; 
#	$srvcobjects_ref->{'amt-blc-port'}{'ports'}{'udp'}{'2848'}++	; 
#	$ports_ref->{'udp'}{'2848'}{'name'} = 'amt-blc-port'		; 
#	$srvcobjects_ref->{'amt-blc-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amt-blc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amt-blc-port'}{'port'}{'tcp'} = '2848'	; 
#	$srvcobjects_ref->{'amt-blc-port'}{'ports'}{'tcp'}{'2848'}++	; 
#	$ports_ref->{'tcp'}{'2848'}{'name'} = 'amt-blc-port'		; 
#	$srvcobjects_ref->{'eicon-x25'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eicon-x25'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eicon-x25'}{'port'}{'udp'} = '1439'	; 
#	$srvcobjects_ref->{'eicon-x25'}{'ports'}{'udp'}{'1439'}++	; 
#	$ports_ref->{'udp'}{'1439'}{'name'} = 'eicon-x25'		; 
#	$srvcobjects_ref->{'eicon-x25'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eicon-x25'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eicon-x25'}{'port'}{'tcp'} = '1439'	; 
#	$srvcobjects_ref->{'eicon-x25'}{'ports'}{'tcp'}{'1439'}++	; 
#	$ports_ref->{'tcp'}{'1439'}{'name'} = 'eicon-x25'		; 
#	$srvcobjects_ref->{'intecourier'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intecourier'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intecourier'}{'port'}{'udp'} = '495'	; 
#	$srvcobjects_ref->{'intecourier'}{'ports'}{'udp'}{'495'}++	; 
#	$ports_ref->{'udp'}{'495'}{'name'} = 'intecourier'		; 
#	$srvcobjects_ref->{'intecourier'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intecourier'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intecourier'}{'port'}{'tcp'} = '495'	; 
#	$srvcobjects_ref->{'intecourier'}{'ports'}{'tcp'}{'495'}++	; 
#	$ports_ref->{'tcp'}{'495'}{'name'} = 'intecourier'		; 
#	$srvcobjects_ref->{'domaintime'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'domaintime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'domaintime'}{'port'}{'udp'} = '9909'	; 
#	$srvcobjects_ref->{'domaintime'}{'ports'}{'udp'}{'9909'}++	; 
#	$ports_ref->{'udp'}{'9909'}{'name'} = 'domaintime'		; 
#	$srvcobjects_ref->{'domaintime'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'domaintime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'domaintime'}{'port'}{'tcp'} = '9909'	; 
#	$srvcobjects_ref->{'domaintime'}{'ports'}{'tcp'}{'9909'}++	; 
#	$ports_ref->{'tcp'}{'9909'}{'name'} = 'domaintime'		; 
#	$srvcobjects_ref->{'skip-cert-send'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'skip-cert-send'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skip-cert-send'}{'port'}{'tcp'} = '6456'	; 
#	$srvcobjects_ref->{'skip-cert-send'}{'ports'}{'tcp'}{'6456'}++	; 
#	$ports_ref->{'tcp'}{'6456'}{'name'} = 'skip-cert-send'		; 
#	$srvcobjects_ref->{'magicnotes'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'magicnotes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magicnotes'}{'port'}{'udp'} = '3023'	; 
#	$srvcobjects_ref->{'magicnotes'}{'ports'}{'udp'}{'3023'}++	; 
#	$ports_ref->{'udp'}{'3023'}{'name'} = 'magicnotes'		; 
#	$srvcobjects_ref->{'magicnotes'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'magicnotes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magicnotes'}{'port'}{'tcp'} = '3023'	; 
#	$srvcobjects_ref->{'magicnotes'}{'ports'}{'tcp'}{'3023'}++	; 
#	$ports_ref->{'tcp'}{'3023'}{'name'} = 'magicnotes'		; 
#	$srvcobjects_ref->{'ms-olap1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-olap1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap1'}{'port'}{'udp'} = '2393'	; 
#	$srvcobjects_ref->{'ms-olap1'}{'ports'}{'udp'}{'2393'}++	; 
#	$ports_ref->{'udp'}{'2393'}{'name'} = 'ms-olap1'		; 
#	$srvcobjects_ref->{'ms-olap1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-olap1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap1'}{'port'}{'tcp'} = '2393'	; 
#	$srvcobjects_ref->{'ms-olap1'}{'ports'}{'tcp'}{'2393'}++	; 
#	$ports_ref->{'tcp'}{'2393'}{'name'} = 'ms-olap1'		; 
#	$srvcobjects_ref->{'jetformpreview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jetformpreview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jetformpreview'}{'port'}{'udp'} = '2097'	; 
#	$srvcobjects_ref->{'jetformpreview'}{'ports'}{'udp'}{'2097'}++	; 
#	$ports_ref->{'udp'}{'2097'}{'name'} = 'jetformpreview'		; 
#	$srvcobjects_ref->{'jetformpreview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jetformpreview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jetformpreview'}{'port'}{'tcp'} = '2097'	; 
#	$srvcobjects_ref->{'jetformpreview'}{'ports'}{'tcp'}{'2097'}++	; 
#	$ports_ref->{'tcp'}{'2097'}{'name'} = 'jetformpreview'		; 
#	$srvcobjects_ref->{'miva-mqs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'miva-mqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miva-mqs'}{'port'}{'udp'} = '1277'	; 
#	$srvcobjects_ref->{'miva-mqs'}{'ports'}{'udp'}{'1277'}++	; 
#	$ports_ref->{'udp'}{'1277'}{'name'} = 'miva-mqs'		; 
#	$srvcobjects_ref->{'miva-mqs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'miva-mqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miva-mqs'}{'port'}{'tcp'} = '1277'	; 
#	$srvcobjects_ref->{'miva-mqs'}{'ports'}{'tcp'}{'1277'}++	; 
#	$ports_ref->{'tcp'}{'1277'}{'name'} = 'miva-mqs'		; 
#	$srvcobjects_ref->{'softpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'softpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softpc'}{'port'}{'udp'} = '215'	; 
#	$srvcobjects_ref->{'softpc'}{'ports'}{'udp'}{'215'}++	; 
#	$ports_ref->{'udp'}{'215'}{'name'} = 'softpc'		; 
#	$srvcobjects_ref->{'softpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'softpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softpc'}{'port'}{'tcp'} = '215'	; 
#	$srvcobjects_ref->{'softpc'}{'ports'}{'tcp'}{'215'}++	; 
#	$ports_ref->{'tcp'}{'215'}{'name'} = 'softpc'		; 
#	$srvcobjects_ref->{'personalos-001'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'personalos-001'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personalos-001'}{'port'}{'udp'} = '3557'	; 
#	$srvcobjects_ref->{'personalos-001'}{'ports'}{'udp'}{'3557'}++	; 
#	$ports_ref->{'udp'}{'3557'}{'name'} = 'personalos-001'		; 
#	$srvcobjects_ref->{'personalos-001'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'personalos-001'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personalos-001'}{'port'}{'tcp'} = '3557'	; 
#	$srvcobjects_ref->{'personalos-001'}{'ports'}{'tcp'}{'3557'}++	; 
#	$ports_ref->{'tcp'}{'3557'}{'name'} = 'personalos-001'		; 
#	$srvcobjects_ref->{'unidata-ldm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unidata-ldm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unidata-ldm'}{'port'}{'udp'} = '388'	; 
#	$srvcobjects_ref->{'unidata-ldm'}{'ports'}{'udp'}{'388'}++	; 
#	$ports_ref->{'udp'}{'388'}{'name'} = 'unidata-ldm'		; 
#	$srvcobjects_ref->{'unidata-ldm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unidata-ldm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unidata-ldm'}{'port'}{'tcp'} = '388'	; 
#	$srvcobjects_ref->{'unidata-ldm'}{'ports'}{'tcp'}{'388'}++	; 
#	$ports_ref->{'tcp'}{'388'}{'name'} = 'unidata-ldm'		; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'port'}{'udp'} = '1778'	; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'ports'}{'udp'}{'1778'}++	; 
#	$ports_ref->{'udp'}{'1778'}{'name'} = 'prodigy-intrnet'		; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'port'}{'tcp'} = '1778'	; 
#	$srvcobjects_ref->{'prodigy-intrnet'}{'ports'}{'tcp'}{'1778'}++	; 
#	$ports_ref->{'tcp'}{'1778'}{'name'} = 'prodigy-intrnet'		; 
#	$srvcobjects_ref->{'mailbox'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mailbox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mailbox'}{'port'}{'tcp'} = '2004'	; 
#	$srvcobjects_ref->{'mailbox'}{'ports'}{'tcp'}{'2004'}++	; 
#	$ports_ref->{'tcp'}{'2004'}{'name'} = 'mailbox'		; 
#	$srvcobjects_ref->{'tlisrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tlisrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tlisrv'}{'port'}{'udp'} = '1527'	; 
#	$srvcobjects_ref->{'tlisrv'}{'ports'}{'udp'}{'1527'}++	; 
#	$ports_ref->{'udp'}{'1527'}{'name'} = 'tlisrv'		; 
#	$srvcobjects_ref->{'tlisrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tlisrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tlisrv'}{'port'}{'tcp'} = '1527'	; 
#	$srvcobjects_ref->{'tlisrv'}{'ports'}{'tcp'}{'1527'}++	; 
#	$ports_ref->{'tcp'}{'1527'}{'name'} = 'tlisrv'		; 
#	$srvcobjects_ref->{'portgate-auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'portgate-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'portgate-auth'}{'port'}{'udp'} = '3710'	; 
#	$srvcobjects_ref->{'portgate-auth'}{'ports'}{'udp'}{'3710'}++	; 
#	$ports_ref->{'udp'}{'3710'}{'name'} = 'portgate-auth'		; 
#	$srvcobjects_ref->{'portgate-auth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'portgate-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'portgate-auth'}{'port'}{'tcp'} = '3710'	; 
#	$srvcobjects_ref->{'portgate-auth'}{'ports'}{'tcp'}{'3710'}++	; 
#	$ports_ref->{'tcp'}{'3710'}{'name'} = 'portgate-auth'		; 
#	$srvcobjects_ref->{'ita-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ita-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ita-agent'}{'port'}{'udp'} = '5051'	; 
#	$srvcobjects_ref->{'ita-agent'}{'ports'}{'udp'}{'5051'}++	; 
#	$ports_ref->{'udp'}{'5051'}{'name'} = 'ita-agent'		; 
#	$srvcobjects_ref->{'ita-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ita-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ita-agent'}{'port'}{'tcp'} = '5051'	; 
#	$srvcobjects_ref->{'ita-agent'}{'ports'}{'tcp'}{'5051'}++	; 
#	$ports_ref->{'tcp'}{'5051'}{'name'} = 'ita-agent'		; 
#	$srvcobjects_ref->{'targus-getdata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'targus-getdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata'}{'port'}{'udp'} = '5200'	; 
#	$srvcobjects_ref->{'targus-getdata'}{'ports'}{'udp'}{'5200'}++	; 
#	$ports_ref->{'udp'}{'5200'}{'name'} = 'targus-getdata'		; 
#	$srvcobjects_ref->{'targus-getdata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'targus-getdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata'}{'port'}{'tcp'} = '5200'	; 
#	$srvcobjects_ref->{'targus-getdata'}{'ports'}{'tcp'}{'5200'}++	; 
#	$ports_ref->{'tcp'}{'5200'}{'name'} = 'targus-getdata'		; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'port'}{'udp'} = '1219'	; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'ports'}{'udp'}{'1219'}++	; 
#	$ports_ref->{'udp'}{'1219'}{'name'} = 'aeroflight-ret'		; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'port'}{'tcp'} = '1219'	; 
#	$srvcobjects_ref->{'aeroflight-ret'}{'ports'}{'tcp'}{'1219'}++	; 
#	$ports_ref->{'tcp'}{'1219'}{'name'} = 'aeroflight-ret'		; 
#	$srvcobjects_ref->{'filenet-nch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filenet-nch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-nch'}{'port'}{'udp'} = '32770'	; 
#	$srvcobjects_ref->{'filenet-nch'}{'ports'}{'udp'}{'32770'}++	; 
#	$ports_ref->{'udp'}{'32770'}{'name'} = 'filenet-nch'		; 
#	$srvcobjects_ref->{'filenet-nch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filenet-nch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-nch'}{'port'}{'tcp'} = '32770'	; 
#	$srvcobjects_ref->{'filenet-nch'}{'ports'}{'tcp'}{'32770'}++	; 
#	$ports_ref->{'tcp'}{'32770'}{'name'} = 'filenet-nch'		; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'port'}{'udp'} = '2469'	; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'ports'}{'udp'}{'2469'}++	; 
#	$ports_ref->{'udp'}{'2469'}{'name'} = 'mti-tcs-comm'		; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'port'}{'tcp'} = '2469'	; 
#	$srvcobjects_ref->{'mti-tcs-comm'}{'ports'}{'tcp'}{'2469'}++	; 
#	$ports_ref->{'tcp'}{'2469'}{'name'} = 'mti-tcs-comm'		; 
#	$srvcobjects_ref->{'afs3-volser'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-volser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-volser'}{'port'}{'udp'} = '7005'	; 
#	$srvcobjects_ref->{'afs3-volser'}{'ports'}{'udp'}{'7005'}++	; 
#	$ports_ref->{'udp'}{'7005'}{'name'} = 'afs3-volser'		; 
#	$srvcobjects_ref->{'afs3-volser'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-volser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-volser'}{'port'}{'tcp'} = '7005'	; 
#	$srvcobjects_ref->{'afs3-volser'}{'ports'}{'tcp'}{'7005'}++	; 
#	$ports_ref->{'tcp'}{'7005'}{'name'} = 'afs3-volser'		; 
#	$srvcobjects_ref->{'hacl-gs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-gs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-gs'}{'port'}{'udp'} = '5301'	; 
#	$srvcobjects_ref->{'hacl-gs'}{'ports'}{'udp'}{'5301'}++	; 
#	$ports_ref->{'udp'}{'5301'}{'name'} = 'hacl-gs'		; 
#	$srvcobjects_ref->{'hacl-gs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-gs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-gs'}{'port'}{'tcp'} = '5301'	; 
#	$srvcobjects_ref->{'hacl-gs'}{'ports'}{'tcp'}{'5301'}++	; 
#	$ports_ref->{'tcp'}{'5301'}{'name'} = 'hacl-gs'		; 
#	$srvcobjects_ref->{'mpfwsas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpfwsas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpfwsas'}{'port'}{'udp'} = '2952'	; 
#	$srvcobjects_ref->{'mpfwsas'}{'ports'}{'udp'}{'2952'}++	; 
#	$ports_ref->{'udp'}{'2952'}{'name'} = 'mpfwsas'		; 
#	$srvcobjects_ref->{'mpfwsas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpfwsas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpfwsas'}{'port'}{'tcp'} = '2952'	; 
#	$srvcobjects_ref->{'mpfwsas'}{'ports'}{'tcp'}{'2952'}++	; 
#	$ports_ref->{'tcp'}{'2952'}{'name'} = 'mpfwsas'		; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'port'}{'udp'} = '2399'	; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'ports'}{'udp'}{'2399'}++	; 
#	$ports_ref->{'udp'}{'2399'}{'name'} = 'fmpro-fdal'		; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'port'}{'tcp'} = '2399'	; 
#	$srvcobjects_ref->{'fmpro-fdal'}{'ports'}{'tcp'}{'2399'}++	; 
#	$ports_ref->{'tcp'}{'2399'}{'name'} = 'fmpro-fdal'		; 
#	$srvcobjects_ref->{'ezproxy-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ezproxy-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezproxy-2'}{'port'}{'udp'} = '10102'	; 
#	$srvcobjects_ref->{'ezproxy-2'}{'ports'}{'udp'}{'10102'}++	; 
#	$ports_ref->{'udp'}{'10102'}{'name'} = 'ezproxy-2'		; 
#	$srvcobjects_ref->{'ezproxy-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ezproxy-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezproxy-2'}{'port'}{'tcp'} = '10102'	; 
#	$srvcobjects_ref->{'ezproxy-2'}{'ports'}{'tcp'}{'10102'}++	; 
#	$ports_ref->{'tcp'}{'10102'}{'name'} = 'ezproxy-2'		; 
#	$srvcobjects_ref->{'nm-game-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nm-game-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-game-server'}{'port'}{'udp'} = '3149'	; 
#	$srvcobjects_ref->{'nm-game-server'}{'ports'}{'udp'}{'3149'}++	; 
#	$ports_ref->{'udp'}{'3149'}{'name'} = 'nm-game-server'		; 
#	$srvcobjects_ref->{'nm-game-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nm-game-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-game-server'}{'port'}{'tcp'} = '3149'	; 
#	$srvcobjects_ref->{'nm-game-server'}{'ports'}{'tcp'}{'3149'}++	; 
#	$ports_ref->{'tcp'}{'3149'}{'name'} = 'nm-game-server'		; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'port'}{'udp'} = '2875'	; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'ports'}{'udp'}{'2875'}++	; 
#	$ports_ref->{'udp'}{'2875'}{'name'} = 'dxmessagebase2'		; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'port'}{'tcp'} = '2875'	; 
#	$srvcobjects_ref->{'dxmessagebase2'}{'ports'}{'tcp'}{'2875'}++	; 
#	$ports_ref->{'tcp'}{'2875'}{'name'} = 'dxmessagebase2'		; 
#	$srvcobjects_ref->{'contentserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'contentserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'contentserver'}{'port'}{'udp'} = '3365'	; 
#	$srvcobjects_ref->{'contentserver'}{'ports'}{'udp'}{'3365'}++	; 
#	$ports_ref->{'udp'}{'3365'}{'name'} = 'contentserver'		; 
#	$srvcobjects_ref->{'contentserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'contentserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'contentserver'}{'port'}{'udp'} = '454'	; 
#	$srvcobjects_ref->{'contentserver'}{'ports'}{'udp'}{'454'}++	; 
#	$ports_ref->{'udp'}{'454'}{'name'} = 'contentserver'		; 
#	$srvcobjects_ref->{'contentserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'contentserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'contentserver'}{'port'}{'tcp'} = '3365'	; 
#	$srvcobjects_ref->{'contentserver'}{'ports'}{'tcp'}{'3365'}++	; 
#	$ports_ref->{'tcp'}{'3365'}{'name'} = 'contentserver'		; 
#	$srvcobjects_ref->{'contentserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'contentserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'contentserver'}{'port'}{'tcp'} = '454'	; 
#	$srvcobjects_ref->{'contentserver'}{'ports'}{'tcp'}{'454'}++	; 
#	$ports_ref->{'tcp'}{'454'}{'name'} = 'contentserver'		; 
#	$srvcobjects_ref->{'a3-sdunode'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'a3-sdunode'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a3-sdunode'}{'port'}{'udp'} = '5604'	; 
#	$srvcobjects_ref->{'a3-sdunode'}{'ports'}{'udp'}{'5604'}++	; 
#	$ports_ref->{'udp'}{'5604'}{'name'} = 'a3-sdunode'		; 
#	$srvcobjects_ref->{'a3-sdunode'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'a3-sdunode'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a3-sdunode'}{'port'}{'tcp'} = '5604'	; 
#	$srvcobjects_ref->{'a3-sdunode'}{'ports'}{'tcp'}{'5604'}++	; 
#	$ports_ref->{'tcp'}{'5604'}{'name'} = 'a3-sdunode'		; 
#	$srvcobjects_ref->{'fcip-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcip-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcip-port'}{'port'}{'udp'} = '3225'	; 
#	$srvcobjects_ref->{'fcip-port'}{'ports'}{'udp'}{'3225'}++	; 
#	$ports_ref->{'udp'}{'3225'}{'name'} = 'fcip-port'		; 
#	$srvcobjects_ref->{'fcip-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcip-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcip-port'}{'port'}{'tcp'} = '3225'	; 
#	$srvcobjects_ref->{'fcip-port'}{'ports'}{'tcp'}{'3225'}++	; 
#	$ports_ref->{'tcp'}{'3225'}{'name'} = 'fcip-port'		; 
#	$srvcobjects_ref->{'chip-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chip-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chip-lm'}{'port'}{'udp'} = '1572'	; 
#	$srvcobjects_ref->{'chip-lm'}{'ports'}{'udp'}{'1572'}++	; 
#	$ports_ref->{'udp'}{'1572'}{'name'} = 'chip-lm'		; 
#	$srvcobjects_ref->{'chip-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chip-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chip-lm'}{'port'}{'tcp'} = '1572'	; 
#	$srvcobjects_ref->{'chip-lm'}{'ports'}{'tcp'}{'1572'}++	; 
#	$ports_ref->{'tcp'}{'1572'}{'name'} = 'chip-lm'		; 
#	$srvcobjects_ref->{'indura'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'indura'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indura'}{'port'}{'udp'} = '3156'	; 
#	$srvcobjects_ref->{'indura'}{'ports'}{'udp'}{'3156'}++	; 
#	$ports_ref->{'udp'}{'3156'}{'name'} = 'indura'		; 
#	$srvcobjects_ref->{'indura'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'indura'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indura'}{'port'}{'tcp'} = '3156'	; 
#	$srvcobjects_ref->{'indura'}{'ports'}{'tcp'}{'3156'}++	; 
#	$ports_ref->{'tcp'}{'3156'}{'name'} = 'indura'		; 
#	$srvcobjects_ref->{'turbonote-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'turbonote-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'turbonote-1'}{'port'}{'udp'} = '39681'	; 
#	$srvcobjects_ref->{'turbonote-1'}{'ports'}{'udp'}{'39681'}++	; 
#	$ports_ref->{'udp'}{'39681'}{'name'} = 'turbonote-1'		; 
#	$srvcobjects_ref->{'turbonote-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'turbonote-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'turbonote-1'}{'port'}{'tcp'} = '39681'	; 
#	$srvcobjects_ref->{'turbonote-1'}{'ports'}{'tcp'}{'39681'}++	; 
#	$ports_ref->{'tcp'}{'39681'}{'name'} = 'turbonote-1'		; 
#	$srvcobjects_ref->{'trivnet2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trivnet2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trivnet2'}{'port'}{'udp'} = '8201'	; 
#	$srvcobjects_ref->{'trivnet2'}{'ports'}{'udp'}{'8201'}++	; 
#	$ports_ref->{'udp'}{'8201'}{'name'} = 'trivnet2'		; 
#	$srvcobjects_ref->{'trivnet2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trivnet2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trivnet2'}{'port'}{'tcp'} = '8201'	; 
#	$srvcobjects_ref->{'trivnet2'}{'ports'}{'tcp'}{'8201'}++	; 
#	$ports_ref->{'tcp'}{'8201'}{'name'} = 'trivnet2'		; 
#	$srvcobjects_ref->{'ito-e-gui'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ito-e-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ito-e-gui'}{'port'}{'udp'} = '2531'	; 
#	$srvcobjects_ref->{'ito-e-gui'}{'ports'}{'udp'}{'2531'}++	; 
#	$ports_ref->{'udp'}{'2531'}{'name'} = 'ito-e-gui'		; 
#	$srvcobjects_ref->{'ito-e-gui'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ito-e-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ito-e-gui'}{'port'}{'tcp'} = '2531'	; 
#	$srvcobjects_ref->{'ito-e-gui'}{'ports'}{'tcp'}{'2531'}++	; 
#	$ports_ref->{'tcp'}{'2531'}{'name'} = 'ito-e-gui'		; 
#	$srvcobjects_ref->{'adapt-sna'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adapt-sna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adapt-sna'}{'port'}{'udp'} = '1365'	; 
#	$srvcobjects_ref->{'adapt-sna'}{'ports'}{'udp'}{'1365'}++	; 
#	$ports_ref->{'udp'}{'1365'}{'name'} = 'adapt-sna'		; 
#	$srvcobjects_ref->{'adapt-sna'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adapt-sna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adapt-sna'}{'port'}{'tcp'} = '1365'	; 
#	$srvcobjects_ref->{'adapt-sna'}{'ports'}{'tcp'}{'1365'}++	; 
#	$ports_ref->{'tcp'}{'1365'}{'name'} = 'adapt-sna'		; 
#	$srvcobjects_ref->{'taskmaster2000'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'port'}{'udp'} = '2403'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'ports'}{'udp'}{'2403'}++	; 
#	$ports_ref->{'udp'}{'2403'}{'name'} = 'taskmaster2000'		; 
#	$srvcobjects_ref->{'taskmaster2000'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'port'}{'udp'} = '2402'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'ports'}{'udp'}{'2402'}++	; 
#	$ports_ref->{'udp'}{'2402'}{'name'} = 'taskmaster2000'		; 
#	$srvcobjects_ref->{'taskmaster2000'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'port'}{'tcp'} = '2403'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'ports'}{'tcp'}{'2403'}++	; 
#	$ports_ref->{'tcp'}{'2403'}{'name'} = 'taskmaster2000'		; 
#	$srvcobjects_ref->{'taskmaster2000'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'port'}{'tcp'} = '2402'	; 
#	$srvcobjects_ref->{'taskmaster2000'}{'ports'}{'tcp'}{'2402'}++	; 
#	$ports_ref->{'tcp'}{'2402'}{'name'} = 'taskmaster2000'		; 
#	$srvcobjects_ref->{'1ci-smcs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'1ci-smcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'1ci-smcs'}{'port'}{'udp'} = '3091'	; 
#	$srvcobjects_ref->{'1ci-smcs'}{'ports'}{'udp'}{'3091'}++	; 
#	$ports_ref->{'udp'}{'3091'}{'name'} = '1ci-smcs'		; 
#	$srvcobjects_ref->{'1ci-smcs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'1ci-smcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'1ci-smcs'}{'port'}{'tcp'} = '3091'	; 
#	$srvcobjects_ref->{'1ci-smcs'}{'ports'}{'tcp'}{'3091'}++	; 
#	$ports_ref->{'tcp'}{'3091'}{'name'} = '1ci-smcs'		; 
#	$srvcobjects_ref->{'dssiapi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dssiapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dssiapi'}{'port'}{'udp'} = '1265'	; 
#	$srvcobjects_ref->{'dssiapi'}{'ports'}{'udp'}{'1265'}++	; 
#	$ports_ref->{'udp'}{'1265'}{'name'} = 'dssiapi'		; 
#	$srvcobjects_ref->{'dssiapi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dssiapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dssiapi'}{'port'}{'tcp'} = '1265'	; 
#	$srvcobjects_ref->{'dssiapi'}{'ports'}{'tcp'}{'1265'}++	; 
#	$ports_ref->{'tcp'}{'1265'}{'name'} = 'dssiapi'		; 
#	$srvcobjects_ref->{'dsx-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsx-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsx-agent'}{'port'}{'udp'} = '3685'	; 
#	$srvcobjects_ref->{'dsx-agent'}{'ports'}{'udp'}{'3685'}++	; 
#	$ports_ref->{'udp'}{'3685'}{'name'} = 'dsx-agent'		; 
#	$srvcobjects_ref->{'dsx-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsx-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsx-agent'}{'port'}{'tcp'} = '3685'	; 
#	$srvcobjects_ref->{'dsx-agent'}{'ports'}{'tcp'}{'3685'}++	; 
#	$ports_ref->{'tcp'}{'3685'}{'name'} = 'dsx-agent'		; 
#	$srvcobjects_ref->{'ndnp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndnp'}{'port'}{'udp'} = '2883'	; 
#	$srvcobjects_ref->{'ndnp'}{'ports'}{'udp'}{'2883'}++	; 
#	$ports_ref->{'udp'}{'2883'}{'name'} = 'ndnp'		; 
#	$srvcobjects_ref->{'ndnp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndnp'}{'port'}{'tcp'} = '2883'	; 
#	$srvcobjects_ref->{'ndnp'}{'ports'}{'tcp'}{'2883'}++	; 
#	$ports_ref->{'tcp'}{'2883'}{'name'} = 'ndnp'		; 
#	$srvcobjects_ref->{'iqserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iqserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iqserver'}{'port'}{'udp'} = '2527'	; 
#	$srvcobjects_ref->{'iqserver'}{'ports'}{'udp'}{'2527'}++	; 
#	$ports_ref->{'udp'}{'2527'}{'name'} = 'iqserver'		; 
#	$srvcobjects_ref->{'iqserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iqserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iqserver'}{'port'}{'tcp'} = '2527'	; 
#	$srvcobjects_ref->{'iqserver'}{'ports'}{'tcp'}{'2527'}++	; 
#	$ports_ref->{'tcp'}{'2527'}{'name'} = 'iqserver'		; 
#	$srvcobjects_ref->{'dj-ice'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dj-ice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dj-ice'}{'port'}{'udp'} = '5419'	; 
#	$srvcobjects_ref->{'dj-ice'}{'ports'}{'udp'}{'5419'}++	; 
#	$ports_ref->{'udp'}{'5419'}{'name'} = 'dj-ice'		; 
#	$srvcobjects_ref->{'dj-ice'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dj-ice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dj-ice'}{'port'}{'tcp'} = '5419'	; 
#	$srvcobjects_ref->{'dj-ice'}{'ports'}{'tcp'}{'5419'}++	; 
#	$ports_ref->{'tcp'}{'5419'}{'name'} = 'dj-ice'		; 
#	$srvcobjects_ref->{'meta5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'meta5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meta5'}{'port'}{'udp'} = '393'	; 
#	$srvcobjects_ref->{'meta5'}{'ports'}{'udp'}{'393'}++	; 
#	$ports_ref->{'udp'}{'393'}{'name'} = 'meta5'		; 
#	$srvcobjects_ref->{'meta5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'meta5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meta5'}{'port'}{'tcp'} = '393'	; 
#	$srvcobjects_ref->{'meta5'}{'ports'}{'tcp'}{'393'}++	; 
#	$ports_ref->{'tcp'}{'393'}{'name'} = 'meta5'		; 
#	$srvcobjects_ref->{'sd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd'}{'port'}{'udp'} = '9876'	; 
#	$srvcobjects_ref->{'sd'}{'ports'}{'udp'}{'9876'}++	; 
#	$ports_ref->{'udp'}{'9876'}{'name'} = 'sd'		; 
#	$srvcobjects_ref->{'sd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd'}{'port'}{'tcp'} = '9876'	; 
#	$srvcobjects_ref->{'sd'}{'ports'}{'tcp'}{'9876'}++	; 
#	$ports_ref->{'tcp'}{'9876'}{'name'} = 'sd'		; 
#	$srvcobjects_ref->{'servexec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'servexec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servexec'}{'port'}{'tcp'} = '2021'	; 
#	$srvcobjects_ref->{'servexec'}{'ports'}{'tcp'}{'2021'}++	; 
#	$ports_ref->{'tcp'}{'2021'}{'name'} = 'servexec'		; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'port'}{'udp'} = '3355'	; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'ports'}{'udp'}{'3355'}++	; 
#	$ports_ref->{'udp'}{'3355'}{'name'} = 'ordinox-dbase'		; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'port'}{'tcp'} = '3355'	; 
#	$srvcobjects_ref->{'ordinox-dbase'}{'ports'}{'tcp'}{'3355'}++	; 
#	$ports_ref->{'tcp'}{'3355'}{'name'} = 'ordinox-dbase'		; 
#	$srvcobjects_ref->{'c3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'c3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'c3'}{'port'}{'udp'} = '2472'	; 
#	$srvcobjects_ref->{'c3'}{'ports'}{'udp'}{'2472'}++	; 
#	$ports_ref->{'udp'}{'2472'}{'name'} = 'c3'		; 
#	$srvcobjects_ref->{'c3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'c3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'c3'}{'port'}{'tcp'} = '2472'	; 
#	$srvcobjects_ref->{'c3'}{'ports'}{'tcp'}{'2472'}++	; 
#	$ports_ref->{'tcp'}{'2472'}{'name'} = 'c3'		; 
#	$srvcobjects_ref->{'itactionserver1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itactionserver1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itactionserver1'}{'port'}{'udp'} = '7280'	; 
#	$srvcobjects_ref->{'itactionserver1'}{'ports'}{'udp'}{'7280'}++	; 
#	$ports_ref->{'udp'}{'7280'}{'name'} = 'itactionserver1'		; 
#	$srvcobjects_ref->{'itactionserver1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itactionserver1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itactionserver1'}{'port'}{'tcp'} = '7280'	; 
#	$srvcobjects_ref->{'itactionserver1'}{'ports'}{'tcp'}{'7280'}++	; 
#	$ports_ref->{'tcp'}{'7280'}{'name'} = 'itactionserver1'		; 
#	$srvcobjects_ref->{'netops-broker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netops-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netops-broker'}{'port'}{'udp'} = '5465'	; 
#	$srvcobjects_ref->{'netops-broker'}{'ports'}{'udp'}{'5465'}++	; 
#	$ports_ref->{'udp'}{'5465'}{'name'} = 'netops-broker'		; 
#	$srvcobjects_ref->{'netops-broker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netops-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netops-broker'}{'port'}{'tcp'} = '5465'	; 
#	$srvcobjects_ref->{'netops-broker'}{'ports'}{'tcp'}{'5465'}++	; 
#	$ports_ref->{'tcp'}{'5465'}{'name'} = 'netops-broker'		; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'port'}{'udp'} = '3537'	; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'ports'}{'udp'}{'3537'}++	; 
#	$ports_ref->{'udp'}{'3537'}{'name'} = 'ni-visa-remote'		; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'port'}{'tcp'} = '3537'	; 
#	$srvcobjects_ref->{'ni-visa-remote'}{'ports'}{'tcp'}{'3537'}++	; 
#	$ports_ref->{'tcp'}{'3537'}{'name'} = 'ni-visa-remote'		; 
#	$srvcobjects_ref->{'icl-twobase6'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase6'}{'port'}{'udp'} = '25005'	; 
#	$srvcobjects_ref->{'icl-twobase6'}{'ports'}{'udp'}{'25005'}++	; 
#	$ports_ref->{'udp'}{'25005'}{'name'} = 'icl-twobase6'		; 
#	$srvcobjects_ref->{'icl-twobase6'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase6'}{'port'}{'tcp'} = '25005'	; 
#	$srvcobjects_ref->{'icl-twobase6'}{'ports'}{'tcp'}{'25005'}++	; 
#	$ports_ref->{'tcp'}{'25005'}{'name'} = 'icl-twobase6'		; 
#	$srvcobjects_ref->{'mdqs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mdqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdqs'}{'port'}{'udp'} = '666'	; 
#	$srvcobjects_ref->{'mdqs'}{'ports'}{'udp'}{'666'}++	; 
#	$ports_ref->{'udp'}{'666'}{'name'} = 'mdqs'		; 
#	$srvcobjects_ref->{'mdqs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mdqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdqs'}{'port'}{'tcp'} = '666'	; 
#	$srvcobjects_ref->{'mdqs'}{'ports'}{'tcp'}{'666'}++	; 
#	$ports_ref->{'tcp'}{'666'}{'name'} = 'mdqs'		; 
#	$srvcobjects_ref->{'openqueue'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openqueue'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openqueue'}{'port'}{'udp'} = '8764'	; 
#	$srvcobjects_ref->{'openqueue'}{'ports'}{'udp'}{'8764'}++	; 
#	$ports_ref->{'udp'}{'8764'}{'name'} = 'openqueue'		; 
#	$srvcobjects_ref->{'openqueue'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openqueue'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openqueue'}{'port'}{'tcp'} = '8764'	; 
#	$srvcobjects_ref->{'openqueue'}{'ports'}{'tcp'}{'8764'}++	; 
#	$ports_ref->{'tcp'}{'8764'}{'name'} = 'openqueue'		; 
#	$srvcobjects_ref->{'gserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gserver'}{'port'}{'udp'} = '26264'	; 
#	$srvcobjects_ref->{'gserver'}{'ports'}{'udp'}{'26264'}++	; 
#	$ports_ref->{'udp'}{'26264'}{'name'} = 'gserver'		; 
#	$srvcobjects_ref->{'gserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gserver'}{'port'}{'tcp'} = '26264'	; 
#	$srvcobjects_ref->{'gserver'}{'ports'}{'tcp'}{'26264'}++	; 
#	$ports_ref->{'tcp'}{'26264'}{'name'} = 'gserver'		; 
#	$srvcobjects_ref->{'ias-auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ias-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ias-auth'}{'port'}{'udp'} = '2139'	; 
#	$srvcobjects_ref->{'ias-auth'}{'ports'}{'udp'}{'2139'}++	; 
#	$ports_ref->{'udp'}{'2139'}{'name'} = 'ias-auth'		; 
#	$srvcobjects_ref->{'ias-auth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ias-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ias-auth'}{'port'}{'tcp'} = '2139'	; 
#	$srvcobjects_ref->{'ias-auth'}{'ports'}{'tcp'}{'2139'}++	; 
#	$ports_ref->{'tcp'}{'2139'}{'name'} = 'ias-auth'		; 
#	$srvcobjects_ref->{'pwdgen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pwdgen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwdgen'}{'port'}{'udp'} = '129'	; 
#	$srvcobjects_ref->{'pwdgen'}{'ports'}{'udp'}{'129'}++	; 
#	$ports_ref->{'udp'}{'129'}{'name'} = 'pwdgen'		; 
#	$srvcobjects_ref->{'pwdgen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pwdgen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwdgen'}{'port'}{'tcp'} = '129'	; 
#	$srvcobjects_ref->{'pwdgen'}{'ports'}{'tcp'}{'129'}++	; 
#	$ports_ref->{'tcp'}{'129'}{'name'} = 'pwdgen'		; 
#	$srvcobjects_ref->{'netmon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmon'}{'port'}{'udp'} = '2606'	; 
#	$srvcobjects_ref->{'netmon'}{'ports'}{'udp'}{'2606'}++	; 
#	$ports_ref->{'udp'}{'2606'}{'name'} = 'netmon'		; 
#	$srvcobjects_ref->{'netmon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmon'}{'port'}{'tcp'} = '2606'	; 
#	$srvcobjects_ref->{'netmon'}{'ports'}{'tcp'}{'2606'}++	; 
#	$ports_ref->{'tcp'}{'2606'}{'name'} = 'netmon'		; 
#	$srvcobjects_ref->{'rfmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rfmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfmp'}{'port'}{'udp'} = '2249'	; 
#	$srvcobjects_ref->{'rfmp'}{'ports'}{'udp'}{'2249'}++	; 
#	$ports_ref->{'udp'}{'2249'}{'name'} = 'rfmp'		; 
#	$srvcobjects_ref->{'rfmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rfmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfmp'}{'port'}{'tcp'} = '2249'	; 
#	$srvcobjects_ref->{'rfmp'}{'ports'}{'tcp'}{'2249'}++	; 
#	$ports_ref->{'tcp'}{'2249'}{'name'} = 'rfmp'		; 
#	$srvcobjects_ref->{'shell'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shell'}{'port'}{'tcp'} = '514'	; 
#	$srvcobjects_ref->{'shell'}{'ports'}{'tcp'}{'514'}++	; 
#	$ports_ref->{'tcp'}{'514'}{'name'} = 'shell'		; 
#	$srvcobjects_ref->{'iafserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iafserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iafserver'}{'port'}{'udp'} = '479'	; 
#	$srvcobjects_ref->{'iafserver'}{'ports'}{'udp'}{'479'}++	; 
#	$ports_ref->{'udp'}{'479'}{'name'} = 'iafserver'		; 
#	$srvcobjects_ref->{'iafserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iafserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iafserver'}{'port'}{'tcp'} = '479'	; 
#	$srvcobjects_ref->{'iafserver'}{'ports'}{'tcp'}{'479'}++	; 
#	$ports_ref->{'tcp'}{'479'}{'name'} = 'iafserver'		; 
#	$srvcobjects_ref->{'cadlock2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadlock2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadlock2'}{'port'}{'udp'} = '1000'	; 
#	$srvcobjects_ref->{'cadlock2'}{'ports'}{'udp'}{'1000'}++	; 
#	$ports_ref->{'udp'}{'1000'}{'name'} = 'cadlock2'		; 
#	$srvcobjects_ref->{'cadlock2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadlock2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadlock2'}{'port'}{'tcp'} = '1000'	; 
#	$srvcobjects_ref->{'cadlock2'}{'ports'}{'tcp'}{'1000'}++	; 
#	$ports_ref->{'tcp'}{'1000'}{'name'} = 'cadlock2'		; 
#	$srvcobjects_ref->{'iasd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iasd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iasd'}{'port'}{'udp'} = '432'	; 
#	$srvcobjects_ref->{'iasd'}{'ports'}{'udp'}{'432'}++	; 
#	$ports_ref->{'udp'}{'432'}{'name'} = 'iasd'		; 
#	$srvcobjects_ref->{'iasd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iasd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iasd'}{'port'}{'tcp'} = '432'	; 
#	$srvcobjects_ref->{'iasd'}{'ports'}{'tcp'}{'432'}++	; 
#	$ports_ref->{'tcp'}{'432'}{'name'} = 'iasd'		; 
#	$srvcobjects_ref->{'orbiter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orbiter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbiter'}{'port'}{'udp'} = '2398'	; 
#	$srvcobjects_ref->{'orbiter'}{'ports'}{'udp'}{'2398'}++	; 
#	$ports_ref->{'udp'}{'2398'}{'name'} = 'orbiter'		; 
#	$srvcobjects_ref->{'orbiter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orbiter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbiter'}{'port'}{'tcp'} = '2398'	; 
#	$srvcobjects_ref->{'orbiter'}{'ports'}{'tcp'}{'2398'}++	; 
#	$ports_ref->{'tcp'}{'2398'}{'name'} = 'orbiter'		; 
#	$srvcobjects_ref->{'lbc-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lbc-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-control'}{'port'}{'udp'} = '2780'	; 
#	$srvcobjects_ref->{'lbc-control'}{'ports'}{'udp'}{'2780'}++	; 
#	$ports_ref->{'udp'}{'2780'}{'name'} = 'lbc-control'		; 
#	$srvcobjects_ref->{'lbc-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lbc-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-control'}{'port'}{'tcp'} = '2780'	; 
#	$srvcobjects_ref->{'lbc-control'}{'ports'}{'tcp'}{'2780'}++	; 
#	$ports_ref->{'tcp'}{'2780'}{'name'} = 'lbc-control'		; 
#	$srvcobjects_ref->{'silc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'silc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silc'}{'port'}{'udp'} = '706'	; 
#	$srvcobjects_ref->{'silc'}{'ports'}{'udp'}{'706'}++	; 
#	$ports_ref->{'udp'}{'706'}{'name'} = 'silc'		; 
#	$srvcobjects_ref->{'silc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'silc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silc'}{'port'}{'tcp'} = '706'	; 
#	$srvcobjects_ref->{'silc'}{'ports'}{'tcp'}{'706'}++	; 
#	$ports_ref->{'tcp'}{'706'}{'name'} = 'silc'		; 
#	$srvcobjects_ref->{'wap-push-https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-push-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-push-https'}{'port'}{'udp'} = '4036'	; 
#	$srvcobjects_ref->{'wap-push-https'}{'ports'}{'udp'}{'4036'}++	; 
#	$ports_ref->{'udp'}{'4036'}{'name'} = 'wap-push-https'		; 
#	$srvcobjects_ref->{'wap-push-https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-push-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-push-https'}{'port'}{'tcp'} = '4036'	; 
#	$srvcobjects_ref->{'wap-push-https'}{'ports'}{'tcp'}{'4036'}++	; 
#	$ports_ref->{'tcp'}{'4036'}{'name'} = 'wap-push-https'		; 
#	$srvcobjects_ref->{'olhost'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'olhost'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'olhost'}{'port'}{'udp'} = '2661'	; 
#	$srvcobjects_ref->{'olhost'}{'ports'}{'udp'}{'2661'}++	; 
#	$ports_ref->{'udp'}{'2661'}{'name'} = 'olhost'		; 
#	$srvcobjects_ref->{'olhost'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'olhost'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'olhost'}{'port'}{'tcp'} = '2661'	; 
#	$srvcobjects_ref->{'olhost'}{'ports'}{'tcp'}{'2661'}++	; 
#	$ports_ref->{'tcp'}{'2661'}{'name'} = 'olhost'		; 
#	$srvcobjects_ref->{'asc-slmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asc-slmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asc-slmd'}{'port'}{'udp'} = '4448'	; 
#	$srvcobjects_ref->{'asc-slmd'}{'ports'}{'udp'}{'4448'}++	; 
#	$ports_ref->{'udp'}{'4448'}{'name'} = 'asc-slmd'		; 
#	$srvcobjects_ref->{'asc-slmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asc-slmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asc-slmd'}{'port'}{'tcp'} = '4448'	; 
#	$srvcobjects_ref->{'asc-slmd'}{'ports'}{'tcp'}{'4448'}++	; 
#	$ports_ref->{'tcp'}{'4448'}{'name'} = 'asc-slmd'		; 
#	$srvcobjects_ref->{'cbt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cbt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cbt'}{'port'}{'udp'} = '7777'	; 
#	$srvcobjects_ref->{'cbt'}{'ports'}{'udp'}{'7777'}++	; 
#	$ports_ref->{'udp'}{'7777'}{'name'} = 'cbt'		; 
#	$srvcobjects_ref->{'cbt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cbt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cbt'}{'port'}{'tcp'} = '7777'	; 
#	$srvcobjects_ref->{'cbt'}{'ports'}{'tcp'}{'7777'}++	; 
#	$ports_ref->{'tcp'}{'7777'}{'name'} = 'cbt'		; 
#	$srvcobjects_ref->{'netviewdm1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netviewdm1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netviewdm1'}{'port'}{'udp'} = '729'	; 
#	$srvcobjects_ref->{'netviewdm1'}{'ports'}{'udp'}{'729'}++	; 
#	$ports_ref->{'udp'}{'729'}{'name'} = 'netviewdm1'		; 
#	$srvcobjects_ref->{'netviewdm1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netviewdm1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netviewdm1'}{'port'}{'tcp'} = '729'	; 
#	$srvcobjects_ref->{'netviewdm1'}{'ports'}{'tcp'}{'729'}++	; 
#	$ports_ref->{'tcp'}{'729'}{'name'} = 'netviewdm1'		; 
#	$srvcobjects_ref->{'filenet-tms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filenet-tms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-tms'}{'port'}{'udp'} = '32768'	; 
#	$srvcobjects_ref->{'filenet-tms'}{'ports'}{'udp'}{'32768'}++	; 
#	$ports_ref->{'udp'}{'32768'}{'name'} = 'filenet-tms'		; 
#	$srvcobjects_ref->{'filenet-tms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filenet-tms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-tms'}{'port'}{'tcp'} = '32768'	; 
#	$srvcobjects_ref->{'filenet-tms'}{'ports'}{'tcp'}{'32768'}++	; 
#	$ports_ref->{'tcp'}{'32768'}{'name'} = 'filenet-tms'		; 
#	$srvcobjects_ref->{'apc-9952'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-9952'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-9952'}{'port'}{'udp'} = '9952'	; 
#	$srvcobjects_ref->{'apc-9952'}{'ports'}{'udp'}{'9952'}++	; 
#	$ports_ref->{'udp'}{'9952'}{'name'} = 'apc-9952'		; 
#	$srvcobjects_ref->{'apc-9952'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-9952'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-9952'}{'port'}{'tcp'} = '9952'	; 
#	$srvcobjects_ref->{'apc-9952'}{'ports'}{'tcp'}{'9952'}++	; 
#	$ports_ref->{'tcp'}{'9952'}{'name'} = 'apc-9952'		; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'port'}{'udp'} = '1699'	; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'ports'}{'udp'}{'1699'}++	; 
#	$ports_ref->{'udp'}{'1699'}{'name'} = 'rsvp-encap-2'		; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'port'}{'tcp'} = '1699'	; 
#	$srvcobjects_ref->{'rsvp-encap-2'}{'ports'}{'tcp'}{'1699'}++	; 
#	$ports_ref->{'tcp'}{'1699'}{'name'} = 'rsvp-encap-2'		; 
#	$srvcobjects_ref->{'patrolview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'patrolview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrolview'}{'port'}{'udp'} = '4097'	; 
#	$srvcobjects_ref->{'patrolview'}{'ports'}{'udp'}{'4097'}++	; 
#	$ports_ref->{'udp'}{'4097'}{'name'} = 'patrolview'		; 
#	$srvcobjects_ref->{'patrolview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'patrolview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrolview'}{'port'}{'tcp'} = '4097'	; 
#	$srvcobjects_ref->{'patrolview'}{'ports'}{'tcp'}{'4097'}++	; 
#	$ports_ref->{'tcp'}{'4097'}{'name'} = 'patrolview'		; 
#	$srvcobjects_ref->{'net-assistant'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'net-assistant'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net-assistant'}{'port'}{'udp'} = '3283'	; 
#	$srvcobjects_ref->{'net-assistant'}{'ports'}{'udp'}{'3283'}++	; 
#	$ports_ref->{'udp'}{'3283'}{'name'} = 'net-assistant'		; 
#	$srvcobjects_ref->{'net-assistant'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'net-assistant'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net-assistant'}{'port'}{'tcp'} = '3283'	; 
#	$srvcobjects_ref->{'net-assistant'}{'ports'}{'tcp'}{'3283'}++	; 
#	$ports_ref->{'tcp'}{'3283'}{'name'} = 'net-assistant'		; 
#	$srvcobjects_ref->{'payrouter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'payrouter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'payrouter'}{'port'}{'udp'} = '1246'	; 
#	$srvcobjects_ref->{'payrouter'}{'ports'}{'udp'}{'1246'}++	; 
#	$ports_ref->{'udp'}{'1246'}{'name'} = 'payrouter'		; 
#	$srvcobjects_ref->{'payrouter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'payrouter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'payrouter'}{'port'}{'tcp'} = '1246'	; 
#	$srvcobjects_ref->{'payrouter'}{'ports'}{'tcp'}{'1246'}++	; 
#	$ports_ref->{'tcp'}{'1246'}{'name'} = 'payrouter'		; 
#	$srvcobjects_ref->{'sm-pas-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sm-pas-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-2'}{'port'}{'udp'} = '2939'	; 
#	$srvcobjects_ref->{'sm-pas-2'}{'ports'}{'udp'}{'2939'}++	; 
#	$ports_ref->{'udp'}{'2939'}{'name'} = 'sm-pas-2'		; 
#	$srvcobjects_ref->{'sm-pas-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sm-pas-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-2'}{'port'}{'tcp'} = '2939'	; 
#	$srvcobjects_ref->{'sm-pas-2'}{'ports'}{'tcp'}{'2939'}++	; 
#	$ports_ref->{'tcp'}{'2939'}{'name'} = 'sm-pas-2'		; 
#	$srvcobjects_ref->{'hdap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hdap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hdap'}{'port'}{'udp'} = '263'	; 
#	$srvcobjects_ref->{'hdap'}{'ports'}{'udp'}{'263'}++	; 
#	$ports_ref->{'udp'}{'263'}{'name'} = 'hdap'		; 
#	$srvcobjects_ref->{'hdap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hdap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hdap'}{'port'}{'tcp'} = '263'	; 
#	$srvcobjects_ref->{'hdap'}{'ports'}{'tcp'}{'263'}++	; 
#	$ports_ref->{'tcp'}{'263'}{'name'} = 'hdap'		; 
#	$srvcobjects_ref->{'brf-gw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'brf-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brf-gw'}{'port'}{'udp'} = '22951'	; 
#	$srvcobjects_ref->{'brf-gw'}{'ports'}{'udp'}{'22951'}++	; 
#	$ports_ref->{'udp'}{'22951'}{'name'} = 'brf-gw'		; 
#	$srvcobjects_ref->{'brf-gw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'brf-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brf-gw'}{'port'}{'tcp'} = '22951'	; 
#	$srvcobjects_ref->{'brf-gw'}{'ports'}{'tcp'}{'22951'}++	; 
#	$ports_ref->{'tcp'}{'22951'}{'name'} = 'brf-gw'		; 
#	$srvcobjects_ref->{'cvmon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cvmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvmon'}{'port'}{'udp'} = '1686'	; 
#	$srvcobjects_ref->{'cvmon'}{'ports'}{'udp'}{'1686'}++	; 
#	$ports_ref->{'udp'}{'1686'}{'name'} = 'cvmon'		; 
#	$srvcobjects_ref->{'cvmon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cvmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvmon'}{'port'}{'tcp'} = '1686'	; 
#	$srvcobjects_ref->{'cvmon'}{'ports'}{'tcp'}{'1686'}++	; 
#	$ports_ref->{'tcp'}{'1686'}{'name'} = 'cvmon'		; 
#	$srvcobjects_ref->{'dbstar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbstar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbstar'}{'port'}{'udp'} = '1415'	; 
#	$srvcobjects_ref->{'dbstar'}{'ports'}{'udp'}{'1415'}++	; 
#	$ports_ref->{'udp'}{'1415'}{'name'} = 'dbstar'		; 
#	$srvcobjects_ref->{'dbstar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbstar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbstar'}{'port'}{'tcp'} = '1415'	; 
#	$srvcobjects_ref->{'dbstar'}{'ports'}{'tcp'}{'1415'}++	; 
#	$ports_ref->{'tcp'}{'1415'}{'name'} = 'dbstar'		; 
#	$srvcobjects_ref->{'esmagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esmagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esmagent'}{'port'}{'udp'} = '5601'	; 
#	$srvcobjects_ref->{'esmagent'}{'ports'}{'udp'}{'5601'}++	; 
#	$ports_ref->{'udp'}{'5601'}{'name'} = 'esmagent'		; 
#	$srvcobjects_ref->{'esmagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esmagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esmagent'}{'port'}{'tcp'} = '5601'	; 
#	$srvcobjects_ref->{'esmagent'}{'ports'}{'tcp'}{'5601'}++	; 
#	$ports_ref->{'tcp'}{'5601'}{'name'} = 'esmagent'		; 
#	$srvcobjects_ref->{'tsaf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tsaf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsaf'}{'port'}{'udp'} = '12753'	; 
#	$srvcobjects_ref->{'tsaf'}{'ports'}{'udp'}{'12753'}++	; 
#	$ports_ref->{'udp'}{'12753'}{'name'} = 'tsaf'		; 
#	$srvcobjects_ref->{'tsaf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tsaf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsaf'}{'port'}{'tcp'} = '12753'	; 
#	$srvcobjects_ref->{'tsaf'}{'ports'}{'tcp'}{'12753'}++	; 
#	$ports_ref->{'tcp'}{'12753'}{'name'} = 'tsaf'		; 
#	$srvcobjects_ref->{'paging-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'paging-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paging-port'}{'port'}{'udp'} = '3771'	; 
#	$srvcobjects_ref->{'paging-port'}{'ports'}{'udp'}{'3771'}++	; 
#	$ports_ref->{'udp'}{'3771'}{'name'} = 'paging-port'		; 
#	$srvcobjects_ref->{'paging-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'paging-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paging-port'}{'port'}{'tcp'} = '3771'	; 
#	$srvcobjects_ref->{'paging-port'}{'ports'}{'tcp'}{'3771'}++	; 
#	$ports_ref->{'tcp'}{'3771'}{'name'} = 'paging-port'		; 
#	$srvcobjects_ref->{'anet-h'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anet-h'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-h'}{'port'}{'udp'} = '3341'	; 
#	$srvcobjects_ref->{'anet-h'}{'ports'}{'udp'}{'3341'}++	; 
#	$ports_ref->{'udp'}{'3341'}{'name'} = 'anet-h'		; 
#	$srvcobjects_ref->{'anet-h'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anet-h'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-h'}{'port'}{'tcp'} = '3341'	; 
#	$srvcobjects_ref->{'anet-h'}{'ports'}{'tcp'}{'3341'}++	; 
#	$ports_ref->{'tcp'}{'3341'}{'name'} = 'anet-h'		; 
#	$srvcobjects_ref->{'megaco-h248'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'megaco-h248'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'megaco-h248'}{'port'}{'udp'} = '2944'	; 
#	$srvcobjects_ref->{'megaco-h248'}{'ports'}{'udp'}{'2944'}++	; 
#	$ports_ref->{'udp'}{'2944'}{'name'} = 'megaco-h248'		; 
#	$srvcobjects_ref->{'megaco-h248'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'megaco-h248'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'megaco-h248'}{'port'}{'tcp'} = '2944'	; 
#	$srvcobjects_ref->{'megaco-h248'}{'ports'}{'tcp'}{'2944'}++	; 
#	$ports_ref->{'tcp'}{'2944'}{'name'} = 'megaco-h248'		; 
#	$srvcobjects_ref->{'nfsd-keepalive'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nfsd-keepalive'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nfsd-keepalive'}{'port'}{'udp'} = '1110'	; 
#	$srvcobjects_ref->{'nfsd-keepalive'}{'ports'}{'udp'}{'1110'}++	; 
#	$ports_ref->{'udp'}{'1110'}{'name'} = 'nfsd-keepalive'		; 
#	$srvcobjects_ref->{'jpegmpeg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jpegmpeg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jpegmpeg'}{'port'}{'udp'} = '3155'	; 
#	$srvcobjects_ref->{'jpegmpeg'}{'ports'}{'udp'}{'3155'}++	; 
#	$ports_ref->{'udp'}{'3155'}{'name'} = 'jpegmpeg'		; 
#	$srvcobjects_ref->{'jpegmpeg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jpegmpeg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jpegmpeg'}{'port'}{'tcp'} = '3155'	; 
#	$srvcobjects_ref->{'jpegmpeg'}{'ports'}{'tcp'}{'3155'}++	; 
#	$ports_ref->{'tcp'}{'3155'}{'name'} = 'jpegmpeg'		; 
#	$srvcobjects_ref->{'gcmonitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gcmonitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gcmonitor'}{'port'}{'udp'} = '2660'	; 
#	$srvcobjects_ref->{'gcmonitor'}{'ports'}{'udp'}{'2660'}++	; 
#	$ports_ref->{'udp'}{'2660'}{'name'} = 'gcmonitor'		; 
#	$srvcobjects_ref->{'gcmonitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gcmonitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gcmonitor'}{'port'}{'tcp'} = '2660'	; 
#	$srvcobjects_ref->{'gcmonitor'}{'ports'}{'tcp'}{'2660'}++	; 
#	$ports_ref->{'tcp'}{'2660'}{'name'} = 'gcmonitor'		; 
#	$srvcobjects_ref->{'o2server-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'o2server-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'o2server-port'}{'port'}{'udp'} = '1894'	; 
#	$srvcobjects_ref->{'o2server-port'}{'ports'}{'udp'}{'1894'}++	; 
#	$ports_ref->{'udp'}{'1894'}{'name'} = 'o2server-port'		; 
#	$srvcobjects_ref->{'o2server-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'o2server-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'o2server-port'}{'port'}{'tcp'} = '1894'	; 
#	$srvcobjects_ref->{'o2server-port'}{'ports'}{'tcp'}{'1894'}++	; 
#	$ports_ref->{'tcp'}{'1894'}{'name'} = 'o2server-port'		; 
#	$srvcobjects_ref->{'msiccp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msiccp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msiccp'}{'port'}{'udp'} = '1731'	; 
#	$srvcobjects_ref->{'msiccp'}{'ports'}{'udp'}{'1731'}++	; 
#	$ports_ref->{'udp'}{'1731'}{'name'} = 'msiccp'		; 
#	$srvcobjects_ref->{'msiccp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msiccp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msiccp'}{'port'}{'tcp'} = '1731'	; 
#	$srvcobjects_ref->{'msiccp'}{'ports'}{'tcp'}{'1731'}++	; 
#	$ports_ref->{'tcp'}{'1731'}{'name'} = 'msiccp'		; 
#	$srvcobjects_ref->{'cst-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cst-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cst-port'}{'port'}{'udp'} = '3742'	; 
#	$srvcobjects_ref->{'cst-port'}{'ports'}{'udp'}{'3742'}++	; 
#	$ports_ref->{'udp'}{'3742'}{'name'} = 'cst-port'		; 
#	$srvcobjects_ref->{'cst-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cst-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cst-port'}{'port'}{'tcp'} = '3742'	; 
#	$srvcobjects_ref->{'cst-port'}{'ports'}{'tcp'}{'3742'}++	; 
#	$ports_ref->{'tcp'}{'3742'}{'name'} = 'cst-port'		; 
#	$srvcobjects_ref->{'sift-uft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sift-uft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sift-uft'}{'port'}{'udp'} = '608'	; 
#	$srvcobjects_ref->{'sift-uft'}{'ports'}{'udp'}{'608'}++	; 
#	$ports_ref->{'udp'}{'608'}{'name'} = 'sift-uft'		; 
#	$srvcobjects_ref->{'sift-uft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sift-uft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sift-uft'}{'port'}{'tcp'} = '608'	; 
#	$srvcobjects_ref->{'sift-uft'}{'ports'}{'tcp'}{'608'}++	; 
#	$ports_ref->{'tcp'}{'608'}{'name'} = 'sift-uft'		; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'port'}{'udp'} = '2495'	; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'ports'}{'udp'}{'2495'}++	; 
#	$ports_ref->{'udp'}{'2495'}{'name'} = 'fast-rem-serv'		; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'port'}{'tcp'} = '2495'	; 
#	$srvcobjects_ref->{'fast-rem-serv'}{'ports'}{'tcp'}{'2495'}++	; 
#	$ports_ref->{'tcp'}{'2495'}{'name'} = 'fast-rem-serv'		; 
#	$srvcobjects_ref->{'epmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epmap'}{'port'}{'udp'} = '135'	; 
#	$srvcobjects_ref->{'epmap'}{'ports'}{'udp'}{'135'}++	; 
#	$ports_ref->{'udp'}{'135'}{'name'} = 'epmap'		; 
#	$srvcobjects_ref->{'epmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epmap'}{'port'}{'tcp'} = '135'	; 
#	$srvcobjects_ref->{'epmap'}{'ports'}{'tcp'}{'135'}++	; 
#	$ports_ref->{'tcp'}{'135'}{'name'} = 'epmap'		; 
#	$srvcobjects_ref->{'palace-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'palace-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-3'}{'port'}{'udp'} = '9994'	; 
#	$srvcobjects_ref->{'palace-3'}{'ports'}{'udp'}{'9994'}++	; 
#	$ports_ref->{'udp'}{'9994'}{'name'} = 'palace-3'		; 
#	$srvcobjects_ref->{'palace-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'palace-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-3'}{'port'}{'tcp'} = '9994'	; 
#	$srvcobjects_ref->{'palace-3'}{'ports'}{'tcp'}{'9994'}++	; 
#	$ports_ref->{'tcp'}{'9994'}{'name'} = 'palace-3'		; 
#	$srvcobjects_ref->{'iccrushmore'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iccrushmore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iccrushmore'}{'port'}{'udp'} = '6850'	; 
#	$srvcobjects_ref->{'iccrushmore'}{'ports'}{'udp'}{'6850'}++	; 
#	$ports_ref->{'udp'}{'6850'}{'name'} = 'iccrushmore'		; 
#	$srvcobjects_ref->{'iccrushmore'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iccrushmore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iccrushmore'}{'port'}{'tcp'} = '6850'	; 
#	$srvcobjects_ref->{'iccrushmore'}{'ports'}{'tcp'}{'6850'}++	; 
#	$ports_ref->{'tcp'}{'6850'}{'name'} = 'iccrushmore'		; 
#	$srvcobjects_ref->{'aas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aas'}{'port'}{'udp'} = '1601'	; 
#	$srvcobjects_ref->{'aas'}{'ports'}{'udp'}{'1601'}++	; 
#	$ports_ref->{'udp'}{'1601'}{'name'} = 'aas'		; 
#	$srvcobjects_ref->{'aas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aas'}{'port'}{'tcp'} = '1601'	; 
#	$srvcobjects_ref->{'aas'}{'ports'}{'tcp'}{'1601'}++	; 
#	$ports_ref->{'tcp'}{'1601'}{'name'} = 'aas'		; 
#	$srvcobjects_ref->{'ibm-pps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-pps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-pps'}{'port'}{'udp'} = '1376'	; 
#	$srvcobjects_ref->{'ibm-pps'}{'ports'}{'udp'}{'1376'}++	; 
#	$ports_ref->{'udp'}{'1376'}{'name'} = 'ibm-pps'		; 
#	$srvcobjects_ref->{'ibm-pps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-pps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-pps'}{'port'}{'tcp'} = '1376'	; 
#	$srvcobjects_ref->{'ibm-pps'}{'ports'}{'tcp'}{'1376'}++	; 
#	$ports_ref->{'tcp'}{'1376'}{'name'} = 'ibm-pps'		; 
#	$srvcobjects_ref->{'jvclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jvclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jvclient'}{'port'}{'udp'} = '1940'	; 
#	$srvcobjects_ref->{'jvclient'}{'ports'}{'udp'}{'1940'}++	; 
#	$ports_ref->{'udp'}{'1940'}{'name'} = 'jvclient'		; 
#	$srvcobjects_ref->{'jvclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jvclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jvclient'}{'port'}{'tcp'} = '1940'	; 
#	$srvcobjects_ref->{'jvclient'}{'ports'}{'tcp'}{'1940'}++	; 
#	$ports_ref->{'tcp'}{'1940'}{'name'} = 'jvclient'		; 
#	$srvcobjects_ref->{'hacl-hb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-hb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-hb'}{'port'}{'udp'} = '5300'	; 
#	$srvcobjects_ref->{'hacl-hb'}{'ports'}{'udp'}{'5300'}++	; 
#	$ports_ref->{'udp'}{'5300'}{'name'} = 'hacl-hb'		; 
#	$srvcobjects_ref->{'hacl-hb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-hb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-hb'}{'port'}{'tcp'} = '5300'	; 
#	$srvcobjects_ref->{'hacl-hb'}{'ports'}{'tcp'}{'5300'}++	; 
#	$ports_ref->{'tcp'}{'5300'}{'name'} = 'hacl-hb'		; 
#	$srvcobjects_ref->{'cft-0'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-0'}{'port'}{'udp'} = '1761'	; 
#	$srvcobjects_ref->{'cft-0'}{'ports'}{'udp'}{'1761'}++	; 
#	$ports_ref->{'udp'}{'1761'}{'name'} = 'cft-0'		; 
#	$srvcobjects_ref->{'cft-0'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-0'}{'port'}{'tcp'} = '1761'	; 
#	$srvcobjects_ref->{'cft-0'}{'ports'}{'tcp'}{'1761'}++	; 
#	$ports_ref->{'tcp'}{'1761'}{'name'} = 'cft-0'		; 
#	$srvcobjects_ref->{'nw-license'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nw-license'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nw-license'}{'port'}{'udp'} = '3697'	; 
#	$srvcobjects_ref->{'nw-license'}{'ports'}{'udp'}{'3697'}++	; 
#	$ports_ref->{'udp'}{'3697'}{'name'} = 'nw-license'		; 
#	$srvcobjects_ref->{'nw-license'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nw-license'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nw-license'}{'port'}{'tcp'} = '3697'	; 
#	$srvcobjects_ref->{'nw-license'}{'ports'}{'tcp'}{'3697'}++	; 
#	$ports_ref->{'tcp'}{'3697'}{'name'} = 'nw-license'		; 
#	$srvcobjects_ref->{'csvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csvr'}{'port'}{'udp'} = '3417'	; 
#	$srvcobjects_ref->{'csvr'}{'ports'}{'udp'}{'3417'}++	; 
#	$ports_ref->{'udp'}{'3417'}{'name'} = 'csvr'		; 
#	$srvcobjects_ref->{'csvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csvr'}{'port'}{'tcp'} = '3417'	; 
#	$srvcobjects_ref->{'csvr'}{'ports'}{'tcp'}{'3417'}++	; 
#	$ports_ref->{'tcp'}{'3417'}{'name'} = 'csvr'		; 
#	$srvcobjects_ref->{'vettcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vettcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vettcp'}{'port'}{'udp'} = '78'	; 
#	$srvcobjects_ref->{'vettcp'}{'ports'}{'udp'}{'78'}++	; 
#	$ports_ref->{'udp'}{'78'}{'name'} = 'vettcp'		; 
#	$srvcobjects_ref->{'vettcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vettcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vettcp'}{'port'}{'tcp'} = '78'	; 
#	$srvcobjects_ref->{'vettcp'}{'ports'}{'tcp'}{'78'}++	; 
#	$ports_ref->{'tcp'}{'78'}{'name'} = 'vettcp'		; 
#	$srvcobjects_ref->{'qo-secure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qo-secure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qo-secure'}{'port'}{'udp'} = '7913'	; 
#	$srvcobjects_ref->{'qo-secure'}{'ports'}{'udp'}{'7913'}++	; 
#	$ports_ref->{'udp'}{'7913'}{'name'} = 'qo-secure'		; 
#	$srvcobjects_ref->{'qo-secure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qo-secure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qo-secure'}{'port'}{'tcp'} = '7913'	; 
#	$srvcobjects_ref->{'qo-secure'}{'ports'}{'tcp'}{'7913'}++	; 
#	$ports_ref->{'tcp'}{'7913'}{'name'} = 'qo-secure'		; 
#	$srvcobjects_ref->{'dbm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbm'}{'port'}{'udp'} = '2345'	; 
#	$srvcobjects_ref->{'dbm'}{'ports'}{'udp'}{'2345'}++	; 
#	$ports_ref->{'udp'}{'2345'}{'name'} = 'dbm'		; 
#	$srvcobjects_ref->{'dbm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbm'}{'port'}{'tcp'} = '2345'	; 
#	$srvcobjects_ref->{'dbm'}{'ports'}{'tcp'}{'2345'}++	; 
#	$ports_ref->{'tcp'}{'2345'}{'name'} = 'dbm'		; 
#	$srvcobjects_ref->{'dlswpn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dlswpn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlswpn'}{'port'}{'udp'} = '2067'	; 
#	$srvcobjects_ref->{'dlswpn'}{'ports'}{'udp'}{'2067'}++	; 
#	$ports_ref->{'udp'}{'2067'}{'name'} = 'dlswpn'		; 
#	$srvcobjects_ref->{'dlswpn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dlswpn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlswpn'}{'port'}{'tcp'} = '2067'	; 
#	$srvcobjects_ref->{'dlswpn'}{'ports'}{'tcp'}{'2067'}++	; 
#	$ports_ref->{'tcp'}{'2067'}{'name'} = 'dlswpn'		; 
#	$srvcobjects_ref->{'sqlsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sqlsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sqlsrv'}{'port'}{'udp'} = '156'	; 
#	$srvcobjects_ref->{'sqlsrv'}{'ports'}{'udp'}{'156'}++	; 
#	$ports_ref->{'udp'}{'156'}{'name'} = 'sqlsrv'		; 
#	$srvcobjects_ref->{'sqlsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sqlsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sqlsrv'}{'port'}{'tcp'} = '156'	; 
#	$srvcobjects_ref->{'sqlsrv'}{'ports'}{'tcp'}{'156'}++	; 
#	$ports_ref->{'tcp'}{'156'}{'name'} = 'sqlsrv'		; 
#	$srvcobjects_ref->{'simple-push'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simple-push'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simple-push'}{'port'}{'udp'} = '3687'	; 
#	$srvcobjects_ref->{'simple-push'}{'ports'}{'udp'}{'3687'}++	; 
#	$ports_ref->{'udp'}{'3687'}{'name'} = 'simple-push'		; 
#	$srvcobjects_ref->{'simple-push'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simple-push'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simple-push'}{'port'}{'tcp'} = '3687'	; 
#	$srvcobjects_ref->{'simple-push'}{'ports'}{'tcp'}{'3687'}++	; 
#	$ports_ref->{'tcp'}{'3687'}{'name'} = 'simple-push'		; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'port'}{'udp'} = '627'	; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'ports'}{'udp'}{'627'}++	; 
#	$ports_ref->{'udp'}{'627'}{'name'} = 'passgo-tivoli'		; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'port'}{'tcp'} = '627'	; 
#	$srvcobjects_ref->{'passgo-tivoli'}{'ports'}{'tcp'}{'627'}++	; 
#	$ports_ref->{'tcp'}{'627'}{'name'} = 'passgo-tivoli'		; 
#	$srvcobjects_ref->{'rockwell-encap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rockwell-encap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-encap'}{'port'}{'udp'} = '44818'	; 
#	$srvcobjects_ref->{'rockwell-encap'}{'ports'}{'udp'}{'44818'}++	; 
#	$ports_ref->{'udp'}{'44818'}{'name'} = 'rockwell-encap'		; 
#	$srvcobjects_ref->{'rockwell-encap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rockwell-encap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-encap'}{'port'}{'tcp'} = '44818'	; 
#	$srvcobjects_ref->{'rockwell-encap'}{'ports'}{'tcp'}{'44818'}++	; 
#	$ports_ref->{'tcp'}{'44818'}{'name'} = 'rockwell-encap'		; 
#	$srvcobjects_ref->{'apc-7846'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-7846'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-7846'}{'port'}{'udp'} = '7846'	; 
#	$srvcobjects_ref->{'apc-7846'}{'ports'}{'udp'}{'7846'}++	; 
#	$ports_ref->{'udp'}{'7846'}{'name'} = 'apc-7846'		; 
#	$srvcobjects_ref->{'apc-7846'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-7846'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-7846'}{'port'}{'tcp'} = '7846'	; 
#	$srvcobjects_ref->{'apc-7846'}{'ports'}{'tcp'}{'7846'}++	; 
#	$ports_ref->{'tcp'}{'7846'}{'name'} = 'apc-7846'		; 
#	$srvcobjects_ref->{'ltctcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ltctcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ltctcp'}{'port'}{'tcp'} = '3487'	; 
#	$srvcobjects_ref->{'ltctcp'}{'ports'}{'tcp'}{'3487'}++	; 
#	$ports_ref->{'tcp'}{'3487'}{'name'} = 'ltctcp'		; 
#	$srvcobjects_ref->{'keyserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'keyserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'keyserver'}{'port'}{'udp'} = '584'	; 
#	$srvcobjects_ref->{'keyserver'}{'ports'}{'udp'}{'584'}++	; 
#	$ports_ref->{'udp'}{'584'}{'name'} = 'keyserver'		; 
#	$srvcobjects_ref->{'keyserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'keyserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'keyserver'}{'port'}{'tcp'} = '584'	; 
#	$srvcobjects_ref->{'keyserver'}{'ports'}{'tcp'}{'584'}++	; 
#	$ports_ref->{'tcp'}{'584'}{'name'} = 'keyserver'		; 
#	$srvcobjects_ref->{'cart-o-rama'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cart-o-rama'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cart-o-rama'}{'port'}{'udp'} = '3292'	; 
#	$srvcobjects_ref->{'cart-o-rama'}{'ports'}{'udp'}{'3292'}++	; 
#	$ports_ref->{'udp'}{'3292'}{'name'} = 'cart-o-rama'		; 
#	$srvcobjects_ref->{'cart-o-rama'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cart-o-rama'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cart-o-rama'}{'port'}{'tcp'} = '3292'	; 
#	$srvcobjects_ref->{'cart-o-rama'}{'ports'}{'tcp'}{'3292'}++	; 
#	$ports_ref->{'tcp'}{'3292'}{'name'} = 'cart-o-rama'		; 
#	$srvcobjects_ref->{'telefinder'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telefinder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telefinder'}{'port'}{'udp'} = '1474'	; 
#	$srvcobjects_ref->{'telefinder'}{'ports'}{'udp'}{'1474'}++	; 
#	$ports_ref->{'udp'}{'1474'}{'name'} = 'telefinder'		; 
#	$srvcobjects_ref->{'telefinder'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telefinder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telefinder'}{'port'}{'tcp'} = '1474'	; 
#	$srvcobjects_ref->{'telefinder'}{'ports'}{'tcp'}{'1474'}++	; 
#	$ports_ref->{'tcp'}{'1474'}{'name'} = 'telefinder'		; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'port'}{'udp'} = '2510'	; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'ports'}{'udp'}{'2510'}++	; 
#	$ports_ref->{'udp'}{'2510'}{'name'} = 'fjappmgrbulk'		; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'port'}{'tcp'} = '2510'	; 
#	$srvcobjects_ref->{'fjappmgrbulk'}{'ports'}{'tcp'}{'2510'}++	; 
#	$ports_ref->{'tcp'}{'2510'}{'name'} = 'fjappmgrbulk'		; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'port'}{'udp'} = '2716'	; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'ports'}{'udp'}{'2716'}++	; 
#	$ports_ref->{'udp'}{'2716'}{'name'} = 'inova-ip-disco'		; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'port'}{'tcp'} = '2716'	; 
#	$srvcobjects_ref->{'inova-ip-disco'}{'ports'}{'tcp'}{'2716'}++	; 
#	$ports_ref->{'tcp'}{'2716'}{'name'} = 'inova-ip-disco'		; 
#	$srvcobjects_ref->{'psprserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'psprserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psprserver'}{'port'}{'udp'} = '2354'	; 
#	$srvcobjects_ref->{'psprserver'}{'ports'}{'udp'}{'2354'}++	; 
#	$ports_ref->{'udp'}{'2354'}{'name'} = 'psprserver'		; 
#	$srvcobjects_ref->{'psprserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'psprserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psprserver'}{'port'}{'tcp'} = '2354'	; 
#	$srvcobjects_ref->{'psprserver'}{'ports'}{'tcp'}{'2354'}++	; 
#	$ports_ref->{'tcp'}{'2354'}{'name'} = 'psprserver'		; 
#	$srvcobjects_ref->{'opi-sock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opi-sock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opi-sock'}{'port'}{'udp'} = '7429'	; 
#	$srvcobjects_ref->{'opi-sock'}{'ports'}{'udp'}{'7429'}++	; 
#	$ports_ref->{'udp'}{'7429'}{'name'} = 'opi-sock'		; 
#	$srvcobjects_ref->{'opi-sock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opi-sock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opi-sock'}{'port'}{'tcp'} = '7429'	; 
#	$srvcobjects_ref->{'opi-sock'}{'ports'}{'tcp'}{'7429'}++	; 
#	$ports_ref->{'tcp'}{'7429'}{'name'} = 'opi-sock'		; 
#	$srvcobjects_ref->{'autodesk-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'autodesk-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autodesk-lm'}{'port'}{'udp'} = '1422'	; 
#	$srvcobjects_ref->{'autodesk-lm'}{'ports'}{'udp'}{'1422'}++	; 
#	$ports_ref->{'udp'}{'1422'}{'name'} = 'autodesk-lm'		; 
#	$srvcobjects_ref->{'autodesk-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'autodesk-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autodesk-lm'}{'port'}{'tcp'} = '1422'	; 
#	$srvcobjects_ref->{'autodesk-lm'}{'ports'}{'tcp'}{'1422'}++	; 
#	$ports_ref->{'tcp'}{'1422'}{'name'} = 'autodesk-lm'		; 
#	$srvcobjects_ref->{'xserveraid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xserveraid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xserveraid'}{'port'}{'udp'} = '3722'	; 
#	$srvcobjects_ref->{'xserveraid'}{'ports'}{'udp'}{'3722'}++	; 
#	$ports_ref->{'udp'}{'3722'}{'name'} = 'xserveraid'		; 
#	$srvcobjects_ref->{'xserveraid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xserveraid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xserveraid'}{'port'}{'tcp'} = '3722'	; 
#	$srvcobjects_ref->{'xserveraid'}{'ports'}{'tcp'}{'3722'}++	; 
#	$ports_ref->{'tcp'}{'3722'}{'name'} = 'xserveraid'		; 
#	$srvcobjects_ref->{'rmtserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmtserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmtserver'}{'port'}{'udp'} = '2416'	; 
#	$srvcobjects_ref->{'rmtserver'}{'ports'}{'udp'}{'2416'}++	; 
#	$ports_ref->{'udp'}{'2416'}{'name'} = 'rmtserver'		; 
#	$srvcobjects_ref->{'rmtserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmtserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmtserver'}{'port'}{'tcp'} = '2416'	; 
#	$srvcobjects_ref->{'rmtserver'}{'ports'}{'tcp'}{'2416'}++	; 
#	$ports_ref->{'tcp'}{'2416'}{'name'} = 'rmtserver'		; 
#	$srvcobjects_ref->{'set'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'set'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'set'}{'port'}{'udp'} = '257'	; 
#	$srvcobjects_ref->{'set'}{'ports'}{'udp'}{'257'}++	; 
#	$ports_ref->{'udp'}{'257'}{'name'} = 'set'		; 
#	$srvcobjects_ref->{'set'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'set'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'set'}{'port'}{'tcp'} = '257'	; 
#	$srvcobjects_ref->{'set'}{'ports'}{'tcp'}{'257'}++	; 
#	$ports_ref->{'tcp'}{'257'}{'name'} = 'set'		; 
#	$srvcobjects_ref->{'dpi-proxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dpi-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpi-proxy'}{'port'}{'udp'} = '1795'	; 
#	$srvcobjects_ref->{'dpi-proxy'}{'ports'}{'udp'}{'1795'}++	; 
#	$ports_ref->{'udp'}{'1795'}{'name'} = 'dpi-proxy'		; 
#	$srvcobjects_ref->{'dpi-proxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dpi-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpi-proxy'}{'port'}{'tcp'} = '1795'	; 
#	$srvcobjects_ref->{'dpi-proxy'}{'ports'}{'tcp'}{'1795'}++	; 
#	$ports_ref->{'tcp'}{'1795'}{'name'} = 'dpi-proxy'		; 
#	$srvcobjects_ref->{'wms-messenger'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wms-messenger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wms-messenger'}{'port'}{'udp'} = '3219'	; 
#	$srvcobjects_ref->{'wms-messenger'}{'ports'}{'udp'}{'3219'}++	; 
#	$ports_ref->{'udp'}{'3219'}{'name'} = 'wms-messenger'		; 
#	$srvcobjects_ref->{'wms-messenger'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wms-messenger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wms-messenger'}{'port'}{'tcp'} = '3219'	; 
#	$srvcobjects_ref->{'wms-messenger'}{'ports'}{'tcp'}{'3219'}++	; 
#	$ports_ref->{'tcp'}{'3219'}{'name'} = 'wms-messenger'		; 
#	$srvcobjects_ref->{'csccfirewall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csccfirewall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csccfirewall'}{'port'}{'udp'} = '40843'	; 
#	$srvcobjects_ref->{'csccfirewall'}{'ports'}{'udp'}{'40843'}++	; 
#	$ports_ref->{'udp'}{'40843'}{'name'} = 'csccfirewall'		; 
#	$srvcobjects_ref->{'csccfirewall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csccfirewall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csccfirewall'}{'port'}{'tcp'} = '40843'	; 
#	$srvcobjects_ref->{'csccfirewall'}{'ports'}{'tcp'}{'40843'}++	; 
#	$ports_ref->{'tcp'}{'40843'}{'name'} = 'csccfirewall'		; 
#	$srvcobjects_ref->{'purenoise'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'purenoise'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'purenoise'}{'port'}{'udp'} = '663'	; 
#	$srvcobjects_ref->{'purenoise'}{'ports'}{'udp'}{'663'}++	; 
#	$ports_ref->{'udp'}{'663'}{'name'} = 'purenoise'		; 
#	$srvcobjects_ref->{'purenoise'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'purenoise'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'purenoise'}{'port'}{'tcp'} = '663'	; 
#	$srvcobjects_ref->{'purenoise'}{'ports'}{'tcp'}{'663'}++	; 
#	$ports_ref->{'tcp'}{'663'}{'name'} = 'purenoise'		; 
#	$srvcobjects_ref->{'srb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'srb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srb'}{'port'}{'udp'} = '6067'	; 
#	$srvcobjects_ref->{'srb'}{'ports'}{'udp'}{'6067'}++	; 
#	$ports_ref->{'udp'}{'6067'}{'name'} = 'srb'		; 
#	$srvcobjects_ref->{'srb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'srb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srb'}{'port'}{'tcp'} = '6067'	; 
#	$srvcobjects_ref->{'srb'}{'ports'}{'tcp'}{'6067'}++	; 
#	$ports_ref->{'tcp'}{'6067'}{'name'} = 'srb'		; 
#	$srvcobjects_ref->{'tapestry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tapestry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tapestry'}{'port'}{'udp'} = '1922'	; 
#	$srvcobjects_ref->{'tapestry'}{'ports'}{'udp'}{'1922'}++	; 
#	$ports_ref->{'udp'}{'1922'}{'name'} = 'tapestry'		; 
#	$srvcobjects_ref->{'tapestry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tapestry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tapestry'}{'port'}{'tcp'} = '1922'	; 
#	$srvcobjects_ref->{'tapestry'}{'ports'}{'tcp'}{'1922'}++	; 
#	$ports_ref->{'tcp'}{'1922'}{'name'} = 'tapestry'		; 
#	$srvcobjects_ref->{'bmc-reporting'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-reporting'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-reporting'}{'port'}{'udp'} = '4568'	; 
#	$srvcobjects_ref->{'bmc-reporting'}{'ports'}{'udp'}{'4568'}++	; 
#	$ports_ref->{'udp'}{'4568'}{'name'} = 'bmc-reporting'		; 
#	$srvcobjects_ref->{'bmc-reporting'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-reporting'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-reporting'}{'port'}{'tcp'} = '4568'	; 
#	$srvcobjects_ref->{'bmc-reporting'}{'ports'}{'tcp'}{'4568'}++	; 
#	$ports_ref->{'tcp'}{'4568'}{'name'} = 'bmc-reporting'		; 
#	$srvcobjects_ref->{'mao'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mao'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mao'}{'port'}{'udp'} = '2908'	; 
#	$srvcobjects_ref->{'mao'}{'ports'}{'udp'}{'2908'}++	; 
#	$ports_ref->{'udp'}{'2908'}{'name'} = 'mao'		; 
#	$srvcobjects_ref->{'mao'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mao'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mao'}{'port'}{'tcp'} = '2908'	; 
#	$srvcobjects_ref->{'mao'}{'ports'}{'tcp'}{'2908'}++	; 
#	$ports_ref->{'tcp'}{'2908'}{'name'} = 'mao'		; 
#	$srvcobjects_ref->{'cft-7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-7'}{'port'}{'udp'} = '1768'	; 
#	$srvcobjects_ref->{'cft-7'}{'ports'}{'udp'}{'1768'}++	; 
#	$ports_ref->{'udp'}{'1768'}{'name'} = 'cft-7'		; 
#	$srvcobjects_ref->{'cft-7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-7'}{'port'}{'tcp'} = '1768'	; 
#	$srvcobjects_ref->{'cft-7'}{'ports'}{'tcp'}{'1768'}++	; 
#	$ports_ref->{'tcp'}{'1768'}{'name'} = 'cft-7'		; 
#	$srvcobjects_ref->{'tns-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tns-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tns-server'}{'port'}{'udp'} = '3308'	; 
#	$srvcobjects_ref->{'tns-server'}{'ports'}{'udp'}{'3308'}++	; 
#	$ports_ref->{'udp'}{'3308'}{'name'} = 'tns-server'		; 
#	$srvcobjects_ref->{'tns-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tns-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tns-server'}{'port'}{'tcp'} = '3308'	; 
#	$srvcobjects_ref->{'tns-server'}{'ports'}{'tcp'}{'3308'}++	; 
#	$ports_ref->{'tcp'}{'3308'}{'name'} = 'tns-server'		; 
#	$srvcobjects_ref->{'mc-client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mc-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-client'}{'port'}{'udp'} = '1180'	; 
#	$srvcobjects_ref->{'mc-client'}{'ports'}{'udp'}{'1180'}++	; 
#	$ports_ref->{'udp'}{'1180'}{'name'} = 'mc-client'		; 
#	$srvcobjects_ref->{'mc-client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mc-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-client'}{'port'}{'tcp'} = '1180'	; 
#	$srvcobjects_ref->{'mc-client'}{'ports'}{'tcp'}{'1180'}++	; 
#	$ports_ref->{'tcp'}{'1180'}{'name'} = 'mc-client'		; 
#	$srvcobjects_ref->{'vqp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vqp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vqp'}{'port'}{'udp'} = '1589'	; 
#	$srvcobjects_ref->{'vqp'}{'ports'}{'udp'}{'1589'}++	; 
#	$ports_ref->{'udp'}{'1589'}{'name'} = 'vqp'		; 
#	$srvcobjects_ref->{'vqp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vqp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vqp'}{'port'}{'tcp'} = '1589'	; 
#	$srvcobjects_ref->{'vqp'}{'ports'}{'tcp'}{'1589'}++	; 
#	$ports_ref->{'tcp'}{'1589'}{'name'} = 'vqp'		; 
#	$srvcobjects_ref->{'maincontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'maincontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maincontrol'}{'port'}{'udp'} = '2516'	; 
#	$srvcobjects_ref->{'maincontrol'}{'ports'}{'udp'}{'2516'}++	; 
#	$ports_ref->{'udp'}{'2516'}{'name'} = 'maincontrol'		; 
#	$srvcobjects_ref->{'maincontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'maincontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maincontrol'}{'port'}{'tcp'} = '2516'	; 
#	$srvcobjects_ref->{'maincontrol'}{'ports'}{'tcp'}{'2516'}++	; 
#	$ports_ref->{'tcp'}{'2516'}{'name'} = 'maincontrol'		; 
#	$srvcobjects_ref->{'boks_servm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boks_servm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks_servm'}{'port'}{'udp'} = '6502'	; 
#	$srvcobjects_ref->{'boks_servm'}{'ports'}{'udp'}{'6502'}++	; 
#	$ports_ref->{'udp'}{'6502'}{'name'} = 'boks_servm'		; 
#	$srvcobjects_ref->{'boks_servm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boks_servm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks_servm'}{'port'}{'tcp'} = '6502'	; 
#	$srvcobjects_ref->{'boks_servm'}{'ports'}{'tcp'}{'6502'}++	; 
#	$ports_ref->{'tcp'}{'6502'}{'name'} = 'boks_servm'		; 
#	$srvcobjects_ref->{'rmopagt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmopagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmopagt'}{'port'}{'udp'} = '2959'	; 
#	$srvcobjects_ref->{'rmopagt'}{'ports'}{'udp'}{'2959'}++	; 
#	$ports_ref->{'udp'}{'2959'}{'name'} = 'rmopagt'		; 
#	$srvcobjects_ref->{'rmopagt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmopagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmopagt'}{'port'}{'tcp'} = '2959'	; 
#	$srvcobjects_ref->{'rmopagt'}{'ports'}{'tcp'}{'2959'}++	; 
#	$ports_ref->{'tcp'}{'2959'}{'name'} = 'rmopagt'		; 
#	$srvcobjects_ref->{'ls3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ls3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ls3'}{'port'}{'udp'} = '3069'	; 
#	$srvcobjects_ref->{'ls3'}{'ports'}{'udp'}{'3069'}++	; 
#	$ports_ref->{'udp'}{'3069'}{'name'} = 'ls3'		; 
#	$srvcobjects_ref->{'ls3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ls3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ls3'}{'port'}{'tcp'} = '3069'	; 
#	$srvcobjects_ref->{'ls3'}{'ports'}{'tcp'}{'3069'}++	; 
#	$ports_ref->{'tcp'}{'3069'}{'name'} = 'ls3'		; 
#	$srvcobjects_ref->{'ansyslmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ansyslmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansyslmd'}{'port'}{'udp'} = '1055'	; 
#	$srvcobjects_ref->{'ansyslmd'}{'ports'}{'udp'}{'1055'}++	; 
#	$ports_ref->{'udp'}{'1055'}{'name'} = 'ansyslmd'		; 
#	$srvcobjects_ref->{'ansyslmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ansyslmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansyslmd'}{'port'}{'tcp'} = '1055'	; 
#	$srvcobjects_ref->{'ansyslmd'}{'ports'}{'tcp'}{'1055'}++	; 
#	$ports_ref->{'tcp'}{'1055'}{'name'} = 'ansyslmd'		; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'port'}{'udp'} = '4003'	; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'ports'}{'udp'}{'4003'}++	; 
#	$ports_ref->{'udp'}{'4003'}{'name'} = 'pxc-splr-ft'		; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'port'}{'tcp'} = '4003'	; 
#	$srvcobjects_ref->{'pxc-splr-ft'}{'ports'}{'tcp'}{'4003'}++	; 
#	$ports_ref->{'tcp'}{'4003'}{'name'} = 'pxc-splr-ft'		; 
#	$srvcobjects_ref->{'uis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uis'}{'port'}{'udp'} = '390'	; 
#	$srvcobjects_ref->{'uis'}{'ports'}{'udp'}{'390'}++	; 
#	$ports_ref->{'udp'}{'390'}{'name'} = 'uis'		; 
#	$srvcobjects_ref->{'uis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uis'}{'port'}{'tcp'} = '390'	; 
#	$srvcobjects_ref->{'uis'}{'ports'}{'tcp'}{'390'}++	; 
#	$ports_ref->{'tcp'}{'390'}{'name'} = 'uis'		; 
#	$srvcobjects_ref->{'watershed-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'watershed-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watershed-lm'}{'port'}{'udp'} = '6143'	; 
#	$srvcobjects_ref->{'watershed-lm'}{'ports'}{'udp'}{'6143'}++	; 
#	$ports_ref->{'udp'}{'6143'}{'name'} = 'watershed-lm'		; 
#	$srvcobjects_ref->{'watershed-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'watershed-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watershed-lm'}{'port'}{'tcp'} = '6143'	; 
#	$srvcobjects_ref->{'watershed-lm'}{'ports'}{'tcp'}{'6143'}++	; 
#	$ports_ref->{'tcp'}{'6143'}{'name'} = 'watershed-lm'		; 
#	$srvcobjects_ref->{'apparenet-tps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apparenet-tps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-tps'}{'port'}{'udp'} = '3237'	; 
#	$srvcobjects_ref->{'apparenet-tps'}{'ports'}{'udp'}{'3237'}++	; 
#	$ports_ref->{'udp'}{'3237'}{'name'} = 'apparenet-tps'		; 
#	$srvcobjects_ref->{'apparenet-tps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apparenet-tps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-tps'}{'port'}{'tcp'} = '3237'	; 
#	$srvcobjects_ref->{'apparenet-tps'}{'ports'}{'tcp'}{'3237'}++	; 
#	$ports_ref->{'tcp'}{'3237'}{'name'} = 'apparenet-tps'		; 
#	$srvcobjects_ref->{'lv-jc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lv-jc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-jc'}{'port'}{'udp'} = '2143'	; 
#	$srvcobjects_ref->{'lv-jc'}{'ports'}{'udp'}{'2143'}++	; 
#	$ports_ref->{'udp'}{'2143'}{'name'} = 'lv-jc'		; 
#	$srvcobjects_ref->{'lv-jc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lv-jc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-jc'}{'port'}{'tcp'} = '2143'	; 
#	$srvcobjects_ref->{'lv-jc'}{'ports'}{'tcp'}{'2143'}++	; 
#	$ports_ref->{'tcp'}{'2143'}{'name'} = 'lv-jc'		; 
#	$srvcobjects_ref->{'raid-sf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raid-sf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-sf'}{'port'}{'udp'} = '2014'	; 
#	$srvcobjects_ref->{'raid-sf'}{'ports'}{'udp'}{'2014'}++	; 
#	$ports_ref->{'udp'}{'2014'}{'name'} = 'raid-sf'		; 
#	$srvcobjects_ref->{'kar2ouche'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kar2ouche'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kar2ouche'}{'port'}{'udp'} = '4661'	; 
#	$srvcobjects_ref->{'kar2ouche'}{'ports'}{'udp'}{'4661'}++	; 
#	$ports_ref->{'udp'}{'4661'}{'name'} = 'kar2ouche'		; 
#	$srvcobjects_ref->{'kar2ouche'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kar2ouche'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kar2ouche'}{'port'}{'tcp'} = '4661'	; 
#	$srvcobjects_ref->{'kar2ouche'}{'ports'}{'tcp'}{'4661'}++	; 
#	$ports_ref->{'tcp'}{'4661'}{'name'} = 'kar2ouche'		; 
#	$srvcobjects_ref->{'sflm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sflm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sflm'}{'port'}{'udp'} = '3162'	; 
#	$srvcobjects_ref->{'sflm'}{'ports'}{'udp'}{'3162'}++	; 
#	$ports_ref->{'udp'}{'3162'}{'name'} = 'sflm'		; 
#	$srvcobjects_ref->{'sflm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sflm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sflm'}{'port'}{'tcp'} = '3162'	; 
#	$srvcobjects_ref->{'sflm'}{'ports'}{'tcp'}{'3162'}++	; 
#	$ports_ref->{'tcp'}{'3162'}{'name'} = 'sflm'		; 
#	$srvcobjects_ref->{'concurrent-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'concurrent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'concurrent-lm'}{'port'}{'udp'} = '1648'	; 
#	$srvcobjects_ref->{'concurrent-lm'}{'ports'}{'udp'}{'1648'}++	; 
#	$ports_ref->{'udp'}{'1648'}{'name'} = 'concurrent-lm'		; 
#	$srvcobjects_ref->{'concurrent-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'concurrent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'concurrent-lm'}{'port'}{'tcp'} = '1648'	; 
#	$srvcobjects_ref->{'concurrent-lm'}{'ports'}{'tcp'}{'1648'}++	; 
#	$ports_ref->{'tcp'}{'1648'}{'name'} = 'concurrent-lm'		; 
#	$srvcobjects_ref->{'rcst'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rcst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rcst'}{'port'}{'udp'} = '3467'	; 
#	$srvcobjects_ref->{'rcst'}{'ports'}{'udp'}{'3467'}++	; 
#	$ports_ref->{'udp'}{'3467'}{'name'} = 'rcst'		; 
#	$srvcobjects_ref->{'rcst'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rcst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rcst'}{'port'}{'tcp'} = '3467'	; 
#	$srvcobjects_ref->{'rcst'}{'ports'}{'tcp'}{'3467'}++	; 
#	$ports_ref->{'tcp'}{'3467'}{'name'} = 'rcst'		; 
#	$srvcobjects_ref->{'datusorb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'datusorb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datusorb'}{'port'}{'udp'} = '3282'	; 
#	$srvcobjects_ref->{'datusorb'}{'ports'}{'udp'}{'3282'}++	; 
#	$ports_ref->{'udp'}{'3282'}{'name'} = 'datusorb'		; 
#	$srvcobjects_ref->{'datusorb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'datusorb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datusorb'}{'port'}{'tcp'} = '3282'	; 
#	$srvcobjects_ref->{'datusorb'}{'ports'}{'tcp'}{'3282'}++	; 
#	$ports_ref->{'tcp'}{'3282'}{'name'} = 'datusorb'		; 
#	$srvcobjects_ref->{'dc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dc'}{'port'}{'tcp'} = '2001'	; 
#	$srvcobjects_ref->{'dc'}{'ports'}{'tcp'}{'2001'}++	; 
#	$ports_ref->{'tcp'}{'2001'}{'name'} = 'dc'		; 
#	$srvcobjects_ref->{'ea1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ea1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ea1'}{'port'}{'udp'} = '1791'	; 
#	$srvcobjects_ref->{'ea1'}{'ports'}{'udp'}{'1791'}++	; 
#	$ports_ref->{'udp'}{'1791'}{'name'} = 'ea1'		; 
#	$srvcobjects_ref->{'ea1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ea1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ea1'}{'port'}{'tcp'} = '1791'	; 
#	$srvcobjects_ref->{'ea1'}{'ports'}{'tcp'}{'1791'}++	; 
#	$ports_ref->{'tcp'}{'1791'}{'name'} = 'ea1'		; 
#	$srvcobjects_ref->{'entrust-sps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entrust-sps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-sps'}{'port'}{'udp'} = '640'	; 
#	$srvcobjects_ref->{'entrust-sps'}{'ports'}{'udp'}{'640'}++	; 
#	$ports_ref->{'udp'}{'640'}{'name'} = 'entrust-sps'		; 
#	$srvcobjects_ref->{'entrust-sps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entrust-sps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-sps'}{'port'}{'tcp'} = '640'	; 
#	$srvcobjects_ref->{'entrust-sps'}{'ports'}{'tcp'}{'640'}++	; 
#	$ports_ref->{'tcp'}{'640'}{'name'} = 'entrust-sps'		; 
#	$srvcobjects_ref->{'na-er-tip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'na-er-tip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'na-er-tip'}{'port'}{'udp'} = '3725'	; 
#	$srvcobjects_ref->{'na-er-tip'}{'ports'}{'udp'}{'3725'}++	; 
#	$ports_ref->{'udp'}{'3725'}{'name'} = 'na-er-tip'		; 
#	$srvcobjects_ref->{'na-er-tip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'na-er-tip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'na-er-tip'}{'port'}{'tcp'} = '3725'	; 
#	$srvcobjects_ref->{'na-er-tip'}{'ports'}{'tcp'}{'3725'}++	; 
#	$ports_ref->{'tcp'}{'3725'}{'name'} = 'na-er-tip'		; 
#	$srvcobjects_ref->{'houdini-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'houdini-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'houdini-lm'}{'port'}{'udp'} = '1715'	; 
#	$srvcobjects_ref->{'houdini-lm'}{'ports'}{'udp'}{'1715'}++	; 
#	$ports_ref->{'udp'}{'1715'}{'name'} = 'houdini-lm'		; 
#	$srvcobjects_ref->{'houdini-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'houdini-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'houdini-lm'}{'port'}{'tcp'} = '1715'	; 
#	$srvcobjects_ref->{'houdini-lm'}{'ports'}{'tcp'}{'1715'}++	; 
#	$ports_ref->{'tcp'}{'1715'}{'name'} = 'houdini-lm'		; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'port'}{'udp'} = '2577'	; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'ports'}{'udp'}{'2577'}++	; 
#	$ports_ref->{'udp'}{'2577'}{'name'} = 'scipticslsrvr'		; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'port'}{'tcp'} = '2577'	; 
#	$srvcobjects_ref->{'scipticslsrvr'}{'ports'}{'tcp'}{'2577'}++	; 
#	$ports_ref->{'tcp'}{'2577'}{'name'} = 'scipticslsrvr'		; 
#	$srvcobjects_ref->{'m2ua'}{'type'} = 'sctp'	; 
#	$srvcobjects_ref->{'m2ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m2ua'}{'port'}{'sctp'} = '2904'	; 
#	$srvcobjects_ref->{'m2ua'}{'ports'}{'sctp'}{'2904'}++	; 
#	$ports_ref->{'sctp'}{'2904'}{'name'} = 'm2ua'		; 
#	$srvcobjects_ref->{'m2ua'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'m2ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m2ua'}{'port'}{'udp'} = '2904'	; 
#	$srvcobjects_ref->{'m2ua'}{'ports'}{'udp'}{'2904'}++	; 
#	$ports_ref->{'udp'}{'2904'}{'name'} = 'm2ua'		; 
#	$srvcobjects_ref->{'m2ua'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'m2ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m2ua'}{'port'}{'tcp'} = '2904'	; 
#	$srvcobjects_ref->{'m2ua'}{'ports'}{'tcp'}{'2904'}++	; 
#	$ports_ref->{'tcp'}{'2904'}{'name'} = 'm2ua'		; 
#	$srvcobjects_ref->{'pctrader'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pctrader'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pctrader'}{'port'}{'udp'} = '3048'	; 
#	$srvcobjects_ref->{'pctrader'}{'ports'}{'udp'}{'3048'}++	; 
#	$ports_ref->{'udp'}{'3048'}{'name'} = 'pctrader'		; 
#	$srvcobjects_ref->{'pctrader'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pctrader'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pctrader'}{'port'}{'tcp'} = '3048'	; 
#	$srvcobjects_ref->{'pctrader'}{'ports'}{'tcp'}{'3048'}++	; 
#	$ports_ref->{'tcp'}{'3048'}{'name'} = 'pctrader'		; 
#	$srvcobjects_ref->{'ca-idms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ca-idms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ca-idms'}{'port'}{'udp'} = '3709'	; 
#	$srvcobjects_ref->{'ca-idms'}{'ports'}{'udp'}{'3709'}++	; 
#	$ports_ref->{'udp'}{'3709'}{'name'} = 'ca-idms'		; 
#	$srvcobjects_ref->{'ca-idms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ca-idms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ca-idms'}{'port'}{'tcp'} = '3709'	; 
#	$srvcobjects_ref->{'ca-idms'}{'ports'}{'tcp'}{'3709'}++	; 
#	$ports_ref->{'tcp'}{'3709'}{'name'} = 'ca-idms'		; 
#	$srvcobjects_ref->{'ergolight'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ergolight'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ergolight'}{'port'}{'udp'} = '2109'	; 
#	$srvcobjects_ref->{'ergolight'}{'ports'}{'udp'}{'2109'}++	; 
#	$ports_ref->{'udp'}{'2109'}{'name'} = 'ergolight'		; 
#	$srvcobjects_ref->{'ergolight'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ergolight'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ergolight'}{'port'}{'tcp'} = '2109'	; 
#	$srvcobjects_ref->{'ergolight'}{'ports'}{'tcp'}{'2109'}++	; 
#	$ports_ref->{'tcp'}{'2109'}{'name'} = 'ergolight'		; 
#	$srvcobjects_ref->{'svnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'svnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svnet'}{'port'}{'udp'} = '3413'	; 
#	$srvcobjects_ref->{'svnet'}{'ports'}{'udp'}{'3413'}++	; 
#	$ports_ref->{'udp'}{'3413'}{'name'} = 'svnet'		; 
#	$srvcobjects_ref->{'svnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'svnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svnet'}{'port'}{'tcp'} = '3413'	; 
#	$srvcobjects_ref->{'svnet'}{'ports'}{'tcp'}{'3413'}++	; 
#	$ports_ref->{'tcp'}{'3413'}{'name'} = 'svnet'		; 
#	$srvcobjects_ref->{'efs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'efs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'efs'}{'port'}{'tcp'} = '520'	; 
#	$srvcobjects_ref->{'efs'}{'ports'}{'tcp'}{'520'}++	; 
#	$ports_ref->{'tcp'}{'520'}{'name'} = 'efs'		; 
#	$srvcobjects_ref->{'dhcp-failover'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dhcp-failover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcp-failover'}{'port'}{'udp'} = '647'	; 
#	$srvcobjects_ref->{'dhcp-failover'}{'ports'}{'udp'}{'647'}++	; 
#	$ports_ref->{'udp'}{'647'}{'name'} = 'dhcp-failover'		; 
#	$srvcobjects_ref->{'dhcp-failover'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dhcp-failover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcp-failover'}{'port'}{'tcp'} = '647'	; 
#	$srvcobjects_ref->{'dhcp-failover'}{'ports'}{'tcp'}{'647'}++	; 
#	$ports_ref->{'tcp'}{'647'}{'name'} = 'dhcp-failover'		; 
#	$srvcobjects_ref->{'search-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'search-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'search-agent'}{'port'}{'udp'} = '1234'	; 
#	$srvcobjects_ref->{'search-agent'}{'ports'}{'udp'}{'1234'}++	; 
#	$ports_ref->{'udp'}{'1234'}{'name'} = 'search-agent'		; 
#	$srvcobjects_ref->{'search-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'search-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'search-agent'}{'port'}{'tcp'} = '1234'	; 
#	$srvcobjects_ref->{'search-agent'}{'ports'}{'tcp'}{'1234'}++	; 
#	$ports_ref->{'tcp'}{'1234'}{'name'} = 'search-agent'		; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'port'}{'udp'} = '5968'	; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'ports'}{'udp'}{'5968'}++	; 
#	$ports_ref->{'udp'}{'5968'}{'name'} = 'mppolicy-v5'		; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'port'}{'tcp'} = '5968'	; 
#	$srvcobjects_ref->{'mppolicy-v5'}{'ports'}{'tcp'}{'5968'}++	; 
#	$ports_ref->{'tcp'}{'5968'}{'name'} = 'mppolicy-v5'		; 
#	$srvcobjects_ref->{'nmsigport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmsigport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsigport'}{'port'}{'udp'} = '2839'	; 
#	$srvcobjects_ref->{'nmsigport'}{'ports'}{'udp'}{'2839'}++	; 
#	$ports_ref->{'udp'}{'2839'}{'name'} = 'nmsigport'		; 
#	$srvcobjects_ref->{'nmsigport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmsigport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsigport'}{'port'}{'udp'} = '2817'	; 
#	$srvcobjects_ref->{'nmsigport'}{'ports'}{'udp'}{'2817'}++	; 
#	$ports_ref->{'udp'}{'2817'}{'name'} = 'nmsigport'		; 
#	$srvcobjects_ref->{'nmsigport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmsigport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsigport'}{'port'}{'tcp'} = '2839'	; 
#	$srvcobjects_ref->{'nmsigport'}{'ports'}{'tcp'}{'2839'}++	; 
#	$ports_ref->{'tcp'}{'2839'}{'name'} = 'nmsigport'		; 
#	$srvcobjects_ref->{'nmsigport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmsigport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsigport'}{'port'}{'tcp'} = '2817'	; 
#	$srvcobjects_ref->{'nmsigport'}{'ports'}{'tcp'}{'2817'}++	; 
#	$ports_ref->{'tcp'}{'2817'}{'name'} = 'nmsigport'		; 
#	$srvcobjects_ref->{'bbn-mmc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bbn-mmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bbn-mmc'}{'port'}{'udp'} = '1347'	; 
#	$srvcobjects_ref->{'bbn-mmc'}{'ports'}{'udp'}{'1347'}++	; 
#	$ports_ref->{'udp'}{'1347'}{'name'} = 'bbn-mmc'		; 
#	$srvcobjects_ref->{'bbn-mmc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bbn-mmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bbn-mmc'}{'port'}{'tcp'} = '1347'	; 
#	$srvcobjects_ref->{'bbn-mmc'}{'ports'}{'tcp'}{'1347'}++	; 
#	$ports_ref->{'tcp'}{'1347'}{'name'} = 'bbn-mmc'		; 
#	$srvcobjects_ref->{'dmidi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dmidi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmidi'}{'port'}{'udp'} = '1199'	; 
#	$srvcobjects_ref->{'dmidi'}{'ports'}{'udp'}{'1199'}++	; 
#	$ports_ref->{'udp'}{'1199'}{'name'} = 'dmidi'		; 
#	$srvcobjects_ref->{'dmidi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dmidi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmidi'}{'port'}{'tcp'} = '1199'	; 
#	$srvcobjects_ref->{'dmidi'}{'ports'}{'tcp'}{'1199'}++	; 
#	$ports_ref->{'tcp'}{'1199'}{'name'} = 'dmidi'		; 
#	$srvcobjects_ref->{'chargen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chargen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chargen'}{'port'}{'udp'} = '19'	; 
#	$srvcobjects_ref->{'chargen'}{'ports'}{'udp'}{'19'}++	; 
#	$ports_ref->{'udp'}{'19'}{'name'} = 'chargen'		; 
#	$srvcobjects_ref->{'chargen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chargen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chargen'}{'port'}{'tcp'} = '19'	; 
#	$srvcobjects_ref->{'chargen'}{'ports'}{'tcp'}{'19'}++	; 
#	$ports_ref->{'tcp'}{'19'}{'name'} = 'chargen'		; 
#	$srvcobjects_ref->{'xvttp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xvttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xvttp'}{'port'}{'udp'} = '508'	; 
#	$srvcobjects_ref->{'xvttp'}{'ports'}{'udp'}{'508'}++	; 
#	$ports_ref->{'udp'}{'508'}{'name'} = 'xvttp'		; 
#	$srvcobjects_ref->{'xvttp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xvttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xvttp'}{'port'}{'tcp'} = '508'	; 
#	$srvcobjects_ref->{'xvttp'}{'ports'}{'tcp'}{'508'}++	; 
#	$ports_ref->{'tcp'}{'508'}{'name'} = 'xvttp'		; 
#	$srvcobjects_ref->{'dashpas-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dashpas-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dashpas-port'}{'port'}{'udp'} = '3498'	; 
#	$srvcobjects_ref->{'dashpas-port'}{'ports'}{'udp'}{'3498'}++	; 
#	$ports_ref->{'udp'}{'3498'}{'name'} = 'dashpas-port'		; 
#	$srvcobjects_ref->{'dashpas-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dashpas-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dashpas-port'}{'port'}{'tcp'} = '3498'	; 
#	$srvcobjects_ref->{'dashpas-port'}{'ports'}{'tcp'}{'3498'}++	; 
#	$ports_ref->{'tcp'}{'3498'}{'name'} = 'dashpas-port'		; 
#	$srvcobjects_ref->{'ddi-tcp-6'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddi-tcp-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-tcp-6'}{'port'}{'tcp'} = '8893'	; 
#	$srvcobjects_ref->{'ddi-tcp-6'}{'ports'}{'tcp'}{'8893'}++	; 
#	$ports_ref->{'tcp'}{'8893'}{'name'} = 'ddi-tcp-6'		; 
#	$srvcobjects_ref->{'indx-dds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'indx-dds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indx-dds'}{'port'}{'udp'} = '2454'	; 
#	$srvcobjects_ref->{'indx-dds'}{'ports'}{'udp'}{'2454'}++	; 
#	$ports_ref->{'udp'}{'2454'}{'name'} = 'indx-dds'		; 
#	$srvcobjects_ref->{'indx-dds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'indx-dds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indx-dds'}{'port'}{'tcp'} = '2454'	; 
#	$srvcobjects_ref->{'indx-dds'}{'ports'}{'tcp'}{'2454'}++	; 
#	$ports_ref->{'tcp'}{'2454'}{'name'} = 'indx-dds'		; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'port'}{'udp'} = '2554'	; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'ports'}{'udp'}{'2554'}++	; 
#	$ports_ref->{'udp'}{'2554'}{'name'} = 'vcnet-link-v10'		; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'port'}{'tcp'} = '2554'	; 
#	$srvcobjects_ref->{'vcnet-link-v10'}{'ports'}{'tcp'}{'2554'}++	; 
#	$ports_ref->{'tcp'}{'2554'}{'name'} = 'vcnet-link-v10'		; 
#	$srvcobjects_ref->{'bcinameservice'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bcinameservice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bcinameservice'}{'port'}{'udp'} = '3415'	; 
#	$srvcobjects_ref->{'bcinameservice'}{'ports'}{'udp'}{'3415'}++	; 
#	$ports_ref->{'udp'}{'3415'}{'name'} = 'bcinameservice'		; 
#	$srvcobjects_ref->{'bcinameservice'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bcinameservice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bcinameservice'}{'port'}{'tcp'} = '3415'	; 
#	$srvcobjects_ref->{'bcinameservice'}{'ports'}{'tcp'}{'3415'}++	; 
#	$ports_ref->{'tcp'}{'3415'}{'name'} = 'bcinameservice'		; 
#	$srvcobjects_ref->{'menandmice-dns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'menandmice-dns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'menandmice-dns'}{'port'}{'udp'} = '1337'	; 
#	$srvcobjects_ref->{'menandmice-dns'}{'ports'}{'udp'}{'1337'}++	; 
#	$ports_ref->{'udp'}{'1337'}{'name'} = 'menandmice-dns'		; 
#	$srvcobjects_ref->{'menandmice-dns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'menandmice-dns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'menandmice-dns'}{'port'}{'tcp'} = '1337'	; 
#	$srvcobjects_ref->{'menandmice-dns'}{'ports'}{'tcp'}{'1337'}++	; 
#	$ports_ref->{'tcp'}{'1337'}{'name'} = 'menandmice-dns'		; 
#	$srvcobjects_ref->{'twcss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'twcss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'twcss'}{'port'}{'udp'} = '3428'	; 
#	$srvcobjects_ref->{'twcss'}{'ports'}{'udp'}{'3428'}++	; 
#	$ports_ref->{'udp'}{'3428'}{'name'} = 'twcss'		; 
#	$srvcobjects_ref->{'twcss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'twcss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'twcss'}{'port'}{'tcp'} = '3428'	; 
#	$srvcobjects_ref->{'twcss'}{'ports'}{'tcp'}{'3428'}++	; 
#	$ports_ref->{'tcp'}{'3428'}{'name'} = 'twcss'		; 
#	$srvcobjects_ref->{'primaserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'primaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'primaserver'}{'port'}{'udp'} = '6105'	; 
#	$srvcobjects_ref->{'primaserver'}{'ports'}{'udp'}{'6105'}++	; 
#	$ports_ref->{'udp'}{'6105'}{'name'} = 'primaserver'		; 
#	$srvcobjects_ref->{'primaserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'primaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'primaserver'}{'port'}{'tcp'} = '6105'	; 
#	$srvcobjects_ref->{'primaserver'}{'ports'}{'tcp'}{'6105'}++	; 
#	$ports_ref->{'tcp'}{'6105'}{'name'} = 'primaserver'		; 
#	$srvcobjects_ref->{'lockstep'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lockstep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lockstep'}{'port'}{'udp'} = '2125'	; 
#	$srvcobjects_ref->{'lockstep'}{'ports'}{'udp'}{'2125'}++	; 
#	$ports_ref->{'udp'}{'2125'}{'name'} = 'lockstep'		; 
#	$srvcobjects_ref->{'lockstep'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lockstep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lockstep'}{'port'}{'tcp'} = '2125'	; 
#	$srvcobjects_ref->{'lockstep'}{'ports'}{'tcp'}{'2125'}++	; 
#	$ports_ref->{'tcp'}{'2125'}{'name'} = 'lockstep'		; 
#	$srvcobjects_ref->{'talon-webserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talon-webserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talon-webserver'}{'port'}{'udp'} = '7015'	; 
#	$srvcobjects_ref->{'talon-webserver'}{'ports'}{'udp'}{'7015'}++	; 
#	$ports_ref->{'udp'}{'7015'}{'name'} = 'talon-webserver'		; 
#	$srvcobjects_ref->{'talon-webserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talon-webserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talon-webserver'}{'port'}{'tcp'} = '7015'	; 
#	$srvcobjects_ref->{'talon-webserver'}{'ports'}{'tcp'}{'7015'}++	; 
#	$ports_ref->{'tcp'}{'7015'}{'name'} = 'talon-webserver'		; 
#	$srvcobjects_ref->{'armtechdaemon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'armtechdaemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'armtechdaemon'}{'port'}{'udp'} = '9292'	; 
#	$srvcobjects_ref->{'armtechdaemon'}{'ports'}{'udp'}{'9292'}++	; 
#	$ports_ref->{'udp'}{'9292'}{'name'} = 'armtechdaemon'		; 
#	$srvcobjects_ref->{'armtechdaemon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'armtechdaemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'armtechdaemon'}{'port'}{'tcp'} = '9292'	; 
#	$srvcobjects_ref->{'armtechdaemon'}{'ports'}{'tcp'}{'9292'}++	; 
#	$ports_ref->{'tcp'}{'9292'}{'name'} = 'armtechdaemon'		; 
#	$srvcobjects_ref->{'global-dtserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'global-dtserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'global-dtserv'}{'port'}{'udp'} = '1774'	; 
#	$srvcobjects_ref->{'global-dtserv'}{'ports'}{'udp'}{'1774'}++	; 
#	$ports_ref->{'udp'}{'1774'}{'name'} = 'global-dtserv'		; 
#	$srvcobjects_ref->{'global-dtserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'global-dtserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'global-dtserv'}{'port'}{'tcp'} = '1774'	; 
#	$srvcobjects_ref->{'global-dtserv'}{'ports'}{'tcp'}{'1774'}++	; 
#	$ports_ref->{'tcp'}{'1774'}{'name'} = 'global-dtserv'		; 
#	$srvcobjects_ref->{'td-replica'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'td-replica'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'td-replica'}{'port'}{'udp'} = '268'	; 
#	$srvcobjects_ref->{'td-replica'}{'ports'}{'udp'}{'268'}++	; 
#	$ports_ref->{'udp'}{'268'}{'name'} = 'td-replica'		; 
#	$srvcobjects_ref->{'td-replica'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'td-replica'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'td-replica'}{'port'}{'tcp'} = '268'	; 
#	$srvcobjects_ref->{'td-replica'}{'ports'}{'tcp'}{'268'}++	; 
#	$ports_ref->{'tcp'}{'268'}{'name'} = 'td-replica'		; 
#	$srvcobjects_ref->{'cmc-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cmc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmc-port'}{'port'}{'udp'} = '3576'	; 
#	$srvcobjects_ref->{'cmc-port'}{'ports'}{'udp'}{'3576'}++	; 
#	$ports_ref->{'udp'}{'3576'}{'name'} = 'cmc-port'		; 
#	$srvcobjects_ref->{'cmc-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cmc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmc-port'}{'port'}{'tcp'} = '3576'	; 
#	$srvcobjects_ref->{'cmc-port'}{'ports'}{'tcp'}{'3576'}++	; 
#	$ports_ref->{'tcp'}{'3576'}{'name'} = 'cmc-port'		; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'port'}{'udp'} = '3214'	; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'ports'}{'udp'}{'3214'}++	; 
#	$ports_ref->{'udp'}{'3214'}{'name'} = 'jmq-daemon-1'		; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'port'}{'tcp'} = '3214'	; 
#	$srvcobjects_ref->{'jmq-daemon-1'}{'ports'}{'tcp'}{'3214'}++	; 
#	$ports_ref->{'tcp'}{'3214'}{'name'} = 'jmq-daemon-1'		; 
#	$srvcobjects_ref->{'esimport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esimport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esimport'}{'port'}{'udp'} = '3564'	; 
#	$srvcobjects_ref->{'esimport'}{'ports'}{'udp'}{'3564'}++	; 
#	$ports_ref->{'udp'}{'3564'}{'name'} = 'esimport'		; 
#	$srvcobjects_ref->{'esimport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esimport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esimport'}{'port'}{'tcp'} = '3564'	; 
#	$srvcobjects_ref->{'esimport'}{'ports'}{'tcp'}{'3564'}++	; 
#	$ports_ref->{'tcp'}{'3564'}{'name'} = 'esimport'		; 
#	$srvcobjects_ref->{'winjaserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'winjaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winjaserver'}{'port'}{'udp'} = '1290'	; 
#	$srvcobjects_ref->{'winjaserver'}{'ports'}{'udp'}{'1290'}++	; 
#	$ports_ref->{'udp'}{'1290'}{'name'} = 'winjaserver'		; 
#	$srvcobjects_ref->{'winjaserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'winjaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winjaserver'}{'port'}{'tcp'} = '1290'	; 
#	$srvcobjects_ref->{'winjaserver'}{'ports'}{'tcp'}{'1290'}++	; 
#	$ports_ref->{'tcp'}{'1290'}{'name'} = 'winjaserver'		; 
#	$srvcobjects_ref->{'catchpole'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'catchpole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'catchpole'}{'port'}{'udp'} = '1185'	; 
#	$srvcobjects_ref->{'catchpole'}{'ports'}{'udp'}{'1185'}++	; 
#	$ports_ref->{'udp'}{'1185'}{'name'} = 'catchpole'		; 
#	$srvcobjects_ref->{'catchpole'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'catchpole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'catchpole'}{'port'}{'tcp'} = '1185'	; 
#	$srvcobjects_ref->{'catchpole'}{'ports'}{'tcp'}{'1185'}++	; 
#	$ports_ref->{'tcp'}{'1185'}{'name'} = 'catchpole'		; 
#	$srvcobjects_ref->{'joltid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'joltid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'joltid'}{'port'}{'udp'} = '3531'	; 
#	$srvcobjects_ref->{'joltid'}{'ports'}{'udp'}{'3531'}++	; 
#	$ports_ref->{'udp'}{'3531'}{'name'} = 'joltid'		; 
#	$srvcobjects_ref->{'joltid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'joltid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'joltid'}{'port'}{'tcp'} = '3531'	; 
#	$srvcobjects_ref->{'joltid'}{'ports'}{'tcp'}{'3531'}++	; 
#	$ports_ref->{'tcp'}{'3531'}{'name'} = 'joltid'		; 
#	$srvcobjects_ref->{'sdfunc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdfunc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdfunc'}{'port'}{'udp'} = '2046'	; 
#	$srvcobjects_ref->{'sdfunc'}{'ports'}{'udp'}{'2046'}++	; 
#	$ports_ref->{'udp'}{'2046'}{'name'} = 'sdfunc'		; 
#	$srvcobjects_ref->{'sdfunc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdfunc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdfunc'}{'port'}{'tcp'} = '2046'	; 
#	$srvcobjects_ref->{'sdfunc'}{'ports'}{'tcp'}{'2046'}++	; 
#	$ports_ref->{'tcp'}{'2046'}{'name'} = 'sdfunc'		; 
#	$srvcobjects_ref->{'spc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spc'}{'port'}{'udp'} = '6111'	; 
#	$srvcobjects_ref->{'spc'}{'ports'}{'udp'}{'6111'}++	; 
#	$ports_ref->{'udp'}{'6111'}{'name'} = 'spc'		; 
#	$srvcobjects_ref->{'spc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spc'}{'port'}{'tcp'} = '6111'	; 
#	$srvcobjects_ref->{'spc'}{'ports'}{'tcp'}{'6111'}++	; 
#	$ports_ref->{'tcp'}{'6111'}{'name'} = 'spc'		; 
#	$srvcobjects_ref->{'nms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nms'}{'port'}{'udp'} = '1429'	; 
#	$srvcobjects_ref->{'nms'}{'ports'}{'udp'}{'1429'}++	; 
#	$ports_ref->{'udp'}{'1429'}{'name'} = 'nms'		; 
#	$srvcobjects_ref->{'nms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nms'}{'port'}{'tcp'} = '1429'	; 
#	$srvcobjects_ref->{'nms'}{'ports'}{'tcp'}{'1429'}++	; 
#	$ports_ref->{'tcp'}{'1429'}{'name'} = 'nms'		; 
#	$srvcobjects_ref->{'imagepump'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imagepump'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imagepump'}{'port'}{'udp'} = '27345'	; 
#	$srvcobjects_ref->{'imagepump'}{'ports'}{'udp'}{'27345'}++	; 
#	$ports_ref->{'udp'}{'27345'}{'name'} = 'imagepump'		; 
#	$srvcobjects_ref->{'imagepump'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imagepump'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imagepump'}{'port'}{'tcp'} = '27345'	; 
#	$srvcobjects_ref->{'imagepump'}{'ports'}{'tcp'}{'27345'}++	; 
#	$ports_ref->{'tcp'}{'27345'}{'name'} = 'imagepump'		; 
#	$srvcobjects_ref->{'business'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'business'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'business'}{'port'}{'udp'} = '3107'	; 
#	$srvcobjects_ref->{'business'}{'ports'}{'udp'}{'3107'}++	; 
#	$ports_ref->{'udp'}{'3107'}{'name'} = 'business'		; 
#	$srvcobjects_ref->{'business'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'business'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'business'}{'port'}{'tcp'} = '3107'	; 
#	$srvcobjects_ref->{'business'}{'ports'}{'tcp'}{'3107'}++	; 
#	$ports_ref->{'tcp'}{'3107'}{'name'} = 'business'		; 
#	$srvcobjects_ref->{'npmp-local'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'npmp-local'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp-local'}{'port'}{'udp'} = '610'	; 
#	$srvcobjects_ref->{'npmp-local'}{'ports'}{'udp'}{'610'}++	; 
#	$ports_ref->{'udp'}{'610'}{'name'} = 'npmp-local'		; 
#	$srvcobjects_ref->{'npmp-local'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'npmp-local'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp-local'}{'port'}{'tcp'} = '610'	; 
#	$srvcobjects_ref->{'npmp-local'}{'ports'}{'tcp'}{'610'}++	; 
#	$ports_ref->{'tcp'}{'610'}{'name'} = 'npmp-local'		; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'port'}{'udp'} = '195'	; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'ports'}{'udp'}{'195'}++	; 
#	$ports_ref->{'udp'}{'195'}{'name'} = 'dn6-nlm-aud'		; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'port'}{'tcp'} = '195'	; 
#	$srvcobjects_ref->{'dn6-nlm-aud'}{'ports'}{'tcp'}{'195'}++	; 
#	$ports_ref->{'tcp'}{'195'}{'name'} = 'dn6-nlm-aud'		; 
#	$srvcobjects_ref->{'varadero-0'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'varadero-0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'varadero-0'}{'port'}{'udp'} = '4837'	; 
#	$srvcobjects_ref->{'varadero-0'}{'ports'}{'udp'}{'4837'}++	; 
#	$ports_ref->{'udp'}{'4837'}{'name'} = 'varadero-0'		; 
#	$srvcobjects_ref->{'varadero-0'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'varadero-0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'varadero-0'}{'port'}{'tcp'} = '4837'	; 
#	$srvcobjects_ref->{'varadero-0'}{'ports'}{'tcp'}{'4837'}++	; 
#	$ports_ref->{'tcp'}{'4837'}{'name'} = 'varadero-0'		; 
#	$srvcobjects_ref->{'tempest-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tempest-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tempest-port'}{'port'}{'udp'} = '11600'	; 
#	$srvcobjects_ref->{'tempest-port'}{'ports'}{'udp'}{'11600'}++	; 
#	$ports_ref->{'udp'}{'11600'}{'name'} = 'tempest-port'		; 
#	$srvcobjects_ref->{'tempest-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tempest-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tempest-port'}{'port'}{'tcp'} = '11600'	; 
#	$srvcobjects_ref->{'tempest-port'}{'ports'}{'tcp'}{'11600'}++	; 
#	$ports_ref->{'tcp'}{'11600'}{'name'} = 'tempest-port'		; 
#	$srvcobjects_ref->{'tftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tftp'}{'port'}{'udp'} = '69'	; 
#	$srvcobjects_ref->{'tftp'}{'ports'}{'udp'}{'69'}++	; 
#	$ports_ref->{'udp'}{'69'}{'name'} = 'tftp'		; 
#	$srvcobjects_ref->{'tftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tftp'}{'port'}{'tcp'} = '69'	; 
#	$srvcobjects_ref->{'tftp'}{'ports'}{'tcp'}{'69'}++	; 
#	$ports_ref->{'tcp'}{'69'}{'name'} = 'tftp'		; 
#	$srvcobjects_ref->{'gnutella-svc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gnutella-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gnutella-svc'}{'port'}{'udp'} = '6346'	; 
#	$srvcobjects_ref->{'gnutella-svc'}{'ports'}{'udp'}{'6346'}++	; 
#	$ports_ref->{'udp'}{'6346'}{'name'} = 'gnutella-svc'		; 
#	$srvcobjects_ref->{'gnutella-svc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gnutella-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gnutella-svc'}{'port'}{'tcp'} = '6346'	; 
#	$srvcobjects_ref->{'gnutella-svc'}{'ports'}{'tcp'}{'6346'}++	; 
#	$ports_ref->{'tcp'}{'6346'}{'name'} = 'gnutella-svc'		; 
#	$srvcobjects_ref->{'ultraseek-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ultraseek-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultraseek-http'}{'port'}{'udp'} = '8765'	; 
#	$srvcobjects_ref->{'ultraseek-http'}{'ports'}{'udp'}{'8765'}++	; 
#	$ports_ref->{'udp'}{'8765'}{'name'} = 'ultraseek-http'		; 
#	$srvcobjects_ref->{'ultraseek-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ultraseek-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultraseek-http'}{'port'}{'tcp'} = '8765'	; 
#	$srvcobjects_ref->{'ultraseek-http'}{'ports'}{'tcp'}{'8765'}++	; 
#	$ports_ref->{'tcp'}{'8765'}{'name'} = 'ultraseek-http'		; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'port'}{'udp'} = '3529'	; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'ports'}{'udp'}{'3529'}++	; 
#	$ports_ref->{'udp'}{'3529'}{'name'} = 'jboss-iiop-ssl'		; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'port'}{'tcp'} = '3529'	; 
#	$srvcobjects_ref->{'jboss-iiop-ssl'}{'ports'}{'tcp'}{'3529'}++	; 
#	$ports_ref->{'tcp'}{'3529'}{'name'} = 'jboss-iiop-ssl'		; 
#	$srvcobjects_ref->{'inspect'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'inspect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'inspect'}{'port'}{'udp'} = '1602'	; 
#	$srvcobjects_ref->{'inspect'}{'ports'}{'udp'}{'1602'}++	; 
#	$ports_ref->{'udp'}{'1602'}{'name'} = 'inspect'		; 
#	$srvcobjects_ref->{'inspect'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'inspect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'inspect'}{'port'}{'tcp'} = '1602'	; 
#	$srvcobjects_ref->{'inspect'}{'ports'}{'tcp'}{'1602'}++	; 
#	$ports_ref->{'tcp'}{'1602'}{'name'} = 'inspect'		; 
#	$srvcobjects_ref->{'scpi-raw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scpi-raw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scpi-raw'}{'port'}{'udp'} = '5025'	; 
#	$srvcobjects_ref->{'scpi-raw'}{'ports'}{'udp'}{'5025'}++	; 
#	$ports_ref->{'udp'}{'5025'}{'name'} = 'scpi-raw'		; 
#	$srvcobjects_ref->{'scpi-raw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scpi-raw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scpi-raw'}{'port'}{'tcp'} = '5025'	; 
#	$srvcobjects_ref->{'scpi-raw'}{'ports'}{'tcp'}{'5025'}++	; 
#	$ports_ref->{'tcp'}{'5025'}{'name'} = 'scpi-raw'		; 
#	$srvcobjects_ref->{'nerv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nerv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nerv'}{'port'}{'udp'} = '1222'	; 
#	$srvcobjects_ref->{'nerv'}{'ports'}{'udp'}{'1222'}++	; 
#	$ports_ref->{'udp'}{'1222'}{'name'} = 'nerv'		; 
#	$srvcobjects_ref->{'nerv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nerv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nerv'}{'port'}{'tcp'} = '1222'	; 
#	$srvcobjects_ref->{'nerv'}{'ports'}{'tcp'}{'1222'}++	; 
#	$ports_ref->{'tcp'}{'1222'}{'name'} = 'nerv'		; 
#	$srvcobjects_ref->{'gsakmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gsakmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsakmp'}{'port'}{'udp'} = '3761'	; 
#	$srvcobjects_ref->{'gsakmp'}{'ports'}{'udp'}{'3761'}++	; 
#	$ports_ref->{'udp'}{'3761'}{'name'} = 'gsakmp'		; 
#	$srvcobjects_ref->{'gsakmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gsakmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsakmp'}{'port'}{'tcp'} = '3761'	; 
#	$srvcobjects_ref->{'gsakmp'}{'ports'}{'tcp'}{'3761'}++	; 
#	$ports_ref->{'tcp'}{'3761'}{'name'} = 'gsakmp'		; 
#	$srvcobjects_ref->{'recipe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'recipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'recipe'}{'port'}{'udp'} = '2240'	; 
#	$srvcobjects_ref->{'recipe'}{'ports'}{'udp'}{'2240'}++	; 
#	$ports_ref->{'udp'}{'2240'}{'name'} = 'recipe'		; 
#	$srvcobjects_ref->{'recipe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'recipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'recipe'}{'port'}{'tcp'} = '2240'	; 
#	$srvcobjects_ref->{'recipe'}{'ports'}{'tcp'}{'2240'}++	; 
#	$ports_ref->{'tcp'}{'2240'}{'name'} = 'recipe'		; 
#	$srvcobjects_ref->{'mcagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcagent'}{'port'}{'udp'} = '1820'	; 
#	$srvcobjects_ref->{'mcagent'}{'ports'}{'udp'}{'1820'}++	; 
#	$ports_ref->{'udp'}{'1820'}{'name'} = 'mcagent'		; 
#	$srvcobjects_ref->{'mcagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcagent'}{'port'}{'tcp'} = '1820'	; 
#	$srvcobjects_ref->{'mcagent'}{'ports'}{'tcp'}{'1820'}++	; 
#	$ports_ref->{'tcp'}{'1820'}{'name'} = 'mcagent'		; 
#	$srvcobjects_ref->{'winshadow-hd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'winshadow-hd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winshadow-hd'}{'port'}{'udp'} = '3861'	; 
#	$srvcobjects_ref->{'winshadow-hd'}{'ports'}{'udp'}{'3861'}++	; 
#	$ports_ref->{'udp'}{'3861'}{'name'} = 'winshadow-hd'		; 
#	$srvcobjects_ref->{'winshadow-hd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'winshadow-hd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winshadow-hd'}{'port'}{'tcp'} = '3861'	; 
#	$srvcobjects_ref->{'winshadow-hd'}{'ports'}{'tcp'}{'3861'}++	; 
#	$ports_ref->{'tcp'}{'3861'}{'name'} = 'winshadow-hd'		; 
#	$srvcobjects_ref->{'argis-te'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'argis-te'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'argis-te'}{'port'}{'udp'} = '2581'	; 
#	$srvcobjects_ref->{'argis-te'}{'ports'}{'udp'}{'2581'}++	; 
#	$ports_ref->{'udp'}{'2581'}{'name'} = 'argis-te'		; 
#	$srvcobjects_ref->{'argis-te'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'argis-te'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'argis-te'}{'port'}{'tcp'} = '2581'	; 
#	$srvcobjects_ref->{'argis-te'}{'ports'}{'tcp'}{'2581'}++	; 
#	$ports_ref->{'tcp'}{'2581'}{'name'} = 'argis-te'		; 
#	$srvcobjects_ref->{'monp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'monp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'monp'}{'port'}{'udp'} = '3445'	; 
#	$srvcobjects_ref->{'monp'}{'ports'}{'udp'}{'3445'}++	; 
#	$ports_ref->{'udp'}{'3445'}{'name'} = 'monp'		; 
#	$srvcobjects_ref->{'monp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'monp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'monp'}{'port'}{'tcp'} = '3445'	; 
#	$srvcobjects_ref->{'monp'}{'ports'}{'tcp'}{'3445'}++	; 
#	$ports_ref->{'tcp'}{'3445'}{'name'} = 'monp'		; 
#	$srvcobjects_ref->{'vinainstall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vinainstall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vinainstall'}{'port'}{'udp'} = '4344'	; 
#	$srvcobjects_ref->{'vinainstall'}{'ports'}{'udp'}{'4344'}++	; 
#	$ports_ref->{'udp'}{'4344'}{'name'} = 'vinainstall'		; 
#	$srvcobjects_ref->{'vinainstall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vinainstall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vinainstall'}{'port'}{'tcp'} = '4344'	; 
#	$srvcobjects_ref->{'vinainstall'}{'ports'}{'tcp'}{'4344'}++	; 
#	$ports_ref->{'tcp'}{'4344'}{'name'} = 'vinainstall'		; 
#	$srvcobjects_ref->{'mpnjsosv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpnjsosv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsosv'}{'port'}{'udp'} = '2684'	; 
#	$srvcobjects_ref->{'mpnjsosv'}{'ports'}{'udp'}{'2684'}++	; 
#	$ports_ref->{'udp'}{'2684'}{'name'} = 'mpnjsosv'		; 
#	$srvcobjects_ref->{'mpnjsosv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpnjsosv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsosv'}{'port'}{'tcp'} = '2684'	; 
#	$srvcobjects_ref->{'mpnjsosv'}{'ports'}{'tcp'}{'2684'}++	; 
#	$ports_ref->{'tcp'}{'2684'}{'name'} = 'mpnjsosv'		; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'port'}{'udp'} = '3191'	; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'ports'}{'udp'}{'3191'}++	; 
#	$ports_ref->{'udp'}{'3191'}{'name'} = 'csvr-sslproxy'		; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'port'}{'tcp'} = '3191'	; 
#	$srvcobjects_ref->{'csvr-sslproxy'}{'ports'}{'tcp'}{'3191'}++	; 
#	$ports_ref->{'tcp'}{'3191'}{'name'} = 'csvr-sslproxy'		; 
#	$srvcobjects_ref->{'midnight-tech'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'midnight-tech'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'midnight-tech'}{'port'}{'udp'} = '3008'	; 
#	$srvcobjects_ref->{'midnight-tech'}{'ports'}{'udp'}{'3008'}++	; 
#	$ports_ref->{'udp'}{'3008'}{'name'} = 'midnight-tech'		; 
#	$srvcobjects_ref->{'midnight-tech'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'midnight-tech'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'midnight-tech'}{'port'}{'tcp'} = '3008'	; 
#	$srvcobjects_ref->{'midnight-tech'}{'ports'}{'tcp'}{'3008'}++	; 
#	$ports_ref->{'tcp'}{'3008'}{'name'} = 'midnight-tech'		; 
#	$srvcobjects_ref->{'rda'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rda'}{'port'}{'udp'} = '630'	; 
#	$srvcobjects_ref->{'rda'}{'ports'}{'udp'}{'630'}++	; 
#	$ports_ref->{'udp'}{'630'}{'name'} = 'rda'		; 
#	$srvcobjects_ref->{'rda'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rda'}{'port'}{'tcp'} = '630'	; 
#	$srvcobjects_ref->{'rda'}{'ports'}{'tcp'}{'630'}++	; 
#	$ports_ref->{'tcp'}{'630'}{'name'} = 'rda'		; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'port'}{'udp'} = '2306'	; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'ports'}{'udp'}{'2306'}++	; 
#	$ports_ref->{'udp'}{'2306'}{'name'} = 'tappi-boxnet'		; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'port'}{'tcp'} = '2306'	; 
#	$srvcobjects_ref->{'tappi-boxnet'}{'ports'}{'tcp'}{'2306'}++	; 
#	$ports_ref->{'tcp'}{'2306'}{'name'} = 'tappi-boxnet'		; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'port'}{'udp'} = '692'	; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'ports'}{'udp'}{'692'}++	; 
#	$ports_ref->{'udp'}{'692'}{'name'} = 'hyperwave-isp'		; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'port'}{'tcp'} = '692'	; 
#	$srvcobjects_ref->{'hyperwave-isp'}{'ports'}{'tcp'}{'692'}++	; 
#	$ports_ref->{'tcp'}{'692'}{'name'} = 'hyperwave-isp'		; 
#	$srvcobjects_ref->{'wag-service'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wag-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wag-service'}{'port'}{'udp'} = '2608'	; 
#	$srvcobjects_ref->{'wag-service'}{'ports'}{'udp'}{'2608'}++	; 
#	$ports_ref->{'udp'}{'2608'}{'name'} = 'wag-service'		; 
#	$srvcobjects_ref->{'wag-service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wag-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wag-service'}{'port'}{'tcp'} = '2608'	; 
#	$srvcobjects_ref->{'wag-service'}{'ports'}{'tcp'}{'2608'}++	; 
#	$ports_ref->{'tcp'}{'2608'}{'name'} = 'wag-service'		; 
#	$srvcobjects_ref->{'scohelp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scohelp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scohelp'}{'port'}{'udp'} = '457'	; 
#	$srvcobjects_ref->{'scohelp'}{'ports'}{'udp'}{'457'}++	; 
#	$ports_ref->{'udp'}{'457'}{'name'} = 'scohelp'		; 
#	$srvcobjects_ref->{'scohelp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scohelp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scohelp'}{'port'}{'tcp'} = '457'	; 
#	$srvcobjects_ref->{'scohelp'}{'ports'}{'tcp'}{'457'}++	; 
#	$ports_ref->{'tcp'}{'457'}{'name'} = 'scohelp'		; 
#	$srvcobjects_ref->{'ssc-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssc-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssc-agent'}{'port'}{'udp'} = '2967'	; 
#	$srvcobjects_ref->{'ssc-agent'}{'ports'}{'udp'}{'2967'}++	; 
#	$ports_ref->{'udp'}{'2967'}{'name'} = 'ssc-agent'		; 
#	$srvcobjects_ref->{'ssc-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssc-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssc-agent'}{'port'}{'tcp'} = '2967'	; 
#	$srvcobjects_ref->{'ssc-agent'}{'ports'}{'tcp'}{'2967'}++	; 
#	$ports_ref->{'tcp'}{'2967'}{'name'} = 'ssc-agent'		; 
#	$srvcobjects_ref->{'sql*net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sql*net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sql*net'}{'port'}{'udp'} = '66'	; 
#	$srvcobjects_ref->{'sql*net'}{'ports'}{'udp'}{'66'}++	; 
#	$ports_ref->{'udp'}{'66'}{'name'} = 'sql*net'		; 
#	$srvcobjects_ref->{'sql*net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sql*net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sql*net'}{'port'}{'tcp'} = '66'	; 
#	$srvcobjects_ref->{'sql*net'}{'ports'}{'tcp'}{'66'}++	; 
#	$ports_ref->{'tcp'}{'66'}{'name'} = 'sql*net'		; 
#	$srvcobjects_ref->{'ddi-tcp-5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddi-tcp-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-tcp-5'}{'port'}{'tcp'} = '8892'	; 
#	$srvcobjects_ref->{'ddi-tcp-5'}{'ports'}{'tcp'}{'8892'}++	; 
#	$ports_ref->{'tcp'}{'8892'}{'name'} = 'ddi-tcp-5'		; 
#	$srvcobjects_ref->{'iims'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iims'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iims'}{'port'}{'udp'} = '4800'	; 
#	$srvcobjects_ref->{'iims'}{'ports'}{'udp'}{'4800'}++	; 
#	$ports_ref->{'udp'}{'4800'}{'name'} = 'iims'		; 
#	$srvcobjects_ref->{'iims'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iims'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iims'}{'port'}{'tcp'} = '4800'	; 
#	$srvcobjects_ref->{'iims'}{'ports'}{'tcp'}{'4800'}++	; 
#	$ports_ref->{'tcp'}{'4800'}{'name'} = 'iims'		; 
#	$srvcobjects_ref->{'ispipes'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ispipes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ispipes'}{'port'}{'udp'} = '2853'	; 
#	$srvcobjects_ref->{'ispipes'}{'ports'}{'udp'}{'2853'}++	; 
#	$ports_ref->{'udp'}{'2853'}{'name'} = 'ispipes'		; 
#	$srvcobjects_ref->{'ispipes'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ispipes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ispipes'}{'port'}{'tcp'} = '2853'	; 
#	$srvcobjects_ref->{'ispipes'}{'ports'}{'tcp'}{'2853'}++	; 
#	$ports_ref->{'tcp'}{'2853'}{'name'} = 'ispipes'		; 
#	$srvcobjects_ref->{'jdatastore'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jdatastore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jdatastore'}{'port'}{'udp'} = '2508'	; 
#	$srvcobjects_ref->{'jdatastore'}{'ports'}{'udp'}{'2508'}++	; 
#	$ports_ref->{'udp'}{'2508'}{'name'} = 'jdatastore'		; 
#	$srvcobjects_ref->{'jdatastore'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jdatastore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jdatastore'}{'port'}{'tcp'} = '2508'	; 
#	$srvcobjects_ref->{'jdatastore'}{'ports'}{'tcp'}{'2508'}++	; 
#	$ports_ref->{'tcp'}{'2508'}{'name'} = 'jdatastore'		; 
#	$srvcobjects_ref->{'skytelnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'skytelnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skytelnet'}{'port'}{'udp'} = '1618'	; 
#	$srvcobjects_ref->{'skytelnet'}{'ports'}{'udp'}{'1618'}++	; 
#	$ports_ref->{'udp'}{'1618'}{'name'} = 'skytelnet'		; 
#	$srvcobjects_ref->{'skytelnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'skytelnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skytelnet'}{'port'}{'tcp'} = '1618'	; 
#	$srvcobjects_ref->{'skytelnet'}{'ports'}{'tcp'}{'1618'}++	; 
#	$ports_ref->{'tcp'}{'1618'}{'name'} = 'skytelnet'		; 
#	$srvcobjects_ref->{'adaptecmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adaptecmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adaptecmgr'}{'port'}{'udp'} = '2521'	; 
#	$srvcobjects_ref->{'adaptecmgr'}{'ports'}{'udp'}{'2521'}++	; 
#	$ports_ref->{'udp'}{'2521'}{'name'} = 'adaptecmgr'		; 
#	$srvcobjects_ref->{'adaptecmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adaptecmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adaptecmgr'}{'port'}{'tcp'} = '2521'	; 
#	$srvcobjects_ref->{'adaptecmgr'}{'ports'}{'tcp'}{'2521'}++	; 
#	$ports_ref->{'tcp'}{'2521'}{'name'} = 'adaptecmgr'		; 
#	$srvcobjects_ref->{'prp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prp'}{'port'}{'udp'} = '2091'	; 
#	$srvcobjects_ref->{'prp'}{'ports'}{'udp'}{'2091'}++	; 
#	$ports_ref->{'udp'}{'2091'}{'name'} = 'prp'		; 
#	$srvcobjects_ref->{'prp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prp'}{'port'}{'tcp'} = '2091'	; 
#	$srvcobjects_ref->{'prp'}{'ports'}{'tcp'}{'2091'}++	; 
#	$ports_ref->{'tcp'}{'2091'}{'name'} = 'prp'		; 
#	$srvcobjects_ref->{'ftp-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftp-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftp-agent'}{'port'}{'udp'} = '574'	; 
#	$srvcobjects_ref->{'ftp-agent'}{'ports'}{'udp'}{'574'}++	; 
#	$ports_ref->{'udp'}{'574'}{'name'} = 'ftp-agent'		; 
#	$srvcobjects_ref->{'ftp-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftp-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftp-agent'}{'port'}{'tcp'} = '574'	; 
#	$srvcobjects_ref->{'ftp-agent'}{'ports'}{'tcp'}{'574'}++	; 
#	$ports_ref->{'tcp'}{'574'}{'name'} = 'ftp-agent'		; 
#	$srvcobjects_ref->{'quaddb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quaddb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quaddb'}{'port'}{'udp'} = '2497'	; 
#	$srvcobjects_ref->{'quaddb'}{'ports'}{'udp'}{'2497'}++	; 
#	$ports_ref->{'udp'}{'2497'}{'name'} = 'quaddb'		; 
#	$srvcobjects_ref->{'quaddb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quaddb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quaddb'}{'port'}{'tcp'} = '2497'	; 
#	$srvcobjects_ref->{'quaddb'}{'ports'}{'tcp'}{'2497'}++	; 
#	$ports_ref->{'tcp'}{'2497'}{'name'} = 'quaddb'		; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'port'}{'udp'} = '2668'	; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'ports'}{'udp'}{'2668'}++	; 
#	$ports_ref->{'udp'}{'2668'}{'name'} = 'alarm-clock-c'		; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'port'}{'tcp'} = '2668'	; 
#	$srvcobjects_ref->{'alarm-clock-c'}{'ports'}{'tcp'}{'2668'}++	; 
#	$ports_ref->{'tcp'}{'2668'}{'name'} = 'alarm-clock-c'		; 
#	$srvcobjects_ref->{'bandwiz-system'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bandwiz-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bandwiz-system'}{'port'}{'udp'} = '1929'	; 
#	$srvcobjects_ref->{'bandwiz-system'}{'ports'}{'udp'}{'1929'}++	; 
#	$ports_ref->{'udp'}{'1929'}{'name'} = 'bandwiz-system'		; 
#	$srvcobjects_ref->{'bandwiz-system'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bandwiz-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bandwiz-system'}{'port'}{'tcp'} = '1929'	; 
#	$srvcobjects_ref->{'bandwiz-system'}{'ports'}{'tcp'}{'1929'}++	; 
#	$ports_ref->{'tcp'}{'1929'}{'name'} = 'bandwiz-system'		; 
#	$srvcobjects_ref->{'hybrid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hybrid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hybrid'}{'port'}{'udp'} = '1424'	; 
#	$srvcobjects_ref->{'hybrid'}{'ports'}{'udp'}{'1424'}++	; 
#	$ports_ref->{'udp'}{'1424'}{'name'} = 'hybrid'		; 
#	$srvcobjects_ref->{'hybrid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hybrid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hybrid'}{'port'}{'tcp'} = '1424'	; 
#	$srvcobjects_ref->{'hybrid'}{'ports'}{'tcp'}{'1424'}++	; 
#	$ports_ref->{'tcp'}{'1424'}{'name'} = 'hybrid'		; 
#	$srvcobjects_ref->{'sms-chat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sms-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-chat'}{'port'}{'udp'} = '2703'	; 
#	$srvcobjects_ref->{'sms-chat'}{'ports'}{'udp'}{'2703'}++	; 
#	$ports_ref->{'udp'}{'2703'}{'name'} = 'sms-chat'		; 
#	$srvcobjects_ref->{'sms-chat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sms-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-chat'}{'port'}{'tcp'} = '2703'	; 
#	$srvcobjects_ref->{'sms-chat'}{'ports'}{'tcp'}{'2703'}++	; 
#	$ports_ref->{'tcp'}{'2703'}{'name'} = 'sms-chat'		; 
#	$srvcobjects_ref->{'chevinservices'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chevinservices'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chevinservices'}{'port'}{'udp'} = '3349'	; 
#	$srvcobjects_ref->{'chevinservices'}{'ports'}{'udp'}{'3349'}++	; 
#	$ports_ref->{'udp'}{'3349'}{'name'} = 'chevinservices'		; 
#	$srvcobjects_ref->{'chevinservices'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chevinservices'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chevinservices'}{'port'}{'tcp'} = '3349'	; 
#	$srvcobjects_ref->{'chevinservices'}{'ports'}{'tcp'}{'3349'}++	; 
#	$ports_ref->{'tcp'}{'3349'}{'name'} = 'chevinservices'		; 
#	$srvcobjects_ref->{'avail-epmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avail-epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avail-epmap'}{'port'}{'udp'} = '2132'	; 
#	$srvcobjects_ref->{'avail-epmap'}{'ports'}{'udp'}{'2132'}++	; 
#	$ports_ref->{'udp'}{'2132'}{'name'} = 'avail-epmap'		; 
#	$srvcobjects_ref->{'avail-epmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avail-epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avail-epmap'}{'port'}{'tcp'} = '2132'	; 
#	$srvcobjects_ref->{'avail-epmap'}{'ports'}{'tcp'}{'2132'}++	; 
#	$ports_ref->{'tcp'}{'2132'}{'name'} = 'avail-epmap'		; 
#	$srvcobjects_ref->{'firepower'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'firepower'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firepower'}{'port'}{'udp'} = '2615'	; 
#	$srvcobjects_ref->{'firepower'}{'ports'}{'udp'}{'2615'}++	; 
#	$ports_ref->{'udp'}{'2615'}{'name'} = 'firepower'		; 
#	$srvcobjects_ref->{'firepower'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'firepower'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firepower'}{'port'}{'tcp'} = '2615'	; 
#	$srvcobjects_ref->{'firepower'}{'ports'}{'tcp'}{'2615'}++	; 
#	$ports_ref->{'tcp'}{'2615'}{'name'} = 'firepower'		; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'port'}{'udp'} = '2235'	; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'ports'}{'udp'}{'2235'}++	; 
#	$ports_ref->{'udp'}{'2235'}{'name'} = 'sercomm-wlink'		; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'port'}{'tcp'} = '2235'	; 
#	$srvcobjects_ref->{'sercomm-wlink'}{'ports'}{'tcp'}{'2235'}++	; 
#	$ports_ref->{'tcp'}{'2235'}{'name'} = 'sercomm-wlink'		; 
#	$srvcobjects_ref->{'abbaccuray'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abbaccuray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abbaccuray'}{'port'}{'udp'} = '1546'	; 
#	$srvcobjects_ref->{'abbaccuray'}{'ports'}{'udp'}{'1546'}++	; 
#	$ports_ref->{'udp'}{'1546'}{'name'} = 'abbaccuray'		; 
#	$srvcobjects_ref->{'abbaccuray'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abbaccuray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abbaccuray'}{'port'}{'tcp'} = '1546'	; 
#	$srvcobjects_ref->{'abbaccuray'}{'ports'}{'tcp'}{'1546'}++	; 
#	$ports_ref->{'tcp'}{'1546'}{'name'} = 'abbaccuray'		; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'port'}{'udp'} = '9201'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'ports'}{'udp'}{'9201'}++	; 
#	$ports_ref->{'udp'}{'9201'}{'name'} = 'wap-wsp-wtp'		; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'port'}{'tcp'} = '9201'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp'}{'ports'}{'tcp'}{'9201'}++	; 
#	$ports_ref->{'tcp'}{'9201'}{'name'} = 'wap-wsp-wtp'		; 
#	$srvcobjects_ref->{'stvp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stvp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stvp'}{'port'}{'udp'} = '3158'	; 
#	$srvcobjects_ref->{'stvp'}{'ports'}{'udp'}{'3158'}++	; 
#	$ports_ref->{'udp'}{'3158'}{'name'} = 'stvp'		; 
#	$srvcobjects_ref->{'stvp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stvp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stvp'}{'port'}{'tcp'} = '3158'	; 
#	$srvcobjects_ref->{'stvp'}{'ports'}{'tcp'}{'3158'}++	; 
#	$ports_ref->{'tcp'}{'3158'}{'name'} = 'stvp'		; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'port'}{'udp'} = '3759'	; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'ports'}{'udp'}{'3759'}++	; 
#	$ports_ref->{'udp'}{'3759'}{'name'} = 'exapt-lmgr'		; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'port'}{'tcp'} = '3759'	; 
#	$srvcobjects_ref->{'exapt-lmgr'}{'ports'}{'tcp'}{'3759'}++	; 
#	$ports_ref->{'tcp'}{'3759'}{'name'} = 'exapt-lmgr'		; 
#	$srvcobjects_ref->{'relief'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'relief'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'relief'}{'port'}{'udp'} = '1353'	; 
#	$srvcobjects_ref->{'relief'}{'ports'}{'udp'}{'1353'}++	; 
#	$ports_ref->{'udp'}{'1353'}{'name'} = 'relief'		; 
#	$srvcobjects_ref->{'relief'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'relief'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'relief'}{'port'}{'tcp'} = '1353'	; 
#	$srvcobjects_ref->{'relief'}{'ports'}{'tcp'}{'1353'}++	; 
#	$ports_ref->{'tcp'}{'1353'}{'name'} = 'relief'		; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'port'}{'udp'} = '2954'	; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'ports'}{'udp'}{'2954'}++	; 
#	$ports_ref->{'udp'}{'2954'}{'name'} = 'ovalarmsrv-cmd'		; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'port'}{'tcp'} = '2954'	; 
#	$srvcobjects_ref->{'ovalarmsrv-cmd'}{'ports'}{'tcp'}{'2954'}++	; 
#	$ports_ref->{'tcp'}{'2954'}{'name'} = 'ovalarmsrv-cmd'		; 
#	$srvcobjects_ref->{'e-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'e-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e-net'}{'port'}{'udp'} = '3286'	; 
#	$srvcobjects_ref->{'e-net'}{'ports'}{'udp'}{'3286'}++	; 
#	$ports_ref->{'udp'}{'3286'}{'name'} = 'e-net'		; 
#	$srvcobjects_ref->{'e-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'e-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e-net'}{'port'}{'tcp'} = '3286'	; 
#	$srvcobjects_ref->{'e-net'}{'ports'}{'tcp'}{'3286'}++	; 
#	$ports_ref->{'tcp'}{'3286'}{'name'} = 'e-net'		; 
#	$srvcobjects_ref->{'netwatcher-db'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netwatcher-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwatcher-db'}{'port'}{'udp'} = '3204'	; 
#	$srvcobjects_ref->{'netwatcher-db'}{'ports'}{'udp'}{'3204'}++	; 
#	$ports_ref->{'udp'}{'3204'}{'name'} = 'netwatcher-db'		; 
#	$srvcobjects_ref->{'netwatcher-db'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netwatcher-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwatcher-db'}{'port'}{'tcp'} = '3204'	; 
#	$srvcobjects_ref->{'netwatcher-db'}{'ports'}{'tcp'}{'3204'}++	; 
#	$ports_ref->{'tcp'}{'3204'}{'name'} = 'netwatcher-db'		; 
#	$srvcobjects_ref->{'dectalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dectalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dectalk'}{'port'}{'tcp'} = '2007'	; 
#	$srvcobjects_ref->{'dectalk'}{'ports'}{'tcp'}{'2007'}++	; 
#	$ports_ref->{'tcp'}{'2007'}{'name'} = 'dectalk'		; 
#	$srvcobjects_ref->{'navbuddy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'navbuddy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navbuddy'}{'port'}{'udp'} = '1288'	; 
#	$srvcobjects_ref->{'navbuddy'}{'ports'}{'udp'}{'1288'}++	; 
#	$ports_ref->{'udp'}{'1288'}{'name'} = 'navbuddy'		; 
#	$srvcobjects_ref->{'navbuddy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'navbuddy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navbuddy'}{'port'}{'tcp'} = '1288'	; 
#	$srvcobjects_ref->{'navbuddy'}{'ports'}{'tcp'}{'1288'}++	; 
#	$ports_ref->{'tcp'}{'1288'}{'name'} = 'navbuddy'		; 
#	$srvcobjects_ref->{'networklenss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'networklenss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'networklenss'}{'port'}{'udp'} = '3410'	; 
#	$srvcobjects_ref->{'networklenss'}{'ports'}{'udp'}{'3410'}++	; 
#	$ports_ref->{'udp'}{'3410'}{'name'} = 'networklenss'		; 
#	$srvcobjects_ref->{'networklenss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'networklenss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'networklenss'}{'port'}{'tcp'} = '3410'	; 
#	$srvcobjects_ref->{'networklenss'}{'ports'}{'tcp'}{'3410'}++	; 
#	$ports_ref->{'tcp'}{'3410'}{'name'} = 'networklenss'		; 
#	$srvcobjects_ref->{'mmpft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mmpft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mmpft'}{'port'}{'udp'} = '1815'	; 
#	$srvcobjects_ref->{'mmpft'}{'ports'}{'udp'}{'1815'}++	; 
#	$ports_ref->{'udp'}{'1815'}{'name'} = 'mmpft'		; 
#	$srvcobjects_ref->{'mmpft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mmpft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mmpft'}{'port'}{'tcp'} = '1815'	; 
#	$srvcobjects_ref->{'mmpft'}{'ports'}{'tcp'}{'1815'}++	; 
#	$ports_ref->{'tcp'}{'1815'}{'name'} = 'mmpft'		; 
#	$srvcobjects_ref->{'xpilot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xpilot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xpilot'}{'port'}{'udp'} = '15345'	; 
#	$srvcobjects_ref->{'xpilot'}{'ports'}{'udp'}{'15345'}++	; 
#	$ports_ref->{'udp'}{'15345'}{'name'} = 'xpilot'		; 
#	$srvcobjects_ref->{'xpilot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xpilot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xpilot'}{'port'}{'tcp'} = '15345'	; 
#	$srvcobjects_ref->{'xpilot'}{'ports'}{'tcp'}{'15345'}++	; 
#	$ports_ref->{'tcp'}{'15345'}{'name'} = 'xpilot'		; 
#	$srvcobjects_ref->{'nv-video'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nv-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nv-video'}{'port'}{'udp'} = '4444'	; 
#	$srvcobjects_ref->{'nv-video'}{'ports'}{'udp'}{'4444'}++	; 
#	$ports_ref->{'udp'}{'4444'}{'name'} = 'nv-video'		; 
#	$srvcobjects_ref->{'nv-video'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nv-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nv-video'}{'port'}{'tcp'} = '4444'	; 
#	$srvcobjects_ref->{'nv-video'}{'ports'}{'tcp'}{'4444'}++	; 
#	$ports_ref->{'tcp'}{'4444'}{'name'} = 'nv-video'		; 
#	$srvcobjects_ref->{'netopia-vo3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netopia-vo3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo3'}{'port'}{'udp'} = '1841'	; 
#	$srvcobjects_ref->{'netopia-vo3'}{'ports'}{'udp'}{'1841'}++	; 
#	$ports_ref->{'udp'}{'1841'}{'name'} = 'netopia-vo3'		; 
#	$srvcobjects_ref->{'netopia-vo3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netopia-vo3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo3'}{'port'}{'tcp'} = '1841'	; 
#	$srvcobjects_ref->{'netopia-vo3'}{'ports'}{'tcp'}{'1841'}++	; 
#	$ports_ref->{'tcp'}{'1841'}{'name'} = 'netopia-vo3'		; 
#	$srvcobjects_ref->{'pnrp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pnrp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnrp-port'}{'port'}{'udp'} = '3540'	; 
#	$srvcobjects_ref->{'pnrp-port'}{'ports'}{'udp'}{'3540'}++	; 
#	$ports_ref->{'udp'}{'3540'}{'name'} = 'pnrp-port'		; 
#	$srvcobjects_ref->{'pnrp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pnrp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnrp-port'}{'port'}{'tcp'} = '3540'	; 
#	$srvcobjects_ref->{'pnrp-port'}{'ports'}{'tcp'}{'3540'}++	; 
#	$ports_ref->{'tcp'}{'3540'}{'name'} = 'pnrp-port'		; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'port'}{'udp'} = '1106'	; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'ports'}{'udp'}{'1106'}++	; 
#	$ports_ref->{'udp'}{'1106'}{'name'} = 'isoipsigport-1'		; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'port'}{'tcp'} = '1106'	; 
#	$srvcobjects_ref->{'isoipsigport-1'}{'ports'}{'tcp'}{'1106'}++	; 
#	$ports_ref->{'tcp'}{'1106'}{'name'} = 'isoipsigport-1'		; 
#	$srvcobjects_ref->{'veritas-tcp1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'veritas-tcp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-tcp1'}{'port'}{'tcp'} = '2802'	; 
#	$srvcobjects_ref->{'veritas-tcp1'}{'ports'}{'tcp'}{'2802'}++	; 
#	$ports_ref->{'tcp'}{'2802'}{'name'} = 'veritas-tcp1'		; 
#	$srvcobjects_ref->{'gppitnp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gppitnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gppitnp'}{'port'}{'udp'} = '103'	; 
#	$srvcobjects_ref->{'gppitnp'}{'ports'}{'udp'}{'103'}++	; 
#	$ports_ref->{'udp'}{'103'}{'name'} = 'gppitnp'		; 
#	$srvcobjects_ref->{'gppitnp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gppitnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gppitnp'}{'port'}{'tcp'} = '103'	; 
#	$srvcobjects_ref->{'gppitnp'}{'ports'}{'tcp'}{'103'}++	; 
#	$ports_ref->{'tcp'}{'103'}{'name'} = 'gppitnp'		; 
#	$srvcobjects_ref->{'ldap-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ldap-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldap-admin'}{'port'}{'udp'} = '3407'	; 
#	$srvcobjects_ref->{'ldap-admin'}{'ports'}{'udp'}{'3407'}++	; 
#	$ports_ref->{'udp'}{'3407'}{'name'} = 'ldap-admin'		; 
#	$srvcobjects_ref->{'ldap-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ldap-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldap-admin'}{'port'}{'tcp'} = '3407'	; 
#	$srvcobjects_ref->{'ldap-admin'}{'ports'}{'tcp'}{'3407'}++	; 
#	$ports_ref->{'tcp'}{'3407'}{'name'} = 'ldap-admin'		; 
#	$srvcobjects_ref->{'equationbuilder'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'equationbuilder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'equationbuilder'}{'port'}{'udp'} = '1351'	; 
#	$srvcobjects_ref->{'equationbuilder'}{'ports'}{'udp'}{'1351'}++	; 
#	$ports_ref->{'udp'}{'1351'}{'name'} = 'equationbuilder'		; 
#	$srvcobjects_ref->{'equationbuilder'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'equationbuilder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'equationbuilder'}{'port'}{'tcp'} = '1351'	; 
#	$srvcobjects_ref->{'equationbuilder'}{'ports'}{'tcp'}{'1351'}++	; 
#	$ports_ref->{'tcp'}{'1351'}{'name'} = 'equationbuilder'		; 
#	$srvcobjects_ref->{'snagas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snagas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snagas'}{'port'}{'udp'} = '108'	; 
#	$srvcobjects_ref->{'snagas'}{'ports'}{'udp'}{'108'}++	; 
#	$ports_ref->{'udp'}{'108'}{'name'} = 'snagas'		; 
#	$srvcobjects_ref->{'snagas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snagas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snagas'}{'port'}{'tcp'} = '108'	; 
#	$srvcobjects_ref->{'snagas'}{'ports'}{'tcp'}{'108'}++	; 
#	$ports_ref->{'tcp'}{'108'}{'name'} = 'snagas'		; 
#	$srvcobjects_ref->{'issapi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'issapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'issapi'}{'port'}{'udp'} = '3408'	; 
#	$srvcobjects_ref->{'issapi'}{'ports'}{'udp'}{'3408'}++	; 
#	$ports_ref->{'udp'}{'3408'}{'name'} = 'issapi'		; 
#	$srvcobjects_ref->{'issapi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'issapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'issapi'}{'port'}{'tcp'} = '3408'	; 
#	$srvcobjects_ref->{'issapi'}{'ports'}{'tcp'}{'3408'}++	; 
#	$ports_ref->{'tcp'}{'3408'}{'name'} = 'issapi'		; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'port'}{'udp'} = '1542'	; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'ports'}{'udp'}{'1542'}++	; 
#	$ports_ref->{'udp'}{'1542'}{'name'} = 'gridgen-elmd'		; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'port'}{'tcp'} = '1542'	; 
#	$srvcobjects_ref->{'gridgen-elmd'}{'ports'}{'tcp'}{'1542'}++	; 
#	$ports_ref->{'tcp'}{'1542'}{'name'} = 'gridgen-elmd'		; 
#	$srvcobjects_ref->{'ddi-tcp-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddi-tcp-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-tcp-3'}{'port'}{'tcp'} = '8890'	; 
#	$srvcobjects_ref->{'ddi-tcp-3'}{'ports'}{'tcp'}{'8890'}++	; 
#	$ports_ref->{'tcp'}{'8890'}{'name'} = 'ddi-tcp-3'		; 
#	$srvcobjects_ref->{'pxc-splr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-splr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-splr'}{'port'}{'udp'} = '4007'	; 
#	$srvcobjects_ref->{'pxc-splr'}{'ports'}{'udp'}{'4007'}++	; 
#	$ports_ref->{'udp'}{'4007'}{'name'} = 'pxc-splr'		; 
#	$srvcobjects_ref->{'pxc-splr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-splr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-splr'}{'port'}{'tcp'} = '4007'	; 
#	$srvcobjects_ref->{'pxc-splr'}{'ports'}{'tcp'}{'4007'}++	; 
#	$ports_ref->{'tcp'}{'4007'}{'name'} = 'pxc-splr'		; 
#	$srvcobjects_ref->{'sds-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sds-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sds-admin'}{'port'}{'udp'} = '2705'	; 
#	$srvcobjects_ref->{'sds-admin'}{'ports'}{'udp'}{'2705'}++	; 
#	$ports_ref->{'udp'}{'2705'}{'name'} = 'sds-admin'		; 
#	$srvcobjects_ref->{'sds-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sds-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sds-admin'}{'port'}{'tcp'} = '2705'	; 
#	$srvcobjects_ref->{'sds-admin'}{'ports'}{'tcp'}{'2705'}++	; 
#	$ports_ref->{'tcp'}{'2705'}{'name'} = 'sds-admin'		; 
#	$srvcobjects_ref->{'symbios-raid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'symbios-raid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'symbios-raid'}{'port'}{'udp'} = '2463'	; 
#	$srvcobjects_ref->{'symbios-raid'}{'ports'}{'udp'}{'2463'}++	; 
#	$ports_ref->{'udp'}{'2463'}{'name'} = 'symbios-raid'		; 
#	$srvcobjects_ref->{'symbios-raid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'symbios-raid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'symbios-raid'}{'port'}{'tcp'} = '2463'	; 
#	$srvcobjects_ref->{'symbios-raid'}{'ports'}{'tcp'}{'2463'}++	; 
#	$ports_ref->{'tcp'}{'2463'}{'name'} = 'symbios-raid'		; 
#	$srvcobjects_ref->{'hello-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hello-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hello-port'}{'port'}{'udp'} = '652'	; 
#	$srvcobjects_ref->{'hello-port'}{'ports'}{'udp'}{'652'}++	; 
#	$ports_ref->{'udp'}{'652'}{'name'} = 'hello-port'		; 
#	$srvcobjects_ref->{'hello-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hello-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hello-port'}{'port'}{'tcp'} = '652'	; 
#	$srvcobjects_ref->{'hello-port'}{'ports'}{'tcp'}{'652'}++	; 
#	$ports_ref->{'tcp'}{'652'}{'name'} = 'hello-port'		; 
#	$srvcobjects_ref->{'siam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'siam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'siam'}{'port'}{'udp'} = '498'	; 
#	$srvcobjects_ref->{'siam'}{'ports'}{'udp'}{'498'}++	; 
#	$ports_ref->{'udp'}{'498'}{'name'} = 'siam'		; 
#	$srvcobjects_ref->{'siam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'siam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'siam'}{'port'}{'tcp'} = '498'	; 
#	$srvcobjects_ref->{'siam'}{'ports'}{'tcp'}{'498'}++	; 
#	$ports_ref->{'tcp'}{'498'}{'name'} = 'siam'		; 
#	$srvcobjects_ref->{'calltrax'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'calltrax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'calltrax'}{'port'}{'udp'} = '3675'	; 
#	$srvcobjects_ref->{'calltrax'}{'ports'}{'udp'}{'3675'}++	; 
#	$ports_ref->{'udp'}{'3675'}{'name'} = 'calltrax'		; 
#	$srvcobjects_ref->{'calltrax'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'calltrax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'calltrax'}{'port'}{'tcp'} = '3675'	; 
#	$srvcobjects_ref->{'calltrax'}{'ports'}{'tcp'}{'3675'}++	; 
#	$ports_ref->{'tcp'}{'3675'}{'name'} = 'calltrax'		; 
#	$srvcobjects_ref->{'submit'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'submit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'submit'}{'port'}{'tcp'} = '773'	; 
#	$srvcobjects_ref->{'submit'}{'ports'}{'tcp'}{'773'}++	; 
#	$ports_ref->{'tcp'}{'773'}{'name'} = 'submit'		; 
#	$srvcobjects_ref->{'nntp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nntp'}{'port'}{'udp'} = '119'	; 
#	$srvcobjects_ref->{'nntp'}{'ports'}{'udp'}{'119'}++	; 
#	$ports_ref->{'udp'}{'119'}{'name'} = 'nntp'		; 
#	$srvcobjects_ref->{'nntp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nntp'}{'port'}{'tcp'} = '119'	; 
#	$srvcobjects_ref->{'nntp'}{'ports'}{'tcp'}{'119'}++	; 
#	$ports_ref->{'tcp'}{'119'}{'name'} = 'nntp'		; 
#	$srvcobjects_ref->{'globecast-id'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'globecast-id'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'globecast-id'}{'port'}{'udp'} = '6109'	; 
#	$srvcobjects_ref->{'globecast-id'}{'ports'}{'udp'}{'6109'}++	; 
#	$ports_ref->{'udp'}{'6109'}{'name'} = 'globecast-id'		; 
#	$srvcobjects_ref->{'globecast-id'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'globecast-id'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'globecast-id'}{'port'}{'tcp'} = '6109'	; 
#	$srvcobjects_ref->{'globecast-id'}{'ports'}{'tcp'}{'6109'}++	; 
#	$ports_ref->{'tcp'}{'6109'}{'name'} = 'globecast-id'		; 
#	$srvcobjects_ref->{'esbroker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esbroker'}{'port'}{'udp'} = '1342'	; 
#	$srvcobjects_ref->{'esbroker'}{'ports'}{'udp'}{'1342'}++	; 
#	$ports_ref->{'udp'}{'1342'}{'name'} = 'esbroker'		; 
#	$srvcobjects_ref->{'esbroker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esbroker'}{'port'}{'tcp'} = '1342'	; 
#	$srvcobjects_ref->{'esbroker'}{'ports'}{'tcp'}{'1342'}++	; 
#	$ports_ref->{'tcp'}{'1342'}{'name'} = 'esbroker'		; 
#	$srvcobjects_ref->{'orasrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orasrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orasrv'}{'port'}{'udp'} = '1525'	; 
#	$srvcobjects_ref->{'orasrv'}{'ports'}{'udp'}{'1525'}++	; 
#	$ports_ref->{'udp'}{'1525'}{'name'} = 'orasrv'		; 
#	$srvcobjects_ref->{'orasrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orasrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orasrv'}{'port'}{'tcp'} = '1525'	; 
#	$srvcobjects_ref->{'orasrv'}{'ports'}{'tcp'}{'1525'}++	; 
#	$ports_ref->{'tcp'}{'1525'}{'name'} = 'orasrv'		; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'port'}{'udp'} = '13820'	; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'ports'}{'udp'}{'13820'}++	; 
#	$ports_ref->{'udp'}{'13820'}{'name'} = 'dsmcc-passthru'		; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'port'}{'tcp'} = '13820'	; 
#	$srvcobjects_ref->{'dsmcc-passthru'}{'ports'}{'tcp'}{'13820'}++	; 
#	$ports_ref->{'tcp'}{'13820'}{'name'} = 'dsmcc-passthru'		; 
#	$srvcobjects_ref->{'netsc-dev'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netsc-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsc-dev'}{'port'}{'udp'} = '155'	; 
#	$srvcobjects_ref->{'netsc-dev'}{'ports'}{'udp'}{'155'}++	; 
#	$ports_ref->{'udp'}{'155'}{'name'} = 'netsc-dev'		; 
#	$srvcobjects_ref->{'netsc-dev'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netsc-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsc-dev'}{'port'}{'tcp'} = '155'	; 
#	$srvcobjects_ref->{'netsc-dev'}{'ports'}{'tcp'}{'155'}++	; 
#	$ports_ref->{'tcp'}{'155'}{'name'} = 'netsc-dev'		; 
#	$srvcobjects_ref->{'nati-logos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nati-logos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-logos'}{'port'}{'udp'} = '2343'	; 
#	$srvcobjects_ref->{'nati-logos'}{'ports'}{'udp'}{'2343'}++	; 
#	$ports_ref->{'udp'}{'2343'}{'name'} = 'nati-logos'		; 
#	$srvcobjects_ref->{'nati-logos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nati-logos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-logos'}{'port'}{'tcp'} = '2343'	; 
#	$srvcobjects_ref->{'nati-logos'}{'ports'}{'tcp'}{'2343'}++	; 
#	$ports_ref->{'tcp'}{'2343'}{'name'} = 'nati-logos'		; 
#	$srvcobjects_ref->{'avantageb2b'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avantageb2b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avantageb2b'}{'port'}{'udp'} = '2131'	; 
#	$srvcobjects_ref->{'avantageb2b'}{'ports'}{'udp'}{'2131'}++	; 
#	$ports_ref->{'udp'}{'2131'}{'name'} = 'avantageb2b'		; 
#	$srvcobjects_ref->{'avantageb2b'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avantageb2b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avantageb2b'}{'port'}{'tcp'} = '2131'	; 
#	$srvcobjects_ref->{'avantageb2b'}{'ports'}{'tcp'}{'2131'}++	; 
#	$ports_ref->{'tcp'}{'2131'}{'name'} = 'avantageb2b'		; 
#	$srvcobjects_ref->{'ecnp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ecnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecnp'}{'port'}{'udp'} = '2858'	; 
#	$srvcobjects_ref->{'ecnp'}{'ports'}{'udp'}{'2858'}++	; 
#	$ports_ref->{'udp'}{'2858'}{'name'} = 'ecnp'		; 
#	$srvcobjects_ref->{'ecnp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ecnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecnp'}{'port'}{'tcp'} = '2858'	; 
#	$srvcobjects_ref->{'ecnp'}{'ports'}{'tcp'}{'2858'}++	; 
#	$ports_ref->{'tcp'}{'2858'}{'name'} = 'ecnp'		; 
#	$srvcobjects_ref->{'xribs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xribs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xribs'}{'port'}{'udp'} = '2025'	; 
#	$srvcobjects_ref->{'xribs'}{'ports'}{'udp'}{'2025'}++	; 
#	$ports_ref->{'udp'}{'2025'}{'name'} = 'xribs'		; 
#	$srvcobjects_ref->{'whoami'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'whoami'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whoami'}{'port'}{'udp'} = '565'	; 
#	$srvcobjects_ref->{'whoami'}{'ports'}{'udp'}{'565'}++	; 
#	$ports_ref->{'udp'}{'565'}{'name'} = 'whoami'		; 
#	$srvcobjects_ref->{'whoami'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'whoami'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whoami'}{'port'}{'tcp'} = '565'	; 
#	$srvcobjects_ref->{'whoami'}{'ports'}{'tcp'}{'565'}++	; 
#	$ports_ref->{'tcp'}{'565'}{'name'} = 'whoami'		; 
#	$srvcobjects_ref->{'sightline'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sightline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sightline'}{'port'}{'udp'} = '1645'	; 
#	$srvcobjects_ref->{'sightline'}{'ports'}{'udp'}{'1645'}++	; 
#	$ports_ref->{'udp'}{'1645'}{'name'} = 'sightline'		; 
#	$srvcobjects_ref->{'sightline'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sightline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sightline'}{'port'}{'tcp'} = '1645'	; 
#	$srvcobjects_ref->{'sightline'}{'ports'}{'tcp'}{'1645'}++	; 
#	$ports_ref->{'tcp'}{'1645'}{'name'} = 'sightline'		; 
#	$srvcobjects_ref->{'pptconference'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pptconference'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pptconference'}{'port'}{'udp'} = '1711'	; 
#	$srvcobjects_ref->{'pptconference'}{'ports'}{'udp'}{'1711'}++	; 
#	$ports_ref->{'udp'}{'1711'}{'name'} = 'pptconference'		; 
#	$srvcobjects_ref->{'pptconference'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pptconference'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pptconference'}{'port'}{'tcp'} = '1711'	; 
#	$srvcobjects_ref->{'pptconference'}{'ports'}{'tcp'}{'1711'}++	; 
#	$ports_ref->{'tcp'}{'1711'}{'name'} = 'pptconference'		; 
#	$srvcobjects_ref->{'upnotifyps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'upnotifyps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upnotifyps'}{'port'}{'udp'} = '3356'	; 
#	$srvcobjects_ref->{'upnotifyps'}{'ports'}{'udp'}{'3356'}++	; 
#	$ports_ref->{'udp'}{'3356'}{'name'} = 'upnotifyps'		; 
#	$srvcobjects_ref->{'upnotifyps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'upnotifyps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upnotifyps'}{'port'}{'tcp'} = '3356'	; 
#	$srvcobjects_ref->{'upnotifyps'}{'ports'}{'tcp'}{'3356'}++	; 
#	$ports_ref->{'tcp'}{'3356'}{'name'} = 'upnotifyps'		; 
#	$srvcobjects_ref->{'xtrm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xtrm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xtrm'}{'port'}{'udp'} = '3423'	; 
#	$srvcobjects_ref->{'xtrm'}{'ports'}{'udp'}{'3423'}++	; 
#	$ports_ref->{'udp'}{'3423'}{'name'} = 'xtrm'		; 
#	$srvcobjects_ref->{'xtrm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xtrm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xtrm'}{'port'}{'tcp'} = '3423'	; 
#	$srvcobjects_ref->{'xtrm'}{'ports'}{'tcp'}{'3423'}++	; 
#	$ports_ref->{'tcp'}{'3423'}{'name'} = 'xtrm'		; 
#	$srvcobjects_ref->{'pslserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pslserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pslserver'}{'port'}{'udp'} = '2352'	; 
#	$srvcobjects_ref->{'pslserver'}{'ports'}{'udp'}{'2352'}++	; 
#	$ports_ref->{'udp'}{'2352'}{'name'} = 'pslserver'		; 
#	$srvcobjects_ref->{'pslserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pslserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pslserver'}{'port'}{'tcp'} = '2352'	; 
#	$srvcobjects_ref->{'pslserver'}{'ports'}{'tcp'}{'2352'}++	; 
#	$ports_ref->{'tcp'}{'2352'}{'name'} = 'pslserver'		; 
#	$srvcobjects_ref->{'netspeak-cps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netspeak-cps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-cps'}{'port'}{'udp'} = '21849'	; 
#	$srvcobjects_ref->{'netspeak-cps'}{'ports'}{'udp'}{'21849'}++	; 
#	$ports_ref->{'udp'}{'21849'}{'name'} = 'netspeak-cps'		; 
#	$srvcobjects_ref->{'netspeak-cps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netspeak-cps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-cps'}{'port'}{'tcp'} = '21849'	; 
#	$srvcobjects_ref->{'netspeak-cps'}{'ports'}{'tcp'}{'21849'}++	; 
#	$ports_ref->{'tcp'}{'21849'}{'name'} = 'netspeak-cps'		; 
#	$srvcobjects_ref->{'vnetd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vnetd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnetd'}{'port'}{'udp'} = '13724'	; 
#	$srvcobjects_ref->{'vnetd'}{'ports'}{'udp'}{'13724'}++	; 
#	$ports_ref->{'udp'}{'13724'}{'name'} = 'vnetd'		; 
#	$srvcobjects_ref->{'vnetd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vnetd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnetd'}{'port'}{'tcp'} = '13724'	; 
#	$srvcobjects_ref->{'vnetd'}{'ports'}{'tcp'}{'13724'}++	; 
#	$ports_ref->{'tcp'}{'13724'}{'name'} = 'vnetd'		; 
#	$srvcobjects_ref->{'ashwin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ashwin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ashwin'}{'port'}{'udp'} = '1556'	; 
#	$srvcobjects_ref->{'ashwin'}{'ports'}{'udp'}{'1556'}++	; 
#	$ports_ref->{'udp'}{'1556'}{'name'} = 'ashwin'		; 
#	$srvcobjects_ref->{'ashwin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ashwin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ashwin'}{'port'}{'tcp'} = '1556'	; 
#	$srvcobjects_ref->{'ashwin'}{'ports'}{'tcp'}{'1556'}++	; 
#	$ports_ref->{'tcp'}{'1556'}{'name'} = 'ashwin'		; 
#	$srvcobjects_ref->{'bullant-rap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bullant-rap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bullant-rap'}{'port'}{'udp'} = '2965'	; 
#	$srvcobjects_ref->{'bullant-rap'}{'ports'}{'udp'}{'2965'}++	; 
#	$ports_ref->{'udp'}{'2965'}{'name'} = 'bullant-rap'		; 
#	$srvcobjects_ref->{'bullant-rap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bullant-rap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bullant-rap'}{'port'}{'tcp'} = '2965'	; 
#	$srvcobjects_ref->{'bullant-rap'}{'ports'}{'tcp'}{'2965'}++	; 
#	$ports_ref->{'tcp'}{'2965'}{'name'} = 'bullant-rap'		; 
#	$srvcobjects_ref->{'simbaservices'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simbaservices'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simbaservices'}{'port'}{'udp'} = '1599'	; 
#	$srvcobjects_ref->{'simbaservices'}{'ports'}{'udp'}{'1599'}++	; 
#	$ports_ref->{'udp'}{'1599'}{'name'} = 'simbaservices'		; 
#	$srvcobjects_ref->{'simbaservices'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simbaservices'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simbaservices'}{'port'}{'tcp'} = '1599'	; 
#	$srvcobjects_ref->{'simbaservices'}{'ports'}{'tcp'}{'1599'}++	; 
#	$ports_ref->{'tcp'}{'1599'}{'name'} = 'simbaservices'		; 
#	$srvcobjects_ref->{'rdrmshc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rdrmshc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdrmshc'}{'port'}{'udp'} = '1075'	; 
#	$srvcobjects_ref->{'rdrmshc'}{'ports'}{'udp'}{'1075'}++	; 
#	$ports_ref->{'udp'}{'1075'}{'name'} = 'rdrmshc'		; 
#	$srvcobjects_ref->{'rdrmshc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rdrmshc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdrmshc'}{'port'}{'tcp'} = '1075'	; 
#	$srvcobjects_ref->{'rdrmshc'}{'ports'}{'tcp'}{'1075'}++	; 
#	$ports_ref->{'tcp'}{'1075'}{'name'} = 'rdrmshc'		; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'port'}{'udp'} = '4351'	; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'ports'}{'udp'}{'4351'}++	; 
#	$ports_ref->{'udp'}{'4351'}{'name'} = 'plcy-net-svcs'		; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'port'}{'tcp'} = '4351'	; 
#	$srvcobjects_ref->{'plcy-net-svcs'}{'ports'}{'tcp'}{'4351'}++	; 
#	$ports_ref->{'tcp'}{'4351'}{'name'} = 'plcy-net-svcs'		; 
#	$srvcobjects_ref->{'acap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acap'}{'port'}{'udp'} = '674'	; 
#	$srvcobjects_ref->{'acap'}{'ports'}{'udp'}{'674'}++	; 
#	$ports_ref->{'udp'}{'674'}{'name'} = 'acap'		; 
#	$srvcobjects_ref->{'acap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acap'}{'port'}{'tcp'} = '674'	; 
#	$srvcobjects_ref->{'acap'}{'ports'}{'tcp'}{'674'}++	; 
#	$ports_ref->{'tcp'}{'674'}{'name'} = 'acap'		; 
#	$srvcobjects_ref->{'netnews'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netnews'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netnews'}{'port'}{'udp'} = '532'	; 
#	$srvcobjects_ref->{'netnews'}{'ports'}{'udp'}{'532'}++	; 
#	$ports_ref->{'udp'}{'532'}{'name'} = 'netnews'		; 
#	$srvcobjects_ref->{'netnews'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netnews'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netnews'}{'port'}{'tcp'} = '532'	; 
#	$srvcobjects_ref->{'netnews'}{'ports'}{'tcp'}{'532'}++	; 
#	$ports_ref->{'tcp'}{'532'}{'name'} = 'netnews'		; 
#	$srvcobjects_ref->{'zephyr-hm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zephyr-hm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zephyr-hm'}{'port'}{'udp'} = '2104'	; 
#	$srvcobjects_ref->{'zephyr-hm'}{'ports'}{'udp'}{'2104'}++	; 
#	$ports_ref->{'udp'}{'2104'}{'name'} = 'zephyr-hm'		; 
#	$srvcobjects_ref->{'zephyr-hm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zephyr-hm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zephyr-hm'}{'port'}{'tcp'} = '2104'	; 
#	$srvcobjects_ref->{'zephyr-hm'}{'ports'}{'tcp'}{'2104'}++	; 
#	$ports_ref->{'tcp'}{'2104'}{'name'} = 'zephyr-hm'		; 
#	$srvcobjects_ref->{'espeech'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'espeech'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'espeech'}{'port'}{'udp'} = '8416'	; 
#	$srvcobjects_ref->{'espeech'}{'ports'}{'udp'}{'8416'}++	; 
#	$ports_ref->{'udp'}{'8416'}{'name'} = 'espeech'		; 
#	$srvcobjects_ref->{'espeech'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'espeech'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'espeech'}{'port'}{'tcp'} = '8416'	; 
#	$srvcobjects_ref->{'espeech'}{'ports'}{'tcp'}{'8416'}++	; 
#	$ports_ref->{'tcp'}{'8416'}{'name'} = 'espeech'		; 
#	$srvcobjects_ref->{'tal-pod'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tal-pod'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tal-pod'}{'port'}{'udp'} = '6149'	; 
#	$srvcobjects_ref->{'tal-pod'}{'ports'}{'udp'}{'6149'}++	; 
#	$ports_ref->{'udp'}{'6149'}{'name'} = 'tal-pod'		; 
#	$srvcobjects_ref->{'tal-pod'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tal-pod'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tal-pod'}{'port'}{'tcp'} = '6149'	; 
#	$srvcobjects_ref->{'tal-pod'}{'ports'}{'tcp'}{'6149'}++	; 
#	$ports_ref->{'tcp'}{'6149'}{'name'} = 'tal-pod'		; 
#	$srvcobjects_ref->{'ibm-cics'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-cics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-cics'}{'port'}{'udp'} = '1435'	; 
#	$srvcobjects_ref->{'ibm-cics'}{'ports'}{'udp'}{'1435'}++	; 
#	$ports_ref->{'udp'}{'1435'}{'name'} = 'ibm-cics'		; 
#	$srvcobjects_ref->{'ibm-cics'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-cics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-cics'}{'port'}{'tcp'} = '1435'	; 
#	$srvcobjects_ref->{'ibm-cics'}{'ports'}{'tcp'}{'1435'}++	; 
#	$ports_ref->{'tcp'}{'1435'}{'name'} = 'ibm-cics'		; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'port'}{'udp'} = '4451'	; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'ports'}{'udp'}{'4451'}++	; 
#	$ports_ref->{'udp'}{'4451'}{'name'} = 'ctisystemmsg'		; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'port'}{'tcp'} = '4451'	; 
#	$srvcobjects_ref->{'ctisystemmsg'}{'ports'}{'tcp'}{'4451'}++	; 
#	$ports_ref->{'tcp'}{'4451'}{'name'} = 'ctisystemmsg'		; 
#	$srvcobjects_ref->{'cs-remote-db'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cs-remote-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-remote-db'}{'port'}{'udp'} = '3630'	; 
#	$srvcobjects_ref->{'cs-remote-db'}{'ports'}{'udp'}{'3630'}++	; 
#	$ports_ref->{'udp'}{'3630'}{'name'} = 'cs-remote-db'		; 
#	$srvcobjects_ref->{'cs-remote-db'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cs-remote-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-remote-db'}{'port'}{'tcp'} = '3630'	; 
#	$srvcobjects_ref->{'cs-remote-db'}{'ports'}{'tcp'}{'3630'}++	; 
#	$ports_ref->{'tcp'}{'3630'}{'name'} = 'cs-remote-db'		; 
#	$srvcobjects_ref->{'pcihreq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcihreq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcihreq'}{'port'}{'udp'} = '3085'	; 
#	$srvcobjects_ref->{'pcihreq'}{'ports'}{'udp'}{'3085'}++	; 
#	$ports_ref->{'udp'}{'3085'}{'name'} = 'pcihreq'		; 
#	$srvcobjects_ref->{'pcihreq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcihreq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcihreq'}{'port'}{'tcp'} = '3085'	; 
#	$srvcobjects_ref->{'pcihreq'}{'ports'}{'tcp'}{'3085'}++	; 
#	$ports_ref->{'tcp'}{'3085'}{'name'} = 'pcihreq'		; 
#	$srvcobjects_ref->{'hacl-cfg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-cfg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-cfg'}{'port'}{'udp'} = '5302'	; 
#	$srvcobjects_ref->{'hacl-cfg'}{'ports'}{'udp'}{'5302'}++	; 
#	$ports_ref->{'udp'}{'5302'}{'name'} = 'hacl-cfg'		; 
#	$srvcobjects_ref->{'hacl-cfg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-cfg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-cfg'}{'port'}{'tcp'} = '5302'	; 
#	$srvcobjects_ref->{'hacl-cfg'}{'ports'}{'tcp'}{'5302'}++	; 
#	$ports_ref->{'tcp'}{'5302'}{'name'} = 'hacl-cfg'		; 
#	$srvcobjects_ref->{'afs3-bos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-bos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-bos'}{'port'}{'udp'} = '7007'	; 
#	$srvcobjects_ref->{'afs3-bos'}{'ports'}{'udp'}{'7007'}++	; 
#	$ports_ref->{'udp'}{'7007'}{'name'} = 'afs3-bos'		; 
#	$srvcobjects_ref->{'afs3-bos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-bos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-bos'}{'port'}{'tcp'} = '7007'	; 
#	$srvcobjects_ref->{'afs3-bos'}{'ports'}{'tcp'}{'7007'}++	; 
#	$ports_ref->{'tcp'}{'7007'}{'name'} = 'afs3-bos'		; 
#	$srvcobjects_ref->{'jetcmeserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jetcmeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jetcmeserver'}{'port'}{'udp'} = '1936'	; 
#	$srvcobjects_ref->{'jetcmeserver'}{'ports'}{'udp'}{'1936'}++	; 
#	$ports_ref->{'udp'}{'1936'}{'name'} = 'jetcmeserver'		; 
#	$srvcobjects_ref->{'jetcmeserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jetcmeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jetcmeserver'}{'port'}{'tcp'} = '1936'	; 
#	$srvcobjects_ref->{'jetcmeserver'}{'ports'}{'tcp'}{'1936'}++	; 
#	$ports_ref->{'tcp'}{'1936'}{'name'} = 'jetcmeserver'		; 
#	$srvcobjects_ref->{'xbox'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xbox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xbox'}{'port'}{'udp'} = '3074'	; 
#	$srvcobjects_ref->{'xbox'}{'ports'}{'udp'}{'3074'}++	; 
#	$ports_ref->{'udp'}{'3074'}{'name'} = 'xbox'		; 
#	$srvcobjects_ref->{'xbox'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xbox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xbox'}{'port'}{'tcp'} = '3074'	; 
#	$srvcobjects_ref->{'xbox'}{'ports'}{'tcp'}{'3074'}++	; 
#	$ports_ref->{'tcp'}{'3074'}{'name'} = 'xbox'		; 
#	$srvcobjects_ref->{'reftek'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'reftek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'reftek'}{'port'}{'udp'} = '2543'	; 
#	$srvcobjects_ref->{'reftek'}{'ports'}{'udp'}{'2543'}++	; 
#	$ports_ref->{'udp'}{'2543'}{'name'} = 'reftek'		; 
#	$srvcobjects_ref->{'reftek'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'reftek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'reftek'}{'port'}{'tcp'} = '2543'	; 
#	$srvcobjects_ref->{'reftek'}{'ports'}{'tcp'}{'2543'}++	; 
#	$ports_ref->{'tcp'}{'2543'}{'name'} = 'reftek'		; 
#	$srvcobjects_ref->{'gandalf-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gandalf-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gandalf-lm'}{'port'}{'udp'} = '1421'	; 
#	$srvcobjects_ref->{'gandalf-lm'}{'ports'}{'udp'}{'1421'}++	; 
#	$ports_ref->{'udp'}{'1421'}{'name'} = 'gandalf-lm'		; 
#	$srvcobjects_ref->{'gandalf-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gandalf-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gandalf-lm'}{'port'}{'tcp'} = '1421'	; 
#	$srvcobjects_ref->{'gandalf-lm'}{'ports'}{'tcp'}{'1421'}++	; 
#	$ports_ref->{'tcp'}{'1421'}{'name'} = 'gandalf-lm'		; 
#	$srvcobjects_ref->{'submission'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'submission'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'submission'}{'port'}{'udp'} = '587'	; 
#	$srvcobjects_ref->{'submission'}{'ports'}{'udp'}{'587'}++	; 
#	$ports_ref->{'udp'}{'587'}{'name'} = 'submission'		; 
#	$srvcobjects_ref->{'submission'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'submission'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'submission'}{'port'}{'tcp'} = '587'	; 
#	$srvcobjects_ref->{'submission'}{'ports'}{'tcp'}{'587'}++	; 
#	$ports_ref->{'tcp'}{'587'}{'name'} = 'submission'		; 
#	$srvcobjects_ref->{'docent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'docent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'docent'}{'port'}{'udp'} = '2151'	; 
#	$srvcobjects_ref->{'docent'}{'ports'}{'udp'}{'2151'}++	; 
#	$ports_ref->{'udp'}{'2151'}{'name'} = 'docent'		; 
#	$srvcobjects_ref->{'docent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'docent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'docent'}{'port'}{'tcp'} = '2151'	; 
#	$srvcobjects_ref->{'docent'}{'ports'}{'tcp'}{'2151'}++	; 
#	$ports_ref->{'tcp'}{'2151'}{'name'} = 'docent'		; 
#	$srvcobjects_ref->{'montage-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'montage-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'montage-lm'}{'port'}{'udp'} = '6147'	; 
#	$srvcobjects_ref->{'montage-lm'}{'ports'}{'udp'}{'6147'}++	; 
#	$ports_ref->{'udp'}{'6147'}{'name'} = 'montage-lm'		; 
#	$srvcobjects_ref->{'montage-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'montage-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'montage-lm'}{'port'}{'tcp'} = '6147'	; 
#	$srvcobjects_ref->{'montage-lm'}{'ports'}{'tcp'}{'6147'}++	; 
#	$ports_ref->{'tcp'}{'6147'}{'name'} = 'montage-lm'		; 
#	$srvcobjects_ref->{'neckar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'neckar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neckar'}{'port'}{'udp'} = '37475'	; 
#	$srvcobjects_ref->{'neckar'}{'ports'}{'udp'}{'37475'}++	; 
#	$ports_ref->{'udp'}{'37475'}{'name'} = 'neckar'		; 
#	$srvcobjects_ref->{'neckar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'neckar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neckar'}{'port'}{'tcp'} = '37475'	; 
#	$srvcobjects_ref->{'neckar'}{'ports'}{'tcp'}{'37475'}++	; 
#	$ports_ref->{'tcp'}{'37475'}{'name'} = 'neckar'		; 
#	$srvcobjects_ref->{'park-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'park-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'park-agent'}{'port'}{'udp'} = '5431'	; 
#	$srvcobjects_ref->{'park-agent'}{'ports'}{'udp'}{'5431'}++	; 
#	$ports_ref->{'udp'}{'5431'}{'name'} = 'park-agent'		; 
#	$srvcobjects_ref->{'park-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'park-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'park-agent'}{'port'}{'tcp'} = '5431'	; 
#	$srvcobjects_ref->{'park-agent'}{'ports'}{'tcp'}{'5431'}++	; 
#	$ports_ref->{'tcp'}{'5431'}{'name'} = 'park-agent'		; 
#	$srvcobjects_ref->{'wg-netforce'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wg-netforce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wg-netforce'}{'port'}{'udp'} = '3359'	; 
#	$srvcobjects_ref->{'wg-netforce'}{'ports'}{'udp'}{'3359'}++	; 
#	$ports_ref->{'udp'}{'3359'}{'name'} = 'wg-netforce'		; 
#	$srvcobjects_ref->{'wg-netforce'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wg-netforce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wg-netforce'}{'port'}{'tcp'} = '3359'	; 
#	$srvcobjects_ref->{'wg-netforce'}{'ports'}{'tcp'}{'3359'}++	; 
#	$ports_ref->{'tcp'}{'3359'}{'name'} = 'wg-netforce'		; 
#	$srvcobjects_ref->{'cft-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-4'}{'port'}{'udp'} = '1765'	; 
#	$srvcobjects_ref->{'cft-4'}{'ports'}{'udp'}{'1765'}++	; 
#	$ports_ref->{'udp'}{'1765'}{'name'} = 'cft-4'		; 
#	$srvcobjects_ref->{'cft-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-4'}{'port'}{'tcp'} = '1765'	; 
#	$srvcobjects_ref->{'cft-4'}{'ports'}{'tcp'}{'1765'}++	; 
#	$ports_ref->{'tcp'}{'1765'}{'name'} = 'cft-4'		; 
#	$srvcobjects_ref->{'entextxid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entextxid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextxid'}{'port'}{'udp'} = '12000'	; 
#	$srvcobjects_ref->{'entextxid'}{'ports'}{'udp'}{'12000'}++	; 
#	$ports_ref->{'udp'}{'12000'}{'name'} = 'entextxid'		; 
#	$srvcobjects_ref->{'entextxid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entextxid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextxid'}{'port'}{'tcp'} = '12000'	; 
#	$srvcobjects_ref->{'entextxid'}{'ports'}{'tcp'}{'12000'}++	; 
#	$ports_ref->{'tcp'}{'12000'}{'name'} = 'entextxid'		; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'port'}{'udp'} = '43189'	; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'ports'}{'udp'}{'43189'}++	; 
#	$ports_ref->{'udp'}{'43189'}{'name'} = 'ndm-agent-port'		; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'port'}{'tcp'} = '43189'	; 
#	$srvcobjects_ref->{'ndm-agent-port'}{'ports'}{'tcp'}{'43189'}++	; 
#	$ports_ref->{'tcp'}{'43189'}{'name'} = 'ndm-agent-port'		; 
#	$srvcobjects_ref->{'msg-auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msg-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msg-auth'}{'port'}{'udp'} = '31'	; 
#	$srvcobjects_ref->{'msg-auth'}{'ports'}{'udp'}{'31'}++	; 
#	$ports_ref->{'udp'}{'31'}{'name'} = 'msg-auth'		; 
#	$srvcobjects_ref->{'msg-auth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msg-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msg-auth'}{'port'}{'tcp'} = '31'	; 
#	$srvcobjects_ref->{'msg-auth'}{'ports'}{'tcp'}{'31'}++	; 
#	$ports_ref->{'tcp'}{'31'}{'name'} = 'msg-auth'		; 
#	$srvcobjects_ref->{'cruise-diags'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cruise-diags'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-diags'}{'port'}{'udp'} = '8379'	; 
#	$srvcobjects_ref->{'cruise-diags'}{'ports'}{'udp'}{'8379'}++	; 
#	$ports_ref->{'udp'}{'8379'}{'name'} = 'cruise-diags'		; 
#	$srvcobjects_ref->{'cruise-diags'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cruise-diags'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-diags'}{'port'}{'tcp'} = '8379'	; 
#	$srvcobjects_ref->{'cruise-diags'}{'ports'}{'tcp'}{'8379'}++	; 
#	$ports_ref->{'tcp'}{'8379'}{'name'} = 'cruise-diags'		; 
#	$srvcobjects_ref->{'bintec-tapi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bintec-tapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bintec-tapi'}{'port'}{'udp'} = '2663'	; 
#	$srvcobjects_ref->{'bintec-tapi'}{'ports'}{'udp'}{'2663'}++	; 
#	$ports_ref->{'udp'}{'2663'}{'name'} = 'bintec-tapi'		; 
#	$srvcobjects_ref->{'bintec-tapi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bintec-tapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bintec-tapi'}{'port'}{'tcp'} = '2663'	; 
#	$srvcobjects_ref->{'bintec-tapi'}{'ports'}{'tcp'}{'2663'}++	; 
#	$ports_ref->{'tcp'}{'2663'}{'name'} = 'bintec-tapi'		; 
#	$srvcobjects_ref->{'at-zis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-zis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-zis'}{'port'}{'udp'} = '206'	; 
#	$srvcobjects_ref->{'at-zis'}{'ports'}{'udp'}{'206'}++	; 
#	$ports_ref->{'udp'}{'206'}{'name'} = 'at-zis'		; 
#	$srvcobjects_ref->{'at-zis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-zis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-zis'}{'port'}{'tcp'} = '206'	; 
#	$srvcobjects_ref->{'at-zis'}{'ports'}{'tcp'}{'206'}++	; 
#	$ports_ref->{'tcp'}{'206'}{'name'} = 'at-zis'		; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'port'}{'udp'} = '1902'	; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'ports'}{'udp'}{'1902'}++	; 
#	$ports_ref->{'udp'}{'1902'}{'name'} = 'fjicl-tep-b'		; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'port'}{'tcp'} = '1902'	; 
#	$srvcobjects_ref->{'fjicl-tep-b'}{'ports'}{'tcp'}{'1902'}++	; 
#	$ports_ref->{'tcp'}{'1902'}{'name'} = 'fjicl-tep-b'		; 
#	$srvcobjects_ref->{'bbn-mmx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bbn-mmx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bbn-mmx'}{'port'}{'udp'} = '1348'	; 
#	$srvcobjects_ref->{'bbn-mmx'}{'ports'}{'udp'}{'1348'}++	; 
#	$ports_ref->{'udp'}{'1348'}{'name'} = 'bbn-mmx'		; 
#	$srvcobjects_ref->{'bbn-mmx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bbn-mmx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bbn-mmx'}{'port'}{'tcp'} = '1348'	; 
#	$srvcobjects_ref->{'bbn-mmx'}{'ports'}{'tcp'}{'1348'}++	; 
#	$ports_ref->{'tcp'}{'1348'}{'name'} = 'bbn-mmx'		; 
#	$srvcobjects_ref->{'nta-us'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nta-us'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nta-us'}{'port'}{'udp'} = '7545'	; 
#	$srvcobjects_ref->{'nta-us'}{'ports'}{'udp'}{'7545'}++	; 
#	$ports_ref->{'udp'}{'7545'}{'name'} = 'nta-us'		; 
#	$srvcobjects_ref->{'nta-us'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nta-us'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nta-us'}{'port'}{'tcp'} = '7545'	; 
#	$srvcobjects_ref->{'nta-us'}{'ports'}{'tcp'}{'7545'}++	; 
#	$ports_ref->{'tcp'}{'7545'}{'name'} = 'nta-us'		; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'port'}{'udp'} = '5427'	; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'ports'}{'udp'}{'5427'}++	; 
#	$ports_ref->{'udp'}{'5427'}{'name'} = 'sco-peer-tta'		; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'port'}{'tcp'} = '5427'	; 
#	$srvcobjects_ref->{'sco-peer-tta'}{'ports'}{'tcp'}{'5427'}++	; 
#	$ports_ref->{'tcp'}{'5427'}{'name'} = 'sco-peer-tta'		; 
#	$srvcobjects_ref->{'apex-mesh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apex-mesh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apex-mesh'}{'port'}{'udp'} = '912'	; 
#	$srvcobjects_ref->{'apex-mesh'}{'ports'}{'udp'}{'912'}++	; 
#	$ports_ref->{'udp'}{'912'}{'name'} = 'apex-mesh'		; 
#	$srvcobjects_ref->{'apex-mesh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apex-mesh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apex-mesh'}{'port'}{'tcp'} = '912'	; 
#	$srvcobjects_ref->{'apex-mesh'}{'ports'}{'tcp'}{'912'}++	; 
#	$ports_ref->{'tcp'}{'912'}{'name'} = 'apex-mesh'		; 
#	$srvcobjects_ref->{'pop2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pop2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pop2'}{'port'}{'udp'} = '109'	; 
#	$srvcobjects_ref->{'pop2'}{'ports'}{'udp'}{'109'}++	; 
#	$ports_ref->{'udp'}{'109'}{'name'} = 'pop2'		; 
#	$srvcobjects_ref->{'pop2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pop2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pop2'}{'port'}{'tcp'} = '109'	; 
#	$srvcobjects_ref->{'pop2'}{'ports'}{'tcp'}{'109'}++	; 
#	$ports_ref->{'tcp'}{'109'}{'name'} = 'pop2'		; 
#	$srvcobjects_ref->{'infolibria'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infolibria'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infolibria'}{'port'}{'udp'} = '2319'	; 
#	$srvcobjects_ref->{'infolibria'}{'ports'}{'udp'}{'2319'}++	; 
#	$ports_ref->{'udp'}{'2319'}{'name'} = 'infolibria'		; 
#	$srvcobjects_ref->{'infolibria'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infolibria'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infolibria'}{'port'}{'tcp'} = '2319'	; 
#	$srvcobjects_ref->{'infolibria'}{'ports'}{'tcp'}{'2319'}++	; 
#	$ports_ref->{'tcp'}{'2319'}{'name'} = 'infolibria'		; 
#	$srvcobjects_ref->{'netplay-port2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netplay-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netplay-port2'}{'port'}{'udp'} = '3641'	; 
#	$srvcobjects_ref->{'netplay-port2'}{'ports'}{'udp'}{'3641'}++	; 
#	$ports_ref->{'udp'}{'3641'}{'name'} = 'netplay-port2'		; 
#	$srvcobjects_ref->{'netplay-port2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netplay-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netplay-port2'}{'port'}{'tcp'} = '3641'	; 
#	$srvcobjects_ref->{'netplay-port2'}{'ports'}{'tcp'}{'3641'}++	; 
#	$ports_ref->{'tcp'}{'3641'}{'name'} = 'netplay-port2'		; 
#	$srvcobjects_ref->{'sharp-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sharp-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sharp-server'}{'port'}{'udp'} = '3617'	; 
#	$srvcobjects_ref->{'sharp-server'}{'ports'}{'udp'}{'3617'}++	; 
#	$ports_ref->{'udp'}{'3617'}{'name'} = 'sharp-server'		; 
#	$srvcobjects_ref->{'sharp-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sharp-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sharp-server'}{'port'}{'tcp'} = '3617'	; 
#	$srvcobjects_ref->{'sharp-server'}{'ports'}{'tcp'}{'3617'}++	; 
#	$ports_ref->{'tcp'}{'3617'}{'name'} = 'sharp-server'		; 
#	$srvcobjects_ref->{'ntp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ntp'}{'port'}{'udp'} = '123'	; 
#	$srvcobjects_ref->{'ntp'}{'ports'}{'udp'}{'123'}++	; 
#	$ports_ref->{'udp'}{'123'}{'name'} = 'ntp'		; 
#	$srvcobjects_ref->{'ntp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ntp'}{'port'}{'tcp'} = '123'	; 
#	$srvcobjects_ref->{'ntp'}{'ports'}{'tcp'}{'123'}++	; 
#	$ports_ref->{'tcp'}{'123'}{'name'} = 'ntp'		; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'port'}{'udp'} = '4019'	; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'ports'}{'udp'}{'4019'}++	; 
#	$ports_ref->{'udp'}{'4019'}{'name'} = 'talarian-mcast5'		; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'port'}{'tcp'} = '4019'	; 
#	$srvcobjects_ref->{'talarian-mcast5'}{'ports'}{'tcp'}{'4019'}++	; 
#	$ports_ref->{'tcp'}{'4019'}{'name'} = 'talarian-mcast5'		; 
#	$srvcobjects_ref->{'rootd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rootd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rootd'}{'port'}{'udp'} = '1094'	; 
#	$srvcobjects_ref->{'rootd'}{'ports'}{'udp'}{'1094'}++	; 
#	$ports_ref->{'udp'}{'1094'}{'name'} = 'rootd'		; 
#	$srvcobjects_ref->{'rootd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rootd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rootd'}{'port'}{'tcp'} = '1094'	; 
#	$srvcobjects_ref->{'rootd'}{'ports'}{'tcp'}{'1094'}++	; 
#	$ports_ref->{'tcp'}{'1094'}{'name'} = 'rootd'		; 
#	$srvcobjects_ref->{'sftdst-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sftdst-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftdst-port'}{'port'}{'udp'} = '3230'	; 
#	$srvcobjects_ref->{'sftdst-port'}{'ports'}{'udp'}{'3230'}++	; 
#	$ports_ref->{'udp'}{'3230'}{'name'} = 'sftdst-port'		; 
#	$srvcobjects_ref->{'sftdst-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sftdst-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftdst-port'}{'port'}{'tcp'} = '3230'	; 
#	$srvcobjects_ref->{'sftdst-port'}{'ports'}{'tcp'}{'3230'}++	; 
#	$ports_ref->{'tcp'}{'3230'}{'name'} = 'sftdst-port'		; 
#	$srvcobjects_ref->{'fln-spx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fln-spx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fln-spx'}{'port'}{'udp'} = '221'	; 
#	$srvcobjects_ref->{'fln-spx'}{'ports'}{'udp'}{'221'}++	; 
#	$ports_ref->{'udp'}{'221'}{'name'} = 'fln-spx'		; 
#	$srvcobjects_ref->{'fln-spx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fln-spx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fln-spx'}{'port'}{'tcp'} = '221'	; 
#	$srvcobjects_ref->{'fln-spx'}{'ports'}{'tcp'}{'221'}++	; 
#	$ports_ref->{'tcp'}{'221'}{'name'} = 'fln-spx'		; 
#	$srvcobjects_ref->{'ddm-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddm-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddm-ssl'}{'port'}{'udp'} = '448'	; 
#	$srvcobjects_ref->{'ddm-ssl'}{'ports'}{'udp'}{'448'}++	; 
#	$ports_ref->{'udp'}{'448'}{'name'} = 'ddm-ssl'		; 
#	$srvcobjects_ref->{'ddm-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddm-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddm-ssl'}{'port'}{'tcp'} = '448'	; 
#	$srvcobjects_ref->{'ddm-ssl'}{'ports'}{'tcp'}{'448'}++	; 
#	$ports_ref->{'tcp'}{'448'}{'name'} = 'ddm-ssl'		; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'port'}{'udp'} = '5410'	; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'ports'}{'udp'}{'5410'}++	; 
#	$ports_ref->{'udp'}{'5410'}{'name'} = 'salient-usrmgr'		; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'port'}{'tcp'} = '5410'	; 
#	$srvcobjects_ref->{'salient-usrmgr'}{'ports'}{'tcp'}{'5410'}++	; 
#	$ports_ref->{'tcp'}{'5410'}{'name'} = 'salient-usrmgr'		; 
#	$srvcobjects_ref->{'sonardata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sonardata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonardata'}{'port'}{'udp'} = '2863'	; 
#	$srvcobjects_ref->{'sonardata'}{'ports'}{'udp'}{'2863'}++	; 
#	$ports_ref->{'udp'}{'2863'}{'name'} = 'sonardata'		; 
#	$srvcobjects_ref->{'sonardata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sonardata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonardata'}{'port'}{'tcp'} = '2863'	; 
#	$srvcobjects_ref->{'sonardata'}{'ports'}{'tcp'}{'2863'}++	; 
#	$ports_ref->{'tcp'}{'2863'}{'name'} = 'sonardata'		; 
#	$srvcobjects_ref->{'corbaloc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'corbaloc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corbaloc'}{'port'}{'udp'} = '2809'	; 
#	$srvcobjects_ref->{'corbaloc'}{'ports'}{'udp'}{'2809'}++	; 
#	$ports_ref->{'udp'}{'2809'}{'name'} = 'corbaloc'		; 
#	$srvcobjects_ref->{'corbaloc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'corbaloc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corbaloc'}{'port'}{'tcp'} = '2809'	; 
#	$srvcobjects_ref->{'corbaloc'}{'ports'}{'tcp'}{'2809'}++	; 
#	$ports_ref->{'tcp'}{'2809'}{'name'} = 'corbaloc'		; 
#	$srvcobjects_ref->{'health-polling'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'health-polling'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'health-polling'}{'port'}{'udp'} = '1161'	; 
#	$srvcobjects_ref->{'health-polling'}{'ports'}{'udp'}{'1161'}++	; 
#	$ports_ref->{'udp'}{'1161'}{'name'} = 'health-polling'		; 
#	$srvcobjects_ref->{'health-polling'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'health-polling'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'health-polling'}{'port'}{'tcp'} = '1161'	; 
#	$srvcobjects_ref->{'health-polling'}{'ports'}{'tcp'}{'1161'}++	; 
#	$ports_ref->{'tcp'}{'1161'}{'name'} = 'health-polling'		; 
#	$srvcobjects_ref->{'lanserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lanserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lanserver'}{'port'}{'udp'} = '637'	; 
#	$srvcobjects_ref->{'lanserver'}{'ports'}{'udp'}{'637'}++	; 
#	$ports_ref->{'udp'}{'637'}{'name'} = 'lanserver'		; 
#	$srvcobjects_ref->{'lanserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lanserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lanserver'}{'port'}{'tcp'} = '637'	; 
#	$srvcobjects_ref->{'lanserver'}{'ports'}{'tcp'}{'637'}++	; 
#	$ports_ref->{'tcp'}{'637'}{'name'} = 'lanserver'		; 
#	$srvcobjects_ref->{'lbf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lbf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbf'}{'port'}{'udp'} = '2466'	; 
#	$srvcobjects_ref->{'lbf'}{'ports'}{'udp'}{'2466'}++	; 
#	$ports_ref->{'udp'}{'2466'}{'name'} = 'lbf'		; 
#	$srvcobjects_ref->{'lbf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lbf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbf'}{'port'}{'tcp'} = '2466'	; 
#	$srvcobjects_ref->{'lbf'}{'ports'}{'tcp'}{'2466'}++	; 
#	$ports_ref->{'tcp'}{'2466'}{'name'} = 'lbf'		; 
#	$srvcobjects_ref->{'codasrv-se'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'codasrv-se'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codasrv-se'}{'port'}{'udp'} = '2433'	; 
#	$srvcobjects_ref->{'codasrv-se'}{'ports'}{'udp'}{'2433'}++	; 
#	$ports_ref->{'udp'}{'2433'}{'name'} = 'codasrv-se'		; 
#	$srvcobjects_ref->{'codasrv-se'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'codasrv-se'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codasrv-se'}{'port'}{'tcp'} = '2433'	; 
#	$srvcobjects_ref->{'codasrv-se'}{'ports'}{'tcp'}{'2433'}++	; 
#	$ports_ref->{'tcp'}{'2433'}{'name'} = 'codasrv-se'		; 
#	$srvcobjects_ref->{'iiop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iiop'}{'port'}{'udp'} = '535'	; 
#	$srvcobjects_ref->{'iiop'}{'ports'}{'udp'}{'535'}++	; 
#	$ports_ref->{'udp'}{'535'}{'name'} = 'iiop'		; 
#	$srvcobjects_ref->{'iiop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iiop'}{'port'}{'tcp'} = '535'	; 
#	$srvcobjects_ref->{'iiop'}{'ports'}{'tcp'}{'535'}++	; 
#	$ports_ref->{'tcp'}{'535'}{'name'} = 'iiop'		; 
#	$srvcobjects_ref->{'casanswmgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'casanswmgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'casanswmgmt'}{'port'}{'udp'} = '3669'	; 
#	$srvcobjects_ref->{'casanswmgmt'}{'ports'}{'udp'}{'3669'}++	; 
#	$ports_ref->{'udp'}{'3669'}{'name'} = 'casanswmgmt'		; 
#	$srvcobjects_ref->{'casanswmgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'casanswmgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'casanswmgmt'}{'port'}{'tcp'} = '3669'	; 
#	$srvcobjects_ref->{'casanswmgmt'}{'ports'}{'tcp'}{'3669'}++	; 
#	$ports_ref->{'tcp'}{'3669'}{'name'} = 'casanswmgmt'		; 
#	$srvcobjects_ref->{'ttnrepository'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttnrepository'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttnrepository'}{'port'}{'udp'} = '2943'	; 
#	$srvcobjects_ref->{'ttnrepository'}{'ports'}{'udp'}{'2943'}++	; 
#	$ports_ref->{'udp'}{'2943'}{'name'} = 'ttnrepository'		; 
#	$srvcobjects_ref->{'ttnrepository'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttnrepository'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttnrepository'}{'port'}{'tcp'} = '2943'	; 
#	$srvcobjects_ref->{'ttnrepository'}{'ports'}{'tcp'}{'2943'}++	; 
#	$ports_ref->{'tcp'}{'2943'}{'name'} = 'ttnrepository'		; 
#	$srvcobjects_ref->{'syncserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'syncserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syncserver'}{'port'}{'udp'} = '2647'	; 
#	$srvcobjects_ref->{'syncserver'}{'ports'}{'udp'}{'2647'}++	; 
#	$ports_ref->{'udp'}{'2647'}{'name'} = 'syncserver'		; 
#	$srvcobjects_ref->{'syncserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'syncserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syncserver'}{'port'}{'tcp'} = '2647'	; 
#	$srvcobjects_ref->{'syncserver'}{'ports'}{'tcp'}{'2647'}++	; 
#	$ports_ref->{'tcp'}{'2647'}{'name'} = 'syncserver'		; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'port'}{'udp'} = '2578'	; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'ports'}{'udp'}{'2578'}++	; 
#	$ports_ref->{'udp'}{'2578'}{'name'} = 'rvs-isdn-dcp'		; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'port'}{'tcp'} = '2578'	; 
#	$srvcobjects_ref->{'rvs-isdn-dcp'}{'ports'}{'tcp'}{'2578'}++	; 
#	$ports_ref->{'tcp'}{'2578'}{'name'} = 'rvs-isdn-dcp'		; 
#	$srvcobjects_ref->{'sanavigator'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sanavigator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sanavigator'}{'port'}{'udp'} = '4033'	; 
#	$srvcobjects_ref->{'sanavigator'}{'ports'}{'udp'}{'4033'}++	; 
#	$ports_ref->{'udp'}{'4033'}{'name'} = 'sanavigator'		; 
#	$srvcobjects_ref->{'sanavigator'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sanavigator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sanavigator'}{'port'}{'tcp'} = '4033'	; 
#	$srvcobjects_ref->{'sanavigator'}{'ports'}{'tcp'}{'4033'}++	; 
#	$ports_ref->{'tcp'}{'4033'}{'name'} = 'sanavigator'		; 
#	$srvcobjects_ref->{'netopia-vo4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netopia-vo4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo4'}{'port'}{'udp'} = '1842'	; 
#	$srvcobjects_ref->{'netopia-vo4'}{'ports'}{'udp'}{'1842'}++	; 
#	$ports_ref->{'udp'}{'1842'}{'name'} = 'netopia-vo4'		; 
#	$srvcobjects_ref->{'netopia-vo4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netopia-vo4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo4'}{'port'}{'tcp'} = '1842'	; 
#	$srvcobjects_ref->{'netopia-vo4'}{'ports'}{'tcp'}{'1842'}++	; 
#	$ports_ref->{'tcp'}{'1842'}{'name'} = 'netopia-vo4'		; 
#	$srvcobjects_ref->{'ddt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddt'}{'port'}{'udp'} = '1052'	; 
#	$srvcobjects_ref->{'ddt'}{'ports'}{'udp'}{'1052'}++	; 
#	$ports_ref->{'udp'}{'1052'}{'name'} = 'ddt'		; 
#	$srvcobjects_ref->{'ddt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddt'}{'port'}{'tcp'} = '1052'	; 
#	$srvcobjects_ref->{'ddt'}{'ports'}{'tcp'}{'1052'}++	; 
#	$ports_ref->{'tcp'}{'1052'}{'name'} = 'ddt'		; 
#	$srvcobjects_ref->{'rsap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsap'}{'port'}{'udp'} = '1647'	; 
#	$srvcobjects_ref->{'rsap'}{'ports'}{'udp'}{'1647'}++	; 
#	$ports_ref->{'udp'}{'1647'}{'name'} = 'rsap'		; 
#	$srvcobjects_ref->{'rsap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsap'}{'port'}{'tcp'} = '1647'	; 
#	$srvcobjects_ref->{'rsap'}{'ports'}{'tcp'}{'1647'}++	; 
#	$ports_ref->{'tcp'}{'1647'}{'name'} = 'rsap'		; 
#	$srvcobjects_ref->{'bspne-pcc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bspne-pcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bspne-pcc'}{'port'}{'udp'} = '1252'	; 
#	$srvcobjects_ref->{'bspne-pcc'}{'ports'}{'udp'}{'1252'}++	; 
#	$ports_ref->{'udp'}{'1252'}{'name'} = 'bspne-pcc'		; 
#	$srvcobjects_ref->{'bspne-pcc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bspne-pcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bspne-pcc'}{'port'}{'tcp'} = '1252'	; 
#	$srvcobjects_ref->{'bspne-pcc'}{'ports'}{'tcp'}{'1252'}++	; 
#	$ports_ref->{'tcp'}{'1252'}{'name'} = 'bspne-pcc'		; 
#	$srvcobjects_ref->{'pnbscada'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pnbscada'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnbscada'}{'port'}{'udp'} = '3875'	; 
#	$srvcobjects_ref->{'pnbscada'}{'ports'}{'udp'}{'3875'}++	; 
#	$ports_ref->{'udp'}{'3875'}{'name'} = 'pnbscada'		; 
#	$srvcobjects_ref->{'pnbscada'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pnbscada'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnbscada'}{'port'}{'tcp'} = '3875'	; 
#	$srvcobjects_ref->{'pnbscada'}{'ports'}{'tcp'}{'3875'}++	; 
#	$ports_ref->{'tcp'}{'3875'}{'name'} = 'pnbscada'		; 
#	$srvcobjects_ref->{'printer_agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'printer_agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'printer_agent'}{'port'}{'udp'} = '3396'	; 
#	$srvcobjects_ref->{'printer_agent'}{'ports'}{'udp'}{'3396'}++	; 
#	$ports_ref->{'udp'}{'3396'}{'name'} = 'printer_agent'		; 
#	$srvcobjects_ref->{'printer_agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'printer_agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'printer_agent'}{'port'}{'tcp'} = '3396'	; 
#	$srvcobjects_ref->{'printer_agent'}{'ports'}{'tcp'}{'3396'}++	; 
#	$ports_ref->{'tcp'}{'3396'}{'name'} = 'printer_agent'		; 
#	$srvcobjects_ref->{'l3-hawk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'l3-hawk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l3-hawk'}{'port'}{'udp'} = '2842'	; 
#	$srvcobjects_ref->{'l3-hawk'}{'ports'}{'udp'}{'2842'}++	; 
#	$ports_ref->{'udp'}{'2842'}{'name'} = 'l3-hawk'		; 
#	$srvcobjects_ref->{'l3-hawk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'l3-hawk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l3-hawk'}{'port'}{'tcp'} = '2842'	; 
#	$srvcobjects_ref->{'l3-hawk'}{'ports'}{'tcp'}{'2842'}++	; 
#	$ports_ref->{'tcp'}{'2842'}{'name'} = 'l3-hawk'		; 
#	$srvcobjects_ref->{'acmsoda'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acmsoda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acmsoda'}{'port'}{'udp'} = '6969'	; 
#	$srvcobjects_ref->{'acmsoda'}{'ports'}{'udp'}{'6969'}++	; 
#	$ports_ref->{'udp'}{'6969'}{'name'} = 'acmsoda'		; 
#	$srvcobjects_ref->{'acmsoda'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acmsoda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acmsoda'}{'port'}{'tcp'} = '6969'	; 
#	$srvcobjects_ref->{'acmsoda'}{'ports'}{'tcp'}{'6969'}++	; 
#	$ports_ref->{'tcp'}{'6969'}{'name'} = 'acmsoda'		; 
#	$srvcobjects_ref->{'ilss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ilss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ilss'}{'port'}{'udp'} = '4802'	; 
#	$srvcobjects_ref->{'ilss'}{'ports'}{'udp'}{'4802'}++	; 
#	$ports_ref->{'udp'}{'4802'}{'name'} = 'ilss'		; 
#	$srvcobjects_ref->{'ilss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ilss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ilss'}{'port'}{'tcp'} = '4802'	; 
#	$srvcobjects_ref->{'ilss'}{'ports'}{'tcp'}{'4802'}++	; 
#	$ports_ref->{'tcp'}{'4802'}{'name'} = 'ilss'		; 
#	$srvcobjects_ref->{'ariliamulti'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ariliamulti'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariliamulti'}{'port'}{'udp'} = '3140'	; 
#	$srvcobjects_ref->{'ariliamulti'}{'ports'}{'udp'}{'3140'}++	; 
#	$ports_ref->{'udp'}{'3140'}{'name'} = 'ariliamulti'		; 
#	$srvcobjects_ref->{'ariliamulti'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ariliamulti'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariliamulti'}{'port'}{'tcp'} = '3140'	; 
#	$srvcobjects_ref->{'ariliamulti'}{'ports'}{'tcp'}{'3140'}++	; 
#	$ports_ref->{'tcp'}{'3140'}{'name'} = 'ariliamulti'		; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'port'}{'udp'} = '2298'	; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'ports'}{'udp'}{'2298'}++	; 
#	$ports_ref->{'udp'}{'2298'}{'name'} = 'd2k-datamover2'		; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'port'}{'tcp'} = '2298'	; 
#	$srvcobjects_ref->{'d2k-datamover2'}{'ports'}{'tcp'}{'2298'}++	; 
#	$ports_ref->{'tcp'}{'2298'}{'name'} = 'd2k-datamover2'		; 
#	$srvcobjects_ref->{'echonet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'echonet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'echonet'}{'port'}{'udp'} = '3610'	; 
#	$srvcobjects_ref->{'echonet'}{'ports'}{'udp'}{'3610'}++	; 
#	$ports_ref->{'udp'}{'3610'}{'name'} = 'echonet'		; 
#	$srvcobjects_ref->{'echonet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'echonet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'echonet'}{'port'}{'tcp'} = '3610'	; 
#	$srvcobjects_ref->{'echonet'}{'ports'}{'tcp'}{'3610'}++	; 
#	$ports_ref->{'tcp'}{'3610'}{'name'} = 'echonet'		; 
#	$srvcobjects_ref->{'ebinsite'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ebinsite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ebinsite'}{'port'}{'udp'} = '2651'	; 
#	$srvcobjects_ref->{'ebinsite'}{'ports'}{'udp'}{'2651'}++	; 
#	$ports_ref->{'udp'}{'2651'}{'name'} = 'ebinsite'		; 
#	$srvcobjects_ref->{'ebinsite'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ebinsite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ebinsite'}{'port'}{'tcp'} = '2651'	; 
#	$srvcobjects_ref->{'ebinsite'}{'ports'}{'tcp'}{'2651'}++	; 
#	$ports_ref->{'tcp'}{'2651'}{'name'} = 'ebinsite'		; 
#	$srvcobjects_ref->{'ace-client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ace-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-client'}{'port'}{'udp'} = '2334'	; 
#	$srvcobjects_ref->{'ace-client'}{'ports'}{'udp'}{'2334'}++	; 
#	$ports_ref->{'udp'}{'2334'}{'name'} = 'ace-client'		; 
#	$srvcobjects_ref->{'ace-client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ace-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-client'}{'port'}{'tcp'} = '2334'	; 
#	$srvcobjects_ref->{'ace-client'}{'ports'}{'tcp'}{'2334'}++	; 
#	$ports_ref->{'tcp'}{'2334'}{'name'} = 'ace-client'		; 
#	$srvcobjects_ref->{'isakmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isakmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isakmp'}{'port'}{'udp'} = '500'	; 
#	$srvcobjects_ref->{'isakmp'}{'ports'}{'udp'}{'500'}++	; 
#	$ports_ref->{'udp'}{'500'}{'name'} = 'isakmp'		; 
#	$srvcobjects_ref->{'isakmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isakmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isakmp'}{'port'}{'tcp'} = '500'	; 
#	$srvcobjects_ref->{'isakmp'}{'ports'}{'tcp'}{'500'}++	; 
#	$ports_ref->{'tcp'}{'500'}{'name'} = 'isakmp'		; 
#	$srvcobjects_ref->{'upgrade'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'upgrade'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upgrade'}{'port'}{'udp'} = '2537'	; 
#	$srvcobjects_ref->{'upgrade'}{'ports'}{'udp'}{'2537'}++	; 
#	$ports_ref->{'udp'}{'2537'}{'name'} = 'upgrade'		; 
#	$srvcobjects_ref->{'upgrade'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'upgrade'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upgrade'}{'port'}{'tcp'} = '2537'	; 
#	$srvcobjects_ref->{'upgrade'}{'ports'}{'tcp'}{'2537'}++	; 
#	$ports_ref->{'tcp'}{'2537'}{'name'} = 'upgrade'		; 
#	$srvcobjects_ref->{'passwrd-policy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'passwrd-policy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'passwrd-policy'}{'port'}{'udp'} = '1333'	; 
#	$srvcobjects_ref->{'passwrd-policy'}{'ports'}{'udp'}{'1333'}++	; 
#	$ports_ref->{'udp'}{'1333'}{'name'} = 'passwrd-policy'		; 
#	$srvcobjects_ref->{'passwrd-policy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'passwrd-policy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'passwrd-policy'}{'port'}{'tcp'} = '1333'	; 
#	$srvcobjects_ref->{'passwrd-policy'}{'ports'}{'tcp'}{'1333'}++	; 
#	$ports_ref->{'tcp'}{'1333'}{'name'} = 'passwrd-policy'		; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'port'}{'udp'} = '2738'	; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'ports'}{'udp'}{'2738'}++	; 
#	$ports_ref->{'udp'}{'2738'}{'name'} = 'ndl-tcp-ois-gw'		; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'port'}{'tcp'} = '2738'	; 
#	$srvcobjects_ref->{'ndl-tcp-ois-gw'}{'ports'}{'tcp'}{'2738'}++	; 
#	$ports_ref->{'tcp'}{'2738'}{'name'} = 'ndl-tcp-ois-gw'		; 
#	$srvcobjects_ref->{'krb524'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'krb524'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'krb524'}{'port'}{'udp'} = '4444'	; 
#	$srvcobjects_ref->{'krb524'}{'ports'}{'udp'}{'4444'}++	; 
#	$ports_ref->{'udp'}{'4444'}{'name'} = 'krb524'		; 
#	$srvcobjects_ref->{'krb524'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'krb524'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'krb524'}{'port'}{'tcp'} = '4444'	; 
#	$srvcobjects_ref->{'krb524'}{'ports'}{'tcp'}{'4444'}++	; 
#	$ports_ref->{'tcp'}{'4444'}{'name'} = 'krb524'		; 
#	$srvcobjects_ref->{'devbasic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'devbasic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'devbasic'}{'port'}{'udp'} = '5426'	; 
#	$srvcobjects_ref->{'devbasic'}{'ports'}{'udp'}{'5426'}++	; 
#	$ports_ref->{'udp'}{'5426'}{'name'} = 'devbasic'		; 
#	$srvcobjects_ref->{'devbasic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'devbasic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'devbasic'}{'port'}{'tcp'} = '5426'	; 
#	$srvcobjects_ref->{'devbasic'}{'ports'}{'tcp'}{'5426'}++	; 
#	$ports_ref->{'tcp'}{'5426'}{'name'} = 'devbasic'		; 
#	$srvcobjects_ref->{'mps-raft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mps-raft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mps-raft'}{'port'}{'udp'} = '1700'	; 
#	$srvcobjects_ref->{'mps-raft'}{'ports'}{'udp'}{'1700'}++	; 
#	$ports_ref->{'udp'}{'1700'}{'name'} = 'mps-raft'		; 
#	$srvcobjects_ref->{'mps-raft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mps-raft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mps-raft'}{'port'}{'tcp'} = '1700'	; 
#	$srvcobjects_ref->{'mps-raft'}{'ports'}{'tcp'}{'1700'}++	; 
#	$ports_ref->{'tcp'}{'1700'}{'name'} = 'mps-raft'		; 
#	$srvcobjects_ref->{'afpovertcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afpovertcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afpovertcp'}{'port'}{'udp'} = '548'	; 
#	$srvcobjects_ref->{'afpovertcp'}{'ports'}{'udp'}{'548'}++	; 
#	$ports_ref->{'udp'}{'548'}{'name'} = 'afpovertcp'		; 
#	$srvcobjects_ref->{'afpovertcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afpovertcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afpovertcp'}{'port'}{'tcp'} = '548'	; 
#	$srvcobjects_ref->{'afpovertcp'}{'ports'}{'tcp'}{'548'}++	; 
#	$ports_ref->{'tcp'}{'548'}{'name'} = 'afpovertcp'		; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'port'}{'udp'} = '3660'	; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'ports'}{'udp'}{'3660'}++	; 
#	$ports_ref->{'udp'}{'3660'}{'name'} = 'can-nds-ssl'		; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'port'}{'tcp'} = '3660'	; 
#	$srvcobjects_ref->{'can-nds-ssl'}{'ports'}{'tcp'}{'3660'}++	; 
#	$ports_ref->{'tcp'}{'3660'}{'name'} = 'can-nds-ssl'		; 
#	$srvcobjects_ref->{'bmc-messaging'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-messaging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-messaging'}{'port'}{'udp'} = '2059'	; 
#	$srvcobjects_ref->{'bmc-messaging'}{'ports'}{'udp'}{'2059'}++	; 
#	$ports_ref->{'udp'}{'2059'}{'name'} = 'bmc-messaging'		; 
#	$srvcobjects_ref->{'bmc-messaging'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-messaging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-messaging'}{'port'}{'tcp'} = '2059'	; 
#	$srvcobjects_ref->{'bmc-messaging'}{'ports'}{'tcp'}{'2059'}++	; 
#	$ports_ref->{'tcp'}{'2059'}{'name'} = 'bmc-messaging'		; 
#	$srvcobjects_ref->{'3com-amp3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3com-amp3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-amp3'}{'port'}{'udp'} = '629'	; 
#	$srvcobjects_ref->{'3com-amp3'}{'ports'}{'udp'}{'629'}++	; 
#	$ports_ref->{'udp'}{'629'}{'name'} = '3com-amp3'		; 
#	$srvcobjects_ref->{'3com-amp3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3com-amp3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-amp3'}{'port'}{'tcp'} = '629'	; 
#	$srvcobjects_ref->{'3com-amp3'}{'ports'}{'tcp'}{'629'}++	; 
#	$ports_ref->{'tcp'}{'629'}{'name'} = '3com-amp3'		; 
#	$srvcobjects_ref->{'ncl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncl'}{'port'}{'udp'} = '2397'	; 
#	$srvcobjects_ref->{'ncl'}{'ports'}{'udp'}{'2397'}++	; 
#	$ports_ref->{'udp'}{'2397'}{'name'} = 'ncl'		; 
#	$srvcobjects_ref->{'ncl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncl'}{'port'}{'tcp'} = '2397'	; 
#	$srvcobjects_ref->{'ncl'}{'ports'}{'tcp'}{'2397'}++	; 
#	$ports_ref->{'tcp'}{'2397'}{'name'} = 'ncl'		; 
#	$srvcobjects_ref->{'dxadmind'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dxadmind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dxadmind'}{'port'}{'udp'} = '1958'	; 
#	$srvcobjects_ref->{'dxadmind'}{'ports'}{'udp'}{'1958'}++	; 
#	$ports_ref->{'udp'}{'1958'}{'name'} = 'dxadmind'		; 
#	$srvcobjects_ref->{'dxadmind'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dxadmind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dxadmind'}{'port'}{'tcp'} = '1958'	; 
#	$srvcobjects_ref->{'dxadmind'}{'ports'}{'tcp'}{'1958'}++	; 
#	$ports_ref->{'tcp'}{'1958'}{'name'} = 'dxadmind'		; 
#	$srvcobjects_ref->{'beacon-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'beacon-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beacon-port'}{'port'}{'udp'} = '3124'	; 
#	$srvcobjects_ref->{'beacon-port'}{'ports'}{'udp'}{'3124'}++	; 
#	$ports_ref->{'udp'}{'3124'}{'name'} = 'beacon-port'		; 
#	$srvcobjects_ref->{'beacon-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'beacon-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beacon-port'}{'port'}{'tcp'} = '3124'	; 
#	$srvcobjects_ref->{'beacon-port'}{'ports'}{'tcp'}{'3124'}++	; 
#	$ports_ref->{'tcp'}{'3124'}{'name'} = 'beacon-port'		; 
#	$srvcobjects_ref->{'abacus-remote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abacus-remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abacus-remote'}{'port'}{'udp'} = '2894'	; 
#	$srvcobjects_ref->{'abacus-remote'}{'ports'}{'udp'}{'2894'}++	; 
#	$ports_ref->{'udp'}{'2894'}{'name'} = 'abacus-remote'		; 
#	$srvcobjects_ref->{'abacus-remote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abacus-remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abacus-remote'}{'port'}{'tcp'} = '2894'	; 
#	$srvcobjects_ref->{'abacus-remote'}{'ports'}{'tcp'}{'2894'}++	; 
#	$ports_ref->{'tcp'}{'2894'}{'name'} = 'abacus-remote'		; 
#	$srvcobjects_ref->{'cspmulti'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cspmulti'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspmulti'}{'port'}{'udp'} = '2807'	; 
#	$srvcobjects_ref->{'cspmulti'}{'ports'}{'udp'}{'2807'}++	; 
#	$ports_ref->{'udp'}{'2807'}{'name'} = 'cspmulti'		; 
#	$srvcobjects_ref->{'cspmulti'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cspmulti'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspmulti'}{'port'}{'tcp'} = '2807'	; 
#	$srvcobjects_ref->{'cspmulti'}{'ports'}{'tcp'}{'2807'}++	; 
#	$ports_ref->{'tcp'}{'2807'}{'name'} = 'cspmulti'		; 
#	$srvcobjects_ref->{'lavenir-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lavenir-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lavenir-lm'}{'port'}{'udp'} = '3373'	; 
#	$srvcobjects_ref->{'lavenir-lm'}{'ports'}{'udp'}{'3373'}++	; 
#	$ports_ref->{'udp'}{'3373'}{'name'} = 'lavenir-lm'		; 
#	$srvcobjects_ref->{'lavenir-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lavenir-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lavenir-lm'}{'port'}{'tcp'} = '3373'	; 
#	$srvcobjects_ref->{'lavenir-lm'}{'ports'}{'tcp'}{'3373'}++	; 
#	$ports_ref->{'tcp'}{'3373'}{'name'} = 'lavenir-lm'		; 
#	$srvcobjects_ref->{'jmact5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmact5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmact5'}{'port'}{'udp'} = '2957'	; 
#	$srvcobjects_ref->{'jmact5'}{'ports'}{'udp'}{'2957'}++	; 
#	$ports_ref->{'udp'}{'2957'}{'name'} = 'jmact5'		; 
#	$srvcobjects_ref->{'jmact5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmact5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmact5'}{'port'}{'tcp'} = '2957'	; 
#	$srvcobjects_ref->{'jmact5'}{'ports'}{'tcp'}{'2957'}++	; 
#	$ports_ref->{'tcp'}{'2957'}{'name'} = 'jmact5'		; 
#	$srvcobjects_ref->{'ccmad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ccmad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmad'}{'port'}{'udp'} = '3114'	; 
#	$srvcobjects_ref->{'ccmad'}{'ports'}{'udp'}{'3114'}++	; 
#	$ports_ref->{'udp'}{'3114'}{'name'} = 'ccmad'		; 
#	$srvcobjects_ref->{'ccmad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ccmad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmad'}{'port'}{'tcp'} = '3114'	; 
#	$srvcobjects_ref->{'ccmad'}{'ports'}{'tcp'}{'3114'}++	; 
#	$ports_ref->{'tcp'}{'3114'}{'name'} = 'ccmad'		; 
#	$srvcobjects_ref->{'nsrmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsrmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsrmp'}{'port'}{'udp'} = '359'	; 
#	$srvcobjects_ref->{'nsrmp'}{'ports'}{'udp'}{'359'}++	; 
#	$ports_ref->{'udp'}{'359'}{'name'} = 'nsrmp'		; 
#	$srvcobjects_ref->{'nsrmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsrmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsrmp'}{'port'}{'tcp'} = '359'	; 
#	$srvcobjects_ref->{'nsrmp'}{'ports'}{'tcp'}{'359'}++	; 
#	$ports_ref->{'tcp'}{'359'}{'name'} = 'nsrmp'		; 
#	$srvcobjects_ref->{'msp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msp'}{'port'}{'udp'} = '18'	; 
#	$srvcobjects_ref->{'msp'}{'ports'}{'udp'}{'18'}++	; 
#	$ports_ref->{'udp'}{'18'}{'name'} = 'msp'		; 
#	$srvcobjects_ref->{'msp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msp'}{'port'}{'udp'} = '2438'	; 
#	$srvcobjects_ref->{'msp'}{'ports'}{'udp'}{'2438'}++	; 
#	$ports_ref->{'udp'}{'2438'}{'name'} = 'msp'		; 
#	$srvcobjects_ref->{'msp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msp'}{'port'}{'tcp'} = '18'	; 
#	$srvcobjects_ref->{'msp'}{'ports'}{'tcp'}{'18'}++	; 
#	$ports_ref->{'tcp'}{'18'}{'name'} = 'msp'		; 
#	$srvcobjects_ref->{'msp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msp'}{'port'}{'tcp'} = '2438'	; 
#	$srvcobjects_ref->{'msp'}{'ports'}{'tcp'}{'2438'}++	; 
#	$ports_ref->{'tcp'}{'2438'}{'name'} = 'msp'		; 
#	$srvcobjects_ref->{'dsnl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsnl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsnl'}{'port'}{'udp'} = '3231'	; 
#	$srvcobjects_ref->{'dsnl'}{'ports'}{'udp'}{'3231'}++	; 
#	$ports_ref->{'udp'}{'3231'}{'name'} = 'dsnl'		; 
#	$srvcobjects_ref->{'dsnl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsnl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsnl'}{'port'}{'tcp'} = '3231'	; 
#	$srvcobjects_ref->{'dsnl'}{'ports'}{'tcp'}{'3231'}++	; 
#	$ports_ref->{'tcp'}{'3231'}{'name'} = 'dsnl'		; 
#	$srvcobjects_ref->{'sweetware-apps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sweetware-apps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sweetware-apps'}{'port'}{'udp'} = '1221'	; 
#	$srvcobjects_ref->{'sweetware-apps'}{'ports'}{'udp'}{'1221'}++	; 
#	$ports_ref->{'udp'}{'1221'}{'name'} = 'sweetware-apps'		; 
#	$srvcobjects_ref->{'sweetware-apps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sweetware-apps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sweetware-apps'}{'port'}{'tcp'} = '1221'	; 
#	$srvcobjects_ref->{'sweetware-apps'}{'ports'}{'tcp'}{'1221'}++	; 
#	$ports_ref->{'tcp'}{'1221'}{'name'} = 'sweetware-apps'		; 
#	$srvcobjects_ref->{'apc-2160'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-2160'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-2160'}{'port'}{'udp'} = '2160'	; 
#	$srvcobjects_ref->{'apc-2160'}{'ports'}{'udp'}{'2160'}++	; 
#	$ports_ref->{'udp'}{'2160'}{'name'} = 'apc-2160'		; 
#	$srvcobjects_ref->{'apc-2160'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-2160'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-2160'}{'port'}{'tcp'} = '2160'	; 
#	$srvcobjects_ref->{'apc-2160'}{'ports'}{'tcp'}{'2160'}++	; 
#	$ports_ref->{'tcp'}{'2160'}{'name'} = 'apc-2160'		; 
#	$srvcobjects_ref->{'espeech-rtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'espeech-rtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'espeech-rtp'}{'port'}{'udp'} = '8417'	; 
#	$srvcobjects_ref->{'espeech-rtp'}{'ports'}{'udp'}{'8417'}++	; 
#	$ports_ref->{'udp'}{'8417'}{'name'} = 'espeech-rtp'		; 
#	$srvcobjects_ref->{'espeech-rtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'espeech-rtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'espeech-rtp'}{'port'}{'tcp'} = '8417'	; 
#	$srvcobjects_ref->{'espeech-rtp'}{'ports'}{'tcp'}{'8417'}++	; 
#	$ports_ref->{'tcp'}{'8417'}{'name'} = 'espeech-rtp'		; 
#	$srvcobjects_ref->{'nettest'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nettest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nettest'}{'port'}{'udp'} = '4138'	; 
#	$srvcobjects_ref->{'nettest'}{'ports'}{'udp'}{'4138'}++	; 
#	$ports_ref->{'udp'}{'4138'}{'name'} = 'nettest'		; 
#	$srvcobjects_ref->{'nettest'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nettest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nettest'}{'port'}{'tcp'} = '4138'	; 
#	$srvcobjects_ref->{'nettest'}{'ports'}{'tcp'}{'4138'}++	; 
#	$ports_ref->{'tcp'}{'4138'}{'name'} = 'nettest'		; 
#	$srvcobjects_ref->{'entp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entp'}{'port'}{'udp'} = '1865'	; 
#	$srvcobjects_ref->{'entp'}{'ports'}{'udp'}{'1865'}++	; 
#	$ports_ref->{'udp'}{'1865'}{'name'} = 'entp'		; 
#	$srvcobjects_ref->{'entp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entp'}{'port'}{'tcp'} = '1865'	; 
#	$srvcobjects_ref->{'entp'}{'ports'}{'tcp'}{'1865'}++	; 
#	$ports_ref->{'tcp'}{'1865'}{'name'} = 'entp'		; 
#	$srvcobjects_ref->{'sage-best-com2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sage-best-com2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sage-best-com2'}{'port'}{'udp'} = '14034'	; 
#	$srvcobjects_ref->{'sage-best-com2'}{'ports'}{'udp'}{'14034'}++	; 
#	$ports_ref->{'udp'}{'14034'}{'name'} = 'sage-best-com2'		; 
#	$srvcobjects_ref->{'sage-best-com2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sage-best-com2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sage-best-com2'}{'port'}{'tcp'} = '14034'	; 
#	$srvcobjects_ref->{'sage-best-com2'}{'ports'}{'tcp'}{'14034'}++	; 
#	$ports_ref->{'tcp'}{'14034'}{'name'} = 'sage-best-com2'		; 
#	$srvcobjects_ref->{'sslp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sslp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sslp'}{'port'}{'udp'} = '1750'	; 
#	$srvcobjects_ref->{'sslp'}{'ports'}{'udp'}{'1750'}++	; 
#	$ports_ref->{'udp'}{'1750'}{'name'} = 'sslp'		; 
#	$srvcobjects_ref->{'sslp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sslp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sslp'}{'port'}{'tcp'} = '1750'	; 
#	$srvcobjects_ref->{'sslp'}{'ports'}{'tcp'}{'1750'}++	; 
#	$ports_ref->{'tcp'}{'1750'}{'name'} = 'sslp'		; 
#	$srvcobjects_ref->{'icl-twobase5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase5'}{'port'}{'udp'} = '25004'	; 
#	$srvcobjects_ref->{'icl-twobase5'}{'ports'}{'udp'}{'25004'}++	; 
#	$ports_ref->{'udp'}{'25004'}{'name'} = 'icl-twobase5'		; 
#	$srvcobjects_ref->{'icl-twobase5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase5'}{'port'}{'tcp'} = '25004'	; 
#	$srvcobjects_ref->{'icl-twobase5'}{'ports'}{'tcp'}{'25004'}++	; 
#	$ports_ref->{'tcp'}{'25004'}{'name'} = 'icl-twobase5'		; 
#	$srvcobjects_ref->{'bprd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bprd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bprd'}{'port'}{'udp'} = '13720'	; 
#	$srvcobjects_ref->{'bprd'}{'ports'}{'udp'}{'13720'}++	; 
#	$ports_ref->{'udp'}{'13720'}{'name'} = 'bprd'		; 
#	$srvcobjects_ref->{'bprd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bprd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bprd'}{'port'}{'tcp'} = '13720'	; 
#	$srvcobjects_ref->{'bprd'}{'ports'}{'tcp'}{'13720'}++	; 
#	$ports_ref->{'tcp'}{'13720'}{'name'} = 'bprd'		; 
#	$srvcobjects_ref->{'swtp-port2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swtp-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swtp-port2'}{'port'}{'udp'} = '9282'	; 
#	$srvcobjects_ref->{'swtp-port2'}{'ports'}{'udp'}{'9282'}++	; 
#	$ports_ref->{'udp'}{'9282'}{'name'} = 'swtp-port2'		; 
#	$srvcobjects_ref->{'swtp-port2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swtp-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swtp-port2'}{'port'}{'tcp'} = '9282'	; 
#	$srvcobjects_ref->{'swtp-port2'}{'ports'}{'tcp'}{'9282'}++	; 
#	$ports_ref->{'tcp'}{'9282'}{'name'} = 'swtp-port2'		; 
#	$srvcobjects_ref->{'pscupd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pscupd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pscupd'}{'port'}{'udp'} = '3453'	; 
#	$srvcobjects_ref->{'pscupd'}{'ports'}{'udp'}{'3453'}++	; 
#	$ports_ref->{'udp'}{'3453'}{'name'} = 'pscupd'		; 
#	$srvcobjects_ref->{'pscupd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pscupd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pscupd'}{'port'}{'tcp'} = '3453'	; 
#	$srvcobjects_ref->{'pscupd'}{'ports'}{'tcp'}{'3453'}++	; 
#	$ports_ref->{'tcp'}{'3453'}{'name'} = 'pscupd'		; 
#	$srvcobjects_ref->{'ontime'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ontime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ontime'}{'port'}{'udp'} = '1622'	; 
#	$srvcobjects_ref->{'ontime'}{'ports'}{'udp'}{'1622'}++	; 
#	$ports_ref->{'udp'}{'1622'}{'name'} = 'ontime'		; 
#	$srvcobjects_ref->{'ontime'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ontime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ontime'}{'port'}{'tcp'} = '1622'	; 
#	$srvcobjects_ref->{'ontime'}{'ports'}{'tcp'}{'1622'}++	; 
#	$ports_ref->{'tcp'}{'1622'}{'name'} = 'ontime'		; 
#	$srvcobjects_ref->{'ms-shuttle'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-shuttle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-shuttle'}{'port'}{'udp'} = '568'	; 
#	$srvcobjects_ref->{'ms-shuttle'}{'ports'}{'udp'}{'568'}++	; 
#	$ports_ref->{'udp'}{'568'}{'name'} = 'ms-shuttle'		; 
#	$srvcobjects_ref->{'ms-shuttle'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-shuttle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-shuttle'}{'port'}{'tcp'} = '568'	; 
#	$srvcobjects_ref->{'ms-shuttle'}{'ports'}{'tcp'}{'568'}++	; 
#	$ports_ref->{'tcp'}{'568'}{'name'} = 'ms-shuttle'		; 
#	$srvcobjects_ref->{'veronica'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'veronica'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veronica'}{'port'}{'udp'} = '2770'	; 
#	$srvcobjects_ref->{'veronica'}{'ports'}{'udp'}{'2770'}++	; 
#	$ports_ref->{'udp'}{'2770'}{'name'} = 'veronica'		; 
#	$srvcobjects_ref->{'veronica'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'veronica'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veronica'}{'port'}{'tcp'} = '2770'	; 
#	$srvcobjects_ref->{'veronica'}{'ports'}{'tcp'}{'2770'}++	; 
#	$ports_ref->{'tcp'}{'2770'}{'name'} = 'veronica'		; 
#	$srvcobjects_ref->{'ncr_ccl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncr_ccl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncr_ccl'}{'port'}{'udp'} = '2528'	; 
#	$srvcobjects_ref->{'ncr_ccl'}{'ports'}{'udp'}{'2528'}++	; 
#	$ports_ref->{'udp'}{'2528'}{'name'} = 'ncr_ccl'		; 
#	$srvcobjects_ref->{'ncr_ccl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncr_ccl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncr_ccl'}{'port'}{'tcp'} = '2528'	; 
#	$srvcobjects_ref->{'ncr_ccl'}{'ports'}{'tcp'}{'2528'}++	; 
#	$ports_ref->{'tcp'}{'2528'}{'name'} = 'ncr_ccl'		; 
#	$srvcobjects_ref->{'dbdb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbdb'}{'port'}{'udp'} = '6104'	; 
#	$srvcobjects_ref->{'dbdb'}{'ports'}{'udp'}{'6104'}++	; 
#	$ports_ref->{'udp'}{'6104'}{'name'} = 'dbdb'		; 
#	$srvcobjects_ref->{'dbdb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbdb'}{'port'}{'tcp'} = '6104'	; 
#	$srvcobjects_ref->{'dbdb'}{'ports'}{'tcp'}{'6104'}++	; 
#	$ports_ref->{'tcp'}{'6104'}{'name'} = 'dbdb'		; 
#	$srvcobjects_ref->{'tcoregagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tcoregagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcoregagent'}{'port'}{'udp'} = '1976'	; 
#	$srvcobjects_ref->{'tcoregagent'}{'ports'}{'udp'}{'1976'}++	; 
#	$ports_ref->{'udp'}{'1976'}{'name'} = 'tcoregagent'		; 
#	$srvcobjects_ref->{'tcoregagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcoregagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcoregagent'}{'port'}{'tcp'} = '1976'	; 
#	$srvcobjects_ref->{'tcoregagent'}{'ports'}{'tcp'}{'1976'}++	; 
#	$ports_ref->{'tcp'}{'1976'}{'name'} = 'tcoregagent'		; 
#	$srvcobjects_ref->{'netbill-prod'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbill-prod'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-prod'}{'port'}{'udp'} = '1616'	; 
#	$srvcobjects_ref->{'netbill-prod'}{'ports'}{'udp'}{'1616'}++	; 
#	$ports_ref->{'udp'}{'1616'}{'name'} = 'netbill-prod'		; 
#	$srvcobjects_ref->{'netbill-prod'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbill-prod'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-prod'}{'port'}{'tcp'} = '1616'	; 
#	$srvcobjects_ref->{'netbill-prod'}{'ports'}{'tcp'}{'1616'}++	; 
#	$ports_ref->{'tcp'}{'1616'}{'name'} = 'netbill-prod'		; 
#	$srvcobjects_ref->{'nbx-ser'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nbx-ser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-ser'}{'port'}{'udp'} = '2095'	; 
#	$srvcobjects_ref->{'nbx-ser'}{'ports'}{'udp'}{'2095'}++	; 
#	$ports_ref->{'udp'}{'2095'}{'name'} = 'nbx-ser'		; 
#	$srvcobjects_ref->{'nbx-ser'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nbx-ser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-ser'}{'port'}{'tcp'} = '2095'	; 
#	$srvcobjects_ref->{'nbx-ser'}{'ports'}{'tcp'}{'2095'}++	; 
#	$ports_ref->{'tcp'}{'2095'}{'name'} = 'nbx-ser'		; 
#	$srvcobjects_ref->{'csvr-proxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csvr-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csvr-proxy'}{'port'}{'udp'} = '3190'	; 
#	$srvcobjects_ref->{'csvr-proxy'}{'ports'}{'udp'}{'3190'}++	; 
#	$ports_ref->{'udp'}{'3190'}{'name'} = 'csvr-proxy'		; 
#	$srvcobjects_ref->{'csvr-proxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csvr-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csvr-proxy'}{'port'}{'tcp'} = '3190'	; 
#	$srvcobjects_ref->{'csvr-proxy'}{'ports'}{'tcp'}{'3190'}++	; 
#	$ports_ref->{'tcp'}{'3190'}{'name'} = 'csvr-proxy'		; 
#	$srvcobjects_ref->{'4talk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'4talk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'4talk'}{'port'}{'udp'} = '3284'	; 
#	$srvcobjects_ref->{'4talk'}{'ports'}{'udp'}{'3284'}++	; 
#	$ports_ref->{'udp'}{'3284'}{'name'} = '4talk'		; 
#	$srvcobjects_ref->{'4talk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'4talk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'4talk'}{'port'}{'tcp'} = '3284'	; 
#	$srvcobjects_ref->{'4talk'}{'ports'}{'tcp'}{'3284'}++	; 
#	$ports_ref->{'tcp'}{'3284'}{'name'} = '4talk'		; 
#	$srvcobjects_ref->{'pawserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pawserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pawserv'}{'port'}{'udp'} = '345'	; 
#	$srvcobjects_ref->{'pawserv'}{'ports'}{'udp'}{'345'}++	; 
#	$ports_ref->{'udp'}{'345'}{'name'} = 'pawserv'		; 
#	$srvcobjects_ref->{'pawserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pawserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pawserv'}{'port'}{'tcp'} = '345'	; 
#	$srvcobjects_ref->{'pawserv'}{'ports'}{'tcp'}{'345'}++	; 
#	$ports_ref->{'tcp'}{'345'}{'name'} = 'pawserv'		; 
#	$srvcobjects_ref->{'evtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'evtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'evtp'}{'port'}{'udp'} = '2834'	; 
#	$srvcobjects_ref->{'evtp'}{'ports'}{'udp'}{'2834'}++	; 
#	$ports_ref->{'udp'}{'2834'}{'name'} = 'evtp'		; 
#	$srvcobjects_ref->{'evtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'evtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'evtp'}{'port'}{'tcp'} = '2834'	; 
#	$srvcobjects_ref->{'evtp'}{'ports'}{'tcp'}{'2834'}++	; 
#	$ports_ref->{'tcp'}{'2834'}{'name'} = 'evtp'		; 
#	$srvcobjects_ref->{'lm-dta'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lm-dta'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-dta'}{'port'}{'udp'} = '8206'	; 
#	$srvcobjects_ref->{'lm-dta'}{'ports'}{'udp'}{'8206'}++	; 
#	$ports_ref->{'udp'}{'8206'}{'name'} = 'lm-dta'		; 
#	$srvcobjects_ref->{'lm-dta'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lm-dta'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-dta'}{'port'}{'tcp'} = '8206'	; 
#	$srvcobjects_ref->{'lm-dta'}{'ports'}{'tcp'}{'8206'}++	; 
#	$ports_ref->{'tcp'}{'8206'}{'name'} = 'lm-dta'		; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'port'}{'udp'} = '1792'	; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'ports'}{'udp'}{'1792'}++	; 
#	$ports_ref->{'udp'}{'1792'}{'name'} = 'ibm-dt-2'		; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'port'}{'tcp'} = '1792'	; 
#	$srvcobjects_ref->{'ibm-dt-2'}{'ports'}{'tcp'}{'1792'}++	; 
#	$ports_ref->{'tcp'}{'1792'}{'name'} = 'ibm-dt-2'		; 
#	$srvcobjects_ref->{'ipcs-command'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipcs-command'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcs-command'}{'port'}{'udp'} = '3743'	; 
#	$srvcobjects_ref->{'ipcs-command'}{'ports'}{'udp'}{'3743'}++	; 
#	$ports_ref->{'udp'}{'3743'}{'name'} = 'ipcs-command'		; 
#	$srvcobjects_ref->{'ipcs-command'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipcs-command'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcs-command'}{'port'}{'tcp'} = '3743'	; 
#	$srvcobjects_ref->{'ipcs-command'}{'ports'}{'tcp'}{'3743'}++	; 
#	$ports_ref->{'tcp'}{'3743'}{'name'} = 'ipcs-command'		; 
#	$srvcobjects_ref->{'phrelaydbg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'phrelaydbg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phrelaydbg'}{'port'}{'udp'} = '4869'	; 
#	$srvcobjects_ref->{'phrelaydbg'}{'ports'}{'udp'}{'4869'}++	; 
#	$ports_ref->{'udp'}{'4869'}{'name'} = 'phrelaydbg'		; 
#	$srvcobjects_ref->{'phrelaydbg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'phrelaydbg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phrelaydbg'}{'port'}{'tcp'} = '4869'	; 
#	$srvcobjects_ref->{'phrelaydbg'}{'ports'}{'tcp'}{'4869'}++	; 
#	$ports_ref->{'tcp'}{'4869'}{'name'} = 'phrelaydbg'		; 
#	$srvcobjects_ref->{'mira'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mira'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mira'}{'port'}{'tcp'} = '3454'	; 
#	$srvcobjects_ref->{'mira'}{'ports'}{'tcp'}{'3454'}++	; 
#	$ports_ref->{'tcp'}{'3454'}{'name'} = 'mira'		; 
#	$srvcobjects_ref->{'netspeak-is'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netspeak-is'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-is'}{'port'}{'udp'} = '21846'	; 
#	$srvcobjects_ref->{'netspeak-is'}{'ports'}{'udp'}{'21846'}++	; 
#	$ports_ref->{'udp'}{'21846'}{'name'} = 'netspeak-is'		; 
#	$srvcobjects_ref->{'netspeak-is'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netspeak-is'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-is'}{'port'}{'tcp'} = '21846'	; 
#	$srvcobjects_ref->{'netspeak-is'}{'ports'}{'tcp'}{'21846'}++	; 
#	$ports_ref->{'tcp'}{'21846'}{'name'} = 'netspeak-is'		; 
#	$srvcobjects_ref->{'drmsfsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'drmsfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'drmsfsd'}{'port'}{'udp'} = '4098'	; 
#	$srvcobjects_ref->{'drmsfsd'}{'ports'}{'udp'}{'4098'}++	; 
#	$ports_ref->{'udp'}{'4098'}{'name'} = 'drmsfsd'		; 
#	$srvcobjects_ref->{'drmsfsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'drmsfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'drmsfsd'}{'port'}{'tcp'} = '4098'	; 
#	$srvcobjects_ref->{'drmsfsd'}{'ports'}{'tcp'}{'4098'}++	; 
#	$ports_ref->{'tcp'}{'4098'}{'name'} = 'drmsfsd'		; 
#	$srvcobjects_ref->{'streettalk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'streettalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'streettalk'}{'port'}{'udp'} = '566'	; 
#	$srvcobjects_ref->{'streettalk'}{'ports'}{'udp'}{'566'}++	; 
#	$ports_ref->{'udp'}{'566'}{'name'} = 'streettalk'		; 
#	$srvcobjects_ref->{'streettalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'streettalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'streettalk'}{'port'}{'tcp'} = '566'	; 
#	$srvcobjects_ref->{'streettalk'}{'ports'}{'tcp'}{'566'}++	; 
#	$ports_ref->{'tcp'}{'566'}{'name'} = 'streettalk'		; 
#	$srvcobjects_ref->{'nkd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nkd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nkd'}{'port'}{'udp'} = '1650'	; 
#	$srvcobjects_ref->{'nkd'}{'ports'}{'udp'}{'1650'}++	; 
#	$ports_ref->{'udp'}{'1650'}{'name'} = 'nkd'		; 
#	$srvcobjects_ref->{'nkd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nkd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nkd'}{'port'}{'tcp'} = '1650'	; 
#	$srvcobjects_ref->{'nkd'}{'ports'}{'tcp'}{'1650'}++	; 
#	$ports_ref->{'tcp'}{'1650'}{'name'} = 'nkd'		; 
#	$srvcobjects_ref->{'bts-x73'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bts-x73'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bts-x73'}{'port'}{'udp'} = '3681'	; 
#	$srvcobjects_ref->{'bts-x73'}{'ports'}{'udp'}{'3681'}++	; 
#	$ports_ref->{'udp'}{'3681'}{'name'} = 'bts-x73'		; 
#	$srvcobjects_ref->{'bts-x73'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bts-x73'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bts-x73'}{'port'}{'tcp'} = '3681'	; 
#	$srvcobjects_ref->{'bts-x73'}{'ports'}{'tcp'}{'3681'}++	; 
#	$ports_ref->{'tcp'}{'3681'}{'name'} = 'bts-x73'		; 
#	$srvcobjects_ref->{'theta-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'theta-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'theta-lm'}{'port'}{'udp'} = '2296'	; 
#	$srvcobjects_ref->{'theta-lm'}{'ports'}{'udp'}{'2296'}++	; 
#	$ports_ref->{'udp'}{'2296'}{'name'} = 'theta-lm'		; 
#	$srvcobjects_ref->{'theta-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'theta-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'theta-lm'}{'port'}{'tcp'} = '2296'	; 
#	$srvcobjects_ref->{'theta-lm'}{'ports'}{'tcp'}{'2296'}++	; 
#	$ports_ref->{'tcp'}{'2296'}{'name'} = 'theta-lm'		; 
#	$srvcobjects_ref->{'spmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spmp'}{'port'}{'udp'} = '656'	; 
#	$srvcobjects_ref->{'spmp'}{'ports'}{'udp'}{'656'}++	; 
#	$ports_ref->{'udp'}{'656'}{'name'} = 'spmp'		; 
#	$srvcobjects_ref->{'spmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spmp'}{'port'}{'tcp'} = '656'	; 
#	$srvcobjects_ref->{'spmp'}{'ports'}{'tcp'}{'656'}++	; 
#	$ports_ref->{'tcp'}{'656'}{'name'} = 'spmp'		; 
#	$srvcobjects_ref->{'e3consultants'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'e3consultants'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e3consultants'}{'port'}{'udp'} = '3157'	; 
#	$srvcobjects_ref->{'e3consultants'}{'ports'}{'udp'}{'3157'}++	; 
#	$ports_ref->{'udp'}{'3157'}{'name'} = 'e3consultants'		; 
#	$srvcobjects_ref->{'e3consultants'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'e3consultants'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e3consultants'}{'port'}{'tcp'} = '3157'	; 
#	$srvcobjects_ref->{'e3consultants'}{'ports'}{'tcp'}{'3157'}++	; 
#	$ports_ref->{'tcp'}{'3157'}{'name'} = 'e3consultants'		; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'port'}{'udp'} = '24002'	; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'ports'}{'udp'}{'24002'}++	; 
#	$ports_ref->{'udp'}{'24002'}{'name'} = 'med-fsp-tx'		; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'port'}{'tcp'} = '24002'	; 
#	$srvcobjects_ref->{'med-fsp-tx'}{'ports'}{'tcp'}{'24002'}++	; 
#	$ports_ref->{'tcp'}{'24002'}{'name'} = 'med-fsp-tx'		; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'port'}{'udp'} = '1993'	; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'ports'}{'udp'}{'1993'}++	; 
#	$ports_ref->{'udp'}{'1993'}{'name'} = 'snmp-tcp-port'		; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'port'}{'tcp'} = '1993'	; 
#	$srvcobjects_ref->{'snmp-tcp-port'}{'ports'}{'tcp'}{'1993'}++	; 
#	$ports_ref->{'tcp'}{'1993'}{'name'} = 'snmp-tcp-port'		; 
#	$srvcobjects_ref->{'pftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pftp'}{'port'}{'udp'} = '662'	; 
#	$srvcobjects_ref->{'pftp'}{'ports'}{'udp'}{'662'}++	; 
#	$ports_ref->{'udp'}{'662'}{'name'} = 'pftp'		; 
#	$srvcobjects_ref->{'pftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pftp'}{'port'}{'tcp'} = '662'	; 
#	$srvcobjects_ref->{'pftp'}{'ports'}{'tcp'}{'662'}++	; 
#	$ports_ref->{'tcp'}{'662'}{'name'} = 'pftp'		; 
#	$srvcobjects_ref->{'bh611'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bh611'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bh611'}{'port'}{'udp'} = '354'	; 
#	$srvcobjects_ref->{'bh611'}{'ports'}{'udp'}{'354'}++	; 
#	$ports_ref->{'udp'}{'354'}{'name'} = 'bh611'		; 
#	$srvcobjects_ref->{'bh611'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bh611'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bh611'}{'port'}{'tcp'} = '354'	; 
#	$srvcobjects_ref->{'bh611'}{'ports'}{'tcp'}{'354'}++	; 
#	$ports_ref->{'tcp'}{'354'}{'name'} = 'bh611'		; 
#	$srvcobjects_ref->{'lnvalarm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lnvalarm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvalarm'}{'port'}{'udp'} = '2282'	; 
#	$srvcobjects_ref->{'lnvalarm'}{'ports'}{'udp'}{'2282'}++	; 
#	$ports_ref->{'udp'}{'2282'}{'name'} = 'lnvalarm'		; 
#	$srvcobjects_ref->{'lnvalarm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lnvalarm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvalarm'}{'port'}{'tcp'} = '2282'	; 
#	$srvcobjects_ref->{'lnvalarm'}{'ports'}{'tcp'}{'2282'}++	; 
#	$ports_ref->{'tcp'}{'2282'}{'name'} = 'lnvalarm'		; 
#	$srvcobjects_ref->{'locus-map'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'locus-map'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'locus-map'}{'port'}{'udp'} = '125'	; 
#	$srvcobjects_ref->{'locus-map'}{'ports'}{'udp'}{'125'}++	; 
#	$ports_ref->{'udp'}{'125'}{'name'} = 'locus-map'		; 
#	$srvcobjects_ref->{'locus-map'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'locus-map'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'locus-map'}{'port'}{'tcp'} = '125'	; 
#	$srvcobjects_ref->{'locus-map'}{'ports'}{'tcp'}{'125'}++	; 
#	$ports_ref->{'tcp'}{'125'}{'name'} = 'locus-map'		; 
#	$srvcobjects_ref->{'decladebug'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'decladebug'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decladebug'}{'port'}{'udp'} = '410'	; 
#	$srvcobjects_ref->{'decladebug'}{'ports'}{'udp'}{'410'}++	; 
#	$ports_ref->{'udp'}{'410'}{'name'} = 'decladebug'		; 
#	$srvcobjects_ref->{'decladebug'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'decladebug'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decladebug'}{'port'}{'tcp'} = '410'	; 
#	$srvcobjects_ref->{'decladebug'}{'ports'}{'tcp'}{'410'}++	; 
#	$ports_ref->{'tcp'}{'410'}{'name'} = 'decladebug'		; 
#	$srvcobjects_ref->{'sigma-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sigma-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sigma-port'}{'port'}{'udp'} = '3614'	; 
#	$srvcobjects_ref->{'sigma-port'}{'ports'}{'udp'}{'3614'}++	; 
#	$ports_ref->{'udp'}{'3614'}{'name'} = 'sigma-port'		; 
#	$srvcobjects_ref->{'sigma-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sigma-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sigma-port'}{'port'}{'tcp'} = '3614'	; 
#	$srvcobjects_ref->{'sigma-port'}{'ports'}{'tcp'}{'3614'}++	; 
#	$ports_ref->{'tcp'}{'3614'}{'name'} = 'sigma-port'		; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'port'}{'udp'} = '3027'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'ports'}{'udp'}{'3027'}++	; 
#	$ports_ref->{'udp'}{'3027'}{'name'} = 'LiebDevMgmt_C'		; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'port'}{'tcp'} = '3027'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_C'}{'ports'}{'tcp'}{'3027'}++	; 
#	$ports_ref->{'tcp'}{'3027'}{'name'} = 'LiebDevMgmt_C'		; 
#	$srvcobjects_ref->{'emfis-cntl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emfis-cntl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emfis-cntl'}{'port'}{'udp'} = '141'	; 
#	$srvcobjects_ref->{'emfis-cntl'}{'ports'}{'udp'}{'141'}++	; 
#	$ports_ref->{'udp'}{'141'}{'name'} = 'emfis-cntl'		; 
#	$srvcobjects_ref->{'emfis-cntl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emfis-cntl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emfis-cntl'}{'port'}{'tcp'} = '141'	; 
#	$srvcobjects_ref->{'emfis-cntl'}{'ports'}{'tcp'}{'141'}++	; 
#	$ports_ref->{'tcp'}{'141'}{'name'} = 'emfis-cntl'		; 
#	$srvcobjects_ref->{'fcopys-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcopys-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcopys-server'}{'port'}{'udp'} = '5746'	; 
#	$srvcobjects_ref->{'fcopys-server'}{'ports'}{'udp'}{'5746'}++	; 
#	$ports_ref->{'udp'}{'5746'}{'name'} = 'fcopys-server'		; 
#	$srvcobjects_ref->{'fcopys-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcopys-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcopys-server'}{'port'}{'tcp'} = '5746'	; 
#	$srvcobjects_ref->{'fcopys-server'}{'ports'}{'tcp'}{'5746'}++	; 
#	$ports_ref->{'tcp'}{'5746'}{'name'} = 'fcopys-server'		; 
#	$srvcobjects_ref->{'appserv-https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appserv-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appserv-https'}{'port'}{'udp'} = '4849'	; 
#	$srvcobjects_ref->{'appserv-https'}{'ports'}{'udp'}{'4849'}++	; 
#	$ports_ref->{'udp'}{'4849'}{'name'} = 'appserv-https'		; 
#	$srvcobjects_ref->{'appserv-https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appserv-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appserv-https'}{'port'}{'tcp'} = '4849'	; 
#	$srvcobjects_ref->{'appserv-https'}{'ports'}{'tcp'}{'4849'}++	; 
#	$ports_ref->{'tcp'}{'4849'}{'name'} = 'appserv-https'		; 
#	$srvcobjects_ref->{'ljk-login'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ljk-login'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ljk-login'}{'port'}{'udp'} = '472'	; 
#	$srvcobjects_ref->{'ljk-login'}{'ports'}{'udp'}{'472'}++	; 
#	$ports_ref->{'udp'}{'472'}{'name'} = 'ljk-login'		; 
#	$srvcobjects_ref->{'ljk-login'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ljk-login'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ljk-login'}{'port'}{'tcp'} = '472'	; 
#	$srvcobjects_ref->{'ljk-login'}{'ports'}{'tcp'}{'472'}++	; 
#	$ports_ref->{'tcp'}{'472'}{'name'} = 'ljk-login'		; 
#	$srvcobjects_ref->{'prchat-user'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prchat-user'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prchat-user'}{'port'}{'udp'} = '4455'	; 
#	$srvcobjects_ref->{'prchat-user'}{'ports'}{'udp'}{'4455'}++	; 
#	$ports_ref->{'udp'}{'4455'}{'name'} = 'prchat-user'		; 
#	$srvcobjects_ref->{'prchat-user'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prchat-user'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prchat-user'}{'port'}{'tcp'} = '4455'	; 
#	$srvcobjects_ref->{'prchat-user'}{'ports'}{'tcp'}{'4455'}++	; 
#	$ports_ref->{'tcp'}{'4455'}{'name'} = 'prchat-user'		; 
#	$srvcobjects_ref->{'ddi-udp-7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddi-udp-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-udp-7'}{'port'}{'udp'} = '8894'	; 
#	$srvcobjects_ref->{'ddi-udp-7'}{'ports'}{'udp'}{'8894'}++	; 
#	$ports_ref->{'udp'}{'8894'}{'name'} = 'ddi-udp-7'		; 
#	$srvcobjects_ref->{'futrix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'futrix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'futrix'}{'port'}{'udp'} = '2358'	; 
#	$srvcobjects_ref->{'futrix'}{'ports'}{'udp'}{'2358'}++	; 
#	$ports_ref->{'udp'}{'2358'}{'name'} = 'futrix'		; 
#	$srvcobjects_ref->{'futrix'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'futrix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'futrix'}{'port'}{'tcp'} = '2358'	; 
#	$srvcobjects_ref->{'futrix'}{'ports'}{'tcp'}{'2358'}++	; 
#	$ports_ref->{'tcp'}{'2358'}{'name'} = 'futrix'		; 
#	$srvcobjects_ref->{'locus-con'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'locus-con'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'locus-con'}{'port'}{'udp'} = '127'	; 
#	$srvcobjects_ref->{'locus-con'}{'ports'}{'udp'}{'127'}++	; 
#	$ports_ref->{'udp'}{'127'}{'name'} = 'locus-con'		; 
#	$srvcobjects_ref->{'locus-con'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'locus-con'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'locus-con'}{'port'}{'tcp'} = '127'	; 
#	$srvcobjects_ref->{'locus-con'}{'ports'}{'tcp'}{'127'}++	; 
#	$ports_ref->{'tcp'}{'127'}{'name'} = 'locus-con'		; 
#	$srvcobjects_ref->{'timestenbroker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timestenbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timestenbroker'}{'port'}{'udp'} = '3754'	; 
#	$srvcobjects_ref->{'timestenbroker'}{'ports'}{'udp'}{'3754'}++	; 
#	$ports_ref->{'udp'}{'3754'}{'name'} = 'timestenbroker'		; 
#	$srvcobjects_ref->{'timestenbroker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timestenbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timestenbroker'}{'port'}{'tcp'} = '3754'	; 
#	$srvcobjects_ref->{'timestenbroker'}{'ports'}{'tcp'}{'3754'}++	; 
#	$ports_ref->{'tcp'}{'3754'}{'name'} = 'timestenbroker'		; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'port'}{'udp'} = '9203'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'ports'}{'udp'}{'9203'}++	; 
#	$ports_ref->{'udp'}{'9203'}{'name'} = 'wap-wsp-wtp-s'		; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'port'}{'tcp'} = '9203'	; 
#	$srvcobjects_ref->{'wap-wsp-wtp-s'}{'ports'}{'tcp'}{'9203'}++	; 
#	$ports_ref->{'tcp'}{'9203'}{'name'} = 'wap-wsp-wtp-s'		; 
#	$srvcobjects_ref->{'bridgecontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bridgecontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bridgecontrol'}{'port'}{'udp'} = '1073'	; 
#	$srvcobjects_ref->{'bridgecontrol'}{'ports'}{'udp'}{'1073'}++	; 
#	$ports_ref->{'udp'}{'1073'}{'name'} = 'bridgecontrol'		; 
#	$srvcobjects_ref->{'bridgecontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bridgecontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bridgecontrol'}{'port'}{'tcp'} = '1073'	; 
#	$srvcobjects_ref->{'bridgecontrol'}{'ports'}{'tcp'}{'1073'}++	; 
#	$ports_ref->{'tcp'}{'1073'}{'name'} = 'bridgecontrol'		; 
#	$srvcobjects_ref->{'emware-epss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emware-epss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emware-epss'}{'port'}{'udp'} = '3568'	; 
#	$srvcobjects_ref->{'emware-epss'}{'ports'}{'udp'}{'3568'}++	; 
#	$ports_ref->{'udp'}{'3568'}{'name'} = 'emware-epss'		; 
#	$srvcobjects_ref->{'emware-epss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emware-epss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emware-epss'}{'port'}{'tcp'} = '3568'	; 
#	$srvcobjects_ref->{'emware-epss'}{'ports'}{'tcp'}{'3568'}++	; 
#	$ports_ref->{'tcp'}{'3568'}{'name'} = 'emware-epss'		; 
#	$srvcobjects_ref->{'wimd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wimd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wimd'}{'port'}{'udp'} = '2980'	; 
#	$srvcobjects_ref->{'wimd'}{'ports'}{'udp'}{'2980'}++	; 
#	$ports_ref->{'udp'}{'2980'}{'name'} = 'wimd'		; 
#	$srvcobjects_ref->{'wimd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wimd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wimd'}{'port'}{'tcp'} = '2980'	; 
#	$srvcobjects_ref->{'wimd'}{'ports'}{'tcp'}{'2980'}++	; 
#	$ports_ref->{'tcp'}{'2980'}{'name'} = 'wimd'		; 
#	$srvcobjects_ref->{'btprjctrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'btprjctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btprjctrl'}{'port'}{'udp'} = '2803'	; 
#	$srvcobjects_ref->{'btprjctrl'}{'ports'}{'udp'}{'2803'}++	; 
#	$ports_ref->{'udp'}{'2803'}{'name'} = 'btprjctrl'		; 
#	$srvcobjects_ref->{'btprjctrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'btprjctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btprjctrl'}{'port'}{'tcp'} = '2803'	; 
#	$srvcobjects_ref->{'btprjctrl'}{'ports'}{'tcp'}{'2803'}++	; 
#	$ports_ref->{'tcp'}{'2803'}{'name'} = 'btprjctrl'		; 
#	$srvcobjects_ref->{'direcpc-si'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'direcpc-si'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direcpc-si'}{'port'}{'udp'} = '2464'	; 
#	$srvcobjects_ref->{'direcpc-si'}{'ports'}{'udp'}{'2464'}++	; 
#	$ports_ref->{'udp'}{'2464'}{'name'} = 'direcpc-si'		; 
#	$srvcobjects_ref->{'direcpc-si'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'direcpc-si'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direcpc-si'}{'port'}{'tcp'} = '2464'	; 
#	$srvcobjects_ref->{'direcpc-si'}{'ports'}{'tcp'}{'2464'}++	; 
#	$ports_ref->{'tcp'}{'2464'}{'name'} = 'direcpc-si'		; 
#	$srvcobjects_ref->{'acp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acp'}{'port'}{'udp'} = '599'	; 
#	$srvcobjects_ref->{'acp'}{'ports'}{'udp'}{'599'}++	; 
#	$ports_ref->{'udp'}{'599'}{'name'} = 'acp'		; 
#	$srvcobjects_ref->{'acp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acp'}{'port'}{'tcp'} = '599'	; 
#	$srvcobjects_ref->{'acp'}{'ports'}{'tcp'}{'599'}++	; 
#	$ports_ref->{'tcp'}{'599'}{'name'} = 'acp'		; 
#	$srvcobjects_ref->{'passgo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'passgo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'passgo'}{'port'}{'udp'} = '511'	; 
#	$srvcobjects_ref->{'passgo'}{'ports'}{'udp'}{'511'}++	; 
#	$ports_ref->{'udp'}{'511'}{'name'} = 'passgo'		; 
#	$srvcobjects_ref->{'passgo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'passgo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'passgo'}{'port'}{'tcp'} = '511'	; 
#	$srvcobjects_ref->{'passgo'}{'ports'}{'tcp'}{'511'}++	; 
#	$ports_ref->{'tcp'}{'511'}{'name'} = 'passgo'		; 
#	$srvcobjects_ref->{'jstel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jstel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jstel'}{'port'}{'udp'} = '1064'	; 
#	$srvcobjects_ref->{'jstel'}{'ports'}{'udp'}{'1064'}++	; 
#	$ports_ref->{'udp'}{'1064'}{'name'} = 'jstel'		; 
#	$srvcobjects_ref->{'jstel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jstel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jstel'}{'port'}{'tcp'} = '1064'	; 
#	$srvcobjects_ref->{'jstel'}{'ports'}{'tcp'}{'1064'}++	; 
#	$ports_ref->{'tcp'}{'1064'}{'name'} = 'jstel'		; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'port'}{'udp'} = '1945'	; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'ports'}{'udp'}{'1945'}++	; 
#	$ports_ref->{'udp'}{'1945'}{'name'} = 'dialogic-elmd'		; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'port'}{'tcp'} = '1945'	; 
#	$srvcobjects_ref->{'dialogic-elmd'}{'ports'}{'tcp'}{'1945'}++	; 
#	$ports_ref->{'tcp'}{'1945'}{'name'} = 'dialogic-elmd'		; 
#	$srvcobjects_ref->{'cadview-3d'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadview-3d'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadview-3d'}{'port'}{'udp'} = '649'	; 
#	$srvcobjects_ref->{'cadview-3d'}{'ports'}{'udp'}{'649'}++	; 
#	$ports_ref->{'udp'}{'649'}{'name'} = 'cadview-3d'		; 
#	$srvcobjects_ref->{'cadview-3d'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadview-3d'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadview-3d'}{'port'}{'tcp'} = '649'	; 
#	$srvcobjects_ref->{'cadview-3d'}{'ports'}{'tcp'}{'649'}++	; 
#	$ports_ref->{'tcp'}{'649'}{'name'} = 'cadview-3d'		; 
#	$srvcobjects_ref->{'opc-job-start'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opc-job-start'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opc-job-start'}{'port'}{'udp'} = '423'	; 
#	$srvcobjects_ref->{'opc-job-start'}{'ports'}{'udp'}{'423'}++	; 
#	$ports_ref->{'udp'}{'423'}{'name'} = 'opc-job-start'		; 
#	$srvcobjects_ref->{'opc-job-start'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opc-job-start'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opc-job-start'}{'port'}{'tcp'} = '423'	; 
#	$srvcobjects_ref->{'opc-job-start'}{'ports'}{'tcp'}{'423'}++	; 
#	$ports_ref->{'tcp'}{'423'}{'name'} = 'opc-job-start'		; 
#	$srvcobjects_ref->{'minipay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'minipay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'minipay'}{'port'}{'udp'} = '2105'	; 
#	$srvcobjects_ref->{'minipay'}{'ports'}{'udp'}{'2105'}++	; 
#	$ports_ref->{'udp'}{'2105'}{'name'} = 'minipay'		; 
#	$srvcobjects_ref->{'minipay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'minipay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'minipay'}{'port'}{'tcp'} = '2105'	; 
#	$srvcobjects_ref->{'minipay'}{'ports'}{'tcp'}{'2105'}++	; 
#	$ports_ref->{'tcp'}{'2105'}{'name'} = 'minipay'		; 
#	$srvcobjects_ref->{'dpcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dpcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpcp'}{'port'}{'udp'} = '4099'	; 
#	$srvcobjects_ref->{'dpcp'}{'ports'}{'udp'}{'4099'}++	; 
#	$ports_ref->{'udp'}{'4099'}{'name'} = 'dpcp'		; 
#	$srvcobjects_ref->{'dpcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dpcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpcp'}{'port'}{'tcp'} = '4099'	; 
#	$srvcobjects_ref->{'dpcp'}{'ports'}{'tcp'}{'4099'}++	; 
#	$ports_ref->{'tcp'}{'4099'}{'name'} = 'dpcp'		; 
#	$srvcobjects_ref->{'autocuesmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'autocuesmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autocuesmi'}{'port'}{'udp'} = '3103'	; 
#	$srvcobjects_ref->{'autocuesmi'}{'ports'}{'udp'}{'3103'}++	; 
#	$ports_ref->{'udp'}{'3103'}{'name'} = 'autocuesmi'		; 
#	$srvcobjects_ref->{'autocuesmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'autocuesmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autocuesmi'}{'port'}{'tcp'} = '3103'	; 
#	$srvcobjects_ref->{'autocuesmi'}{'ports'}{'tcp'}{'3103'}++	; 
#	$ports_ref->{'tcp'}{'3103'}{'name'} = 'autocuesmi'		; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'port'}{'udp'} = '8130'	; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'ports'}{'udp'}{'8130'}++	; 
#	$ports_ref->{'udp'}{'8130'}{'name'} = 'indigo-vrmi'		; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'port'}{'tcp'} = '8130'	; 
#	$srvcobjects_ref->{'indigo-vrmi'}{'ports'}{'tcp'}{'8130'}++	; 
#	$ports_ref->{'tcp'}{'8130'}{'name'} = 'indigo-vrmi'		; 
#	$srvcobjects_ref->{'attachmate-uts'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'attachmate-uts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'attachmate-uts'}{'port'}{'udp'} = '2304'	; 
#	$srvcobjects_ref->{'attachmate-uts'}{'ports'}{'udp'}{'2304'}++	; 
#	$ports_ref->{'udp'}{'2304'}{'name'} = 'attachmate-uts'		; 
#	$srvcobjects_ref->{'attachmate-uts'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'attachmate-uts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'attachmate-uts'}{'port'}{'tcp'} = '2304'	; 
#	$srvcobjects_ref->{'attachmate-uts'}{'ports'}{'tcp'}{'2304'}++	; 
#	$ports_ref->{'tcp'}{'2304'}{'name'} = 'attachmate-uts'		; 
#	$srvcobjects_ref->{'niobserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'niobserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'niobserver'}{'port'}{'udp'} = '25901'	; 
#	$srvcobjects_ref->{'niobserver'}{'ports'}{'udp'}{'25901'}++	; 
#	$ports_ref->{'udp'}{'25901'}{'name'} = 'niobserver'		; 
#	$srvcobjects_ref->{'niobserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'niobserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'niobserver'}{'port'}{'tcp'} = '25901'	; 
#	$srvcobjects_ref->{'niobserver'}{'ports'}{'tcp'}{'25901'}++	; 
#	$ports_ref->{'tcp'}{'25901'}{'name'} = 'niobserver'		; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'port'}{'udp'} = '670'	; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'ports'}{'udp'}{'670'}++	; 
#	$ports_ref->{'udp'}{'670'}{'name'} = 'vacdsm-sws'		; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'port'}{'tcp'} = '670'	; 
#	$srvcobjects_ref->{'vacdsm-sws'}{'ports'}{'tcp'}{'670'}++	; 
#	$ports_ref->{'tcp'}{'670'}{'name'} = 'vacdsm-sws'		; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'port'}{'udp'} = '5409'	; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'ports'}{'udp'}{'5409'}++	; 
#	$ports_ref->{'udp'}{'5409'}{'name'} = 'salient-dtasrv'		; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'port'}{'tcp'} = '5409'	; 
#	$srvcobjects_ref->{'salient-dtasrv'}{'ports'}{'tcp'}{'5409'}++	; 
#	$ports_ref->{'tcp'}{'5409'}{'name'} = 'salient-dtasrv'		; 
#	$srvcobjects_ref->{'ofsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ofsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ofsd'}{'port'}{'udp'} = '2322'	; 
#	$srvcobjects_ref->{'ofsd'}{'ports'}{'udp'}{'2322'}++	; 
#	$ports_ref->{'udp'}{'2322'}{'name'} = 'ofsd'		; 
#	$srvcobjects_ref->{'ofsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ofsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ofsd'}{'port'}{'tcp'} = '2322'	; 
#	$srvcobjects_ref->{'ofsd'}{'ports'}{'tcp'}{'2322'}++	; 
#	$ports_ref->{'tcp'}{'2322'}{'name'} = 'ofsd'		; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'port'}{'udp'} = '3311'	; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'ports'}{'udp'}{'3311'}++	; 
#	$ports_ref->{'udp'}{'3311'}{'name'} = 'mcns-tel-ret'		; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'port'}{'tcp'} = '3311'	; 
#	$srvcobjects_ref->{'mcns-tel-ret'}{'ports'}{'tcp'}{'3311'}++	; 
#	$ports_ref->{'tcp'}{'3311'}{'name'} = 'mcns-tel-ret'		; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'port'}{'udp'} = '3539'	; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'ports'}{'udp'}{'3539'}++	; 
#	$ports_ref->{'udp'}{'3539'}{'name'} = 'ibm-diradm-ssl'		; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'port'}{'tcp'} = '3539'	; 
#	$srvcobjects_ref->{'ibm-diradm-ssl'}{'ports'}{'tcp'}{'3539'}++	; 
#	$ports_ref->{'tcp'}{'3539'}{'name'} = 'ibm-diradm-ssl'		; 
#	$srvcobjects_ref->{'visionpyramid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'visionpyramid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visionpyramid'}{'port'}{'udp'} = '1247'	; 
#	$srvcobjects_ref->{'visionpyramid'}{'ports'}{'udp'}{'1247'}++	; 
#	$ports_ref->{'udp'}{'1247'}{'name'} = 'visionpyramid'		; 
#	$srvcobjects_ref->{'visionpyramid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'visionpyramid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visionpyramid'}{'port'}{'tcp'} = '1247'	; 
#	$srvcobjects_ref->{'visionpyramid'}{'ports'}{'tcp'}{'1247'}++	; 
#	$ports_ref->{'tcp'}{'1247'}{'name'} = 'visionpyramid'		; 
#	$srvcobjects_ref->{'swispol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swispol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swispol'}{'port'}{'udp'} = '6966'	; 
#	$srvcobjects_ref->{'swispol'}{'ports'}{'udp'}{'6966'}++	; 
#	$ports_ref->{'udp'}{'6966'}{'name'} = 'swispol'		; 
#	$srvcobjects_ref->{'swispol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swispol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swispol'}{'port'}{'tcp'} = '6966'	; 
#	$srvcobjects_ref->{'swispol'}{'ports'}{'tcp'}{'6966'}++	; 
#	$ports_ref->{'tcp'}{'6966'}{'name'} = 'swispol'		; 
#	$srvcobjects_ref->{'veracity'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'veracity'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veracity'}{'port'}{'udp'} = '1062'	; 
#	$srvcobjects_ref->{'veracity'}{'ports'}{'udp'}{'1062'}++	; 
#	$ports_ref->{'udp'}{'1062'}{'name'} = 'veracity'		; 
#	$srvcobjects_ref->{'veracity'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'veracity'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veracity'}{'port'}{'tcp'} = '1062'	; 
#	$srvcobjects_ref->{'veracity'}{'ports'}{'tcp'}{'1062'}++	; 
#	$ports_ref->{'tcp'}{'1062'}{'name'} = 'veracity'		; 
#	$srvcobjects_ref->{'openmailpxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openmailpxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmailpxy'}{'port'}{'udp'} = '5768'	; 
#	$srvcobjects_ref->{'openmailpxy'}{'ports'}{'udp'}{'5768'}++	; 
#	$ports_ref->{'udp'}{'5768'}{'name'} = 'openmailpxy'		; 
#	$srvcobjects_ref->{'openmailpxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openmailpxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmailpxy'}{'port'}{'tcp'} = '5768'	; 
#	$srvcobjects_ref->{'openmailpxy'}{'ports'}{'tcp'}{'5768'}++	; 
#	$ports_ref->{'tcp'}{'5768'}{'name'} = 'openmailpxy'		; 
#	$srvcobjects_ref->{'apri-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apri-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apri-lm'}{'port'}{'udp'} = '1447'	; 
#	$srvcobjects_ref->{'apri-lm'}{'ports'}{'udp'}{'1447'}++	; 
#	$ports_ref->{'udp'}{'1447'}{'name'} = 'apri-lm'		; 
#	$srvcobjects_ref->{'apri-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apri-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apri-lm'}{'port'}{'tcp'} = '1447'	; 
#	$srvcobjects_ref->{'apri-lm'}{'ports'}{'tcp'}{'1447'}++	; 
#	$ports_ref->{'tcp'}{'1447'}{'name'} = 'apri-lm'		; 
#	$srvcobjects_ref->{'edb-server1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edb-server1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edb-server1'}{'port'}{'udp'} = '1635'	; 
#	$srvcobjects_ref->{'edb-server1'}{'ports'}{'udp'}{'1635'}++	; 
#	$ports_ref->{'udp'}{'1635'}{'name'} = 'edb-server1'		; 
#	$srvcobjects_ref->{'edb-server1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edb-server1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edb-server1'}{'port'}{'tcp'} = '1635'	; 
#	$srvcobjects_ref->{'edb-server1'}{'ports'}{'tcp'}{'1635'}++	; 
#	$ports_ref->{'tcp'}{'1635'}{'name'} = 'edb-server1'		; 
#	$srvcobjects_ref->{'ctsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctsd'}{'port'}{'udp'} = '5137'	; 
#	$srvcobjects_ref->{'ctsd'}{'ports'}{'udp'}{'5137'}++	; 
#	$ports_ref->{'udp'}{'5137'}{'name'} = 'ctsd'		; 
#	$srvcobjects_ref->{'ctsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctsd'}{'port'}{'tcp'} = '5137'	; 
#	$srvcobjects_ref->{'ctsd'}{'ports'}{'tcp'}{'5137'}++	; 
#	$ports_ref->{'tcp'}{'5137'}{'name'} = 'ctsd'		; 
#	$srvcobjects_ref->{'lispworks-orb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lispworks-orb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lispworks-orb'}{'port'}{'udp'} = '3672'	; 
#	$srvcobjects_ref->{'lispworks-orb'}{'ports'}{'udp'}{'3672'}++	; 
#	$ports_ref->{'udp'}{'3672'}{'name'} = 'lispworks-orb'		; 
#	$srvcobjects_ref->{'lispworks-orb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lispworks-orb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lispworks-orb'}{'port'}{'tcp'} = '3672'	; 
#	$srvcobjects_ref->{'lispworks-orb'}{'ports'}{'tcp'}{'3672'}++	; 
#	$ports_ref->{'tcp'}{'3672'}{'name'} = 'lispworks-orb'		; 
#	$srvcobjects_ref->{'efidiningport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'efidiningport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'efidiningport'}{'port'}{'udp'} = '2553'	; 
#	$srvcobjects_ref->{'efidiningport'}{'ports'}{'udp'}{'2553'}++	; 
#	$ports_ref->{'udp'}{'2553'}{'name'} = 'efidiningport'		; 
#	$srvcobjects_ref->{'efidiningport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'efidiningport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'efidiningport'}{'port'}{'tcp'} = '2553'	; 
#	$srvcobjects_ref->{'efidiningport'}{'ports'}{'tcp'}{'2553'}++	; 
#	$ports_ref->{'tcp'}{'2553'}{'name'} = 'efidiningport'		; 
#	$srvcobjects_ref->{'ideesrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ideesrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ideesrv'}{'port'}{'udp'} = '2337'	; 
#	$srvcobjects_ref->{'ideesrv'}{'ports'}{'udp'}{'2337'}++	; 
#	$ports_ref->{'udp'}{'2337'}{'name'} = 'ideesrv'		; 
#	$srvcobjects_ref->{'ideesrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ideesrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ideesrv'}{'port'}{'tcp'} = '2337'	; 
#	$srvcobjects_ref->{'ideesrv'}{'ports'}{'tcp'}{'2337'}++	; 
#	$ports_ref->{'tcp'}{'2337'}{'name'} = 'ideesrv'		; 
#	$srvcobjects_ref->{'talk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talk'}{'port'}{'udp'} = '517'	; 
#	$srvcobjects_ref->{'talk'}{'ports'}{'udp'}{'517'}++	; 
#	$ports_ref->{'udp'}{'517'}{'name'} = 'talk'		; 
#	$srvcobjects_ref->{'talk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talk'}{'port'}{'tcp'} = '517'	; 
#	$srvcobjects_ref->{'talk'}{'ports'}{'tcp'}{'517'}++	; 
#	$ports_ref->{'tcp'}{'517'}{'name'} = 'talk'		; 
#	$srvcobjects_ref->{'vision_server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vision_server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vision_server'}{'port'}{'udp'} = '6672'	; 
#	$srvcobjects_ref->{'vision_server'}{'ports'}{'udp'}{'6672'}++	; 
#	$ports_ref->{'udp'}{'6672'}{'name'} = 'vision_server'		; 
#	$srvcobjects_ref->{'vision_server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vision_server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vision_server'}{'port'}{'tcp'} = '6672'	; 
#	$srvcobjects_ref->{'vision_server'}{'ports'}{'tcp'}{'6672'}++	; 
#	$ports_ref->{'tcp'}{'6672'}{'name'} = 'vision_server'		; 
#	$srvcobjects_ref->{'prosharenotify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prosharenotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharenotify'}{'port'}{'udp'} = '5717'	; 
#	$srvcobjects_ref->{'prosharenotify'}{'ports'}{'udp'}{'5717'}++	; 
#	$ports_ref->{'udp'}{'5717'}{'name'} = 'prosharenotify'		; 
#	$srvcobjects_ref->{'prosharenotify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prosharenotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharenotify'}{'port'}{'tcp'} = '5717'	; 
#	$srvcobjects_ref->{'prosharenotify'}{'ports'}{'tcp'}{'5717'}++	; 
#	$ports_ref->{'tcp'}{'5717'}{'name'} = 'prosharenotify'		; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'port'}{'udp'} = '1951'	; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'ports'}{'udp'}{'1951'}++	; 
#	$ports_ref->{'udp'}{'1951'}{'name'} = 'bcs-lmserver'		; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'port'}{'tcp'} = '1951'	; 
#	$srvcobjects_ref->{'bcs-lmserver'}{'ports'}{'tcp'}{'1951'}++	; 
#	$ports_ref->{'tcp'}{'1951'}{'name'} = 'bcs-lmserver'		; 
#	$srvcobjects_ref->{'cma'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cma'}{'port'}{'udp'} = '1050'	; 
#	$srvcobjects_ref->{'cma'}{'ports'}{'udp'}{'1050'}++	; 
#	$ports_ref->{'udp'}{'1050'}{'name'} = 'cma'		; 
#	$srvcobjects_ref->{'cma'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cma'}{'port'}{'tcp'} = '1050'	; 
#	$srvcobjects_ref->{'cma'}{'ports'}{'tcp'}{'1050'}++	; 
#	$ports_ref->{'tcp'}{'1050'}{'name'} = 'cma'		; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'port'}{'udp'} = '196'	; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'ports'}{'udp'}{'196'}++	; 
#	$ports_ref->{'udp'}{'196'}{'name'} = 'dn6-smm-red'		; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'port'}{'tcp'} = '196'	; 
#	$srvcobjects_ref->{'dn6-smm-red'}{'ports'}{'tcp'}{'196'}++	; 
#	$ports_ref->{'tcp'}{'196'}{'name'} = 'dn6-smm-red'		; 
#	$srvcobjects_ref->{'heartbeat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'heartbeat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'heartbeat'}{'port'}{'udp'} = '3740'	; 
#	$srvcobjects_ref->{'heartbeat'}{'ports'}{'udp'}{'3740'}++	; 
#	$ports_ref->{'udp'}{'3740'}{'name'} = 'heartbeat'		; 
#	$srvcobjects_ref->{'heartbeat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'heartbeat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'heartbeat'}{'port'}{'tcp'} = '3740'	; 
#	$srvcobjects_ref->{'heartbeat'}{'ports'}{'tcp'}{'3740'}++	; 
#	$ports_ref->{'tcp'}{'3740'}{'name'} = 'heartbeat'		; 
#	$srvcobjects_ref->{'tn-timing'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tn-timing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-timing'}{'port'}{'udp'} = '2739'	; 
#	$srvcobjects_ref->{'tn-timing'}{'ports'}{'udp'}{'2739'}++	; 
#	$ports_ref->{'udp'}{'2739'}{'name'} = 'tn-timing'		; 
#	$srvcobjects_ref->{'tn-timing'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tn-timing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-timing'}{'port'}{'tcp'} = '2739'	; 
#	$srvcobjects_ref->{'tn-timing'}{'ports'}{'tcp'}{'2739'}++	; 
#	$ports_ref->{'tcp'}{'2739'}{'name'} = 'tn-timing'		; 
#	$srvcobjects_ref->{'idonix-metanet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idonix-metanet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idonix-metanet'}{'port'}{'udp'} = '2112'	; 
#	$srvcobjects_ref->{'idonix-metanet'}{'ports'}{'udp'}{'2112'}++	; 
#	$ports_ref->{'udp'}{'2112'}{'name'} = 'idonix-metanet'		; 
#	$srvcobjects_ref->{'idonix-metanet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idonix-metanet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idonix-metanet'}{'port'}{'tcp'} = '2112'	; 
#	$srvcobjects_ref->{'idonix-metanet'}{'ports'}{'tcp'}{'2112'}++	; 
#	$ports_ref->{'tcp'}{'2112'}{'name'} = 'idonix-metanet'		; 
#	$srvcobjects_ref->{'cdfunc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cdfunc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdfunc'}{'port'}{'udp'} = '2045'	; 
#	$srvcobjects_ref->{'cdfunc'}{'ports'}{'udp'}{'2045'}++	; 
#	$ports_ref->{'udp'}{'2045'}{'name'} = 'cdfunc'		; 
#	$srvcobjects_ref->{'cdfunc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cdfunc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdfunc'}{'port'}{'tcp'} = '2045'	; 
#	$srvcobjects_ref->{'cdfunc'}{'ports'}{'tcp'}{'2045'}++	; 
#	$ports_ref->{'tcp'}{'2045'}{'name'} = 'cdfunc'		; 
#	$srvcobjects_ref->{'xdmcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xdmcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xdmcp'}{'port'}{'udp'} = '177'	; 
#	$srvcobjects_ref->{'xdmcp'}{'ports'}{'udp'}{'177'}++	; 
#	$ports_ref->{'udp'}{'177'}{'name'} = 'xdmcp'		; 
#	$srvcobjects_ref->{'xdmcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xdmcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xdmcp'}{'port'}{'tcp'} = '177'	; 
#	$srvcobjects_ref->{'xdmcp'}{'ports'}{'tcp'}{'177'}++	; 
#	$ports_ref->{'tcp'}{'177'}{'name'} = 'xdmcp'		; 
#	$srvcobjects_ref->{'nntps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nntps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nntps'}{'port'}{'udp'} = '563'	; 
#	$srvcobjects_ref->{'nntps'}{'ports'}{'udp'}{'563'}++	; 
#	$ports_ref->{'udp'}{'563'}{'name'} = 'nntps'		; 
#	$srvcobjects_ref->{'nntps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nntps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nntps'}{'port'}{'tcp'} = '563'	; 
#	$srvcobjects_ref->{'nntps'}{'ports'}{'tcp'}{'563'}++	; 
#	$ports_ref->{'tcp'}{'563'}{'name'} = 'nntps'		; 
#	$srvcobjects_ref->{'dberegister'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dberegister'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dberegister'}{'port'}{'udp'} = '1479'	; 
#	$srvcobjects_ref->{'dberegister'}{'ports'}{'udp'}{'1479'}++	; 
#	$ports_ref->{'udp'}{'1479'}{'name'} = 'dberegister'		; 
#	$srvcobjects_ref->{'dberegister'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dberegister'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dberegister'}{'port'}{'tcp'} = '1479'	; 
#	$srvcobjects_ref->{'dberegister'}{'ports'}{'tcp'}{'1479'}++	; 
#	$ports_ref->{'tcp'}{'1479'}{'name'} = 'dberegister'		; 
#	$srvcobjects_ref->{'ssm-cvs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssm-cvs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssm-cvs'}{'port'}{'udp'} = '2477'	; 
#	$srvcobjects_ref->{'ssm-cvs'}{'ports'}{'udp'}{'2477'}++	; 
#	$ports_ref->{'udp'}{'2477'}{'name'} = 'ssm-cvs'		; 
#	$srvcobjects_ref->{'ssm-cvs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssm-cvs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssm-cvs'}{'port'}{'tcp'} = '2477'	; 
#	$srvcobjects_ref->{'ssm-cvs'}{'ports'}{'tcp'}{'2477'}++	; 
#	$ports_ref->{'tcp'}{'2477'}{'name'} = 'ssm-cvs'		; 
#	$srvcobjects_ref->{'3ds-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3ds-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3ds-lm'}{'port'}{'udp'} = '1538'	; 
#	$srvcobjects_ref->{'3ds-lm'}{'ports'}{'udp'}{'1538'}++	; 
#	$ports_ref->{'udp'}{'1538'}{'name'} = '3ds-lm'		; 
#	$srvcobjects_ref->{'3ds-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3ds-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3ds-lm'}{'port'}{'tcp'} = '1538'	; 
#	$srvcobjects_ref->{'3ds-lm'}{'ports'}{'tcp'}{'1538'}++	; 
#	$ports_ref->{'tcp'}{'1538'}{'name'} = '3ds-lm'		; 
#	$srvcobjects_ref->{'jediserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jediserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jediserver'}{'port'}{'udp'} = '2406'	; 
#	$srvcobjects_ref->{'jediserver'}{'ports'}{'udp'}{'2406'}++	; 
#	$ports_ref->{'udp'}{'2406'}{'name'} = 'jediserver'		; 
#	$srvcobjects_ref->{'jediserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jediserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jediserver'}{'port'}{'tcp'} = '2406'	; 
#	$srvcobjects_ref->{'jediserver'}{'ports'}{'tcp'}{'2406'}++	; 
#	$ports_ref->{'tcp'}{'2406'}{'name'} = 'jediserver'		; 
#	$srvcobjects_ref->{'acas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acas'}{'port'}{'udp'} = '62'	; 
#	$srvcobjects_ref->{'acas'}{'ports'}{'udp'}{'62'}++	; 
#	$ports_ref->{'udp'}{'62'}{'name'} = 'acas'		; 
#	$srvcobjects_ref->{'acas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acas'}{'port'}{'tcp'} = '62'	; 
#	$srvcobjects_ref->{'acas'}{'ports'}{'tcp'}{'62'}++	; 
#	$ports_ref->{'tcp'}{'62'}{'name'} = 'acas'		; 
#	$srvcobjects_ref->{'spice'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spice'}{'port'}{'udp'} = '1923'	; 
#	$srvcobjects_ref->{'spice'}{'ports'}{'udp'}{'1923'}++	; 
#	$ports_ref->{'udp'}{'1923'}{'name'} = 'spice'		; 
#	$srvcobjects_ref->{'spice'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spice'}{'port'}{'tcp'} = '1923'	; 
#	$srvcobjects_ref->{'spice'}{'ports'}{'tcp'}{'1923'}++	; 
#	$ports_ref->{'tcp'}{'1923'}{'name'} = 'spice'		; 
#	$srvcobjects_ref->{'global-cd-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'global-cd-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'global-cd-port'}{'port'}{'udp'} = '3229'	; 
#	$srvcobjects_ref->{'global-cd-port'}{'ports'}{'udp'}{'3229'}++	; 
#	$ports_ref->{'udp'}{'3229'}{'name'} = 'global-cd-port'		; 
#	$srvcobjects_ref->{'global-cd-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'global-cd-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'global-cd-port'}{'port'}{'tcp'} = '3229'	; 
#	$srvcobjects_ref->{'global-cd-port'}{'ports'}{'tcp'}{'3229'}++	; 
#	$ports_ref->{'tcp'}{'3229'}{'name'} = 'global-cd-port'		; 
#	$srvcobjects_ref->{'dnc-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dnc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnc-port'}{'port'}{'udp'} = '3448'	; 
#	$srvcobjects_ref->{'dnc-port'}{'ports'}{'udp'}{'3448'}++	; 
#	$ports_ref->{'udp'}{'3448'}{'name'} = 'dnc-port'		; 
#	$srvcobjects_ref->{'dnc-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dnc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnc-port'}{'port'}{'tcp'} = '3448'	; 
#	$srvcobjects_ref->{'dnc-port'}{'ports'}{'tcp'}{'3448'}++	; 
#	$ports_ref->{'tcp'}{'3448'}{'name'} = 'dnc-port'		; 
#	$srvcobjects_ref->{'tams'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tams'}{'port'}{'udp'} = '2726'	; 
#	$srvcobjects_ref->{'tams'}{'ports'}{'udp'}{'2726'}++	; 
#	$ports_ref->{'udp'}{'2726'}{'name'} = 'tams'		; 
#	$srvcobjects_ref->{'tams'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tams'}{'port'}{'tcp'} = '2726'	; 
#	$srvcobjects_ref->{'tams'}{'ports'}{'tcp'}{'2726'}++	; 
#	$ports_ref->{'tcp'}{'2726'}{'name'} = 'tams'		; 
#	$srvcobjects_ref->{'jmb-cds1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmb-cds1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmb-cds1'}{'port'}{'udp'} = '8900'	; 
#	$srvcobjects_ref->{'jmb-cds1'}{'ports'}{'udp'}{'8900'}++	; 
#	$ports_ref->{'udp'}{'8900'}{'name'} = 'jmb-cds1'		; 
#	$srvcobjects_ref->{'jmb-cds1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmb-cds1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmb-cds1'}{'port'}{'tcp'} = '8900'	; 
#	$srvcobjects_ref->{'jmb-cds1'}{'ports'}{'tcp'}{'8900'}++	; 
#	$ports_ref->{'tcp'}{'8900'}{'name'} = 'jmb-cds1'		; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'port'}{'udp'} = '5502'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'ports'}{'udp'}{'5502'}++	; 
#	$ports_ref->{'udp'}{'5502'}{'name'} = 'fcp-srvr-inst1'		; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'port'}{'tcp'} = '5502'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst1'}{'ports'}{'tcp'}{'5502'}++	; 
#	$ports_ref->{'tcp'}{'5502'}{'name'} = 'fcp-srvr-inst1'		; 
#	$srvcobjects_ref->{'symplex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'symplex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'symplex'}{'port'}{'udp'} = '1507'	; 
#	$srvcobjects_ref->{'symplex'}{'ports'}{'udp'}{'1507'}++	; 
#	$ports_ref->{'udp'}{'1507'}{'name'} = 'symplex'		; 
#	$srvcobjects_ref->{'symplex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'symplex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'symplex'}{'port'}{'tcp'} = '1507'	; 
#	$srvcobjects_ref->{'symplex'}{'ports'}{'tcp'}{'1507'}++	; 
#	$ports_ref->{'tcp'}{'1507'}{'name'} = 'symplex'		; 
#	$srvcobjects_ref->{'parsec-master'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'parsec-master'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parsec-master'}{'port'}{'udp'} = '6580'	; 
#	$srvcobjects_ref->{'parsec-master'}{'ports'}{'udp'}{'6580'}++	; 
#	$ports_ref->{'udp'}{'6580'}{'name'} = 'parsec-master'		; 
#	$srvcobjects_ref->{'parsec-master'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'parsec-master'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parsec-master'}{'port'}{'tcp'} = '6580'	; 
#	$srvcobjects_ref->{'parsec-master'}{'ports'}{'tcp'}{'6580'}++	; 
#	$ports_ref->{'tcp'}{'6580'}{'name'} = 'parsec-master'		; 
#	$srvcobjects_ref->{'xiip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xiip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xiip'}{'port'}{'udp'} = '1924'	; 
#	$srvcobjects_ref->{'xiip'}{'ports'}{'udp'}{'1924'}++	; 
#	$ports_ref->{'udp'}{'1924'}{'name'} = 'xiip'		; 
#	$srvcobjects_ref->{'xiip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xiip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xiip'}{'port'}{'tcp'} = '1924'	; 
#	$srvcobjects_ref->{'xiip'}{'ports'}{'tcp'}{'1924'}++	; 
#	$ports_ref->{'tcp'}{'1924'}{'name'} = 'xiip'		; 
#	$srvcobjects_ref->{'powerclientcsf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'powerclientcsf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerclientcsf'}{'port'}{'udp'} = '2443'	; 
#	$srvcobjects_ref->{'powerclientcsf'}{'ports'}{'udp'}{'2443'}++	; 
#	$ports_ref->{'udp'}{'2443'}{'name'} = 'powerclientcsf'		; 
#	$srvcobjects_ref->{'powerclientcsf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'powerclientcsf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerclientcsf'}{'port'}{'tcp'} = '2443'	; 
#	$srvcobjects_ref->{'powerclientcsf'}{'ports'}{'tcp'}{'2443'}++	; 
#	$ports_ref->{'tcp'}{'2443'}{'name'} = 'powerclientcsf'		; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'port'}{'udp'} = '3608'	; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'ports'}{'udp'}{'3608'}++	; 
#	$ports_ref->{'udp'}{'3608'}{'name'} = 'trendchip-dcp'		; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'port'}{'tcp'} = '3608'	; 
#	$srvcobjects_ref->{'trendchip-dcp'}{'ports'}{'tcp'}{'3608'}++	; 
#	$ports_ref->{'tcp'}{'3608'}{'name'} = 'trendchip-dcp'		; 
#	$srvcobjects_ref->{'lansurveyor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lansurveyor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lansurveyor'}{'port'}{'udp'} = '4347'	; 
#	$srvcobjects_ref->{'lansurveyor'}{'ports'}{'udp'}{'4347'}++	; 
#	$ports_ref->{'udp'}{'4347'}{'name'} = 'lansurveyor'		; 
#	$srvcobjects_ref->{'lansurveyor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lansurveyor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lansurveyor'}{'port'}{'tcp'} = '4347'	; 
#	$srvcobjects_ref->{'lansurveyor'}{'ports'}{'tcp'}{'4347'}++	; 
#	$ports_ref->{'tcp'}{'4347'}{'name'} = 'lansurveyor'		; 
#	$srvcobjects_ref->{'dyniplookup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dyniplookup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dyniplookup'}{'port'}{'udp'} = '3295'	; 
#	$srvcobjects_ref->{'dyniplookup'}{'ports'}{'udp'}{'3295'}++	; 
#	$ports_ref->{'udp'}{'3295'}{'name'} = 'dyniplookup'		; 
#	$srvcobjects_ref->{'dyniplookup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dyniplookup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dyniplookup'}{'port'}{'tcp'} = '3295'	; 
#	$srvcobjects_ref->{'dyniplookup'}{'ports'}{'tcp'}{'3295'}++	; 
#	$ports_ref->{'tcp'}{'3295'}{'name'} = 'dyniplookup'		; 
#	$srvcobjects_ref->{'netgw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netgw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netgw'}{'port'}{'udp'} = '741'	; 
#	$srvcobjects_ref->{'netgw'}{'ports'}{'udp'}{'741'}++	; 
#	$ports_ref->{'udp'}{'741'}{'name'} = 'netgw'		; 
#	$srvcobjects_ref->{'netgw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netgw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netgw'}{'port'}{'tcp'} = '741'	; 
#	$srvcobjects_ref->{'netgw'}{'ports'}{'tcp'}{'741'}++	; 
#	$ports_ref->{'tcp'}{'741'}{'name'} = 'netgw'		; 
#	$srvcobjects_ref->{'bmpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmpp'}{'port'}{'udp'} = '632'	; 
#	$srvcobjects_ref->{'bmpp'}{'ports'}{'udp'}{'632'}++	; 
#	$ports_ref->{'udp'}{'632'}{'name'} = 'bmpp'		; 
#	$srvcobjects_ref->{'bmpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmpp'}{'port'}{'tcp'} = '632'	; 
#	$srvcobjects_ref->{'bmpp'}{'ports'}{'tcp'}{'632'}++	; 
#	$ports_ref->{'tcp'}{'632'}{'name'} = 'bmpp'		; 
#	$srvcobjects_ref->{'tacacs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tacacs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacacs'}{'port'}{'udp'} = '49'	; 
#	$srvcobjects_ref->{'tacacs'}{'ports'}{'udp'}{'49'}++	; 
#	$ports_ref->{'udp'}{'49'}{'name'} = 'tacacs'		; 
#	$srvcobjects_ref->{'tacacs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tacacs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacacs'}{'port'}{'tcp'} = '49'	; 
#	$srvcobjects_ref->{'tacacs'}{'ports'}{'tcp'}{'49'}++	; 
#	$ports_ref->{'tcp'}{'49'}{'name'} = 'tacacs'		; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'port'}{'udp'} = '3443'	; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'ports'}{'udp'}{'3443'}++	; 
#	$ports_ref->{'udp'}{'3443'}{'name'} = 'ov-nnm-websrv'		; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'port'}{'tcp'} = '3443'	; 
#	$srvcobjects_ref->{'ov-nnm-websrv'}{'ports'}{'tcp'}{'3443'}++	; 
#	$ports_ref->{'tcp'}{'3443'}{'name'} = 'ov-nnm-websrv'		; 
#	$srvcobjects_ref->{'cspclmulti'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cspclmulti'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspclmulti'}{'port'}{'udp'} = '2890'	; 
#	$srvcobjects_ref->{'cspclmulti'}{'ports'}{'udp'}{'2890'}++	; 
#	$ports_ref->{'udp'}{'2890'}{'name'} = 'cspclmulti'		; 
#	$srvcobjects_ref->{'cspclmulti'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cspclmulti'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspclmulti'}{'port'}{'tcp'} = '2890'	; 
#	$srvcobjects_ref->{'cspclmulti'}{'ports'}{'tcp'}{'2890'}++	; 
#	$ports_ref->{'tcp'}{'2890'}{'name'} = 'cspclmulti'		; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'port'}{'udp'} = '2547'	; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'ports'}{'udp'}{'2547'}++	; 
#	$ports_ref->{'udp'}{'2547'}{'name'} = 'vytalvaultvsmp'		; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'port'}{'tcp'} = '2547'	; 
#	$srvcobjects_ref->{'vytalvaultvsmp'}{'ports'}{'tcp'}{'2547'}++	; 
#	$ports_ref->{'tcp'}{'2547'}{'name'} = 'vytalvaultvsmp'		; 
#	$srvcobjects_ref->{'netop-rc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netop-rc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netop-rc'}{'port'}{'udp'} = '1970'	; 
#	$srvcobjects_ref->{'netop-rc'}{'ports'}{'udp'}{'1970'}++	; 
#	$ports_ref->{'udp'}{'1970'}{'name'} = 'netop-rc'		; 
#	$srvcobjects_ref->{'netop-rc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netop-rc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netop-rc'}{'port'}{'tcp'} = '1970'	; 
#	$srvcobjects_ref->{'netop-rc'}{'ports'}{'tcp'}{'1970'}++	; 
#	$ports_ref->{'tcp'}{'1970'}{'name'} = 'netop-rc'		; 
#	$srvcobjects_ref->{'hacl-monitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-monitor'}{'port'}{'udp'} = '3542'	; 
#	$srvcobjects_ref->{'hacl-monitor'}{'ports'}{'udp'}{'3542'}++	; 
#	$ports_ref->{'udp'}{'3542'}{'name'} = 'hacl-monitor'		; 
#	$srvcobjects_ref->{'hacl-monitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-monitor'}{'port'}{'tcp'} = '3542'	; 
#	$srvcobjects_ref->{'hacl-monitor'}{'ports'}{'tcp'}{'3542'}++	; 
#	$ports_ref->{'tcp'}{'3542'}{'name'} = 'hacl-monitor'		; 
#	$srvcobjects_ref->{'ars-master'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ars-master'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ars-master'}{'port'}{'udp'} = '3176'	; 
#	$srvcobjects_ref->{'ars-master'}{'ports'}{'udp'}{'3176'}++	; 
#	$ports_ref->{'udp'}{'3176'}{'name'} = 'ars-master'		; 
#	$srvcobjects_ref->{'ars-master'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ars-master'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ars-master'}{'port'}{'tcp'} = '3176'	; 
#	$srvcobjects_ref->{'ars-master'}{'ports'}{'tcp'}{'3176'}++	; 
#	$ports_ref->{'tcp'}{'3176'}{'name'} = 'ars-master'		; 
#	$srvcobjects_ref->{'alpha-sms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alpha-sms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alpha-sms'}{'port'}{'udp'} = '1849'	; 
#	$srvcobjects_ref->{'alpha-sms'}{'ports'}{'udp'}{'1849'}++	; 
#	$ports_ref->{'udp'}{'1849'}{'name'} = 'alpha-sms'		; 
#	$srvcobjects_ref->{'alpha-sms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alpha-sms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alpha-sms'}{'port'}{'tcp'} = '1849'	; 
#	$srvcobjects_ref->{'alpha-sms'}{'ports'}{'tcp'}{'1849'}++	; 
#	$ports_ref->{'tcp'}{'1849'}{'name'} = 'alpha-sms'		; 
#	$srvcobjects_ref->{'registrar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'registrar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'registrar'}{'port'}{'udp'} = '1712'	; 
#	$srvcobjects_ref->{'registrar'}{'ports'}{'udp'}{'1712'}++	; 
#	$ports_ref->{'udp'}{'1712'}{'name'} = 'registrar'		; 
#	$srvcobjects_ref->{'registrar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'registrar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'registrar'}{'port'}{'tcp'} = '1712'	; 
#	$srvcobjects_ref->{'registrar'}{'ports'}{'tcp'}{'1712'}++	; 
#	$ports_ref->{'tcp'}{'1712'}{'name'} = 'registrar'		; 
#	$srvcobjects_ref->{'zicom'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zicom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zicom'}{'port'}{'udp'} = '3774'	; 
#	$srvcobjects_ref->{'zicom'}{'ports'}{'udp'}{'3774'}++	; 
#	$ports_ref->{'udp'}{'3774'}{'name'} = 'zicom'		; 
#	$srvcobjects_ref->{'zicom'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zicom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zicom'}{'port'}{'tcp'} = '3774'	; 
#	$srvcobjects_ref->{'zicom'}{'ports'}{'tcp'}{'3774'}++	; 
#	$ports_ref->{'tcp'}{'3774'}{'name'} = 'zicom'		; 
#	$srvcobjects_ref->{'phonex-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'phonex-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phonex-port'}{'port'}{'udp'} = '3177'	; 
#	$srvcobjects_ref->{'phonex-port'}{'ports'}{'udp'}{'3177'}++	; 
#	$ports_ref->{'udp'}{'3177'}{'name'} = 'phonex-port'		; 
#	$srvcobjects_ref->{'phonex-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'phonex-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phonex-port'}{'port'}{'tcp'} = '3177'	; 
#	$srvcobjects_ref->{'phonex-port'}{'ports'}{'tcp'}{'3177'}++	; 
#	$ports_ref->{'tcp'}{'3177'}{'name'} = 'phonex-port'		; 
#	$srvcobjects_ref->{'netview-aix-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-4'}{'port'}{'udp'} = '1664'	; 
#	$srvcobjects_ref->{'netview-aix-4'}{'ports'}{'udp'}{'1664'}++	; 
#	$ports_ref->{'udp'}{'1664'}{'name'} = 'netview-aix-4'		; 
#	$srvcobjects_ref->{'netview-aix-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-4'}{'port'}{'tcp'} = '1664'	; 
#	$srvcobjects_ref->{'netview-aix-4'}{'ports'}{'tcp'}{'1664'}++	; 
#	$ports_ref->{'tcp'}{'1664'}{'name'} = 'netview-aix-4'		; 
#	$srvcobjects_ref->{'qip-audup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qip-audup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-audup'}{'port'}{'udp'} = '2765'	; 
#	$srvcobjects_ref->{'qip-audup'}{'ports'}{'udp'}{'2765'}++	; 
#	$ports_ref->{'udp'}{'2765'}{'name'} = 'qip-audup'		; 
#	$srvcobjects_ref->{'qip-audup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qip-audup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-audup'}{'port'}{'tcp'} = '2765'	; 
#	$srvcobjects_ref->{'qip-audup'}{'ports'}{'tcp'}{'2765'}++	; 
#	$ports_ref->{'tcp'}{'2765'}{'name'} = 'qip-audup'		; 
#	$srvcobjects_ref->{'jvserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jvserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jvserver'}{'port'}{'udp'} = '1939'	; 
#	$srvcobjects_ref->{'jvserver'}{'ports'}{'udp'}{'1939'}++	; 
#	$ports_ref->{'udp'}{'1939'}{'name'} = 'jvserver'		; 
#	$srvcobjects_ref->{'jvserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jvserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jvserver'}{'port'}{'tcp'} = '1939'	; 
#	$srvcobjects_ref->{'jvserver'}{'ports'}{'tcp'}{'1939'}++	; 
#	$ports_ref->{'tcp'}{'1939'}{'name'} = 'jvserver'		; 
#	$srvcobjects_ref->{'llsurfup-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'llsurfup-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llsurfup-http'}{'port'}{'udp'} = '1183'	; 
#	$srvcobjects_ref->{'llsurfup-http'}{'ports'}{'udp'}{'1183'}++	; 
#	$ports_ref->{'udp'}{'1183'}{'name'} = 'llsurfup-http'		; 
#	$srvcobjects_ref->{'llsurfup-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'llsurfup-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llsurfup-http'}{'port'}{'tcp'} = '1183'	; 
#	$srvcobjects_ref->{'llsurfup-http'}{'ports'}{'tcp'}{'1183'}++	; 
#	$ports_ref->{'tcp'}{'1183'}{'name'} = 'llsurfup-http'		; 
#	$srvcobjects_ref->{'hecmtl-db'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hecmtl-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hecmtl-db'}{'port'}{'udp'} = '1551'	; 
#	$srvcobjects_ref->{'hecmtl-db'}{'ports'}{'udp'}{'1551'}++	; 
#	$ports_ref->{'udp'}{'1551'}{'name'} = 'hecmtl-db'		; 
#	$srvcobjects_ref->{'hecmtl-db'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hecmtl-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hecmtl-db'}{'port'}{'tcp'} = '1551'	; 
#	$srvcobjects_ref->{'hecmtl-db'}{'ports'}{'tcp'}{'1551'}++	; 
#	$ports_ref->{'tcp'}{'1551'}{'name'} = 'hecmtl-db'		; 
#	$srvcobjects_ref->{'synapsis-edge'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synapsis-edge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synapsis-edge'}{'port'}{'udp'} = '5008'	; 
#	$srvcobjects_ref->{'synapsis-edge'}{'ports'}{'udp'}{'5008'}++	; 
#	$ports_ref->{'udp'}{'5008'}{'name'} = 'synapsis-edge'		; 
#	$srvcobjects_ref->{'synapsis-edge'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synapsis-edge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synapsis-edge'}{'port'}{'tcp'} = '5008'	; 
#	$srvcobjects_ref->{'synapsis-edge'}{'ports'}{'tcp'}{'5008'}++	; 
#	$ports_ref->{'tcp'}{'5008'}{'name'} = 'synapsis-edge'		; 
#	$srvcobjects_ref->{'connection'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'connection'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connection'}{'port'}{'udp'} = '2607'	; 
#	$srvcobjects_ref->{'connection'}{'ports'}{'udp'}{'2607'}++	; 
#	$ports_ref->{'udp'}{'2607'}{'name'} = 'connection'		; 
#	$srvcobjects_ref->{'connection'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'connection'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connection'}{'port'}{'tcp'} = '2607'	; 
#	$srvcobjects_ref->{'connection'}{'ports'}{'tcp'}{'2607'}++	; 
#	$ports_ref->{'tcp'}{'2607'}{'name'} = 'connection'		; 
#	$srvcobjects_ref->{'stanag-5066'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stanag-5066'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stanag-5066'}{'port'}{'udp'} = '5066'	; 
#	$srvcobjects_ref->{'stanag-5066'}{'ports'}{'udp'}{'5066'}++	; 
#	$ports_ref->{'udp'}{'5066'}{'name'} = 'stanag-5066'		; 
#	$srvcobjects_ref->{'stanag-5066'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stanag-5066'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stanag-5066'}{'port'}{'tcp'} = '5066'	; 
#	$srvcobjects_ref->{'stanag-5066'}{'ports'}{'tcp'}{'5066'}++	; 
#	$ports_ref->{'tcp'}{'5066'}{'name'} = 'stanag-5066'		; 
#	$srvcobjects_ref->{'supermon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'supermon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'supermon'}{'port'}{'udp'} = '2709'	; 
#	$srvcobjects_ref->{'supermon'}{'ports'}{'udp'}{'2709'}++	; 
#	$ports_ref->{'udp'}{'2709'}{'name'} = 'supermon'		; 
#	$srvcobjects_ref->{'supermon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'supermon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'supermon'}{'port'}{'tcp'} = '2709'	; 
#	$srvcobjects_ref->{'supermon'}{'ports'}{'tcp'}{'2709'}++	; 
#	$ports_ref->{'tcp'}{'2709'}{'name'} = 'supermon'		; 
#	$srvcobjects_ref->{'alchemy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alchemy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alchemy'}{'port'}{'udp'} = '3234'	; 
#	$srvcobjects_ref->{'alchemy'}{'ports'}{'udp'}{'3234'}++	; 
#	$ports_ref->{'udp'}{'3234'}{'name'} = 'alchemy'		; 
#	$srvcobjects_ref->{'alchemy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alchemy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alchemy'}{'port'}{'tcp'} = '3234'	; 
#	$srvcobjects_ref->{'alchemy'}{'ports'}{'tcp'}{'3234'}++	; 
#	$ports_ref->{'tcp'}{'3234'}{'name'} = 'alchemy'		; 
#	$srvcobjects_ref->{'slp-notify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slp-notify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slp-notify'}{'port'}{'udp'} = '1847'	; 
#	$srvcobjects_ref->{'slp-notify'}{'ports'}{'udp'}{'1847'}++	; 
#	$ports_ref->{'udp'}{'1847'}{'name'} = 'slp-notify'		; 
#	$srvcobjects_ref->{'slp-notify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slp-notify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slp-notify'}{'port'}{'tcp'} = '1847'	; 
#	$srvcobjects_ref->{'slp-notify'}{'ports'}{'tcp'}{'1847'}++	; 
#	$ports_ref->{'tcp'}{'1847'}{'name'} = 'slp-notify'		; 
#	$srvcobjects_ref->{'statsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'statsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statsrv'}{'port'}{'udp'} = '133'	; 
#	$srvcobjects_ref->{'statsrv'}{'ports'}{'udp'}{'133'}++	; 
#	$ports_ref->{'udp'}{'133'}{'name'} = 'statsrv'		; 
#	$srvcobjects_ref->{'statsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'statsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statsrv'}{'port'}{'tcp'} = '133'	; 
#	$srvcobjects_ref->{'statsrv'}{'ports'}{'tcp'}{'133'}++	; 
#	$ports_ref->{'tcp'}{'133'}{'name'} = 'statsrv'		; 
#	$srvcobjects_ref->{'foresyte-clear'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'foresyte-clear'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'foresyte-clear'}{'port'}{'udp'} = '5407'	; 
#	$srvcobjects_ref->{'foresyte-clear'}{'ports'}{'udp'}{'5407'}++	; 
#	$ports_ref->{'udp'}{'5407'}{'name'} = 'foresyte-clear'		; 
#	$srvcobjects_ref->{'foresyte-clear'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'foresyte-clear'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'foresyte-clear'}{'port'}{'tcp'} = '5407'	; 
#	$srvcobjects_ref->{'foresyte-clear'}{'ports'}{'tcp'}{'5407'}++	; 
#	$ports_ref->{'tcp'}{'5407'}{'name'} = 'foresyte-clear'		; 
#	$srvcobjects_ref->{'cardax'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cardax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cardax'}{'port'}{'udp'} = '1072'	; 
#	$srvcobjects_ref->{'cardax'}{'ports'}{'udp'}{'1072'}++	; 
#	$ports_ref->{'udp'}{'1072'}{'name'} = 'cardax'		; 
#	$srvcobjects_ref->{'cardax'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cardax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cardax'}{'port'}{'tcp'} = '1072'	; 
#	$srvcobjects_ref->{'cardax'}{'ports'}{'tcp'}{'1072'}++	; 
#	$ports_ref->{'tcp'}{'1072'}{'name'} = 'cardax'		; 
#	$srvcobjects_ref->{'plethora'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'plethora'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plethora'}{'port'}{'udp'} = '3480'	; 
#	$srvcobjects_ref->{'plethora'}{'ports'}{'udp'}{'3480'}++	; 
#	$ports_ref->{'udp'}{'3480'}{'name'} = 'plethora'		; 
#	$srvcobjects_ref->{'plethora'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'plethora'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plethora'}{'port'}{'tcp'} = '3480'	; 
#	$srvcobjects_ref->{'plethora'}{'ports'}{'tcp'}{'3480'}++	; 
#	$ports_ref->{'tcp'}{'3480'}{'name'} = 'plethora'		; 
#	$srvcobjects_ref->{'digital-vrc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'digital-vrc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digital-vrc'}{'port'}{'udp'} = '466'	; 
#	$srvcobjects_ref->{'digital-vrc'}{'ports'}{'udp'}{'466'}++	; 
#	$ports_ref->{'udp'}{'466'}{'name'} = 'digital-vrc'		; 
#	$srvcobjects_ref->{'digital-vrc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'digital-vrc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digital-vrc'}{'port'}{'tcp'} = '466'	; 
#	$srvcobjects_ref->{'digital-vrc'}{'ports'}{'tcp'}{'466'}++	; 
#	$ports_ref->{'tcp'}{'466'}{'name'} = 'digital-vrc'		; 
#	$srvcobjects_ref->{'apertus-ldp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apertus-ldp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apertus-ldp'}{'port'}{'udp'} = '539'	; 
#	$srvcobjects_ref->{'apertus-ldp'}{'ports'}{'udp'}{'539'}++	; 
#	$ports_ref->{'udp'}{'539'}{'name'} = 'apertus-ldp'		; 
#	$srvcobjects_ref->{'apertus-ldp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apertus-ldp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apertus-ldp'}{'port'}{'tcp'} = '539'	; 
#	$srvcobjects_ref->{'apertus-ldp'}{'ports'}{'tcp'}{'539'}++	; 
#	$ports_ref->{'tcp'}{'539'}{'name'} = 'apertus-ldp'		; 
#	$srvcobjects_ref->{'terabase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'terabase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'terabase'}{'port'}{'udp'} = '4000'	; 
#	$srvcobjects_ref->{'terabase'}{'ports'}{'udp'}{'4000'}++	; 
#	$ports_ref->{'udp'}{'4000'}{'name'} = 'terabase'		; 
#	$srvcobjects_ref->{'terabase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'terabase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'terabase'}{'port'}{'tcp'} = '4000'	; 
#	$srvcobjects_ref->{'terabase'}{'ports'}{'tcp'}{'4000'}++	; 
#	$ports_ref->{'tcp'}{'4000'}{'name'} = 'terabase'		; 
#	$srvcobjects_ref->{'navegaweb-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'navegaweb-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navegaweb-port'}{'port'}{'udp'} = '3159'	; 
#	$srvcobjects_ref->{'navegaweb-port'}{'ports'}{'udp'}{'3159'}++	; 
#	$ports_ref->{'udp'}{'3159'}{'name'} = 'navegaweb-port'		; 
#	$srvcobjects_ref->{'navegaweb-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'navegaweb-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navegaweb-port'}{'port'}{'tcp'} = '3159'	; 
#	$srvcobjects_ref->{'navegaweb-port'}{'ports'}{'tcp'}{'3159'}++	; 
#	$ports_ref->{'tcp'}{'3159'}{'name'} = 'navegaweb-port'		; 
#	$srvcobjects_ref->{'idp-infotrieve'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idp-infotrieve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idp-infotrieve'}{'port'}{'udp'} = '2966'	; 
#	$srvcobjects_ref->{'idp-infotrieve'}{'ports'}{'udp'}{'2966'}++	; 
#	$ports_ref->{'udp'}{'2966'}{'name'} = 'idp-infotrieve'		; 
#	$srvcobjects_ref->{'idp-infotrieve'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idp-infotrieve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aviva-sna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aviva-sna'}{'port'}{'udp'} = '2238'	; 
#	$srvcobjects_ref->{'aviva-sna'}{'ports'}{'udp'}{'2238'}++	; 
#	$ports_ref->{'udp'}{'2238'}{'name'} = 'aviva-sna'		; 
#	$srvcobjects_ref->{'aviva-sna'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aviva-sna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aviva-sna'}{'port'}{'tcp'} = '2238'	; 
#	$srvcobjects_ref->{'aviva-sna'}{'ports'}{'tcp'}{'2238'}++	; 
#	$ports_ref->{'tcp'}{'2238'}{'name'} = 'aviva-sna'		; 
#	$srvcobjects_ref->{'postgresql'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'postgresql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'postgresql'}{'port'}{'udp'} = '5432'	; 
#	$srvcobjects_ref->{'postgresql'}{'ports'}{'udp'}{'5432'}++	; 
#	$ports_ref->{'udp'}{'5432'}{'name'} = 'postgresql'		; 
#	$srvcobjects_ref->{'postgresql'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'postgresql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'postgresql'}{'port'}{'tcp'} = '5432'	; 
#	$srvcobjects_ref->{'postgresql'}{'ports'}{'tcp'}{'5432'}++	; 
#	$ports_ref->{'tcp'}{'5432'}{'name'} = 'postgresql'		; 
#	$srvcobjects_ref->{'trustestablish'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trustestablish'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trustestablish'}{'port'}{'udp'} = '2573'	; 
#	$srvcobjects_ref->{'trustestablish'}{'ports'}{'udp'}{'2573'}++	; 
#	$ports_ref->{'udp'}{'2573'}{'name'} = 'trustestablish'		; 
#	$srvcobjects_ref->{'trustestablish'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trustestablish'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trustestablish'}{'port'}{'tcp'} = '2573'	; 
#	$srvcobjects_ref->{'trustestablish'}{'ports'}{'tcp'}{'2573'}++	; 
#	$ports_ref->{'tcp'}{'2573'}{'name'} = 'trustestablish'		; 
#	$srvcobjects_ref->{'dawn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dawn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dawn'}{'port'}{'udp'} = '1908'	; 
#	$srvcobjects_ref->{'dawn'}{'ports'}{'udp'}{'1908'}++	; 
#	$ports_ref->{'udp'}{'1908'}{'name'} = 'dawn'		; 
#	$srvcobjects_ref->{'dawn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dawn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dawn'}{'port'}{'tcp'} = '1908'	; 
#	$srvcobjects_ref->{'dawn'}{'ports'}{'tcp'}{'1908'}++	; 
#	$ports_ref->{'tcp'}{'1908'}{'name'} = 'dawn'		; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'port'}{'udp'} = '2648'	; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'ports'}{'udp'}{'2648'}++	; 
#	$ports_ref->{'udp'}{'2648'}{'name'} = 'upsnotifyprot'		; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'port'}{'tcp'} = '2648'	; 
#	$srvcobjects_ref->{'upsnotifyprot'}{'ports'}{'tcp'}{'2648'}++	; 
#	$ports_ref->{'tcp'}{'2648'}{'name'} = 'upsnotifyprot'		; 
#	$srvcobjects_ref->{'high-criteria'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'high-criteria'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'high-criteria'}{'port'}{'udp'} = '2467'	; 
#	$srvcobjects_ref->{'high-criteria'}{'ports'}{'udp'}{'2467'}++	; 
#	$ports_ref->{'udp'}{'2467'}{'name'} = 'high-criteria'		; 
#	$srvcobjects_ref->{'high-criteria'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'high-criteria'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'high-criteria'}{'port'}{'tcp'} = '2467'	; 
#	$srvcobjects_ref->{'high-criteria'}{'ports'}{'tcp'}{'2467'}++	; 
#	$ports_ref->{'tcp'}{'2467'}{'name'} = 'high-criteria'		; 
#	$srvcobjects_ref->{'cmmdriver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cmmdriver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmmdriver'}{'port'}{'udp'} = '1294'	; 
#	$srvcobjects_ref->{'cmmdriver'}{'ports'}{'udp'}{'1294'}++	; 
#	$ports_ref->{'udp'}{'1294'}{'name'} = 'cmmdriver'		; 
#	$srvcobjects_ref->{'cmmdriver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cmmdriver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmmdriver'}{'port'}{'tcp'} = '1294'	; 
#	$srvcobjects_ref->{'cmmdriver'}{'ports'}{'tcp'}{'1294'}++	; 
#	$ports_ref->{'tcp'}{'1294'}{'name'} = 'cmmdriver'		; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'port'}{'udp'} = '2816'	; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'ports'}{'udp'}{'2816'}++	; 
#	$ports_ref->{'udp'}{'2816'}{'name'} = 'lbc-watchdog'		; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'port'}{'tcp'} = '2816'	; 
#	$srvcobjects_ref->{'lbc-watchdog'}{'ports'}{'tcp'}{'2816'}++	; 
#	$ports_ref->{'tcp'}{'2816'}{'name'} = 'lbc-watchdog'		; 
#	$srvcobjects_ref->{'xdtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xdtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xdtp'}{'port'}{'udp'} = '3088'	; 
#	$srvcobjects_ref->{'xdtp'}{'ports'}{'udp'}{'3088'}++	; 
#	$ports_ref->{'udp'}{'3088'}{'name'} = 'xdtp'		; 
#	$srvcobjects_ref->{'xdtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xdtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xdtp'}{'port'}{'tcp'} = '3088'	; 
#	$srvcobjects_ref->{'xdtp'}{'ports'}{'tcp'}{'3088'}++	; 
#	$ports_ref->{'tcp'}{'3088'}{'name'} = 'xdtp'		; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'port'}{'udp'} = '1883'	; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'ports'}{'udp'}{'1883'}++	; 
#	$ports_ref->{'udp'}{'1883'}{'name'} = 'ibm-mqisdp'		; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'port'}{'tcp'} = '1883'	; 
#	$srvcobjects_ref->{'ibm-mqisdp'}{'ports'}{'tcp'}{'1883'}++	; 
#	$ports_ref->{'tcp'}{'1883'}{'name'} = 'ibm-mqisdp'		; 
#	$srvcobjects_ref->{'dec_dlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dec_dlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec_dlm'}{'port'}{'udp'} = '625'	; 
#	$srvcobjects_ref->{'dec_dlm'}{'ports'}{'udp'}{'625'}++	; 
#	$ports_ref->{'udp'}{'625'}{'name'} = 'dec_dlm'		; 
#	$srvcobjects_ref->{'dec_dlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dec_dlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec_dlm'}{'port'}{'tcp'} = '625'	; 
#	$srvcobjects_ref->{'dec_dlm'}{'ports'}{'tcp'}{'625'}++	; 
#	$ports_ref->{'tcp'}{'625'}{'name'} = 'dec_dlm'		; 
#	$srvcobjects_ref->{'adobeserver-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adobeserver-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-2'}{'port'}{'udp'} = '1103'	; 
#	$srvcobjects_ref->{'adobeserver-2'}{'ports'}{'udp'}{'1103'}++	; 
#	$ports_ref->{'udp'}{'1103'}{'name'} = 'adobeserver-2'		; 
#	$srvcobjects_ref->{'adobeserver-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adobeserver-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-2'}{'port'}{'tcp'} = '1103'	; 
#	$srvcobjects_ref->{'adobeserver-2'}{'ports'}{'tcp'}{'1103'}++	; 
#	$ports_ref->{'tcp'}{'1103'}{'name'} = 'adobeserver-2'		; 
#	$srvcobjects_ref->{'nimhub'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nimhub'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimhub'}{'port'}{'udp'} = '48002'	; 
#	$srvcobjects_ref->{'nimhub'}{'ports'}{'udp'}{'48002'}++	; 
#	$ports_ref->{'udp'}{'48002'}{'name'} = 'nimhub'		; 
#	$srvcobjects_ref->{'nimhub'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nimhub'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimhub'}{'port'}{'tcp'} = '48002'	; 
#	$srvcobjects_ref->{'nimhub'}{'ports'}{'tcp'}{'48002'}++	; 
#	$ports_ref->{'tcp'}{'48002'}{'name'} = 'nimhub'		; 
#	$srvcobjects_ref->{'privateark'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'privateark'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privateark'}{'port'}{'udp'} = '1858'	; 
#	$srvcobjects_ref->{'privateark'}{'ports'}{'udp'}{'1858'}++	; 
#	$ports_ref->{'udp'}{'1858'}{'name'} = 'privateark'		; 
#	$srvcobjects_ref->{'privateark'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'privateark'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privateark'}{'port'}{'tcp'} = '1858'	; 
#	$srvcobjects_ref->{'privateark'}{'ports'}{'tcp'}{'1858'}++	; 
#	$ports_ref->{'tcp'}{'1858'}{'name'} = 'privateark'		; 
#	$srvcobjects_ref->{'dctp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dctp'}{'port'}{'udp'} = '675'	; 
#	$srvcobjects_ref->{'dctp'}{'ports'}{'udp'}{'675'}++	; 
#	$ports_ref->{'udp'}{'675'}{'name'} = 'dctp'		; 
#	$srvcobjects_ref->{'dctp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dctp'}{'port'}{'tcp'} = '675'	; 
#	$srvcobjects_ref->{'dctp'}{'ports'}{'tcp'}{'675'}++	; 
#	$ports_ref->{'tcp'}{'675'}{'name'} = 'dctp'		; 
#	$srvcobjects_ref->{'compaq-evm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'compaq-evm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-evm'}{'port'}{'udp'} = '619'	; 
#	$srvcobjects_ref->{'compaq-evm'}{'ports'}{'udp'}{'619'}++	; 
#	$ports_ref->{'udp'}{'619'}{'name'} = 'compaq-evm'		; 
#	$srvcobjects_ref->{'compaq-evm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'compaq-evm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-evm'}{'port'}{'tcp'} = '619'	; 
#	$srvcobjects_ref->{'compaq-evm'}{'ports'}{'tcp'}{'619'}++	; 
#	$ports_ref->{'tcp'}{'619'}{'name'} = 'compaq-evm'		; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'port'}{'udp'} = '2060'	; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'ports'}{'udp'}{'2060'}++	; 
#	$ports_ref->{'udp'}{'2060'}{'name'} = 'teleniumdaemon'		; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'port'}{'tcp'} = '2060'	; 
#	$srvcobjects_ref->{'teleniumdaemon'}{'ports'}{'tcp'}{'2060'}++	; 
#	$ports_ref->{'tcp'}{'2060'}{'name'} = 'teleniumdaemon'		; 
#	$srvcobjects_ref->{'rgtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rgtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rgtp'}{'port'}{'udp'} = '1431'	; 
#	$srvcobjects_ref->{'rgtp'}{'ports'}{'udp'}{'1431'}++	; 
#	$ports_ref->{'udp'}{'1431'}{'name'} = 'rgtp'		; 
#	$srvcobjects_ref->{'rgtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rgtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rgtp'}{'port'}{'tcp'} = '1431'	; 
#	$srvcobjects_ref->{'rgtp'}{'ports'}{'tcp'}{'1431'}++	; 
#	$ports_ref->{'tcp'}{'1431'}{'name'} = 'rgtp'		; 
#	$srvcobjects_ref->{'event-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'event-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'event-port'}{'port'}{'udp'} = '2069'	; 
#	$srvcobjects_ref->{'event-port'}{'ports'}{'udp'}{'2069'}++	; 
#	$ports_ref->{'udp'}{'2069'}{'name'} = 'event-port'		; 
#	$srvcobjects_ref->{'event-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'event-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'event-port'}{'port'}{'tcp'} = '2069'	; 
#	$srvcobjects_ref->{'event-port'}{'ports'}{'tcp'}{'2069'}++	; 
#	$ports_ref->{'tcp'}{'2069'}{'name'} = 'event-port'		; 
#	$srvcobjects_ref->{'ricardo-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'port'}{'udp'} = '1522'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'ports'}{'udp'}{'1522'}++	; 
#	$ports_ref->{'udp'}{'1522'}{'name'} = 'ricardo-lm'		; 
#	$srvcobjects_ref->{'ricardo-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'port'}{'udp'} = '6148'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'ports'}{'udp'}{'6148'}++	; 
#	$ports_ref->{'udp'}{'6148'}{'name'} = 'ricardo-lm'		; 
#	$srvcobjects_ref->{'ricardo-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'port'}{'tcp'} = '1522'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'ports'}{'tcp'}{'1522'}++	; 
#	$ports_ref->{'tcp'}{'1522'}{'name'} = 'ricardo-lm'		; 
#	$srvcobjects_ref->{'ricardo-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'port'}{'tcp'} = '6148'	; 
#	$srvcobjects_ref->{'ricardo-lm'}{'ports'}{'tcp'}{'6148'}++	; 
#	$ports_ref->{'tcp'}{'6148'}{'name'} = 'ricardo-lm'		; 
#	$srvcobjects_ref->{'ttntspauto'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttntspauto'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttntspauto'}{'port'}{'udp'} = '3474'	; 
#	$srvcobjects_ref->{'ttntspauto'}{'ports'}{'udp'}{'3474'}++	; 
#	$ports_ref->{'udp'}{'3474'}{'name'} = 'ttntspauto'		; 
#	$srvcobjects_ref->{'ttntspauto'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttntspauto'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttntspauto'}{'port'}{'tcp'} = '3474'	; 
#	$srvcobjects_ref->{'ttntspauto'}{'ports'}{'tcp'}{'3474'}++	; 
#	$ports_ref->{'tcp'}{'3474'}{'name'} = 'ttntspauto'		; 
#	$srvcobjects_ref->{'natuslink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'natuslink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'natuslink'}{'port'}{'udp'} = '2895'	; 
#	$srvcobjects_ref->{'natuslink'}{'ports'}{'udp'}{'2895'}++	; 
#	$ports_ref->{'udp'}{'2895'}{'name'} = 'natuslink'		; 
#	$srvcobjects_ref->{'natuslink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'natuslink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'natuslink'}{'port'}{'tcp'} = '2895'	; 
#	$srvcobjects_ref->{'natuslink'}{'ports'}{'tcp'}{'2895'}++	; 
#	$ports_ref->{'tcp'}{'2895'}{'name'} = 'natuslink'		; 
#	$srvcobjects_ref->{'imap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imap'}{'port'}{'udp'} = '143'	; 
#	$srvcobjects_ref->{'imap'}{'ports'}{'udp'}{'143'}++	; 
#	$ports_ref->{'udp'}{'143'}{'name'} = 'imap'		; 
#	$srvcobjects_ref->{'imap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imap'}{'port'}{'tcp'} = '143'	; 
#	$srvcobjects_ref->{'imap'}{'ports'}{'tcp'}{'143'}++	; 
#	$ports_ref->{'tcp'}{'143'}{'name'} = 'imap'		; 
#	$srvcobjects_ref->{'smsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smsd'}{'port'}{'udp'} = '596'	; 
#	$srvcobjects_ref->{'smsd'}{'ports'}{'udp'}{'596'}++	; 
#	$ports_ref->{'udp'}{'596'}{'name'} = 'smsd'		; 
#	$srvcobjects_ref->{'smsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smsd'}{'port'}{'tcp'} = '596'	; 
#	$srvcobjects_ref->{'smsd'}{'ports'}{'tcp'}{'596'}++	; 
#	$ports_ref->{'tcp'}{'596'}{'name'} = 'smsd'		; 
#	$srvcobjects_ref->{'serverview-icc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'serverview-icc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-icc'}{'port'}{'udp'} = '3173'	; 
#	$srvcobjects_ref->{'serverview-icc'}{'ports'}{'udp'}{'3173'}++	; 
#	$ports_ref->{'udp'}{'3173'}{'name'} = 'serverview-icc'		; 
#	$srvcobjects_ref->{'serverview-icc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'serverview-icc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-icc'}{'port'}{'tcp'} = '3173'	; 
#	$srvcobjects_ref->{'serverview-icc'}{'ports'}{'tcp'}{'3173'}++	; 
#	$ports_ref->{'tcp'}{'3173'}{'name'} = 'serverview-icc'		; 
#	$srvcobjects_ref->{'itm-mccs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itm-mccs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-mccs'}{'port'}{'udp'} = '3084'	; 
#	$srvcobjects_ref->{'itm-mccs'}{'ports'}{'udp'}{'3084'}++	; 
#	$ports_ref->{'udp'}{'3084'}{'name'} = 'itm-mccs'		; 
#	$srvcobjects_ref->{'itm-mccs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itm-mccs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-mccs'}{'port'}{'tcp'} = '3084'	; 
#	$srvcobjects_ref->{'itm-mccs'}{'ports'}{'tcp'}{'3084'}++	; 
#	$ports_ref->{'tcp'}{'3084'}{'name'} = 'itm-mccs'		; 
#	$srvcobjects_ref->{'ff-sm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ff-sm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-sm'}{'port'}{'udp'} = '1091'	; 
#	$srvcobjects_ref->{'ff-sm'}{'ports'}{'udp'}{'1091'}++	; 
#	$ports_ref->{'udp'}{'1091'}{'name'} = 'ff-sm'		; 
#	$srvcobjects_ref->{'ff-sm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ff-sm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-sm'}{'port'}{'tcp'} = '1091'	; 
#	$srvcobjects_ref->{'ff-sm'}{'ports'}{'tcp'}{'1091'}++	; 
#	$ports_ref->{'tcp'}{'1091'}{'name'} = 'ff-sm'		; 
#	$srvcobjects_ref->{'prm-nm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prm-nm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-nm'}{'port'}{'udp'} = '409'	; 
#	$srvcobjects_ref->{'prm-nm'}{'ports'}{'udp'}{'409'}++	; 
#	$ports_ref->{'udp'}{'409'}{'name'} = 'prm-nm'		; 
#	$srvcobjects_ref->{'prm-nm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prm-nm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-nm'}{'port'}{'tcp'} = '409'	; 
#	$srvcobjects_ref->{'prm-nm'}{'ports'}{'tcp'}{'409'}++	; 
#	$ports_ref->{'tcp'}{'409'}{'name'} = 'prm-nm'		; 
#	$srvcobjects_ref->{'who'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'who'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'who'}{'port'}{'udp'} = '513'	; 
#	$srvcobjects_ref->{'who'}{'ports'}{'udp'}{'513'}++	; 
#	$ports_ref->{'udp'}{'513'}{'name'} = 'who'		; 
#	$srvcobjects_ref->{'xs-openstorage'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xs-openstorage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xs-openstorage'}{'port'}{'udp'} = '1619'	; 
#	$srvcobjects_ref->{'xs-openstorage'}{'ports'}{'udp'}{'1619'}++	; 
#	$ports_ref->{'udp'}{'1619'}{'name'} = 'xs-openstorage'		; 
#	$srvcobjects_ref->{'xs-openstorage'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xs-openstorage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xs-openstorage'}{'port'}{'tcp'} = '1619'	; 
#	$srvcobjects_ref->{'xs-openstorage'}{'ports'}{'tcp'}{'1619'}++	; 
#	$ports_ref->{'tcp'}{'1619'}{'name'} = 'xs-openstorage'		; 
#	$srvcobjects_ref->{'bootps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bootps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bootps'}{'port'}{'udp'} = '67'	; 
#	$srvcobjects_ref->{'bootps'}{'ports'}{'udp'}{'67'}++	; 
#	$ports_ref->{'udp'}{'67'}{'name'} = 'bootps'		; 
#	$srvcobjects_ref->{'bootps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bootps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bootps'}{'port'}{'tcp'} = '67'	; 
#	$srvcobjects_ref->{'bootps'}{'ports'}{'tcp'}{'67'}++	; 
#	$ports_ref->{'tcp'}{'67'}{'name'} = 'bootps'		; 
#	$srvcobjects_ref->{'cadkey-licman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadkey-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadkey-licman'}{'port'}{'udp'} = '1399'	; 
#	$srvcobjects_ref->{'cadkey-licman'}{'ports'}{'udp'}{'1399'}++	; 
#	$ports_ref->{'udp'}{'1399'}{'name'} = 'cadkey-licman'		; 
#	$srvcobjects_ref->{'cadkey-licman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadkey-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadkey-licman'}{'port'}{'tcp'} = '1399'	; 
#	$srvcobjects_ref->{'cadkey-licman'}{'ports'}{'tcp'}{'1399'}++	; 
#	$ports_ref->{'tcp'}{'1399'}{'name'} = 'cadkey-licman'		; 
#	$srvcobjects_ref->{'neod2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'neod2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neod2'}{'port'}{'udp'} = '1048'	; 
#	$srvcobjects_ref->{'neod2'}{'ports'}{'udp'}{'1048'}++	; 
#	$ports_ref->{'udp'}{'1048'}{'name'} = 'neod2'		; 
#	$srvcobjects_ref->{'neod2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'neod2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neod2'}{'port'}{'tcp'} = '1048'	; 
#	$srvcobjects_ref->{'neod2'}{'ports'}{'tcp'}{'1048'}++	; 
#	$ports_ref->{'tcp'}{'1048'}{'name'} = 'neod2'		; 
#	$srvcobjects_ref->{'amdsched'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amdsched'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amdsched'}{'port'}{'udp'} = '1931'	; 
#	$srvcobjects_ref->{'amdsched'}{'ports'}{'udp'}{'1931'}++	; 
#	$ports_ref->{'udp'}{'1931'}{'name'} = 'amdsched'		; 
#	$srvcobjects_ref->{'amdsched'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amdsched'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amdsched'}{'port'}{'tcp'} = '1931'	; 
#	$srvcobjects_ref->{'amdsched'}{'ports'}{'tcp'}{'1931'}++	; 
#	$ports_ref->{'tcp'}{'1931'}{'name'} = 'amdsched'		; 
#	$srvcobjects_ref->{'ibprotocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibprotocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibprotocol'}{'port'}{'udp'} = '6714'	; 
#	$srvcobjects_ref->{'ibprotocol'}{'ports'}{'udp'}{'6714'}++	; 
#	$ports_ref->{'udp'}{'6714'}{'name'} = 'ibprotocol'		; 
#	$srvcobjects_ref->{'ibprotocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibprotocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibprotocol'}{'port'}{'tcp'} = '6714'	; 
#	$srvcobjects_ref->{'ibprotocol'}{'ports'}{'tcp'}{'6714'}++	; 
#	$ports_ref->{'tcp'}{'6714'}{'name'} = 'ibprotocol'		; 
#	$srvcobjects_ref->{'geolocate'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'geolocate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'geolocate'}{'port'}{'udp'} = '3108'	; 
#	$srvcobjects_ref->{'geolocate'}{'ports'}{'udp'}{'3108'}++	; 
#	$ports_ref->{'udp'}{'3108'}{'name'} = 'geolocate'		; 
#	$srvcobjects_ref->{'geolocate'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'geolocate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'geolocate'}{'port'}{'tcp'} = '3108'	; 
#	$srvcobjects_ref->{'geolocate'}{'ports'}{'tcp'}{'3108'}++	; 
#	$ports_ref->{'tcp'}{'3108'}{'name'} = 'geolocate'		; 
#	$srvcobjects_ref->{'gat-lmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gat-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gat-lmd'}{'port'}{'udp'} = '1708'	; 
#	$srvcobjects_ref->{'gat-lmd'}{'ports'}{'udp'}{'1708'}++	; 
#	$ports_ref->{'udp'}{'1708'}{'name'} = 'gat-lmd'		; 
#	$srvcobjects_ref->{'gat-lmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gat-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gat-lmd'}{'port'}{'tcp'} = '1708'	; 
#	$srvcobjects_ref->{'gat-lmd'}{'ports'}{'tcp'}{'1708'}++	; 
#	$ports_ref->{'tcp'}{'1708'}{'name'} = 'gat-lmd'		; 
#	$srvcobjects_ref->{'busboy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'busboy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'busboy'}{'port'}{'tcp'} = '998'	; 
#	$srvcobjects_ref->{'busboy'}{'ports'}{'tcp'}{'998'}++	; 
#	$ports_ref->{'tcp'}{'998'}{'name'} = 'busboy'		; 
#	$srvcobjects_ref->{'work-sol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'work-sol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'work-sol'}{'port'}{'udp'} = '400'	; 
#	$srvcobjects_ref->{'work-sol'}{'ports'}{'udp'}{'400'}++	; 
#	$ports_ref->{'udp'}{'400'}{'name'} = 'work-sol'		; 
#	$srvcobjects_ref->{'work-sol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'work-sol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'work-sol'}{'port'}{'tcp'} = '400'	; 
#	$srvcobjects_ref->{'work-sol'}{'ports'}{'tcp'}{'400'}++	; 
#	$ports_ref->{'tcp'}{'400'}{'name'} = 'work-sol'		; 
#	$srvcobjects_ref->{'xdsxdm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xdsxdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xdsxdm'}{'port'}{'udp'} = '6558'	; 
#	$srvcobjects_ref->{'xdsxdm'}{'ports'}{'udp'}{'6558'}++	; 
#	$ports_ref->{'udp'}{'6558'}{'name'} = 'xdsxdm'		; 
#	$srvcobjects_ref->{'xdsxdm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xdsxdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xdsxdm'}{'port'}{'tcp'} = '6558'	; 
#	$srvcobjects_ref->{'xdsxdm'}{'ports'}{'tcp'}{'6558'}++	; 
#	$ports_ref->{'tcp'}{'6558'}{'name'} = 'xdsxdm'		; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'port'}{'udp'} = '2546'	; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'ports'}{'udp'}{'2546'}++	; 
#	$ports_ref->{'udp'}{'2546'}{'name'} = 'vytalvaultbrtp'		; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'port'}{'tcp'} = '2546'	; 
#	$srvcobjects_ref->{'vytalvaultbrtp'}{'ports'}{'tcp'}{'2546'}++	; 
#	$ports_ref->{'tcp'}{'2546'}{'name'} = 'vytalvaultbrtp'		; 
#	$srvcobjects_ref->{'sunrpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sunrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunrpc'}{'port'}{'udp'} = '111'	; 
#	$srvcobjects_ref->{'sunrpc'}{'ports'}{'udp'}{'111'}++	; 
#	$ports_ref->{'udp'}{'111'}{'name'} = 'sunrpc'		; 
#	$srvcobjects_ref->{'sunrpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sunrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunrpc'}{'port'}{'tcp'} = '111'	; 
#	$srvcobjects_ref->{'sunrpc'}{'ports'}{'tcp'}{'111'}++	; 
#	$ports_ref->{'tcp'}{'111'}{'name'} = 'sunrpc'		; 
#	$srvcobjects_ref->{'wnn6-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wnn6-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wnn6-ds'}{'port'}{'udp'} = '26208'	; 
#	$srvcobjects_ref->{'wnn6-ds'}{'ports'}{'udp'}{'26208'}++	; 
#	$ports_ref->{'udp'}{'26208'}{'name'} = 'wnn6-ds'		; 
#	$srvcobjects_ref->{'wnn6-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wnn6-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wnn6-ds'}{'port'}{'tcp'} = '26208'	; 
#	$srvcobjects_ref->{'wnn6-ds'}{'ports'}{'tcp'}{'26208'}++	; 
#	$ports_ref->{'tcp'}{'26208'}{'name'} = 'wnn6-ds'		; 
#	$srvcobjects_ref->{'abr-secure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abr-secure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abr-secure'}{'port'}{'udp'} = '1955'	; 
#	$srvcobjects_ref->{'abr-secure'}{'ports'}{'udp'}{'1955'}++	; 
#	$ports_ref->{'udp'}{'1955'}{'name'} = 'abr-secure'		; 
#	$srvcobjects_ref->{'abr-secure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abr-secure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abr-secure'}{'port'}{'tcp'} = '1955'	; 
#	$srvcobjects_ref->{'abr-secure'}{'ports'}{'tcp'}{'1955'}++	; 
#	$ports_ref->{'tcp'}{'1955'}{'name'} = 'abr-secure'		; 
#	$srvcobjects_ref->{'saris'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'saris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saris'}{'port'}{'udp'} = '4442'	; 
#	$srvcobjects_ref->{'saris'}{'ports'}{'udp'}{'4442'}++	; 
#	$ports_ref->{'udp'}{'4442'}{'name'} = 'saris'		; 
#	$srvcobjects_ref->{'saris'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'saris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saris'}{'port'}{'tcp'} = '4442'	; 
#	$srvcobjects_ref->{'saris'}{'ports'}{'tcp'}{'4442'}++	; 
#	$ports_ref->{'tcp'}{'4442'}{'name'} = 'saris'		; 
#	$srvcobjects_ref->{'alphatech-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alphatech-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alphatech-lm'}{'port'}{'udp'} = '1653'	; 
#	$srvcobjects_ref->{'alphatech-lm'}{'ports'}{'udp'}{'1653'}++	; 
#	$ports_ref->{'udp'}{'1653'}{'name'} = 'alphatech-lm'		; 
#	$srvcobjects_ref->{'alphatech-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alphatech-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alphatech-lm'}{'port'}{'tcp'} = '1653'	; 
#	$srvcobjects_ref->{'alphatech-lm'}{'ports'}{'tcp'}{'1653'}++	; 
#	$ports_ref->{'tcp'}{'1653'}{'name'} = 'alphatech-lm'		; 
#	$srvcobjects_ref->{'ansys-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ansys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansys-lm'}{'port'}{'udp'} = '1800'	; 
#	$srvcobjects_ref->{'ansys-lm'}{'ports'}{'udp'}{'1800'}++	; 
#	$ports_ref->{'udp'}{'1800'}{'name'} = 'ansys-lm'		; 
#	$srvcobjects_ref->{'ansys-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ansys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansys-lm'}{'port'}{'tcp'} = '1800'	; 
#	$srvcobjects_ref->{'ansys-lm'}{'ports'}{'tcp'}{'1800'}++	; 
#	$ports_ref->{'tcp'}{'1800'}{'name'} = 'ansys-lm'		; 
#	$srvcobjects_ref->{'jlicelmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jlicelmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jlicelmd'}{'port'}{'udp'} = '1567'	; 
#	$srvcobjects_ref->{'jlicelmd'}{'ports'}{'udp'}{'1567'}++	; 
#	$ports_ref->{'udp'}{'1567'}{'name'} = 'jlicelmd'		; 
#	$srvcobjects_ref->{'jlicelmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jlicelmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jlicelmd'}{'port'}{'tcp'} = '1567'	; 
#	$srvcobjects_ref->{'jlicelmd'}{'ports'}{'tcp'}{'1567'}++	; 
#	$ports_ref->{'tcp'}{'1567'}{'name'} = 'jlicelmd'		; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'port'}{'udp'} = '3716'	; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'ports'}{'udp'}{'3716'}++	; 
#	$ports_ref->{'udp'}{'3716'}{'name'} = 'wv-csp-sms-cir'		; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'port'}{'tcp'} = '3716'	; 
#	$srvcobjects_ref->{'wv-csp-sms-cir'}{'ports'}{'tcp'}{'3716'}++	; 
#	$ports_ref->{'tcp'}{'3716'}{'name'} = 'wv-csp-sms-cir'		; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'port'}{'udp'} = '4447'	; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'ports'}{'udp'}{'4447'}++	; 
#	$ports_ref->{'udp'}{'4447'}{'name'} = 'n1-rmgmt'		; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'port'}{'tcp'} = '4447'	; 
#	$srvcobjects_ref->{'n1-rmgmt'}{'ports'}{'tcp'}{'4447'}++	; 
#	$ports_ref->{'tcp'}{'4447'}{'name'} = 'n1-rmgmt'		; 
#	$srvcobjects_ref->{'smartpackets'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smartpackets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smartpackets'}{'port'}{'udp'} = '3218'	; 
#	$srvcobjects_ref->{'smartpackets'}{'ports'}{'udp'}{'3218'}++	; 
#	$ports_ref->{'udp'}{'3218'}{'name'} = 'smartpackets'		; 
#	$srvcobjects_ref->{'smartpackets'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smartpackets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smartpackets'}{'port'}{'tcp'} = '3218'	; 
#	$srvcobjects_ref->{'smartpackets'}{'ports'}{'tcp'}{'3218'}++	; 
#	$ports_ref->{'tcp'}{'3218'}{'name'} = 'smartpackets'		; 
#	$srvcobjects_ref->{'hp-managed-node'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-managed-node'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-managed-node'}{'port'}{'udp'} = '382'	; 
#	$srvcobjects_ref->{'hp-managed-node'}{'ports'}{'udp'}{'382'}++	; 
#	$ports_ref->{'udp'}{'382'}{'name'} = 'hp-managed-node'		; 
#	$srvcobjects_ref->{'hp-managed-node'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-managed-node'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-managed-node'}{'port'}{'tcp'} = '382'	; 
#	$srvcobjects_ref->{'hp-managed-node'}{'ports'}{'tcp'}{'382'}++	; 
#	$ports_ref->{'tcp'}{'382'}{'name'} = 'hp-managed-node'		; 
#	$srvcobjects_ref->{'vids-avtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vids-avtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vids-avtp'}{'port'}{'udp'} = '1853'	; 
#	$srvcobjects_ref->{'vids-avtp'}{'ports'}{'udp'}{'1853'}++	; 
#	$ports_ref->{'udp'}{'1853'}{'name'} = 'vids-avtp'		; 
#	$srvcobjects_ref->{'vids-avtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vids-avtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vids-avtp'}{'port'}{'tcp'} = '1853'	; 
#	$srvcobjects_ref->{'vids-avtp'}{'ports'}{'tcp'}{'1853'}++	; 
#	$ports_ref->{'tcp'}{'1853'}{'name'} = 'vids-avtp'		; 
#	$srvcobjects_ref->{'data-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'data-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'data-port'}{'port'}{'udp'} = '3578'	; 
#	$srvcobjects_ref->{'data-port'}{'ports'}{'udp'}{'3578'}++	; 
#	$ports_ref->{'udp'}{'3578'}{'name'} = 'data-port'		; 
#	$srvcobjects_ref->{'data-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'data-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'data-port'}{'port'}{'tcp'} = '3578'	; 
#	$srvcobjects_ref->{'data-port'}{'ports'}{'tcp'}{'3578'}++	; 
#	$ports_ref->{'tcp'}{'3578'}{'name'} = 'data-port'		; 
#	$srvcobjects_ref->{'nesh-broker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nesh-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nesh-broker'}{'port'}{'udp'} = '3507'	; 
#	$srvcobjects_ref->{'nesh-broker'}{'ports'}{'udp'}{'3507'}++	; 
#	$ports_ref->{'udp'}{'3507'}{'name'} = 'nesh-broker'		; 
#	$srvcobjects_ref->{'nesh-broker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nesh-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nesh-broker'}{'port'}{'tcp'} = '3507'	; 
#	$srvcobjects_ref->{'nesh-broker'}{'ports'}{'tcp'}{'3507'}++	; 
#	$ports_ref->{'tcp'}{'3507'}{'name'} = 'nesh-broker'		; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'port'}{'udp'} = '3393'	; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'ports'}{'udp'}{'3393'}++	; 
#	$ports_ref->{'udp'}{'3393'}{'name'} = 'd2k-tapestry1'		; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'port'}{'tcp'} = '3393'	; 
#	$srvcobjects_ref->{'d2k-tapestry1'}{'ports'}{'tcp'}{'3393'}++	; 
#	$ports_ref->{'tcp'}{'3393'}{'name'} = 'd2k-tapestry1'		; 
#	$srvcobjects_ref->{'bears-01'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bears-01'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bears-01'}{'port'}{'udp'} = '2852'	; 
#	$srvcobjects_ref->{'bears-01'}{'ports'}{'udp'}{'2852'}++	; 
#	$ports_ref->{'udp'}{'2852'}{'name'} = 'bears-01'		; 
#	$srvcobjects_ref->{'bears-01'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bears-01'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bears-01'}{'port'}{'tcp'} = '2852'	; 
#	$srvcobjects_ref->{'bears-01'}{'ports'}{'tcp'}{'2852'}++	; 
#	$ports_ref->{'tcp'}{'2852'}{'name'} = 'bears-01'		; 
#	$srvcobjects_ref->{'starbot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'starbot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'starbot'}{'port'}{'udp'} = '2838'	; 
#	$srvcobjects_ref->{'starbot'}{'ports'}{'udp'}{'2838'}++	; 
#	$ports_ref->{'udp'}{'2838'}{'name'} = 'starbot'		; 
#	$srvcobjects_ref->{'starbot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'starbot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'starbot'}{'port'}{'tcp'} = '2838'	; 
#	$srvcobjects_ref->{'starbot'}{'ports'}{'tcp'}{'2838'}++	; 
#	$ports_ref->{'tcp'}{'2838'}{'name'} = 'starbot'		; 
#	$srvcobjects_ref->{'nmsserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmsserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsserver'}{'port'}{'udp'} = '2244'	; 
#	$srvcobjects_ref->{'nmsserver'}{'ports'}{'udp'}{'2244'}++	; 
#	$ports_ref->{'udp'}{'2244'}{'name'} = 'nmsserver'		; 
#	$srvcobjects_ref->{'nmsserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmsserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsserver'}{'port'}{'tcp'} = '2244'	; 
#	$srvcobjects_ref->{'nmsserver'}{'ports'}{'tcp'}{'2244'}++	; 
#	$ports_ref->{'tcp'}{'2244'}{'name'} = 'nmsserver'		; 
#	$srvcobjects_ref->{'caiccipc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'caiccipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caiccipc'}{'port'}{'udp'} = '1202'	; 
#	$srvcobjects_ref->{'caiccipc'}{'ports'}{'udp'}{'1202'}++	; 
#	$ports_ref->{'udp'}{'1202'}{'name'} = 'caiccipc'		; 
#	$srvcobjects_ref->{'caiccipc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'caiccipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caiccipc'}{'port'}{'tcp'} = '1202'	; 
#	$srvcobjects_ref->{'caiccipc'}{'ports'}{'tcp'}{'1202'}++	; 
#	$ports_ref->{'tcp'}{'1202'}{'name'} = 'caiccipc'		; 
#	$srvcobjects_ref->{'htuilsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'htuilsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'htuilsrv'}{'port'}{'udp'} = '5023'	; 
#	$srvcobjects_ref->{'htuilsrv'}{'ports'}{'udp'}{'5023'}++	; 
#	$ports_ref->{'udp'}{'5023'}{'name'} = 'htuilsrv'		; 
#	$srvcobjects_ref->{'htuilsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'htuilsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'htuilsrv'}{'port'}{'tcp'} = '5023'	; 
#	$srvcobjects_ref->{'htuilsrv'}{'ports'}{'tcp'}{'5023'}++	; 
#	$ports_ref->{'tcp'}{'5023'}{'name'} = 'htuilsrv'		; 
#	$srvcobjects_ref->{'ups-engine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ups-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ups-engine'}{'port'}{'udp'} = '3664'	; 
#	$srvcobjects_ref->{'ups-engine'}{'ports'}{'udp'}{'3664'}++	; 
#	$ports_ref->{'udp'}{'3664'}{'name'} = 'ups-engine'		; 
#	$srvcobjects_ref->{'ups-engine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ups-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ups-engine'}{'port'}{'tcp'} = '3664'	; 
#	$srvcobjects_ref->{'ups-engine'}{'ports'}{'tcp'}{'3664'}++	; 
#	$ports_ref->{'tcp'}{'3664'}{'name'} = 'ups-engine'		; 
#	$srvcobjects_ref->{'directv-soft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directv-soft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-soft'}{'port'}{'udp'} = '3335'	; 
#	$srvcobjects_ref->{'directv-soft'}{'ports'}{'udp'}{'3335'}++	; 
#	$ports_ref->{'udp'}{'3335'}{'name'} = 'directv-soft'		; 
#	$srvcobjects_ref->{'directv-soft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directv-soft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-soft'}{'port'}{'tcp'} = '3335'	; 
#	$srvcobjects_ref->{'directv-soft'}{'ports'}{'tcp'}{'3335'}++	; 
#	$ports_ref->{'tcp'}{'3335'}{'name'} = 'directv-soft'		; 
#	$srvcobjects_ref->{'cardbox-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cardbox-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cardbox-http'}{'port'}{'udp'} = '3106'	; 
#	$srvcobjects_ref->{'cardbox-http'}{'ports'}{'udp'}{'3106'}++	; 
#	$ports_ref->{'udp'}{'3106'}{'name'} = 'cardbox-http'		; 
#	$srvcobjects_ref->{'cardbox-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cardbox-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cardbox-http'}{'port'}{'tcp'} = '3106'	; 
#	$srvcobjects_ref->{'cardbox-http'}{'ports'}{'tcp'}{'3106'}++	; 
#	$ports_ref->{'tcp'}{'3106'}{'name'} = 'cardbox-http'		; 
#	$srvcobjects_ref->{'estamp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'estamp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'estamp'}{'port'}{'udp'} = '1982'	; 
#	$srvcobjects_ref->{'estamp'}{'ports'}{'udp'}{'1982'}++	; 
#	$ports_ref->{'udp'}{'1982'}{'name'} = 'estamp'		; 
#	$srvcobjects_ref->{'estamp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'estamp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'estamp'}{'port'}{'tcp'} = '1982'	; 
#	$srvcobjects_ref->{'estamp'}{'ports'}{'tcp'}{'1982'}++	; 
#	$ports_ref->{'tcp'}{'1982'}{'name'} = 'estamp'		; 
#	$srvcobjects_ref->{'nicname'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nicname'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicname'}{'port'}{'udp'} = '43'	; 
#	$srvcobjects_ref->{'nicname'}{'ports'}{'udp'}{'43'}++	; 
#	$ports_ref->{'udp'}{'43'}{'name'} = 'nicname'		; 
#	$srvcobjects_ref->{'nicname'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nicname'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicname'}{'port'}{'tcp'} = '43'	; 
#	$srvcobjects_ref->{'nicname'}{'ports'}{'tcp'}{'43'}++	; 
#	$ports_ref->{'tcp'}{'43'}{'name'} = 'nicname'		; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'port'}{'udp'} = '1339'	; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'ports'}{'udp'}{'1339'}++	; 
#	$ports_ref->{'udp'}{'1339'}{'name'} = 'kjtsiteserver'		; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'port'}{'tcp'} = '1339'	; 
#	$srvcobjects_ref->{'kjtsiteserver'}{'ports'}{'tcp'}{'1339'}++	; 
#	$ports_ref->{'tcp'}{'1339'}{'name'} = 'kjtsiteserver'		; 
#	$srvcobjects_ref->{'pn-requester'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pn-requester'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pn-requester'}{'port'}{'udp'} = '2717'	; 
#	$srvcobjects_ref->{'pn-requester'}{'ports'}{'udp'}{'2717'}++	; 
#	$ports_ref->{'udp'}{'2717'}{'name'} = 'pn-requester'		; 
#	$srvcobjects_ref->{'pn-requester'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pn-requester'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pn-requester'}{'port'}{'tcp'} = '2717'	; 
#	$srvcobjects_ref->{'pn-requester'}{'ports'}{'tcp'}{'2717'}++	; 
#	$ports_ref->{'tcp'}{'2717'}{'name'} = 'pn-requester'		; 
#	$srvcobjects_ref->{'mpnjsc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpnjsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsc'}{'port'}{'udp'} = '1952'	; 
#	$srvcobjects_ref->{'mpnjsc'}{'ports'}{'udp'}{'1952'}++	; 
#	$ports_ref->{'udp'}{'1952'}{'name'} = 'mpnjsc'		; 
#	$srvcobjects_ref->{'mpnjsc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpnjsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsc'}{'port'}{'tcp'} = '1952'	; 
#	$srvcobjects_ref->{'mpnjsc'}{'ports'}{'tcp'}{'1952'}++	; 
#	$ports_ref->{'tcp'}{'1952'}{'name'} = 'mpnjsc'		; 
#	$srvcobjects_ref->{'hpidsadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpidsadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpidsadmin'}{'port'}{'udp'} = '2984'	; 
#	$srvcobjects_ref->{'hpidsadmin'}{'ports'}{'udp'}{'2984'}++	; 
#	$ports_ref->{'udp'}{'2984'}{'name'} = 'hpidsadmin'		; 
#	$srvcobjects_ref->{'hpidsadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpidsadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpidsadmin'}{'port'}{'tcp'} = '2984'	; 
#	$srvcobjects_ref->{'hpidsadmin'}{'ports'}{'tcp'}{'2984'}++	; 
#	$ports_ref->{'tcp'}{'2984'}{'name'} = 'hpidsadmin'		; 
#	$srvcobjects_ref->{'yo-main'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'yo-main'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'yo-main'}{'port'}{'udp'} = '4040'	; 
#	$srvcobjects_ref->{'yo-main'}{'ports'}{'udp'}{'4040'}++	; 
#	$ports_ref->{'udp'}{'4040'}{'name'} = 'yo-main'		; 
#	$srvcobjects_ref->{'yo-main'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'yo-main'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'yo-main'}{'port'}{'tcp'} = '4040'	; 
#	$srvcobjects_ref->{'yo-main'}{'ports'}{'tcp'}{'4040'}++	; 
#	$ports_ref->{'tcp'}{'4040'}{'name'} = 'yo-main'		; 
#	$srvcobjects_ref->{'cisco-tdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cisco-tdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-tdp'}{'port'}{'udp'} = '711'	; 
#	$srvcobjects_ref->{'cisco-tdp'}{'ports'}{'udp'}{'711'}++	; 
#	$ports_ref->{'udp'}{'711'}{'name'} = 'cisco-tdp'		; 
#	$srvcobjects_ref->{'cisco-tdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cisco-tdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-tdp'}{'port'}{'tcp'} = '711'	; 
#	$srvcobjects_ref->{'cisco-tdp'}{'ports'}{'tcp'}{'711'}++	; 
#	$ports_ref->{'tcp'}{'711'}{'name'} = 'cisco-tdp'		; 
#	$srvcobjects_ref->{'incognitorv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'incognitorv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'incognitorv'}{'port'}{'udp'} = '3139'	; 
#	$srvcobjects_ref->{'incognitorv'}{'ports'}{'udp'}{'3139'}++	; 
#	$ports_ref->{'udp'}{'3139'}{'name'} = 'incognitorv'		; 
#	$srvcobjects_ref->{'incognitorv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'incognitorv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'incognitorv'}{'port'}{'tcp'} = '3139'	; 
#	$srvcobjects_ref->{'incognitorv'}{'ports'}{'tcp'}{'3139'}++	; 
#	$ports_ref->{'tcp'}{'3139'}{'name'} = 'incognitorv'		; 
#	$srvcobjects_ref->{'vcrp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vcrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcrp'}{'port'}{'udp'} = '3073'	; 
#	$srvcobjects_ref->{'vcrp'}{'ports'}{'udp'}{'3073'}++	; 
#	$ports_ref->{'udp'}{'3073'}{'name'} = 'vcrp'		; 
#	$srvcobjects_ref->{'vcrp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vcrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcrp'}{'port'}{'tcp'} = '3073'	; 
#	$srvcobjects_ref->{'vcrp'}{'ports'}{'tcp'}{'3073'}++	; 
#	$ports_ref->{'tcp'}{'3073'}{'name'} = 'vcrp'		; 
#	$srvcobjects_ref->{'ptcnameservice'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ptcnameservice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptcnameservice'}{'port'}{'udp'} = '597'	; 
#	$srvcobjects_ref->{'ptcnameservice'}{'ports'}{'udp'}{'597'}++	; 
#	$ports_ref->{'udp'}{'597'}{'name'} = 'ptcnameservice'		; 
#	$srvcobjects_ref->{'ptcnameservice'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ptcnameservice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptcnameservice'}{'port'}{'tcp'} = '597'	; 
#	$srvcobjects_ref->{'ptcnameservice'}{'ports'}{'tcp'}{'597'}++	; 
#	$ports_ref->{'tcp'}{'597'}{'name'} = 'ptcnameservice'		; 
#	$srvcobjects_ref->{'qotps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qotps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qotps'}{'port'}{'udp'} = '2724'	; 
#	$srvcobjects_ref->{'qotps'}{'ports'}{'udp'}{'2724'}++	; 
#	$ports_ref->{'udp'}{'2724'}{'name'} = 'qotps'		; 
#	$srvcobjects_ref->{'qotps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qotps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qotps'}{'port'}{'tcp'} = '2724'	; 
#	$srvcobjects_ref->{'qotps'}{'ports'}{'tcp'}{'2724'}++	; 
#	$ports_ref->{'tcp'}{'2724'}{'name'} = 'qotps'		; 
#	$srvcobjects_ref->{'traceroute'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'traceroute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'traceroute'}{'port'}{'udp'} = '33434'	; 
#	$srvcobjects_ref->{'traceroute'}{'ports'}{'udp'}{'33434'}++	; 
#	$ports_ref->{'udp'}{'33434'}{'name'} = 'traceroute'		; 
#	$srvcobjects_ref->{'traceroute'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'traceroute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'traceroute'}{'port'}{'tcp'} = '33434'	; 
#	$srvcobjects_ref->{'traceroute'}{'ports'}{'tcp'}{'33434'}++	; 
#	$ports_ref->{'tcp'}{'33434'}{'name'} = 'traceroute'		; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'port'}{'udp'} = '6064'	; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'ports'}{'udp'}{'6064'}++	; 
#	$ports_ref->{'udp'}{'6064'}{'name'} = 'ndl-ahp-svc'		; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'port'}{'tcp'} = '6064'	; 
#	$srvcobjects_ref->{'ndl-ahp-svc'}{'ports'}{'tcp'}{'6064'}++	; 
#	$ports_ref->{'tcp'}{'6064'}{'name'} = 'ndl-ahp-svc'		; 
#	$srvcobjects_ref->{'stun-p3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stun-p3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-p3'}{'port'}{'udp'} = '1992'	; 
#	$srvcobjects_ref->{'stun-p3'}{'ports'}{'udp'}{'1992'}++	; 
#	$ports_ref->{'udp'}{'1992'}{'name'} = 'stun-p3'		; 
#	$srvcobjects_ref->{'stun-p3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stun-p3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-p3'}{'port'}{'tcp'} = '1992'	; 
#	$srvcobjects_ref->{'stun-p3'}{'ports'}{'tcp'}{'1992'}++	; 
#	$ports_ref->{'tcp'}{'1992'}{'name'} = 'stun-p3'		; 
#	$srvcobjects_ref->{'s-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'s-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'s-net'}{'port'}{'udp'} = '166'	; 
#	$srvcobjects_ref->{'s-net'}{'ports'}{'udp'}{'166'}++	; 
#	$ports_ref->{'udp'}{'166'}{'name'} = 's-net'		; 
#	$srvcobjects_ref->{'s-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'s-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'s-net'}{'port'}{'tcp'} = '166'	; 
#	$srvcobjects_ref->{'s-net'}{'ports'}{'tcp'}{'166'}++	; 
#	$ports_ref->{'tcp'}{'166'}{'name'} = 's-net'		; 
#	$srvcobjects_ref->{'qpasa-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qpasa-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qpasa-agent'}{'port'}{'udp'} = '2612'	; 
#	$srvcobjects_ref->{'qpasa-agent'}{'ports'}{'udp'}{'2612'}++	; 
#	$ports_ref->{'udp'}{'2612'}{'name'} = 'qpasa-agent'		; 
#	$srvcobjects_ref->{'qpasa-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qpasa-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qpasa-agent'}{'port'}{'tcp'} = '2612'	; 
#	$srvcobjects_ref->{'qpasa-agent'}{'ports'}{'tcp'}{'2612'}++	; 
#	$ports_ref->{'tcp'}{'2612'}{'name'} = 'qpasa-agent'		; 
#	$srvcobjects_ref->{'icl-twobase8'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase8'}{'port'}{'udp'} = '25007'	; 
#	$srvcobjects_ref->{'icl-twobase8'}{'ports'}{'udp'}{'25007'}++	; 
#	$ports_ref->{'udp'}{'25007'}{'name'} = 'icl-twobase8'		; 
#	$srvcobjects_ref->{'icl-twobase8'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase8'}{'port'}{'tcp'} = '25007'	; 
#	$srvcobjects_ref->{'icl-twobase8'}{'ports'}{'tcp'}{'25007'}++	; 
#	$ports_ref->{'tcp'}{'25007'}{'name'} = 'icl-twobase8'		; 
#	$srvcobjects_ref->{'vfo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vfo'}{'port'}{'udp'} = '1056'	; 
#	$srvcobjects_ref->{'vfo'}{'ports'}{'udp'}{'1056'}++	; 
#	$ports_ref->{'udp'}{'1056'}{'name'} = 'vfo'		; 
#	$srvcobjects_ref->{'vfo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vfo'}{'port'}{'tcp'} = '1056'	; 
#	$srvcobjects_ref->{'vfo'}{'ports'}{'tcp'}{'1056'}++	; 
#	$ports_ref->{'tcp'}{'1056'}{'name'} = 'vfo'		; 
#	$srvcobjects_ref->{'linkname'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'linkname'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'linkname'}{'port'}{'udp'} = '1903'	; 
#	$srvcobjects_ref->{'linkname'}{'ports'}{'udp'}{'1903'}++	; 
#	$ports_ref->{'udp'}{'1903'}{'name'} = 'linkname'		; 
#	$srvcobjects_ref->{'linkname'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'linkname'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'linkname'}{'port'}{'tcp'} = '1903'	; 
#	$srvcobjects_ref->{'linkname'}{'ports'}{'tcp'}{'1903'}++	; 
#	$ports_ref->{'tcp'}{'1903'}{'name'} = 'linkname'		; 
#	$srvcobjects_ref->{'husky'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'husky'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'husky'}{'port'}{'udp'} = '1310'	; 
#	$srvcobjects_ref->{'husky'}{'ports'}{'udp'}{'1310'}++	; 
#	$ports_ref->{'udp'}{'1310'}{'name'} = 'husky'		; 
#	$srvcobjects_ref->{'husky'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'husky'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'husky'}{'port'}{'tcp'} = '1310'	; 
#	$srvcobjects_ref->{'husky'}{'ports'}{'tcp'}{'1310'}++	; 
#	$ports_ref->{'tcp'}{'1310'}{'name'} = 'husky'		; 
#	$srvcobjects_ref->{'ms-sna-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-sna-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sna-server'}{'port'}{'udp'} = '1477'	; 
#	$srvcobjects_ref->{'ms-sna-server'}{'ports'}{'udp'}{'1477'}++	; 
#	$ports_ref->{'udp'}{'1477'}{'name'} = 'ms-sna-server'		; 
#	$srvcobjects_ref->{'ms-sna-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-sna-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sna-server'}{'port'}{'tcp'} = '1477'	; 
#	$srvcobjects_ref->{'ms-sna-server'}{'ports'}{'tcp'}{'1477'}++	; 
#	$ports_ref->{'tcp'}{'1477'}{'name'} = 'ms-sna-server'		; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'port'}{'udp'} = '2420'	; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'ports'}{'udp'}{'2420'}++	; 
#	$ports_ref->{'udp'}{'2420'}{'name'} = 'dslremote-mgmt'		; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'port'}{'tcp'} = '2420'	; 
#	$srvcobjects_ref->{'dslremote-mgmt'}{'ports'}{'tcp'}{'2420'}++	; 
#	$ports_ref->{'tcp'}{'2420'}{'name'} = 'dslremote-mgmt'		; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'port'}{'udp'} = '5099'	; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'ports'}{'udp'}{'5099'}++	; 
#	$ports_ref->{'udp'}{'5099'}{'name'} = 'sentlm-srv2srv'		; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'port'}{'tcp'} = '5099'	; 
#	$srvcobjects_ref->{'sentlm-srv2srv'}{'ports'}{'tcp'}{'5099'}++	; 
#	$ports_ref->{'tcp'}{'5099'}{'name'} = 'sentlm-srv2srv'		; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'port'}{'udp'} = '2962'	; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'ports'}{'udp'}{'2962'}++	; 
#	$ports_ref->{'udp'}{'2962'}{'name'} = 'iph-policy-cli'		; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'port'}{'tcp'} = '2962'	; 
#	$srvcobjects_ref->{'iph-policy-cli'}{'ports'}{'tcp'}{'2962'}++	; 
#	$ports_ref->{'tcp'}{'2962'}{'name'} = 'iph-policy-cli'		; 
#	$srvcobjects_ref->{'fastlynx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fastlynx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fastlynx'}{'port'}{'udp'} = '2689'	; 
#	$srvcobjects_ref->{'fastlynx'}{'ports'}{'udp'}{'2689'}++	; 
#	$ports_ref->{'udp'}{'2689'}{'name'} = 'fastlynx'		; 
#	$srvcobjects_ref->{'fastlynx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fastlynx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fastlynx'}{'port'}{'tcp'} = '2689'	; 
#	$srvcobjects_ref->{'fastlynx'}{'ports'}{'tcp'}{'2689'}++	; 
#	$ports_ref->{'tcp'}{'2689'}{'name'} = 'fastlynx'		; 
#	$srvcobjects_ref->{'tftp-mcast'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tftp-mcast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tftp-mcast'}{'port'}{'udp'} = '1758'	; 
#	$srvcobjects_ref->{'tftp-mcast'}{'ports'}{'udp'}{'1758'}++	; 
#	$ports_ref->{'udp'}{'1758'}{'name'} = 'tftp-mcast'		; 
#	$srvcobjects_ref->{'tftp-mcast'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tftp-mcast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tftp-mcast'}{'port'}{'tcp'} = '1758'	; 
#	$srvcobjects_ref->{'tftp-mcast'}{'ports'}{'tcp'}{'1758'}++	; 
#	$ports_ref->{'tcp'}{'1758'}{'name'} = 'tftp-mcast'		; 
#	$srvcobjects_ref->{'comscm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'comscm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'comscm'}{'port'}{'udp'} = '437'	; 
#	$srvcobjects_ref->{'comscm'}{'ports'}{'udp'}{'437'}++	; 
#	$ports_ref->{'udp'}{'437'}{'name'} = 'comscm'		; 
#	$srvcobjects_ref->{'comscm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'comscm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'comscm'}{'port'}{'tcp'} = '437'	; 
#	$srvcobjects_ref->{'comscm'}{'ports'}{'tcp'}{'437'}++	; 
#	$ports_ref->{'tcp'}{'437'}{'name'} = 'comscm'		; 
#	$srvcobjects_ref->{'ssh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssh'}{'port'}{'udp'} = '22'	; 
#	$srvcobjects_ref->{'ssh'}{'ports'}{'udp'}{'22'}++	; 
#	$ports_ref->{'udp'}{'22'}{'name'} = 'ssh'		; 
#	$srvcobjects_ref->{'ssh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssh'}{'port'}{'tcp'} = '22'	; 
#	$srvcobjects_ref->{'ssh'}{'ports'}{'tcp'}{'22'}++	; 
#	$ports_ref->{'tcp'}{'22'}{'name'} = 'ssh'		; 
#	$srvcobjects_ref->{'kofax-svr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kofax-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kofax-svr'}{'port'}{'udp'} = '2424'	; 
#	$srvcobjects_ref->{'kofax-svr'}{'ports'}{'udp'}{'2424'}++	; 
#	$ports_ref->{'udp'}{'2424'}{'name'} = 'kofax-svr'		; 
#	$srvcobjects_ref->{'kofax-svr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kofax-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kofax-svr'}{'port'}{'tcp'} = '2424'	; 
#	$srvcobjects_ref->{'kofax-svr'}{'ports'}{'tcp'}{'2424'}++	; 
#	$ports_ref->{'tcp'}{'2424'}{'name'} = 'kofax-svr'		; 
#	$srvcobjects_ref->{'entrust-aams'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entrust-aams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-aams'}{'port'}{'udp'} = '681'	; 
#	$srvcobjects_ref->{'entrust-aams'}{'ports'}{'udp'}{'681'}++	; 
#	$ports_ref->{'udp'}{'681'}{'name'} = 'entrust-aams'		; 
#	$srvcobjects_ref->{'entrust-aams'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entrust-aams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-aams'}{'port'}{'tcp'} = '681'	; 
#	$srvcobjects_ref->{'entrust-aams'}{'ports'}{'tcp'}{'681'}++	; 
#	$ports_ref->{'tcp'}{'681'}{'name'} = 'entrust-aams'		; 
#	$srvcobjects_ref->{'call-sig-trans'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'call-sig-trans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'call-sig-trans'}{'port'}{'udp'} = '2517'	; 
#	$srvcobjects_ref->{'call-sig-trans'}{'ports'}{'udp'}{'2517'}++	; 
#	$ports_ref->{'udp'}{'2517'}{'name'} = 'call-sig-trans'		; 
#	$srvcobjects_ref->{'call-sig-trans'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'call-sig-trans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'call-sig-trans'}{'port'}{'tcp'} = '2517'	; 
#	$srvcobjects_ref->{'call-sig-trans'}{'ports'}{'tcp'}{'2517'}++	; 
#	$ports_ref->{'tcp'}{'2517'}{'name'} = 'call-sig-trans'		; 
#	$srvcobjects_ref->{'ndl-aas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndl-aas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-aas'}{'port'}{'udp'} = '3128'	; 
#	$srvcobjects_ref->{'ndl-aas'}{'ports'}{'udp'}{'3128'}++	; 
#	$ports_ref->{'udp'}{'3128'}{'name'} = 'ndl-aas'		; 
#	$srvcobjects_ref->{'ndl-aas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndl-aas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-aas'}{'port'}{'tcp'} = '3128'	; 
#	$srvcobjects_ref->{'ndl-aas'}{'ports'}{'tcp'}{'3128'}++	; 
#	$ports_ref->{'tcp'}{'3128'}{'name'} = 'ndl-aas'		; 
#	$srvcobjects_ref->{'apc-3052'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-3052'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-3052'}{'port'}{'udp'} = '3052'	; 
#	$srvcobjects_ref->{'apc-3052'}{'ports'}{'udp'}{'3052'}++	; 
#	$ports_ref->{'udp'}{'3052'}{'name'} = 'apc-3052'		; 
#	$srvcobjects_ref->{'apc-3052'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-3052'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-3052'}{'port'}{'tcp'} = '3052'	; 
#	$srvcobjects_ref->{'apc-3052'}{'ports'}{'tcp'}{'3052'}++	; 
#	$ports_ref->{'tcp'}{'3052'}{'name'} = 'apc-3052'		; 
#	$srvcobjects_ref->{'brp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'brp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brp'}{'port'}{'udp'} = '3043'	; 
#	$srvcobjects_ref->{'brp'}{'ports'}{'udp'}{'3043'}++	; 
#	$ports_ref->{'udp'}{'3043'}{'name'} = 'brp'		; 
#	$srvcobjects_ref->{'brp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'brp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brp'}{'port'}{'tcp'} = '3043'	; 
#	$srvcobjects_ref->{'brp'}{'ports'}{'tcp'}{'3043'}++	; 
#	$ports_ref->{'tcp'}{'3043'}{'name'} = 'brp'		; 
#	$srvcobjects_ref->{'pkagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pkagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkagent'}{'port'}{'udp'} = '3118'	; 
#	$srvcobjects_ref->{'pkagent'}{'ports'}{'udp'}{'3118'}++	; 
#	$ports_ref->{'udp'}{'3118'}{'name'} = 'pkagent'		; 
#	$srvcobjects_ref->{'pkagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pkagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkagent'}{'port'}{'tcp'} = '3118'	; 
#	$srvcobjects_ref->{'pkagent'}{'ports'}{'tcp'}{'3118'}++	; 
#	$ports_ref->{'tcp'}{'3118'}{'name'} = 'pkagent'		; 
#	$srvcobjects_ref->{'opsession-prxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsession-prxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsession-prxy'}{'port'}{'udp'} = '3307'	; 
#	$srvcobjects_ref->{'opsession-prxy'}{'ports'}{'udp'}{'3307'}++	; 
#	$ports_ref->{'udp'}{'3307'}{'name'} = 'opsession-prxy'		; 
#	$srvcobjects_ref->{'opsession-prxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsession-prxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsession-prxy'}{'port'}{'tcp'} = '3307'	; 
#	$srvcobjects_ref->{'opsession-prxy'}{'ports'}{'tcp'}{'3307'}++	; 
#	$ports_ref->{'tcp'}{'3307'}{'name'} = 'opsession-prxy'		; 
#	$srvcobjects_ref->{'altav-remmgt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'altav-remmgt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altav-remmgt'}{'port'}{'udp'} = '2456'	; 
#	$srvcobjects_ref->{'altav-remmgt'}{'ports'}{'udp'}{'2456'}++	; 
#	$ports_ref->{'udp'}{'2456'}{'name'} = 'altav-remmgt'		; 
#	$srvcobjects_ref->{'altav-remmgt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'altav-remmgt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altav-remmgt'}{'port'}{'tcp'} = '2456'	; 
#	$srvcobjects_ref->{'altav-remmgt'}{'ports'}{'tcp'}{'2456'}++	; 
#	$ports_ref->{'tcp'}{'2456'}{'name'} = 'altav-remmgt'		; 
#	$srvcobjects_ref->{'pip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pip'}{'port'}{'udp'} = '1321'	; 
#	$srvcobjects_ref->{'pip'}{'ports'}{'udp'}{'1321'}++	; 
#	$ports_ref->{'udp'}{'1321'}{'name'} = 'pip'		; 
#	$srvcobjects_ref->{'pip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pip'}{'port'}{'udp'} = '321'	; 
#	$srvcobjects_ref->{'pip'}{'ports'}{'udp'}{'321'}++	; 
#	$ports_ref->{'udp'}{'321'}{'name'} = 'pip'		; 
#	$srvcobjects_ref->{'pip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pip'}{'port'}{'tcp'} = '1321'	; 
#	$srvcobjects_ref->{'pip'}{'ports'}{'tcp'}{'1321'}++	; 
#	$ports_ref->{'tcp'}{'1321'}{'name'} = 'pip'		; 
#	$srvcobjects_ref->{'pip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pip'}{'port'}{'tcp'} = '321'	; 
#	$srvcobjects_ref->{'pip'}{'ports'}{'tcp'}{'321'}++	; 
#	$ports_ref->{'tcp'}{'321'}{'name'} = 'pip'		; 
#	$srvcobjects_ref->{'z39.50'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'z39.50'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'z39.50'}{'port'}{'udp'} = '210'	; 
#	$srvcobjects_ref->{'z39.50'}{'ports'}{'udp'}{'210'}++	; 
#	$ports_ref->{'udp'}{'210'}{'name'} = 'z39.50'		; 
#	$srvcobjects_ref->{'z39.50'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'z39.50'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'z39.50'}{'port'}{'tcp'} = '210'	; 
#	$srvcobjects_ref->{'z39.50'}{'ports'}{'tcp'}{'210'}++	; 
#	$ports_ref->{'tcp'}{'210'}{'name'} = 'z39.50'		; 
#	$srvcobjects_ref->{'imip-channels'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imip-channels'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imip-channels'}{'port'}{'udp'} = '11320'	; 
#	$srvcobjects_ref->{'imip-channels'}{'ports'}{'udp'}{'11320'}++	; 
#	$ports_ref->{'udp'}{'11320'}{'name'} = 'imip-channels'		; 
#	$srvcobjects_ref->{'imip-channels'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imip-channels'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imip-channels'}{'port'}{'tcp'} = '11320'	; 
#	$srvcobjects_ref->{'imip-channels'}{'ports'}{'tcp'}{'11320'}++	; 
#	$ports_ref->{'tcp'}{'11320'}{'name'} = 'imip-channels'		; 
#	$srvcobjects_ref->{'vmodem'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vmodem'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vmodem'}{'port'}{'udp'} = '3141'	; 
#	$srvcobjects_ref->{'vmodem'}{'ports'}{'udp'}{'3141'}++	; 
#	$ports_ref->{'udp'}{'3141'}{'name'} = 'vmodem'		; 
#	$srvcobjects_ref->{'vmodem'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vmodem'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vmodem'}{'port'}{'tcp'} = '3141'	; 
#	$srvcobjects_ref->{'vmodem'}{'ports'}{'tcp'}{'3141'}++	; 
#	$ports_ref->{'tcp'}{'3141'}{'name'} = 'vmodem'		; 
#	$srvcobjects_ref->{'lm-sserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lm-sserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-sserver'}{'port'}{'udp'} = '8207'	; 
#	$srvcobjects_ref->{'lm-sserver'}{'ports'}{'udp'}{'8207'}++	; 
#	$ports_ref->{'udp'}{'8207'}{'name'} = 'lm-sserver'		; 
#	$srvcobjects_ref->{'lm-sserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lm-sserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-sserver'}{'port'}{'tcp'} = '8207'	; 
#	$srvcobjects_ref->{'lm-sserver'}{'ports'}{'tcp'}{'8207'}++	; 
#	$ports_ref->{'tcp'}{'8207'}{'name'} = 'lm-sserver'		; 
#	$srvcobjects_ref->{'meregister'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'meregister'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meregister'}{'port'}{'udp'} = '669'	; 
#	$srvcobjects_ref->{'meregister'}{'ports'}{'udp'}{'669'}++	; 
#	$ports_ref->{'udp'}{'669'}{'name'} = 'meregister'		; 
#	$srvcobjects_ref->{'meregister'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'meregister'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meregister'}{'port'}{'tcp'} = '669'	; 
#	$srvcobjects_ref->{'meregister'}{'ports'}{'tcp'}{'669'}++	; 
#	$ports_ref->{'tcp'}{'669'}{'name'} = 'meregister'		; 
#	$srvcobjects_ref->{'psrserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'psrserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psrserver'}{'port'}{'udp'} = '2351'	; 
#	$srvcobjects_ref->{'psrserver'}{'ports'}{'udp'}{'2351'}++	; 
#	$ports_ref->{'udp'}{'2351'}{'name'} = 'psrserver'		; 
#	$srvcobjects_ref->{'psrserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'psrserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psrserver'}{'port'}{'tcp'} = '2351'	; 
#	$srvcobjects_ref->{'psrserver'}{'ports'}{'tcp'}{'2351'}++	; 
#	$ports_ref->{'tcp'}{'2351'}{'name'} = 'psrserver'		; 
#	$srvcobjects_ref->{'utime'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'utime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utime'}{'port'}{'udp'} = '519'	; 
#	$srvcobjects_ref->{'utime'}{'ports'}{'udp'}{'519'}++	; 
#	$ports_ref->{'udp'}{'519'}{'name'} = 'utime'		; 
#	$srvcobjects_ref->{'utime'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'utime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utime'}{'port'}{'tcp'} = '519'	; 
#	$srvcobjects_ref->{'utime'}{'ports'}{'tcp'}{'519'}++	; 
#	$ports_ref->{'tcp'}{'519'}{'name'} = 'utime'		; 
#	$srvcobjects_ref->{'hacl-local'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-local'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-local'}{'port'}{'udp'} = '5304'	; 
#	$srvcobjects_ref->{'hacl-local'}{'ports'}{'udp'}{'5304'}++	; 
#	$ports_ref->{'udp'}{'5304'}{'name'} = 'hacl-local'		; 
#	$srvcobjects_ref->{'hacl-local'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-local'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-local'}{'port'}{'tcp'} = '5304'	; 
#	$srvcobjects_ref->{'hacl-local'}{'ports'}{'tcp'}{'5304'}++	; 
#	$ports_ref->{'tcp'}{'5304'}{'name'} = 'hacl-local'		; 
#	$srvcobjects_ref->{'sdsc-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdsc-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdsc-lm'}{'port'}{'udp'} = '1537'	; 
#	$srvcobjects_ref->{'sdsc-lm'}{'ports'}{'udp'}{'1537'}++	; 
#	$ports_ref->{'udp'}{'1537'}{'name'} = 'sdsc-lm'		; 
#	$srvcobjects_ref->{'sdsc-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdsc-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdsc-lm'}{'port'}{'tcp'} = '1537'	; 
#	$srvcobjects_ref->{'sdsc-lm'}{'ports'}{'tcp'}{'1537'}++	; 
#	$ports_ref->{'tcp'}{'1537'}{'name'} = 'sdsc-lm'		; 
#	$srvcobjects_ref->{'tl1-telnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tl1-telnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1-telnet'}{'port'}{'udp'} = '3083'	; 
#	$srvcobjects_ref->{'tl1-telnet'}{'ports'}{'udp'}{'3083'}++	; 
#	$ports_ref->{'udp'}{'3083'}{'name'} = 'tl1-telnet'		; 
#	$srvcobjects_ref->{'tl1-telnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tl1-telnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1-telnet'}{'port'}{'tcp'} = '3083'	; 
#	$srvcobjects_ref->{'tl1-telnet'}{'ports'}{'tcp'}{'3083'}++	; 
#	$ports_ref->{'tcp'}{'3083'}{'name'} = 'tl1-telnet'		; 
#	$srvcobjects_ref->{'xmsg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmsg'}{'port'}{'udp'} = '1716'	; 
#	$srvcobjects_ref->{'xmsg'}{'ports'}{'udp'}{'1716'}++	; 
#	$ports_ref->{'udp'}{'1716'}{'name'} = 'xmsg'		; 
#	$srvcobjects_ref->{'xmsg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmsg'}{'port'}{'tcp'} = '1716'	; 
#	$srvcobjects_ref->{'xmsg'}{'ports'}{'tcp'}{'1716'}++	; 
#	$ports_ref->{'tcp'}{'1716'}{'name'} = 'xmsg'		; 
#	$srvcobjects_ref->{'h323hostcall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h323hostcall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323hostcall'}{'port'}{'udp'} = '1720'	; 
#	$srvcobjects_ref->{'h323hostcall'}{'ports'}{'udp'}{'1720'}++	; 
#	$ports_ref->{'udp'}{'1720'}{'name'} = 'h323hostcall'		; 
#	$srvcobjects_ref->{'h323hostcall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h323hostcall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323hostcall'}{'port'}{'tcp'} = '1720'	; 
#	$srvcobjects_ref->{'h323hostcall'}{'ports'}{'tcp'}{'1720'}++	; 
#	$ports_ref->{'tcp'}{'1720'}{'name'} = 'h323hostcall'		; 
#	$srvcobjects_ref->{'emperion'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emperion'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emperion'}{'port'}{'udp'} = '1282'	; 
#	$srvcobjects_ref->{'emperion'}{'ports'}{'udp'}{'1282'}++	; 
#	$ports_ref->{'udp'}{'1282'}{'name'} = 'emperion'		; 
#	$srvcobjects_ref->{'emperion'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emperion'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emperion'}{'port'}{'tcp'} = '1282'	; 
#	$srvcobjects_ref->{'emperion'}{'ports'}{'tcp'}{'1282'}++	; 
#	$ports_ref->{'tcp'}{'1282'}{'name'} = 'emperion'		; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'port'}{'udp'} = '709'	; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'ports'}{'udp'}{'709'}++	; 
#	$ports_ref->{'udp'}{'709'}{'name'} = 'entrust-kmsh'		; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'port'}{'tcp'} = '709'	; 
#	$srvcobjects_ref->{'entrust-kmsh'}{'ports'}{'tcp'}{'709'}++	; 
#	$ports_ref->{'tcp'}{'709'}{'name'} = 'entrust-kmsh'		; 
#	$srvcobjects_ref->{'entexthigh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entexthigh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entexthigh'}{'port'}{'udp'} = '12002'	; 
#	$srvcobjects_ref->{'entexthigh'}{'ports'}{'udp'}{'12002'}++	; 
#	$ports_ref->{'udp'}{'12002'}{'name'} = 'entexthigh'		; 
#	$srvcobjects_ref->{'entexthigh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entexthigh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entexthigh'}{'port'}{'tcp'} = '12002'	; 
#	$srvcobjects_ref->{'entexthigh'}{'ports'}{'tcp'}{'12002'}++	; 
#	$ports_ref->{'tcp'}{'12002'}{'name'} = 'entexthigh'		; 
#	$srvcobjects_ref->{'serialgateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'serialgateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serialgateway'}{'port'}{'udp'} = '1243'	; 
#	$srvcobjects_ref->{'serialgateway'}{'ports'}{'udp'}{'1243'}++	; 
#	$ports_ref->{'udp'}{'1243'}{'name'} = 'serialgateway'		; 
#	$srvcobjects_ref->{'serialgateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'serialgateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serialgateway'}{'port'}{'tcp'} = '1243'	; 
#	$srvcobjects_ref->{'serialgateway'}{'ports'}{'tcp'}{'1243'}++	; 
#	$ports_ref->{'tcp'}{'1243'}{'name'} = 'serialgateway'		; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'port'}{'udp'} = '6101'	; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'ports'}{'udp'}{'6101'}++	; 
#	$ports_ref->{'udp'}{'6101'}{'name'} = 'synchronet-rtc'		; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'port'}{'tcp'} = '6101'	; 
#	$srvcobjects_ref->{'synchronet-rtc'}{'ports'}{'tcp'}{'6101'}++	; 
#	$ports_ref->{'tcp'}{'6101'}{'name'} = 'synchronet-rtc'		; 
#	$srvcobjects_ref->{'raven-rdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raven-rdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven-rdp'}{'port'}{'udp'} = '3533'	; 
#	$srvcobjects_ref->{'raven-rdp'}{'ports'}{'udp'}{'3533'}++	; 
#	$ports_ref->{'udp'}{'3533'}{'name'} = 'raven-rdp'		; 
#	$srvcobjects_ref->{'raven-rdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raven-rdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven-rdp'}{'port'}{'tcp'} = '3533'	; 
#	$srvcobjects_ref->{'raven-rdp'}{'ports'}{'tcp'}{'3533'}++	; 
#	$ports_ref->{'tcp'}{'3533'}{'name'} = 'raven-rdp'		; 
#	$srvcobjects_ref->{'nexstorindltd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nexstorindltd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nexstorindltd'}{'port'}{'udp'} = '2360'	; 
#	$srvcobjects_ref->{'nexstorindltd'}{'ports'}{'udp'}{'2360'}++	; 
#	$ports_ref->{'udp'}{'2360'}{'name'} = 'nexstorindltd'		; 
#	$srvcobjects_ref->{'nexstorindltd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nexstorindltd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nexstorindltd'}{'port'}{'tcp'} = '2360'	; 
#	$srvcobjects_ref->{'nexstorindltd'}{'ports'}{'tcp'}{'2360'}++	; 
#	$ports_ref->{'tcp'}{'2360'}{'name'} = 'nexstorindltd'		; 
#	$srvcobjects_ref->{'opscenter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opscenter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opscenter'}{'port'}{'udp'} = '3636'	; 
#	$srvcobjects_ref->{'opscenter'}{'ports'}{'udp'}{'3636'}++	; 
#	$ports_ref->{'udp'}{'3636'}{'name'} = 'opscenter'		; 
#	$srvcobjects_ref->{'opscenter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opscenter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opscenter'}{'port'}{'tcp'} = '3636'	; 
#	$srvcobjects_ref->{'opscenter'}{'ports'}{'tcp'}{'3636'}++	; 
#	$ports_ref->{'tcp'}{'3636'}{'name'} = 'opscenter'		; 
#	$srvcobjects_ref->{'lipsinc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lipsinc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lipsinc'}{'port'}{'udp'} = '1968'	; 
#	$srvcobjects_ref->{'lipsinc'}{'ports'}{'udp'}{'1968'}++	; 
#	$ports_ref->{'udp'}{'1968'}{'name'} = 'lipsinc'		; 
#	$srvcobjects_ref->{'lipsinc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lipsinc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lipsinc'}{'port'}{'tcp'} = '1968'	; 
#	$srvcobjects_ref->{'lipsinc'}{'ports'}{'tcp'}{'1968'}++	; 
#	$ports_ref->{'tcp'}{'1968'}{'name'} = 'lipsinc'		; 
#	$srvcobjects_ref->{'corerjd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'corerjd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corerjd'}{'port'}{'udp'} = '284'	; 
#	$srvcobjects_ref->{'corerjd'}{'ports'}{'udp'}{'284'}++	; 
#	$ports_ref->{'udp'}{'284'}{'name'} = 'corerjd'		; 
#	$srvcobjects_ref->{'corerjd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'corerjd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corerjd'}{'port'}{'tcp'} = '284'	; 
#	$srvcobjects_ref->{'corerjd'}{'ports'}{'tcp'}{'284'}++	; 
#	$ports_ref->{'tcp'}{'284'}{'name'} = 'corerjd'		; 
#	$srvcobjects_ref->{'ac-cluster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ac-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ac-cluster'}{'port'}{'udp'} = '18463'	; 
#	$srvcobjects_ref->{'ac-cluster'}{'ports'}{'udp'}{'18463'}++	; 
#	$ports_ref->{'udp'}{'18463'}{'name'} = 'ac-cluster'		; 
#	$srvcobjects_ref->{'ac-cluster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ac-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ac-cluster'}{'port'}{'tcp'} = '18463'	; 
#	$srvcobjects_ref->{'ac-cluster'}{'ports'}{'tcp'}{'18463'}++	; 
#	$ports_ref->{'tcp'}{'18463'}{'name'} = 'ac-cluster'		; 
#	$srvcobjects_ref->{'mc-appserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mc-appserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-appserver'}{'port'}{'udp'} = '8763'	; 
#	$srvcobjects_ref->{'mc-appserver'}{'ports'}{'udp'}{'8763'}++	; 
#	$ports_ref->{'udp'}{'8763'}{'name'} = 'mc-appserver'		; 
#	$srvcobjects_ref->{'mc-appserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mc-appserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-appserver'}{'port'}{'tcp'} = '8763'	; 
#	$srvcobjects_ref->{'mc-appserver'}{'ports'}{'tcp'}{'8763'}++	; 
#	$ports_ref->{'tcp'}{'8763'}{'name'} = 'mc-appserver'		; 
#	$srvcobjects_ref->{'dnox'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dnox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnox'}{'port'}{'udp'} = '4022'	; 
#	$srvcobjects_ref->{'dnox'}{'ports'}{'udp'}{'4022'}++	; 
#	$ports_ref->{'udp'}{'4022'}{'name'} = 'dnox'		; 
#	$srvcobjects_ref->{'dnox'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dnox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnox'}{'port'}{'tcp'} = '4022'	; 
#	$srvcobjects_ref->{'dnox'}{'ports'}{'tcp'}{'4022'}++	; 
#	$ports_ref->{'tcp'}{'4022'}{'name'} = 'dnox'		; 
#	$srvcobjects_ref->{'pehelp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pehelp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pehelp'}{'port'}{'udp'} = '2307'	; 
#	$srvcobjects_ref->{'pehelp'}{'ports'}{'udp'}{'2307'}++	; 
#	$ports_ref->{'udp'}{'2307'}{'name'} = 'pehelp'		; 
#	$srvcobjects_ref->{'pehelp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pehelp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pehelp'}{'port'}{'tcp'} = '2307'	; 
#	$srvcobjects_ref->{'pehelp'}{'ports'}{'tcp'}{'2307'}++	; 
#	$ports_ref->{'tcp'}{'2307'}{'name'} = 'pehelp'		; 
#	$srvcobjects_ref->{'noadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'noadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'noadmin'}{'port'}{'udp'} = '1921'	; 
#	$srvcobjects_ref->{'noadmin'}{'ports'}{'udp'}{'1921'}++	; 
#	$ports_ref->{'udp'}{'1921'}{'name'} = 'noadmin'		; 
#	$srvcobjects_ref->{'noadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'noadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'noadmin'}{'port'}{'tcp'} = '1921'	; 
#	$srvcobjects_ref->{'noadmin'}{'ports'}{'tcp'}{'1921'}++	; 
#	$ports_ref->{'tcp'}{'1921'}{'name'} = 'noadmin'		; 
#	$srvcobjects_ref->{'smpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpp'}{'port'}{'udp'} = '2775'	; 
#	$srvcobjects_ref->{'smpp'}{'ports'}{'udp'}{'2775'}++	; 
#	$ports_ref->{'udp'}{'2775'}{'name'} = 'smpp'		; 
#	$srvcobjects_ref->{'smpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpp'}{'port'}{'tcp'} = '2775'	; 
#	$srvcobjects_ref->{'smpp'}{'ports'}{'tcp'}{'2775'}++	; 
#	$ports_ref->{'tcp'}{'2775'}{'name'} = 'smpp'		; 
#	$srvcobjects_ref->{'intrinsa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intrinsa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intrinsa'}{'port'}{'udp'} = '503'	; 
#	$srvcobjects_ref->{'intrinsa'}{'ports'}{'udp'}{'503'}++	; 
#	$ports_ref->{'udp'}{'503'}{'name'} = 'intrinsa'		; 
#	$srvcobjects_ref->{'intrinsa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intrinsa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intrinsa'}{'port'}{'tcp'} = '503'	; 
#	$srvcobjects_ref->{'intrinsa'}{'ports'}{'tcp'}{'503'}++	; 
#	$ports_ref->{'tcp'}{'503'}{'name'} = 'intrinsa'		; 
#	$srvcobjects_ref->{'snaresecure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snaresecure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snaresecure'}{'port'}{'udp'} = '1684'	; 
#	$srvcobjects_ref->{'snaresecure'}{'ports'}{'udp'}{'1684'}++	; 
#	$ports_ref->{'udp'}{'1684'}{'name'} = 'snaresecure'		; 
#	$srvcobjects_ref->{'snaresecure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snaresecure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snaresecure'}{'port'}{'tcp'} = '1684'	; 
#	$srvcobjects_ref->{'snaresecure'}{'ports'}{'tcp'}{'1684'}++	; 
#	$ports_ref->{'tcp'}{'1684'}{'name'} = 'snaresecure'		; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'port'}{'udp'} = '5677'	; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'ports'}{'udp'}{'5677'}++	; 
#	$ports_ref->{'udp'}{'5677'}{'name'} = 'questdb2-lnchr'		; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'port'}{'tcp'} = '5677'	; 
#	$srvcobjects_ref->{'questdb2-lnchr'}{'ports'}{'tcp'}{'5677'}++	; 
#	$ports_ref->{'tcp'}{'5677'}{'name'} = 'questdb2-lnchr'		; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'port'}{'udp'} = '8001'	; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'ports'}{'udp'}{'8001'}++	; 
#	$ports_ref->{'udp'}{'8001'}{'name'} = 'vcom-tunnel'		; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'port'}{'tcp'} = '8001'	; 
#	$srvcobjects_ref->{'vcom-tunnel'}{'ports'}{'tcp'}{'8001'}++	; 
#	$ports_ref->{'tcp'}{'8001'}{'name'} = 'vcom-tunnel'		; 
#	$srvcobjects_ref->{'commplex-link'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'commplex-link'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commplex-link'}{'port'}{'udp'} = '5001'	; 
#	$srvcobjects_ref->{'commplex-link'}{'ports'}{'udp'}{'5001'}++	; 
#	$ports_ref->{'udp'}{'5001'}{'name'} = 'commplex-link'		; 
#	$srvcobjects_ref->{'commplex-link'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'commplex-link'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commplex-link'}{'port'}{'tcp'} = '5001'	; 
#	$srvcobjects_ref->{'commplex-link'}{'ports'}{'tcp'}{'5001'}++	; 
#	$ports_ref->{'tcp'}{'5001'}{'name'} = 'commplex-link'		; 
#	$srvcobjects_ref->{'apc-6547'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-6547'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-6547'}{'port'}{'udp'} = '6547'	; 
#	$srvcobjects_ref->{'apc-6547'}{'ports'}{'udp'}{'6547'}++	; 
#	$ports_ref->{'udp'}{'6547'}{'name'} = 'apc-6547'		; 
#	$srvcobjects_ref->{'apc-6547'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-6547'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-6547'}{'port'}{'tcp'} = '6547'	; 
#	$srvcobjects_ref->{'apc-6547'}{'ports'}{'tcp'}{'6547'}++	; 
#	$ports_ref->{'tcp'}{'6547'}{'name'} = 'apc-6547'		; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'port'}{'udp'} = '2419'	; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'ports'}{'udp'}{'2419'}++	; 
#	$ports_ref->{'udp'}{'2419'}{'name'} = 'attachmate-s2s'		; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'port'}{'tcp'} = '2419'	; 
#	$srvcobjects_ref->{'attachmate-s2s'}{'ports'}{'tcp'}{'2419'}++	; 
#	$ports_ref->{'tcp'}{'2419'}{'name'} = 'attachmate-s2s'		; 
#	$srvcobjects_ref->{'sd-capacity'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sd-capacity'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd-capacity'}{'port'}{'udp'} = '2384'	; 
#	$srvcobjects_ref->{'sd-capacity'}{'ports'}{'udp'}{'2384'}++	; 
#	$ports_ref->{'udp'}{'2384'}{'name'} = 'sd-capacity'		; 
#	$srvcobjects_ref->{'udpradio'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'udpradio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udpradio'}{'port'}{'udp'} = '1833'	; 
#	$srvcobjects_ref->{'udpradio'}{'ports'}{'udp'}{'1833'}++	; 
#	$ports_ref->{'udp'}{'1833'}{'name'} = 'udpradio'		; 
#	$srvcobjects_ref->{'udpradio'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'udpradio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udpradio'}{'port'}{'tcp'} = '1833'	; 
#	$srvcobjects_ref->{'udpradio'}{'ports'}{'tcp'}{'1833'}++	; 
#	$ports_ref->{'tcp'}{'1833'}{'name'} = 'udpradio'		; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'port'}{'udp'} = '9202'	; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'ports'}{'udp'}{'9202'}++	; 
#	$ports_ref->{'udp'}{'9202'}{'name'} = 'wap-wsp-s'		; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'port'}{'tcp'} = '9202'	; 
#	$srvcobjects_ref->{'wap-wsp-s'}{'ports'}{'tcp'}{'9202'}++	; 
#	$ports_ref->{'tcp'}{'9202'}{'name'} = 'wap-wsp-s'		; 
#	$srvcobjects_ref->{'virtualuser'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'virtualuser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtualuser'}{'port'}{'udp'} = '5423'	; 
#	$srvcobjects_ref->{'virtualuser'}{'ports'}{'udp'}{'5423'}++	; 
#	$ports_ref->{'udp'}{'5423'}{'name'} = 'virtualuser'		; 
#	$srvcobjects_ref->{'virtualuser'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'virtualuser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtualuser'}{'port'}{'tcp'} = '5423'	; 
#	$srvcobjects_ref->{'virtualuser'}{'ports'}{'tcp'}{'5423'}++	; 
#	$ports_ref->{'tcp'}{'5423'}{'name'} = 'virtualuser'		; 
#	$srvcobjects_ref->{'ispmmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ispmmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ispmmgr'}{'port'}{'udp'} = '3775'	; 
#	$srvcobjects_ref->{'ispmmgr'}{'ports'}{'udp'}{'3775'}++	; 
#	$ports_ref->{'udp'}{'3775'}{'name'} = 'ispmmgr'		; 
#	$srvcobjects_ref->{'ispmmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ispmmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ispmmgr'}{'port'}{'tcp'} = '3775'	; 
#	$srvcobjects_ref->{'ispmmgr'}{'ports'}{'tcp'}{'3775'}++	; 
#	$ports_ref->{'tcp'}{'3775'}{'name'} = 'ispmmgr'		; 
#	$srvcobjects_ref->{'tpip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tpip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tpip'}{'port'}{'udp'} = '594'	; 
#	$srvcobjects_ref->{'tpip'}{'ports'}{'udp'}{'594'}++	; 
#	$ports_ref->{'udp'}{'594'}{'name'} = 'tpip'		; 
#	$srvcobjects_ref->{'tpip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tpip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tpip'}{'port'}{'tcp'} = '594'	; 
#	$srvcobjects_ref->{'tpip'}{'ports'}{'tcp'}{'594'}++	; 
#	$ports_ref->{'tcp'}{'594'}{'name'} = 'tpip'		; 
#	$srvcobjects_ref->{'epnsdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'epnsdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epnsdp'}{'port'}{'udp'} = '2051'	; 
#	$srvcobjects_ref->{'epnsdp'}{'ports'}{'udp'}{'2051'}++	; 
#	$ports_ref->{'udp'}{'2051'}{'name'} = 'epnsdp'		; 
#	$srvcobjects_ref->{'epnsdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'epnsdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epnsdp'}{'port'}{'tcp'} = '2051'	; 
#	$srvcobjects_ref->{'epnsdp'}{'ports'}{'tcp'}{'2051'}++	; 
#	$ports_ref->{'tcp'}{'2051'}{'name'} = 'epnsdp'		; 
#	$srvcobjects_ref->{'videobeans'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'videobeans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'videobeans'}{'port'}{'udp'} = '3058'	; 
#	$srvcobjects_ref->{'videobeans'}{'ports'}{'udp'}{'3058'}++	; 
#	$ports_ref->{'udp'}{'3058'}{'name'} = 'videobeans'		; 
#	$srvcobjects_ref->{'videobeans'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'videobeans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'videobeans'}{'port'}{'tcp'} = '3058'	; 
#	$srvcobjects_ref->{'videobeans'}{'ports'}{'tcp'}{'3058'}++	; 
#	$ports_ref->{'tcp'}{'3058'}{'name'} = 'videobeans'		; 
#	$srvcobjects_ref->{'boscap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boscap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boscap'}{'port'}{'udp'} = '2990'	; 
#	$srvcobjects_ref->{'boscap'}{'ports'}{'udp'}{'2990'}++	; 
#	$ports_ref->{'udp'}{'2990'}{'name'} = 'boscap'		; 
#	$srvcobjects_ref->{'boscap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boscap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boscap'}{'port'}{'tcp'} = '2990'	; 
#	$srvcobjects_ref->{'boscap'}{'ports'}{'tcp'}{'2990'}++	; 
#	$ports_ref->{'tcp'}{'2990'}{'name'} = 'boscap'		; 
#	$srvcobjects_ref->{'nmasoverip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmasoverip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmasoverip'}{'port'}{'udp'} = '1242'	; 
#	$srvcobjects_ref->{'nmasoverip'}{'ports'}{'udp'}{'1242'}++	; 
#	$ports_ref->{'udp'}{'1242'}{'name'} = 'nmasoverip'		; 
#	$srvcobjects_ref->{'nmasoverip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmasoverip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmasoverip'}{'port'}{'tcp'} = '1242'	; 
#	$srvcobjects_ref->{'nmasoverip'}{'ports'}{'tcp'}{'1242'}++	; 
#	$ports_ref->{'tcp'}{'1242'}{'name'} = 'nmasoverip'		; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'port'}{'udp'} = '3332'	; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'ports'}{'udp'}{'3332'}++	; 
#	$ports_ref->{'udp'}{'3332'}{'name'} = 'mcs-mailsvr'		; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'port'}{'tcp'} = '3332'	; 
#	$srvcobjects_ref->{'mcs-mailsvr'}{'ports'}{'tcp'}{'3332'}++	; 
#	$ports_ref->{'tcp'}{'3332'}{'name'} = 'mcs-mailsvr'		; 
#	$srvcobjects_ref->{'ii-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ii-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ii-admin'}{'port'}{'udp'} = '3006'	; 
#	$srvcobjects_ref->{'ii-admin'}{'ports'}{'udp'}{'3006'}++	; 
#	$ports_ref->{'udp'}{'3006'}{'name'} = 'ii-admin'		; 
#	$srvcobjects_ref->{'ii-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ii-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ii-admin'}{'port'}{'tcp'} = '3006'	; 
#	$srvcobjects_ref->{'ii-admin'}{'ports'}{'tcp'}{'3006'}++	; 
#	$ports_ref->{'tcp'}{'3006'}{'name'} = 'ii-admin'		; 
#	$srvcobjects_ref->{'slslavemon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slslavemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slslavemon'}{'port'}{'udp'} = '3102'	; 
#	$srvcobjects_ref->{'slslavemon'}{'ports'}{'udp'}{'3102'}++	; 
#	$ports_ref->{'udp'}{'3102'}{'name'} = 'slslavemon'		; 
#	$srvcobjects_ref->{'slslavemon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slslavemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slslavemon'}{'port'}{'tcp'} = '3102'	; 
#	$srvcobjects_ref->{'slslavemon'}{'ports'}{'tcp'}{'3102'}++	; 
#	$ports_ref->{'tcp'}{'3102'}{'name'} = 'slslavemon'		; 
#	$srvcobjects_ref->{'ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ns'}{'port'}{'udp'} = '760'	; 
#	$srvcobjects_ref->{'ns'}{'ports'}{'udp'}{'760'}++	; 
#	$ports_ref->{'udp'}{'760'}{'name'} = 'ns'		; 
#	$srvcobjects_ref->{'ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ns'}{'port'}{'tcp'} = '760'	; 
#	$srvcobjects_ref->{'ns'}{'ports'}{'tcp'}{'760'}++	; 
#	$ports_ref->{'tcp'}{'760'}{'name'} = 'ns'		; 
#	$srvcobjects_ref->{'cloanto-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cloanto-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cloanto-lm'}{'port'}{'udp'} = '3397'	; 
#	$srvcobjects_ref->{'cloanto-lm'}{'ports'}{'udp'}{'3397'}++	; 
#	$ports_ref->{'udp'}{'3397'}{'name'} = 'cloanto-lm'		; 
#	$srvcobjects_ref->{'cloanto-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cloanto-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cloanto-lm'}{'port'}{'tcp'} = '3397'	; 
#	$srvcobjects_ref->{'cloanto-lm'}{'ports'}{'tcp'}{'3397'}++	; 
#	$ports_ref->{'tcp'}{'3397'}{'name'} = 'cloanto-lm'		; 
#	$srvcobjects_ref->{'hpidsagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpidsagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpidsagent'}{'port'}{'udp'} = '2985'	; 
#	$srvcobjects_ref->{'hpidsagent'}{'ports'}{'udp'}{'2985'}++	; 
#	$ports_ref->{'udp'}{'2985'}{'name'} = 'hpidsagent'		; 
#	$srvcobjects_ref->{'hpidsagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpidsagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpidsagent'}{'port'}{'tcp'} = '2985'	; 
#	$srvcobjects_ref->{'hpidsagent'}{'ports'}{'tcp'}{'2985'}++	; 
#	$ports_ref->{'tcp'}{'2985'}{'name'} = 'hpidsagent'		; 
#	$srvcobjects_ref->{'icp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icp'}{'port'}{'udp'} = '1112'	; 
#	$srvcobjects_ref->{'icp'}{'ports'}{'udp'}{'1112'}++	; 
#	$ports_ref->{'udp'}{'1112'}{'name'} = 'icp'		; 
#	$srvcobjects_ref->{'icp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icp'}{'port'}{'tcp'} = '1112'	; 
#	$srvcobjects_ref->{'icp'}{'ports'}{'tcp'}{'1112'}++	; 
#	$ports_ref->{'tcp'}{'1112'}{'name'} = 'icp'		; 
#	$srvcobjects_ref->{'panasas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'panasas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panasas'}{'port'}{'udp'} = '3095'	; 
#	$srvcobjects_ref->{'panasas'}{'ports'}{'udp'}{'3095'}++	; 
#	$ports_ref->{'udp'}{'3095'}{'name'} = 'panasas'		; 
#	$srvcobjects_ref->{'panasas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'panasas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panasas'}{'port'}{'tcp'} = '3095'	; 
#	$srvcobjects_ref->{'panasas'}{'ports'}{'tcp'}{'3095'}++	; 
#	$ports_ref->{'tcp'}{'3095'}{'name'} = 'panasas'		; 
#	$srvcobjects_ref->{'metaagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metaagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metaagent'}{'port'}{'udp'} = '1897'	; 
#	$srvcobjects_ref->{'metaagent'}{'ports'}{'udp'}{'1897'}++	; 
#	$ports_ref->{'udp'}{'1897'}{'name'} = 'metaagent'		; 
#	$srvcobjects_ref->{'metaagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metaagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metaagent'}{'port'}{'tcp'} = '1897'	; 
#	$srvcobjects_ref->{'metaagent'}{'ports'}{'tcp'}{'1897'}++	; 
#	$ports_ref->{'tcp'}{'1897'}{'name'} = 'metaagent'		; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'port'}{'udp'} = '24001'	; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'ports'}{'udp'}{'24001'}++	; 
#	$ports_ref->{'udp'}{'24001'}{'name'} = 'med-fsp-rx'		; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'port'}{'tcp'} = '24001'	; 
#	$srvcobjects_ref->{'med-fsp-rx'}{'ports'}{'tcp'}{'24001'}++	; 
#	$ports_ref->{'tcp'}{'24001'}{'name'} = 'med-fsp-rx'		; 
#	$srvcobjects_ref->{'afs3-callback'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-callback'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-callback'}{'port'}{'udp'} = '7001'	; 
#	$srvcobjects_ref->{'afs3-callback'}{'ports'}{'udp'}{'7001'}++	; 
#	$ports_ref->{'udp'}{'7001'}{'name'} = 'afs3-callback'		; 
#	$srvcobjects_ref->{'afs3-callback'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-callback'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-callback'}{'port'}{'tcp'} = '7001'	; 
#	$srvcobjects_ref->{'afs3-callback'}{'ports'}{'tcp'}{'7001'}++	; 
#	$ports_ref->{'tcp'}{'7001'}{'name'} = 'afs3-callback'		; 
#	$srvcobjects_ref->{'wbem-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wbem-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wbem-http'}{'port'}{'udp'} = '5988'	; 
#	$srvcobjects_ref->{'wbem-http'}{'ports'}{'udp'}{'5988'}++	; 
#	$ports_ref->{'udp'}{'5988'}{'name'} = 'wbem-http'		; 
#	$srvcobjects_ref->{'wbem-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wbem-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wbem-http'}{'port'}{'tcp'} = '5988'	; 
#	$srvcobjects_ref->{'wbem-http'}{'ports'}{'tcp'}{'5988'}++	; 
#	$ports_ref->{'tcp'}{'5988'}{'name'} = 'wbem-http'		; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'port'}{'udp'} = '6108'	; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'ports'}{'udp'}{'6108'}++	; 
#	$ports_ref->{'udp'}{'6108'}{'name'} = 'sercomm-scadmin'		; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'port'}{'tcp'} = '6108'	; 
#	$srvcobjects_ref->{'sercomm-scadmin'}{'ports'}{'tcp'}{'6108'}++	; 
#	$ports_ref->{'tcp'}{'6108'}{'name'} = 'sercomm-scadmin'		; 
#	$srvcobjects_ref->{'digiman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'digiman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digiman'}{'port'}{'udp'} = '2362'	; 
#	$srvcobjects_ref->{'digiman'}{'ports'}{'udp'}{'2362'}++	; 
#	$ports_ref->{'udp'}{'2362'}{'name'} = 'digiman'		; 
#	$srvcobjects_ref->{'digiman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'digiman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digiman'}{'port'}{'tcp'} = '2362'	; 
#	$srvcobjects_ref->{'digiman'}{'ports'}{'tcp'}{'2362'}++	; 
#	$ports_ref->{'tcp'}{'2362'}{'name'} = 'digiman'		; 
#	$srvcobjects_ref->{'fcopy-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcopy-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcopy-server'}{'port'}{'udp'} = '5745'	; 
#	$srvcobjects_ref->{'fcopy-server'}{'ports'}{'udp'}{'5745'}++	; 
#	$ports_ref->{'udp'}{'5745'}{'name'} = 'fcopy-server'		; 
#	$srvcobjects_ref->{'fcopy-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcopy-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcopy-server'}{'port'}{'tcp'} = '5745'	; 
#	$srvcobjects_ref->{'fcopy-server'}{'ports'}{'tcp'}{'5745'}++	; 
#	$ports_ref->{'tcp'}{'5745'}{'name'} = 'fcopy-server'		; 
#	$srvcobjects_ref->{'hagel-dump'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hagel-dump'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hagel-dump'}{'port'}{'udp'} = '3036'	; 
#	$srvcobjects_ref->{'hagel-dump'}{'ports'}{'udp'}{'3036'}++	; 
#	$ports_ref->{'udp'}{'3036'}{'name'} = 'hagel-dump'		; 
#	$srvcobjects_ref->{'hagel-dump'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hagel-dump'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hagel-dump'}{'port'}{'tcp'} = '3036'	; 
#	$srvcobjects_ref->{'hagel-dump'}{'ports'}{'tcp'}{'3036'}++	; 
#	$ports_ref->{'tcp'}{'3036'}{'name'} = 'hagel-dump'		; 
#	$srvcobjects_ref->{'bpcp-trap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bpcp-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpcp-trap'}{'port'}{'udp'} = '2845'	; 
#	$srvcobjects_ref->{'bpcp-trap'}{'ports'}{'udp'}{'2845'}++	; 
#	$ports_ref->{'udp'}{'2845'}{'name'} = 'bpcp-trap'		; 
#	$srvcobjects_ref->{'bpcp-trap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bpcp-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpcp-trap'}{'port'}{'tcp'} = '2845'	; 
#	$srvcobjects_ref->{'bpcp-trap'}{'ports'}{'tcp'}{'2845'}++	; 
#	$ports_ref->{'tcp'}{'2845'}{'name'} = 'bpcp-trap'		; 
#	$srvcobjects_ref->{'de-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'de-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-server'}{'port'}{'udp'} = '1256'	; 
#	$srvcobjects_ref->{'de-server'}{'ports'}{'udp'}{'1256'}++	; 
#	$ports_ref->{'udp'}{'1256'}{'name'} = 'de-server'		; 
#	$srvcobjects_ref->{'de-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'de-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-server'}{'port'}{'tcp'} = '1256'	; 
#	$srvcobjects_ref->{'de-server'}{'ports'}{'tcp'}{'1256'}++	; 
#	$ports_ref->{'tcp'}{'1256'}{'name'} = 'de-server'		; 
#	$srvcobjects_ref->{'cruise-swroute'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cruise-swroute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-swroute'}{'port'}{'udp'} = '8377'	; 
#	$srvcobjects_ref->{'cruise-swroute'}{'ports'}{'udp'}{'8377'}++	; 
#	$ports_ref->{'udp'}{'8377'}{'name'} = 'cruise-swroute'		; 
#	$srvcobjects_ref->{'cruise-swroute'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cruise-swroute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-swroute'}{'port'}{'tcp'} = '8377'	; 
#	$srvcobjects_ref->{'cruise-swroute'}{'ports'}{'tcp'}{'8377'}++	; 
#	$ports_ref->{'tcp'}{'8377'}{'name'} = 'cruise-swroute'		; 
#	$srvcobjects_ref->{'bintec-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bintec-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bintec-admin'}{'port'}{'udp'} = '2107'	; 
#	$srvcobjects_ref->{'bintec-admin'}{'ports'}{'udp'}{'2107'}++	; 
#	$ports_ref->{'udp'}{'2107'}{'name'} = 'bintec-admin'		; 
#	$srvcobjects_ref->{'bintec-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bintec-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bintec-admin'}{'port'}{'tcp'} = '2107'	; 
#	$srvcobjects_ref->{'bintec-admin'}{'ports'}{'tcp'}{'2107'}++	; 
#	$ports_ref->{'tcp'}{'2107'}{'name'} = 'bintec-admin'		; 
#	$srvcobjects_ref->{'stm_pproc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stm_pproc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stm_pproc'}{'port'}{'udp'} = '3080'	; 
#	$srvcobjects_ref->{'stm_pproc'}{'ports'}{'udp'}{'3080'}++	; 
#	$ports_ref->{'udp'}{'3080'}{'name'} = 'stm_pproc'		; 
#	$srvcobjects_ref->{'stm_pproc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stm_pproc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stm_pproc'}{'port'}{'tcp'} = '3080'	; 
#	$srvcobjects_ref->{'stm_pproc'}{'ports'}{'tcp'}{'3080'}++	; 
#	$ports_ref->{'tcp'}{'3080'}{'name'} = 'stm_pproc'		; 
#	$srvcobjects_ref->{'veritas-udp1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'veritas-udp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-udp1'}{'port'}{'udp'} = '2802'	; 
#	$srvcobjects_ref->{'veritas-udp1'}{'ports'}{'udp'}{'2802'}++	; 
#	$ports_ref->{'udp'}{'2802'}{'name'} = 'veritas-udp1'		; 
#	$srvcobjects_ref->{'tcp-id-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tcp-id-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcp-id-port'}{'port'}{'udp'} = '1999'	; 
#	$srvcobjects_ref->{'tcp-id-port'}{'ports'}{'udp'}{'1999'}++	; 
#	$ports_ref->{'udp'}{'1999'}{'name'} = 'tcp-id-port'		; 
#	$srvcobjects_ref->{'tcp-id-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcp-id-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcp-id-port'}{'port'}{'tcp'} = '1999'	; 
#	$srvcobjects_ref->{'tcp-id-port'}{'ports'}{'tcp'}{'1999'}++	; 
#	$ports_ref->{'tcp'}{'1999'}{'name'} = 'tcp-id-port'		; 
#	$srvcobjects_ref->{'udrive'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'udrive'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udrive'}{'port'}{'udp'} = '1867'	; 
#	$srvcobjects_ref->{'udrive'}{'ports'}{'udp'}{'1867'}++	; 
#	$ports_ref->{'udp'}{'1867'}{'name'} = 'udrive'		; 
#	$srvcobjects_ref->{'udrive'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'udrive'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udrive'}{'port'}{'tcp'} = '1867'	; 
#	$srvcobjects_ref->{'udrive'}{'ports'}{'tcp'}{'1867'}++	; 
#	$ports_ref->{'tcp'}{'1867'}{'name'} = 'udrive'		; 
#	$srvcobjects_ref->{'td-postman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'td-postman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'td-postman'}{'port'}{'udp'} = '1049'	; 
#	$srvcobjects_ref->{'td-postman'}{'ports'}{'udp'}{'1049'}++	; 
#	$ports_ref->{'udp'}{'1049'}{'name'} = 'td-postman'		; 
#	$srvcobjects_ref->{'td-postman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'td-postman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'td-postman'}{'port'}{'tcp'} = '1049'	; 
#	$srvcobjects_ref->{'td-postman'}{'ports'}{'tcp'}{'1049'}++	; 
#	$ports_ref->{'tcp'}{'1049'}{'name'} = 'td-postman'		; 
#	$srvcobjects_ref->{'elan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elan'}{'port'}{'udp'} = '1378'	; 
#	$srvcobjects_ref->{'elan'}{'ports'}{'udp'}{'1378'}++	; 
#	$ports_ref->{'udp'}{'1378'}{'name'} = 'elan'		; 
#	$srvcobjects_ref->{'elan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elan'}{'port'}{'tcp'} = '1378'	; 
#	$srvcobjects_ref->{'elan'}{'ports'}{'tcp'}{'1378'}++	; 
#	$ports_ref->{'tcp'}{'1378'}{'name'} = 'elan'		; 
#	$srvcobjects_ref->{'pharos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pharos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pharos'}{'port'}{'udp'} = '4443'	; 
#	$srvcobjects_ref->{'pharos'}{'ports'}{'udp'}{'4443'}++	; 
#	$ports_ref->{'udp'}{'4443'}{'name'} = 'pharos'		; 
#	$srvcobjects_ref->{'pharos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pharos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pharos'}{'port'}{'tcp'} = '4443'	; 
#	$srvcobjects_ref->{'pharos'}{'ports'}{'tcp'}{'4443'}++	; 
#	$ports_ref->{'tcp'}{'4443'}{'name'} = 'pharos'		; 
#	$srvcobjects_ref->{'cesdcdman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cesdcdman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cesdcdman'}{'port'}{'udp'} = '2921'	; 
#	$srvcobjects_ref->{'cesdcdman'}{'ports'}{'udp'}{'2921'}++	; 
#	$ports_ref->{'udp'}{'2921'}{'name'} = 'cesdcdman'		; 
#	$srvcobjects_ref->{'cesdcdman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cesdcdman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cesdcdman'}{'port'}{'tcp'} = '2921'	; 
#	$srvcobjects_ref->{'cesdcdman'}{'ports'}{'tcp'}{'2921'}++	; 
#	$ports_ref->{'tcp'}{'2921'}{'name'} = 'cesdcdman'		; 
#	$srvcobjects_ref->{'kshell'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kshell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kshell'}{'port'}{'udp'} = '544'	; 
#	$srvcobjects_ref->{'kshell'}{'ports'}{'udp'}{'544'}++	; 
#	$ports_ref->{'udp'}{'544'}{'name'} = 'kshell'		; 
#	$srvcobjects_ref->{'kshell'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kshell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kshell'}{'port'}{'tcp'} = '544'	; 
#	$srvcobjects_ref->{'kshell'}{'ports'}{'tcp'}{'544'}++	; 
#	$ports_ref->{'tcp'}{'544'}{'name'} = 'kshell'		; 
#	$srvcobjects_ref->{'ibus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibus'}{'port'}{'udp'} = '8733'	; 
#	$srvcobjects_ref->{'ibus'}{'ports'}{'udp'}{'8733'}++	; 
#	$ports_ref->{'udp'}{'8733'}{'name'} = 'ibus'		; 
#	$srvcobjects_ref->{'ibus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibus'}{'port'}{'tcp'} = '8733'	; 
#	$srvcobjects_ref->{'ibus'}{'ports'}{'tcp'}{'8733'}++	; 
#	$ports_ref->{'tcp'}{'8733'}{'name'} = 'ibus'		; 
#	$srvcobjects_ref->{'epicon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'epicon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epicon'}{'port'}{'udp'} = '2912'	; 
#	$srvcobjects_ref->{'epicon'}{'ports'}{'udp'}{'2912'}++	; 
#	$ports_ref->{'udp'}{'2912'}{'name'} = 'epicon'		; 
#	$srvcobjects_ref->{'epicon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'epicon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epicon'}{'port'}{'tcp'} = '2912'	; 
#	$srvcobjects_ref->{'epicon'}{'ports'}{'tcp'}{'2912'}++	; 
#	$ports_ref->{'tcp'}{'2912'}{'name'} = 'epicon'		; 
#	$srvcobjects_ref->{'westell-stats'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'westell-stats'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'westell-stats'}{'port'}{'udp'} = '1875'	; 
#	$srvcobjects_ref->{'westell-stats'}{'ports'}{'udp'}{'1875'}++	; 
#	$ports_ref->{'udp'}{'1875'}{'name'} = 'westell-stats'		; 
#	$srvcobjects_ref->{'westell-stats'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'westell-stats'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'westell-stats'}{'port'}{'tcp'} = '1875'	; 
#	$srvcobjects_ref->{'westell-stats'}{'ports'}{'tcp'}{'1875'}++	; 
#	$ports_ref->{'tcp'}{'1875'}{'name'} = 'westell-stats'		; 
#	$srvcobjects_ref->{'telnets'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telnets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telnets'}{'port'}{'udp'} = '992'	; 
#	$srvcobjects_ref->{'telnets'}{'ports'}{'udp'}{'992'}++	; 
#	$ports_ref->{'udp'}{'992'}{'name'} = 'telnets'		; 
#	$srvcobjects_ref->{'telnets'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telnets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telnets'}{'port'}{'tcp'} = '992'	; 
#	$srvcobjects_ref->{'telnets'}{'ports'}{'tcp'}{'992'}++	; 
#	$ports_ref->{'tcp'}{'992'}{'name'} = 'telnets'		; 
#	$srvcobjects_ref->{'blackboard'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'blackboard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blackboard'}{'port'}{'udp'} = '2032'	; 
#	$srvcobjects_ref->{'blackboard'}{'ports'}{'udp'}{'2032'}++	; 
#	$ports_ref->{'udp'}{'2032'}{'name'} = 'blackboard'		; 
#	$srvcobjects_ref->{'blackboard'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'blackboard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blackboard'}{'port'}{'tcp'} = '2032'	; 
#	$srvcobjects_ref->{'blackboard'}{'ports'}{'tcp'}{'2032'}++	; 
#	$ports_ref->{'tcp'}{'2032'}{'name'} = 'blackboard'		; 
#	$srvcobjects_ref->{'stonefalls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stonefalls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stonefalls'}{'port'}{'udp'} = '2986'	; 
#	$srvcobjects_ref->{'stonefalls'}{'ports'}{'udp'}{'2986'}++	; 
#	$ports_ref->{'udp'}{'2986'}{'name'} = 'stonefalls'		; 
#	$srvcobjects_ref->{'stonefalls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stonefalls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stonefalls'}{'port'}{'tcp'} = '2986'	; 
#	$srvcobjects_ref->{'stonefalls'}{'ports'}{'tcp'}{'2986'}++	; 
#	$ports_ref->{'tcp'}{'2986'}{'name'} = 'stonefalls'		; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'port'}{'udp'} = '3113'	; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'ports'}{'udp'}{'3113'}++	; 
#	$ports_ref->{'udp'}{'3113'}{'name'} = 'cs-auth-svr'		; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'port'}{'tcp'} = '3113'	; 
#	$srvcobjects_ref->{'cs-auth-svr'}{'ports'}{'tcp'}{'3113'}++	; 
#	$ports_ref->{'tcp'}{'3113'}{'name'} = 'cs-auth-svr'		; 
#	$srvcobjects_ref->{'vulture'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vulture'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vulture'}{'port'}{'udp'} = '3482'	; 
#	$srvcobjects_ref->{'vulture'}{'ports'}{'udp'}{'3482'}++	; 
#	$ports_ref->{'udp'}{'3482'}{'name'} = 'vulture'		; 
#	$srvcobjects_ref->{'vulture'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vulture'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vulture'}{'port'}{'tcp'} = '3482'	; 
#	$srvcobjects_ref->{'vulture'}{'ports'}{'tcp'}{'3482'}++	; 
#	$ports_ref->{'tcp'}{'3482'}{'name'} = 'vulture'		; 
#	$srvcobjects_ref->{'groupwise'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'groupwise'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'groupwise'}{'port'}{'udp'} = '1677'	; 
#	$srvcobjects_ref->{'groupwise'}{'ports'}{'udp'}{'1677'}++	; 
#	$ports_ref->{'udp'}{'1677'}{'name'} = 'groupwise'		; 
#	$srvcobjects_ref->{'groupwise'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'groupwise'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'groupwise'}{'port'}{'tcp'} = '1677'	; 
#	$srvcobjects_ref->{'groupwise'}{'ports'}{'tcp'}{'1677'}++	; 
#	$ports_ref->{'tcp'}{'1677'}{'name'} = 'groupwise'		; 
#	$srvcobjects_ref->{'omserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'omserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'omserv'}{'port'}{'udp'} = '764'	; 
#	$srvcobjects_ref->{'omserv'}{'ports'}{'udp'}{'764'}++	; 
#	$ports_ref->{'udp'}{'764'}{'name'} = 'omserv'		; 
#	$srvcobjects_ref->{'omserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'omserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'omserv'}{'port'}{'tcp'} = '764'	; 
#	$srvcobjects_ref->{'omserv'}{'ports'}{'tcp'}{'764'}++	; 
#	$ports_ref->{'tcp'}{'764'}{'name'} = 'omserv'		; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'port'}{'udp'} = '1760'	; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'ports'}{'udp'}{'1760'}++	; 
#	$ports_ref->{'udp'}{'1760'}{'name'} = 'www-ldap-gw'		; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'port'}{'tcp'} = '1760'	; 
#	$srvcobjects_ref->{'www-ldap-gw'}{'ports'}{'tcp'}{'1760'}++	; 
#	$ports_ref->{'tcp'}{'1760'}{'name'} = 'www-ldap-gw'		; 
#	$srvcobjects_ref->{'p2pq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'p2pq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'p2pq'}{'port'}{'udp'} = '1981'	; 
#	$srvcobjects_ref->{'p2pq'}{'ports'}{'udp'}{'1981'}++	; 
#	$ports_ref->{'udp'}{'1981'}{'name'} = 'p2pq'		; 
#	$srvcobjects_ref->{'p2pq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'p2pq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'p2pq'}{'port'}{'tcp'} = '1981'	; 
#	$srvcobjects_ref->{'p2pq'}{'ports'}{'tcp'}{'1981'}++	; 
#	$ports_ref->{'tcp'}{'1981'}{'name'} = 'p2pq'		; 
#	$srvcobjects_ref->{'rmiactivation'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmiactivation'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmiactivation'}{'port'}{'udp'} = '1098'	; 
#	$srvcobjects_ref->{'rmiactivation'}{'ports'}{'udp'}{'1098'}++	; 
#	$ports_ref->{'udp'}{'1098'}{'name'} = 'rmiactivation'		; 
#	$srvcobjects_ref->{'rmiactivation'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmiactivation'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmiactivation'}{'port'}{'tcp'} = '1098'	; 
#	$srvcobjects_ref->{'rmiactivation'}{'ports'}{'tcp'}{'1098'}++	; 
#	$ports_ref->{'tcp'}{'1098'}{'name'} = 'rmiactivation'		; 
#	$srvcobjects_ref->{'pnet-conn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pnet-conn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnet-conn'}{'port'}{'udp'} = '7797'	; 
#	$srvcobjects_ref->{'pnet-conn'}{'ports'}{'udp'}{'7797'}++	; 
#	$ports_ref->{'udp'}{'7797'}{'name'} = 'pnet-conn'		; 
#	$srvcobjects_ref->{'pnet-conn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pnet-conn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnet-conn'}{'port'}{'tcp'} = '7797'	; 
#	$srvcobjects_ref->{'pnet-conn'}{'ports'}{'tcp'}{'7797'}++	; 
#	$ports_ref->{'tcp'}{'7797'}{'name'} = 'pnet-conn'		; 
#	$srvcobjects_ref->{'telexis-vtu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telexis-vtu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telexis-vtu'}{'port'}{'udp'} = '2804'	; 
#	$srvcobjects_ref->{'telexis-vtu'}{'ports'}{'udp'}{'2804'}++	; 
#	$ports_ref->{'udp'}{'2804'}{'name'} = 'telexis-vtu'		; 
#	$srvcobjects_ref->{'telexis-vtu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telexis-vtu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telexis-vtu'}{'port'}{'tcp'} = '2804'	; 
#	$srvcobjects_ref->{'telexis-vtu'}{'ports'}{'tcp'}{'2804'}++	; 
#	$ports_ref->{'tcp'}{'2804'}{'name'} = 'telexis-vtu'		; 
#	$srvcobjects_ref->{'med-net-svc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'med-net-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-net-svc'}{'port'}{'udp'} = '24006'	; 
#	$srvcobjects_ref->{'med-net-svc'}{'ports'}{'udp'}{'24006'}++	; 
#	$ports_ref->{'udp'}{'24006'}{'name'} = 'med-net-svc'		; 
#	$srvcobjects_ref->{'med-net-svc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'med-net-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-net-svc'}{'port'}{'tcp'} = '24006'	; 
#	$srvcobjects_ref->{'med-net-svc'}{'ports'}{'tcp'}{'24006'}++	; 
#	$ports_ref->{'tcp'}{'24006'}{'name'} = 'med-net-svc'		; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'port'}{'udp'} = '4032'	; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'ports'}{'udp'}{'4032'}++	; 
#	$ports_ref->{'udp'}{'4032'}{'name'} = 'vrts-auth-port'		; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'port'}{'tcp'} = '4032'	; 
#	$srvcobjects_ref->{'vrts-auth-port'}{'ports'}{'tcp'}{'4032'}++	; 
#	$ports_ref->{'tcp'}{'4032'}{'name'} = 'vrts-auth-port'		; 
#	$srvcobjects_ref->{'siebel-ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'siebel-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'siebel-ns'}{'port'}{'udp'} = '2320'	; 
#	$srvcobjects_ref->{'siebel-ns'}{'ports'}{'udp'}{'2320'}++	; 
#	$ports_ref->{'udp'}{'2320'}{'name'} = 'siebel-ns'		; 
#	$srvcobjects_ref->{'siebel-ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'siebel-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'siebel-ns'}{'port'}{'tcp'} = '2320'	; 
#	$srvcobjects_ref->{'siebel-ns'}{'ports'}{'tcp'}{'2320'}++	; 
#	$ports_ref->{'tcp'}{'2320'}{'name'} = 'siebel-ns'		; 
#	$srvcobjects_ref->{'epncdp2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'epncdp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epncdp2'}{'port'}{'udp'} = '3259'	; 
#	$srvcobjects_ref->{'epncdp2'}{'ports'}{'udp'}{'3259'}++	; 
#	$ports_ref->{'udp'}{'3259'}{'name'} = 'epncdp2'		; 
#	$srvcobjects_ref->{'epncdp2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'epncdp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epncdp2'}{'port'}{'tcp'} = '3259'	; 
#	$srvcobjects_ref->{'epncdp2'}{'ports'}{'tcp'}{'3259'}++	; 
#	$ports_ref->{'tcp'}{'3259'}{'name'} = 'epncdp2'		; 
#	$srvcobjects_ref->{'rrh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrh'}{'port'}{'udp'} = '753'	; 
#	$srvcobjects_ref->{'rrh'}{'ports'}{'udp'}{'753'}++	; 
#	$ports_ref->{'udp'}{'753'}{'name'} = 'rrh'		; 
#	$srvcobjects_ref->{'rrh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrh'}{'port'}{'tcp'} = '753'	; 
#	$srvcobjects_ref->{'rrh'}{'ports'}{'tcp'}{'753'}++	; 
#	$ports_ref->{'tcp'}{'753'}{'name'} = 'rrh'		; 
#	$srvcobjects_ref->{'fjswapsnp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjswapsnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjswapsnp'}{'port'}{'udp'} = '1874'	; 
#	$srvcobjects_ref->{'fjswapsnp'}{'ports'}{'udp'}{'1874'}++	; 
#	$ports_ref->{'udp'}{'1874'}{'name'} = 'fjswapsnp'		; 
#	$srvcobjects_ref->{'fjswapsnp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjswapsnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjswapsnp'}{'port'}{'tcp'} = '1874'	; 
#	$srvcobjects_ref->{'fjswapsnp'}{'ports'}{'tcp'}{'1874'}++	; 
#	$ports_ref->{'tcp'}{'1874'}{'name'} = 'fjswapsnp'		; 
#	$srvcobjects_ref->{'cymtec-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cymtec-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cymtec-port'}{'port'}{'udp'} = '1898'	; 
#	$srvcobjects_ref->{'cymtec-port'}{'ports'}{'udp'}{'1898'}++	; 
#	$ports_ref->{'udp'}{'1898'}{'name'} = 'cymtec-port'		; 
#	$srvcobjects_ref->{'cymtec-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cymtec-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cymtec-port'}{'port'}{'tcp'} = '1898'	; 
#	$srvcobjects_ref->{'cymtec-port'}{'ports'}{'tcp'}{'1898'}++	; 
#	$ports_ref->{'tcp'}{'1898'}{'name'} = 'cymtec-port'		; 
#	$srvcobjects_ref->{'mpm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpm'}{'port'}{'udp'} = '45'	; 
#	$srvcobjects_ref->{'mpm'}{'ports'}{'udp'}{'45'}++	; 
#	$ports_ref->{'udp'}{'45'}{'name'} = 'mpm'		; 
#	$srvcobjects_ref->{'mpm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpm'}{'port'}{'tcp'} = '45'	; 
#	$srvcobjects_ref->{'mpm'}{'ports'}{'tcp'}{'45'}++	; 
#	$ports_ref->{'tcp'}{'45'}{'name'} = 'mpm'		; 
#	$srvcobjects_ref->{'svn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'svn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svn'}{'port'}{'udp'} = '3690'	; 
#	$srvcobjects_ref->{'svn'}{'ports'}{'udp'}{'3690'}++	; 
#	$ports_ref->{'udp'}{'3690'}{'name'} = 'svn'		; 
#	$srvcobjects_ref->{'svn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'svn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svn'}{'port'}{'tcp'} = '3690'	; 
#	$srvcobjects_ref->{'svn'}{'ports'}{'tcp'}{'3690'}++	; 
#	$ports_ref->{'tcp'}{'3690'}{'name'} = 'svn'		; 
#	$srvcobjects_ref->{'kv-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kv-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kv-agent'}{'port'}{'udp'} = '3361'	; 
#	$srvcobjects_ref->{'kv-agent'}{'ports'}{'udp'}{'3361'}++	; 
#	$ports_ref->{'udp'}{'3361'}{'name'} = 'kv-agent'		; 
#	$srvcobjects_ref->{'kv-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kv-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kv-agent'}{'port'}{'tcp'} = '3361'	; 
#	$srvcobjects_ref->{'kv-agent'}{'ports'}{'tcp'}{'3361'}++	; 
#	$ports_ref->{'tcp'}{'3361'}{'name'} = 'kv-agent'		; 
#	$srvcobjects_ref->{'udpplus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'udpplus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udpplus'}{'port'}{'udp'} = '5566'	; 
#	$srvcobjects_ref->{'udpplus'}{'ports'}{'udp'}{'5566'}++	; 
#	$ports_ref->{'udp'}{'5566'}{'name'} = 'udpplus'		; 
#	$srvcobjects_ref->{'udpplus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'udpplus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udpplus'}{'port'}{'tcp'} = '5566'	; 
#	$srvcobjects_ref->{'udpplus'}{'ports'}{'tcp'}{'5566'}++	; 
#	$ports_ref->{'tcp'}{'5566'}{'name'} = 'udpplus'		; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'port'}{'udp'} = '1860'	; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'ports'}{'udp'}{'1860'}++	; 
#	$ports_ref->{'udp'}{'1860'}{'name'} = 'sunscalar-svc'		; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'port'}{'tcp'} = '1860'	; 
#	$srvcobjects_ref->{'sunscalar-svc'}{'ports'}{'tcp'}{'1860'}++	; 
#	$ports_ref->{'tcp'}{'1860'}{'name'} = 'sunscalar-svc'		; 
#	$srvcobjects_ref->{'rxmon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rxmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rxmon'}{'port'}{'udp'} = '1311'	; 
#	$srvcobjects_ref->{'rxmon'}{'ports'}{'udp'}{'1311'}++	; 
#	$ports_ref->{'udp'}{'1311'}{'name'} = 'rxmon'		; 
#	$srvcobjects_ref->{'rxmon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rxmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rxmon'}{'port'}{'tcp'} = '1311'	; 
#	$srvcobjects_ref->{'rxmon'}{'ports'}{'tcp'}{'1311'}++	; 
#	$ports_ref->{'tcp'}{'1311'}{'name'} = 'rxmon'		; 
#	$srvcobjects_ref->{'cifs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cifs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cifs'}{'port'}{'udp'} = '3020'	; 
#	$srvcobjects_ref->{'cifs'}{'ports'}{'udp'}{'3020'}++	; 
#	$ports_ref->{'udp'}{'3020'}{'name'} = 'cifs'		; 
#	$srvcobjects_ref->{'cifs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cifs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cifs'}{'port'}{'tcp'} = '3020'	; 
#	$srvcobjects_ref->{'cifs'}{'ports'}{'tcp'}{'3020'}++	; 
#	$ports_ref->{'tcp'}{'3020'}{'name'} = 'cifs'		; 
#	$srvcobjects_ref->{'pxc-epmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-epmap'}{'port'}{'udp'} = '2434'	; 
#	$srvcobjects_ref->{'pxc-epmap'}{'ports'}{'udp'}{'2434'}++	; 
#	$ports_ref->{'udp'}{'2434'}{'name'} = 'pxc-epmap'		; 
#	$srvcobjects_ref->{'pxc-epmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-epmap'}{'port'}{'tcp'} = '2434'	; 
#	$srvcobjects_ref->{'pxc-epmap'}{'ports'}{'tcp'}{'2434'}++	; 
#	$ports_ref->{'tcp'}{'2434'}{'name'} = 'pxc-epmap'		; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'port'}{'udp'} = '2926'	; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'ports'}{'udp'}{'2926'}++	; 
#	$ports_ref->{'udp'}{'2926'}{'name'} = 'mobile-file-dl'		; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'port'}{'tcp'} = '2926'	; 
#	$srvcobjects_ref->{'mobile-file-dl'}{'ports'}{'tcp'}{'2926'}++	; 
#	$ports_ref->{'tcp'}{'2926'}{'name'} = 'mobile-file-dl'		; 
#	$srvcobjects_ref->{'shockwave'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shockwave'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shockwave'}{'port'}{'udp'} = '1626'	; 
#	$srvcobjects_ref->{'shockwave'}{'ports'}{'udp'}{'1626'}++	; 
#	$ports_ref->{'udp'}{'1626'}{'name'} = 'shockwave'		; 
#	$srvcobjects_ref->{'shockwave'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shockwave'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shockwave'}{'port'}{'tcp'} = '1626'	; 
#	$srvcobjects_ref->{'shockwave'}{'ports'}{'tcp'}{'1626'}++	; 
#	$ports_ref->{'tcp'}{'1626'}{'name'} = 'shockwave'		; 
#	$srvcobjects_ref->{'vacdsm-app'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vacdsm-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vacdsm-app'}{'port'}{'udp'} = '671'	; 
#	$srvcobjects_ref->{'vacdsm-app'}{'ports'}{'udp'}{'671'}++	; 
#	$ports_ref->{'udp'}{'671'}{'name'} = 'vacdsm-app'		; 
#	$srvcobjects_ref->{'vacdsm-app'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vacdsm-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vacdsm-app'}{'port'}{'tcp'} = '671'	; 
#	$srvcobjects_ref->{'vacdsm-app'}{'ports'}{'tcp'}{'671'}++	; 
#	$ports_ref->{'tcp'}{'671'}{'name'} = 'vacdsm-app'		; 
#	$srvcobjects_ref->{'idware-router'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idware-router'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idware-router'}{'port'}{'udp'} = '2079'	; 
#	$srvcobjects_ref->{'idware-router'}{'ports'}{'udp'}{'2079'}++	; 
#	$ports_ref->{'udp'}{'2079'}{'name'} = 'idware-router'		; 
#	$srvcobjects_ref->{'idware-router'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idware-router'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idware-router'}{'port'}{'tcp'} = '2079'	; 
#	$srvcobjects_ref->{'idware-router'}{'ports'}{'tcp'}{'2079'}++	; 
#	$ports_ref->{'tcp'}{'2079'}{'name'} = 'idware-router'		; 
#	$srvcobjects_ref->{'xinuexpansion2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xinuexpansion2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinuexpansion2'}{'port'}{'udp'} = '2022'	; 
#	$srvcobjects_ref->{'xinuexpansion2'}{'ports'}{'udp'}{'2022'}++	; 
#	$ports_ref->{'udp'}{'2022'}{'name'} = 'xinuexpansion2'		; 
#	$srvcobjects_ref->{'msft-gc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msft-gc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msft-gc'}{'port'}{'udp'} = '3268'	; 
#	$srvcobjects_ref->{'msft-gc'}{'ports'}{'udp'}{'3268'}++	; 
#	$ports_ref->{'udp'}{'3268'}{'name'} = 'msft-gc'		; 
#	$srvcobjects_ref->{'msft-gc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msft-gc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msft-gc'}{'port'}{'tcp'} = '3268'	; 
#	$srvcobjects_ref->{'msft-gc'}{'ports'}{'tcp'}{'3268'}++	; 
#	$ports_ref->{'tcp'}{'3268'}{'name'} = 'msft-gc'		; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'port'}{'udp'} = '3188'	; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'ports'}{'udp'}{'3188'}++	; 
#	$ports_ref->{'udp'}{'3188'}{'name'} = 'brcm-comm-port'		; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'port'}{'tcp'} = '3188'	; 
#	$srvcobjects_ref->{'brcm-comm-port'}{'ports'}{'tcp'}{'3188'}++	; 
#	$ports_ref->{'tcp'}{'3188'}{'name'} = 'brcm-comm-port'		; 
#	$srvcobjects_ref->{'whisker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'whisker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whisker'}{'port'}{'udp'} = '3233'	; 
#	$srvcobjects_ref->{'whisker'}{'ports'}{'udp'}{'3233'}++	; 
#	$ports_ref->{'udp'}{'3233'}{'name'} = 'whisker'		; 
#	$srvcobjects_ref->{'whisker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'whisker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whisker'}{'port'}{'tcp'} = '3233'	; 
#	$srvcobjects_ref->{'whisker'}{'ports'}{'tcp'}{'3233'}++	; 
#	$ports_ref->{'tcp'}{'3233'}{'name'} = 'whisker'		; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'port'}{'udp'} = '1988'	; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'ports'}{'udp'}{'1988'}++	; 
#	$ports_ref->{'udp'}{'1988'}{'name'} = 'tr-rsrb-p2'		; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'port'}{'tcp'} = '1988'	; 
#	$srvcobjects_ref->{'tr-rsrb-p2'}{'ports'}{'tcp'}{'1988'}++	; 
#	$ports_ref->{'tcp'}{'1988'}{'name'} = 'tr-rsrb-p2'		; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'port'}{'udp'} = '14937'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'ports'}{'udp'}{'14937'}++	; 
#	$ports_ref->{'udp'}{'14937'}{'name'} = 'hde-lcesrvr-2'		; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'port'}{'tcp'} = '14937'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-2'}{'ports'}{'tcp'}{'14937'}++	; 
#	$ports_ref->{'tcp'}{'14937'}{'name'} = 'hde-lcesrvr-2'		; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'port'}{'udp'} = '8115'	; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'ports'}{'udp'}{'8115'}++	; 
#	$ports_ref->{'udp'}{'8115'}{'name'} = 'mtl8000-matrix'		; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'port'}{'tcp'} = '8115'	; 
#	$srvcobjects_ref->{'mtl8000-matrix'}{'ports'}{'tcp'}{'8115'}++	; 
#	$ports_ref->{'tcp'}{'8115'}{'name'} = 'mtl8000-matrix'		; 
#	$srvcobjects_ref->{'talarian-mqs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talarian-mqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mqs'}{'port'}{'udp'} = '2493'	; 
#	$srvcobjects_ref->{'talarian-mqs'}{'ports'}{'udp'}{'2493'}++	; 
#	$ports_ref->{'udp'}{'2493'}{'name'} = 'talarian-mqs'		; 
#	$srvcobjects_ref->{'talarian-mqs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talarian-mqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mqs'}{'port'}{'tcp'} = '2493'	; 
#	$srvcobjects_ref->{'talarian-mqs'}{'ports'}{'tcp'}{'2493'}++	; 
#	$ports_ref->{'tcp'}{'2493'}{'name'} = 'talarian-mqs'		; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'port'}{'udp'} = '1418'	; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'ports'}{'udp'}{'1418'}++	; 
#	$ports_ref->{'udp'}{'1418'}{'name'} = 'timbuktu-srv2'		; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'port'}{'tcp'} = '1418'	; 
#	$srvcobjects_ref->{'timbuktu-srv2'}{'ports'}{'tcp'}{'1418'}++	; 
#	$ports_ref->{'tcp'}{'1418'}{'name'} = 'timbuktu-srv2'		; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'port'}{'udp'} = '800'	; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'ports'}{'udp'}{'800'}++	; 
#	$ports_ref->{'udp'}{'800'}{'name'} = 'mdbs_daemon'		; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'port'}{'tcp'} = '800'	; 
#	$srvcobjects_ref->{'mdbs_daemon'}{'ports'}{'tcp'}{'800'}++	; 
#	$ports_ref->{'tcp'}{'800'}{'name'} = 'mdbs_daemon'		; 
#	$srvcobjects_ref->{'palace-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'palace-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-4'}{'port'}{'udp'} = '9995'	; 
#	$srvcobjects_ref->{'palace-4'}{'ports'}{'udp'}{'9995'}++	; 
#	$ports_ref->{'udp'}{'9995'}{'name'} = 'palace-4'		; 
#	$srvcobjects_ref->{'palace-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'palace-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-4'}{'port'}{'tcp'} = '9995'	; 
#	$srvcobjects_ref->{'palace-4'}{'ports'}{'tcp'}{'9995'}++	; 
#	$ports_ref->{'tcp'}{'9995'}{'name'} = 'palace-4'		; 
#	$srvcobjects_ref->{'apc-2260'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-2260'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-2260'}{'port'}{'udp'} = '2260'	; 
#	$srvcobjects_ref->{'apc-2260'}{'ports'}{'udp'}{'2260'}++	; 
#	$ports_ref->{'udp'}{'2260'}{'name'} = 'apc-2260'		; 
#	$srvcobjects_ref->{'apc-2260'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-2260'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-2260'}{'port'}{'tcp'} = '2260'	; 
#	$srvcobjects_ref->{'apc-2260'}{'ports'}{'tcp'}{'2260'}++	; 
#	$ports_ref->{'tcp'}{'2260'}{'name'} = 'apc-2260'		; 
#	$srvcobjects_ref->{'egs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'egs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'egs'}{'port'}{'udp'} = '1926'	; 
#	$srvcobjects_ref->{'egs'}{'ports'}{'udp'}{'1926'}++	; 
#	$ports_ref->{'udp'}{'1926'}{'name'} = 'egs'		; 
#	$srvcobjects_ref->{'egs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'egs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'egs'}{'port'}{'tcp'} = '1926'	; 
#	$srvcobjects_ref->{'egs'}{'ports'}{'tcp'}{'1926'}++	; 
#	$ports_ref->{'tcp'}{'1926'}{'name'} = 'egs'		; 
#	$srvcobjects_ref->{'gprs-cube'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gprs-cube'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gprs-cube'}{'port'}{'udp'} = '3751'	; 
#	$srvcobjects_ref->{'gprs-cube'}{'ports'}{'udp'}{'3751'}++	; 
#	$ports_ref->{'udp'}{'3751'}{'name'} = 'gprs-cube'		; 
#	$srvcobjects_ref->{'gprs-cube'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gprs-cube'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gprs-cube'}{'port'}{'tcp'} = '3751'	; 
#	$srvcobjects_ref->{'gprs-cube'}{'ports'}{'tcp'}{'3751'}++	; 
#	$ports_ref->{'tcp'}{'3751'}{'name'} = 'gprs-cube'		; 
#	$srvcobjects_ref->{'infowave'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infowave'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infowave'}{'port'}{'udp'} = '2082'	; 
#	$srvcobjects_ref->{'infowave'}{'ports'}{'udp'}{'2082'}++	; 
#	$ports_ref->{'udp'}{'2082'}{'name'} = 'infowave'		; 
#	$srvcobjects_ref->{'infowave'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infowave'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infowave'}{'port'}{'tcp'} = '2082'	; 
#	$srvcobjects_ref->{'infowave'}{'ports'}{'tcp'}{'2082'}++	; 
#	$ports_ref->{'tcp'}{'2082'}{'name'} = 'infowave'		; 
#	$srvcobjects_ref->{'ms-la'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-la'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-la'}{'port'}{'udp'} = '3535'	; 
#	$srvcobjects_ref->{'ms-la'}{'ports'}{'udp'}{'3535'}++	; 
#	$ports_ref->{'udp'}{'3535'}{'name'} = 'ms-la'		; 
#	$srvcobjects_ref->{'ms-la'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-la'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-la'}{'port'}{'tcp'} = '3535'	; 
#	$srvcobjects_ref->{'ms-la'}{'ports'}{'tcp'}{'3535'}++	; 
#	$ports_ref->{'tcp'}{'3535'}{'name'} = 'ms-la'		; 
#	$srvcobjects_ref->{'custix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'custix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'custix'}{'port'}{'udp'} = '528'	; 
#	$srvcobjects_ref->{'custix'}{'ports'}{'udp'}{'528'}++	; 
#	$ports_ref->{'udp'}{'528'}{'name'} = 'custix'		; 
#	$srvcobjects_ref->{'custix'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'custix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'custix'}{'port'}{'tcp'} = '528'	; 
#	$srvcobjects_ref->{'custix'}{'ports'}{'tcp'}{'528'}++	; 
#	$ports_ref->{'tcp'}{'528'}{'name'} = 'custix'		; 
#	$srvcobjects_ref->{'nip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nip'}{'port'}{'udp'} = '376'	; 
#	$srvcobjects_ref->{'nip'}{'ports'}{'udp'}{'376'}++	; 
#	$ports_ref->{'udp'}{'376'}{'name'} = 'nip'		; 
#	$srvcobjects_ref->{'nip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nip'}{'port'}{'tcp'} = '376'	; 
#	$srvcobjects_ref->{'nip'}{'ports'}{'tcp'}{'376'}++	; 
#	$ports_ref->{'tcp'}{'376'}{'name'} = 'nip'		; 
#	$srvcobjects_ref->{'vchat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vchat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vchat'}{'port'}{'udp'} = '1168'	; 
#	$srvcobjects_ref->{'vchat'}{'ports'}{'udp'}{'1168'}++	; 
#	$ports_ref->{'udp'}{'1168'}{'name'} = 'vchat'		; 
#	$srvcobjects_ref->{'vchat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vchat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vchat'}{'port'}{'tcp'} = '1168'	; 
#	$srvcobjects_ref->{'vchat'}{'ports'}{'tcp'}{'1168'}++	; 
#	$ports_ref->{'tcp'}{'1168'}{'name'} = 'vchat'		; 
#	$srvcobjects_ref->{'qmtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qmtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qmtp'}{'port'}{'udp'} = '209'	; 
#	$srvcobjects_ref->{'qmtp'}{'ports'}{'udp'}{'209'}++	; 
#	$ports_ref->{'udp'}{'209'}{'name'} = 'qmtp'		; 
#	$srvcobjects_ref->{'qmtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qmtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qmtp'}{'port'}{'tcp'} = '209'	; 
#	$srvcobjects_ref->{'qmtp'}{'ports'}{'tcp'}{'209'}++	; 
#	$ports_ref->{'tcp'}{'209'}{'name'} = 'qmtp'		; 
#	$srvcobjects_ref->{'syslog-conn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'syslog-conn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syslog-conn'}{'port'}{'udp'} = '601'	; 
#	$srvcobjects_ref->{'syslog-conn'}{'ports'}{'udp'}{'601'}++	; 
#	$ports_ref->{'udp'}{'601'}{'name'} = 'syslog-conn'		; 
#	$srvcobjects_ref->{'syslog-conn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'syslog-conn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syslog-conn'}{'port'}{'tcp'} = '601'	; 
#	$srvcobjects_ref->{'syslog-conn'}{'ports'}{'tcp'}{'601'}++	; 
#	$ports_ref->{'tcp'}{'601'}{'name'} = 'syslog-conn'		; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'port'}{'udp'} = '2070'	; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'ports'}{'udp'}{'2070'}++	; 
#	$ports_ref->{'udp'}{'2070'}{'name'} = 'ah-esp-encap'		; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'port'}{'tcp'} = '2070'	; 
#	$srvcobjects_ref->{'ah-esp-encap'}{'ports'}{'tcp'}{'2070'}++	; 
#	$ports_ref->{'tcp'}{'2070'}{'name'} = 'ah-esp-encap'		; 
#	$srvcobjects_ref->{'saiseh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'saiseh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saiseh'}{'port'}{'tcp'} = '1644'	; 
#	$srvcobjects_ref->{'saiseh'}{'ports'}{'tcp'}{'1644'}++	; 
#	$ports_ref->{'tcp'}{'1644'}{'name'} = 'saiseh'		; 
#	$srvcobjects_ref->{'dynamic3d'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dynamic3d'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dynamic3d'}{'port'}{'udp'} = '2150'	; 
#	$srvcobjects_ref->{'dynamic3d'}{'ports'}{'udp'}{'2150'}++	; 
#	$ports_ref->{'udp'}{'2150'}{'name'} = 'dynamic3d'		; 
#	$srvcobjects_ref->{'dynamic3d'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dynamic3d'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dynamic3d'}{'port'}{'tcp'} = '2150'	; 
#	$srvcobjects_ref->{'dynamic3d'}{'ports'}{'tcp'}{'2150'}++	; 
#	$ports_ref->{'tcp'}{'2150'}{'name'} = 'dynamic3d'		; 
#	$srvcobjects_ref->{'srssend'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'srssend'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srssend'}{'port'}{'udp'} = '362'	; 
#	$srvcobjects_ref->{'srssend'}{'ports'}{'udp'}{'362'}++	; 
#	$ports_ref->{'udp'}{'362'}{'name'} = 'srssend'		; 
#	$srvcobjects_ref->{'srssend'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'srssend'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srssend'}{'port'}{'tcp'} = '362'	; 
#	$srvcobjects_ref->{'srssend'}{'ports'}{'tcp'}{'362'}++	; 
#	$ports_ref->{'tcp'}{'362'}{'name'} = 'srssend'		; 
#	$srvcobjects_ref->{'pwgpsi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pwgpsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwgpsi'}{'port'}{'udp'} = '3800'	; 
#	$srvcobjects_ref->{'pwgpsi'}{'ports'}{'udp'}{'3800'}++	; 
#	$ports_ref->{'udp'}{'3800'}{'name'} = 'pwgpsi'		; 
#	$srvcobjects_ref->{'pwgpsi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pwgpsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwgpsi'}{'port'}{'tcp'} = '3800'	; 
#	$srvcobjects_ref->{'pwgpsi'}{'ports'}{'tcp'}{'3800'}++	; 
#	$ports_ref->{'tcp'}{'3800'}{'name'} = 'pwgpsi'		; 
#	$srvcobjects_ref->{'indi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'indi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indi'}{'port'}{'udp'} = '7624'	; 
#	$srvcobjects_ref->{'indi'}{'ports'}{'udp'}{'7624'}++	; 
#	$ports_ref->{'udp'}{'7624'}{'name'} = 'indi'		; 
#	$srvcobjects_ref->{'indi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'indi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indi'}{'port'}{'tcp'} = '7624'	; 
#	$srvcobjects_ref->{'indi'}{'ports'}{'tcp'}{'7624'}++	; 
#	$ports_ref->{'tcp'}{'7624'}{'name'} = 'indi'		; 
#	$srvcobjects_ref->{'lv-pici'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lv-pici'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-pici'}{'port'}{'udp'} = '2145'	; 
#	$srvcobjects_ref->{'lv-pici'}{'ports'}{'udp'}{'2145'}++	; 
#	$ports_ref->{'udp'}{'2145'}{'name'} = 'lv-pici'		; 
#	$srvcobjects_ref->{'lv-pici'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lv-pici'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-pici'}{'port'}{'tcp'} = '2145'	; 
#	$srvcobjects_ref->{'lv-pici'}{'ports'}{'tcp'}{'2145'}++	; 
#	$ports_ref->{'tcp'}{'2145'}{'name'} = 'lv-pici'		; 
#	$srvcobjects_ref->{'teradataordbms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'teradataordbms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teradataordbms'}{'port'}{'udp'} = '8002'	; 
#	$srvcobjects_ref->{'teradataordbms'}{'ports'}{'udp'}{'8002'}++	; 
#	$ports_ref->{'udp'}{'8002'}{'name'} = 'teradataordbms'		; 
#	$srvcobjects_ref->{'teradataordbms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'teradataordbms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teradataordbms'}{'port'}{'tcp'} = '8002'	; 
#	$srvcobjects_ref->{'teradataordbms'}{'ports'}{'tcp'}{'8002'}++	; 
#	$ports_ref->{'tcp'}{'8002'}{'name'} = 'teradataordbms'		; 
#	$srvcobjects_ref->{'sstp-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sstp-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sstp-1'}{'port'}{'udp'} = '7743'	; 
#	$srvcobjects_ref->{'sstp-1'}{'ports'}{'udp'}{'7743'}++	; 
#	$ports_ref->{'udp'}{'7743'}{'name'} = 'sstp-1'		; 
#	$srvcobjects_ref->{'sstp-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sstp-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sstp-1'}{'port'}{'tcp'} = '7743'	; 
#	$srvcobjects_ref->{'sstp-1'}{'ports'}{'tcp'}{'7743'}++	; 
#	$ports_ref->{'tcp'}{'7743'}{'name'} = 'sstp-1'		; 
#	$srvcobjects_ref->{'compaq-scp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'compaq-scp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-scp'}{'port'}{'udp'} = '2766'	; 
#	$srvcobjects_ref->{'compaq-scp'}{'ports'}{'udp'}{'2766'}++	; 
#	$ports_ref->{'udp'}{'2766'}{'name'} = 'compaq-scp'		; 
#	$srvcobjects_ref->{'compaq-scp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'compaq-scp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-scp'}{'port'}{'tcp'} = '2766'	; 
#	$srvcobjects_ref->{'compaq-scp'}{'ports'}{'tcp'}{'2766'}++	; 
#	$ports_ref->{'tcp'}{'2766'}{'name'} = 'compaq-scp'		; 
#	$srvcobjects_ref->{'truecm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'truecm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'truecm'}{'port'}{'udp'} = '8804'	; 
#	$srvcobjects_ref->{'truecm'}{'ports'}{'udp'}{'8804'}++	; 
#	$ports_ref->{'udp'}{'8804'}{'name'} = 'truecm'		; 
#	$srvcobjects_ref->{'truecm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'truecm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'truecm'}{'port'}{'tcp'} = '8804'	; 
#	$srvcobjects_ref->{'truecm'}{'ports'}{'tcp'}{'8804'}++	; 
#	$ports_ref->{'tcp'}{'8804'}{'name'} = 'truecm'		; 
#	$srvcobjects_ref->{'avenue'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avenue'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avenue'}{'port'}{'udp'} = '2134'	; 
#	$srvcobjects_ref->{'avenue'}{'ports'}{'udp'}{'2134'}++	; 
#	$ports_ref->{'udp'}{'2134'}{'name'} = 'avenue'		; 
#	$srvcobjects_ref->{'avenue'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avenue'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avenue'}{'port'}{'tcp'} = '2134'	; 
#	$srvcobjects_ref->{'avenue'}{'ports'}{'tcp'}{'2134'}++	; 
#	$ports_ref->{'tcp'}{'2134'}{'name'} = 'avenue'		; 
#	$srvcobjects_ref->{'dbref'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbref'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbref'}{'port'}{'udp'} = '2365'	; 
#	$srvcobjects_ref->{'dbref'}{'ports'}{'udp'}{'2365'}++	; 
#	$ports_ref->{'udp'}{'2365'}{'name'} = 'dbref'		; 
#	$srvcobjects_ref->{'dbref'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbref'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbref'}{'port'}{'tcp'} = '2365'	; 
#	$srvcobjects_ref->{'dbref'}{'ports'}{'tcp'}{'2365'}++	; 
#	$ports_ref->{'tcp'}{'2365'}{'name'} = 'dbref'		; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'port'}{'udp'} = '1956'	; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'ports'}{'udp'}{'1956'}++	; 
#	$ports_ref->{'udp'}{'1956'}{'name'} = 'vrtl-vmf-ds'		; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'port'}{'tcp'} = '1956'	; 
#	$srvcobjects_ref->{'vrtl-vmf-ds'}{'ports'}{'tcp'}{'1956'}++	; 
#	$ports_ref->{'tcp'}{'1956'}{'name'} = 'vrtl-vmf-ds'		; 
#	$srvcobjects_ref->{'3com-tsmux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3com-tsmux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-tsmux'}{'port'}{'udp'} = '106'	; 
#	$srvcobjects_ref->{'3com-tsmux'}{'ports'}{'udp'}{'106'}++	; 
#	$ports_ref->{'udp'}{'106'}{'name'} = '3com-tsmux'		; 
#	$srvcobjects_ref->{'3com-tsmux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3com-tsmux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-tsmux'}{'port'}{'tcp'} = '106'	; 
#	$srvcobjects_ref->{'3com-tsmux'}{'ports'}{'tcp'}{'106'}++	; 
#	$ports_ref->{'tcp'}{'106'}{'name'} = '3com-tsmux'		; 
#	$srvcobjects_ref->{'netlock5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netlock5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock5'}{'port'}{'udp'} = '9164'	; 
#	$srvcobjects_ref->{'netlock5'}{'ports'}{'udp'}{'9164'}++	; 
#	$ports_ref->{'udp'}{'9164'}{'name'} = 'netlock5'		; 
#	$srvcobjects_ref->{'netlock5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netlock5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock5'}{'port'}{'tcp'} = '9164'	; 
#	$srvcobjects_ref->{'netlock5'}{'ports'}{'tcp'}{'9164'}++	; 
#	$ports_ref->{'tcp'}{'9164'}{'name'} = 'netlock5'		; 
#	$srvcobjects_ref->{'spiral-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spiral-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spiral-admin'}{'port'}{'udp'} = '3438'	; 
#	$srvcobjects_ref->{'spiral-admin'}{'ports'}{'udp'}{'3438'}++	; 
#	$ports_ref->{'udp'}{'3438'}{'name'} = 'spiral-admin'		; 
#	$srvcobjects_ref->{'spiral-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spiral-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spiral-admin'}{'port'}{'tcp'} = '3438'	; 
#	$srvcobjects_ref->{'spiral-admin'}{'ports'}{'tcp'}{'3438'}++	; 
#	$ports_ref->{'tcp'}{'3438'}{'name'} = 'spiral-admin'		; 
#	$srvcobjects_ref->{'raid-am'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raid-am'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-am'}{'port'}{'udp'} = '2007'	; 
#	$srvcobjects_ref->{'raid-am'}{'ports'}{'udp'}{'2007'}++	; 
#	$ports_ref->{'udp'}{'2007'}{'name'} = 'raid-am'		; 
#	$srvcobjects_ref->{'raid-am'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raid-am'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-am'}{'port'}{'tcp'} = '2013'	; 
#	$srvcobjects_ref->{'raid-am'}{'ports'}{'tcp'}{'2013'}++	; 
#	$ports_ref->{'tcp'}{'2013'}{'name'} = 'raid-am'		; 
#	$srvcobjects_ref->{'mondex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mondex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mondex'}{'port'}{'udp'} = '471'	; 
#	$srvcobjects_ref->{'mondex'}{'ports'}{'udp'}{'471'}++	; 
#	$ports_ref->{'udp'}{'471'}{'name'} = 'mondex'		; 
#	$srvcobjects_ref->{'mondex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mondex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mondex'}{'port'}{'tcp'} = '471'	; 
#	$srvcobjects_ref->{'mondex'}{'ports'}{'tcp'}{'471'}++	; 
#	$ports_ref->{'tcp'}{'471'}{'name'} = 'mondex'		; 
#	$srvcobjects_ref->{'adtech-test'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adtech-test'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adtech-test'}{'port'}{'udp'} = '3357'	; 
#	$srvcobjects_ref->{'adtech-test'}{'ports'}{'udp'}{'3357'}++	; 
#	$ports_ref->{'udp'}{'3357'}{'name'} = 'adtech-test'		; 
#	$srvcobjects_ref->{'adtech-test'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adtech-test'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adtech-test'}{'port'}{'tcp'} = '3357'	; 
#	$srvcobjects_ref->{'adtech-test'}{'ports'}{'tcp'}{'3357'}++	; 
#	$ports_ref->{'tcp'}{'3357'}{'name'} = 'adtech-test'		; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'port'}{'udp'} = '3473'	; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'ports'}{'udp'}{'3473'}++	; 
#	$ports_ref->{'udp'}{'3473'}{'name'} = 'jaugsremotec-2'		; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'port'}{'tcp'} = '3473'	; 
#	$srvcobjects_ref->{'jaugsremotec-2'}{'ports'}{'tcp'}{'3473'}++	; 
#	$ports_ref->{'tcp'}{'3473'}{'name'} = 'jaugsremotec-2'		; 
#	$srvcobjects_ref->{'street-stream'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'street-stream'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'street-stream'}{'port'}{'udp'} = '1736'	; 
#	$srvcobjects_ref->{'street-stream'}{'ports'}{'udp'}{'1736'}++	; 
#	$ports_ref->{'udp'}{'1736'}{'name'} = 'street-stream'		; 
#	$srvcobjects_ref->{'street-stream'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'street-stream'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'street-stream'}{'port'}{'tcp'} = '1736'	; 
#	$srvcobjects_ref->{'street-stream'}{'ports'}{'tcp'}{'1736'}++	; 
#	$ports_ref->{'tcp'}{'1736'}{'name'} = 'street-stream'		; 
#	$srvcobjects_ref->{'ntalk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ntalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ntalk'}{'port'}{'udp'} = '518'	; 
#	$srvcobjects_ref->{'ntalk'}{'ports'}{'udp'}{'518'}++	; 
#	$ports_ref->{'udp'}{'518'}{'name'} = 'ntalk'		; 
#	$srvcobjects_ref->{'ntalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ntalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ntalk'}{'port'}{'tcp'} = '518'	; 
#	$srvcobjects_ref->{'ntalk'}{'ports'}{'tcp'}{'518'}++	; 
#	$ports_ref->{'tcp'}{'518'}{'name'} = 'ntalk'		; 
#	$srvcobjects_ref->{'ovhpas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovhpas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovhpas'}{'port'}{'udp'} = '7510'	; 
#	$srvcobjects_ref->{'ovhpas'}{'ports'}{'udp'}{'7510'}++	; 
#	$ports_ref->{'udp'}{'7510'}{'name'} = 'ovhpas'		; 
#	$srvcobjects_ref->{'ovhpas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovhpas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovhpas'}{'port'}{'tcp'} = '7510'	; 
#	$srvcobjects_ref->{'ovhpas'}{'ports'}{'tcp'}{'7510'}++	; 
#	$ports_ref->{'tcp'}{'7510'}{'name'} = 'ovhpas'		; 
#	$srvcobjects_ref->{'ordinox-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ordinox-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ordinox-server'}{'port'}{'udp'} = '3274'	; 
#	$srvcobjects_ref->{'ordinox-server'}{'ports'}{'udp'}{'3274'}++	; 
#	$ports_ref->{'udp'}{'3274'}{'name'} = 'ordinox-server'		; 
#	$srvcobjects_ref->{'ordinox-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ordinox-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ordinox-server'}{'port'}{'tcp'} = '3274'	; 
#	$srvcobjects_ref->{'ordinox-server'}{'ports'}{'tcp'}{'3274'}++	; 
#	$ports_ref->{'tcp'}{'3274'}{'name'} = 'ordinox-server'		; 
#	$srvcobjects_ref->{'ovwdb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovwdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovwdb'}{'port'}{'udp'} = '2447'	; 
#	$srvcobjects_ref->{'ovwdb'}{'ports'}{'udp'}{'2447'}++	; 
#	$ports_ref->{'udp'}{'2447'}{'name'} = 'ovwdb'		; 
#	$srvcobjects_ref->{'ovwdb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovwdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovwdb'}{'port'}{'tcp'} = '2447'	; 
#	$srvcobjects_ref->{'ovwdb'}{'ports'}{'tcp'}{'2447'}++	; 
#	$ports_ref->{'tcp'}{'2447'}{'name'} = 'ovwdb'		; 
#	$srvcobjects_ref->{'ms-sql-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-sql-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sql-s'}{'port'}{'udp'} = '1433'	; 
#	$srvcobjects_ref->{'ms-sql-s'}{'ports'}{'udp'}{'1433'}++	; 
#	$ports_ref->{'udp'}{'1433'}{'name'} = 'ms-sql-s'		; 
#	$srvcobjects_ref->{'ms-sql-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-sql-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sql-s'}{'port'}{'tcp'} = '1433'	; 
#	$srvcobjects_ref->{'ms-sql-s'}{'ports'}{'tcp'}{'1433'}++	; 
#	$ports_ref->{'tcp'}{'1433'}{'name'} = 'ms-sql-s'		; 
#	$srvcobjects_ref->{'llm-csv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'llm-csv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llm-csv'}{'port'}{'udp'} = '2814'	; 
#	$srvcobjects_ref->{'llm-csv'}{'ports'}{'udp'}{'2814'}++	; 
#	$ports_ref->{'udp'}{'2814'}{'name'} = 'llm-csv'		; 
#	$srvcobjects_ref->{'llm-csv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'llm-csv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llm-csv'}{'port'}{'tcp'} = '2814'	; 
#	$srvcobjects_ref->{'llm-csv'}{'ports'}{'tcp'}{'2814'}++	; 
#	$ports_ref->{'tcp'}{'2814'}{'name'} = 'llm-csv'		; 
#	$srvcobjects_ref->{'ocs_cmu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ocs_cmu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocs_cmu'}{'port'}{'udp'} = '428'	; 
#	$srvcobjects_ref->{'ocs_cmu'}{'ports'}{'udp'}{'428'}++	; 
#	$ports_ref->{'udp'}{'428'}{'name'} = 'ocs_cmu'		; 
#	$srvcobjects_ref->{'ocs_cmu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ocs_cmu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocs_cmu'}{'port'}{'tcp'} = '428'	; 
#	$srvcobjects_ref->{'ocs_cmu'}{'ports'}{'tcp'}{'428'}++	; 
#	$ports_ref->{'tcp'}{'428'}{'name'} = 'ocs_cmu'		; 
#	$srvcobjects_ref->{'jprinter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jprinter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jprinter'}{'port'}{'udp'} = '5309'	; 
#	$srvcobjects_ref->{'jprinter'}{'ports'}{'udp'}{'5309'}++	; 
#	$ports_ref->{'udp'}{'5309'}{'name'} = 'jprinter'		; 
#	$srvcobjects_ref->{'jprinter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jprinter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jprinter'}{'port'}{'tcp'} = '5309'	; 
#	$srvcobjects_ref->{'jprinter'}{'ports'}{'tcp'}{'5309'}++	; 
#	$ports_ref->{'tcp'}{'5309'}{'name'} = 'jprinter'		; 
#	$srvcobjects_ref->{'vtr-emulator'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vtr-emulator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vtr-emulator'}{'port'}{'udp'} = '3122'	; 
#	$srvcobjects_ref->{'vtr-emulator'}{'ports'}{'udp'}{'3122'}++	; 
#	$ports_ref->{'udp'}{'3122'}{'name'} = 'vtr-emulator'		; 
#	$srvcobjects_ref->{'vtr-emulator'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vtr-emulator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vtr-emulator'}{'port'}{'tcp'} = '3122'	; 
#	$srvcobjects_ref->{'vtr-emulator'}{'ports'}{'tcp'}{'3122'}++	; 
#	$ports_ref->{'tcp'}{'3122'}{'name'} = 'vtr-emulator'		; 
#	$srvcobjects_ref->{'mns-mail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mns-mail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mns-mail'}{'port'}{'udp'} = '2593'	; 
#	$srvcobjects_ref->{'mns-mail'}{'ports'}{'udp'}{'2593'}++	; 
#	$ports_ref->{'udp'}{'2593'}{'name'} = 'mns-mail'		; 
#	$srvcobjects_ref->{'mns-mail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mns-mail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mns-mail'}{'port'}{'tcp'} = '2593'	; 
#	$srvcobjects_ref->{'mns-mail'}{'ports'}{'tcp'}{'2593'}++	; 
#	$ports_ref->{'tcp'}{'2593'}{'name'} = 'mns-mail'		; 
#	$srvcobjects_ref->{'swa-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swa-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-3'}{'port'}{'udp'} = '9025'	; 
#	$srvcobjects_ref->{'swa-3'}{'ports'}{'udp'}{'9025'}++	; 
#	$ports_ref->{'udp'}{'9025'}{'name'} = 'swa-3'		; 
#	$srvcobjects_ref->{'swa-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swa-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-3'}{'port'}{'tcp'} = '9025'	; 
#	$srvcobjects_ref->{'swa-3'}{'ports'}{'tcp'}{'9025'}++	; 
#	$ports_ref->{'tcp'}{'9025'}{'name'} = 'swa-3'		; 
#	$srvcobjects_ref->{'npmp-trap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'npmp-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp-trap'}{'port'}{'udp'} = '609'	; 
#	$srvcobjects_ref->{'npmp-trap'}{'ports'}{'udp'}{'609'}++	; 
#	$ports_ref->{'udp'}{'609'}{'name'} = 'npmp-trap'		; 
#	$srvcobjects_ref->{'npmp-trap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'npmp-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp-trap'}{'port'}{'tcp'} = '609'	; 
#	$srvcobjects_ref->{'npmp-trap'}{'ports'}{'tcp'}{'609'}++	; 
#	$ports_ref->{'tcp'}{'609'}{'name'} = 'npmp-trap'		; 
#	$srvcobjects_ref->{'lvision-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lvision-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lvision-lm'}{'port'}{'udp'} = '6471'	; 
#	$srvcobjects_ref->{'lvision-lm'}{'ports'}{'udp'}{'6471'}++	; 
#	$ports_ref->{'udp'}{'6471'}{'name'} = 'lvision-lm'		; 
#	$srvcobjects_ref->{'lvision-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lvision-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lvision-lm'}{'port'}{'tcp'} = '6471'	; 
#	$srvcobjects_ref->{'lvision-lm'}{'ports'}{'tcp'}{'6471'}++	; 
#	$ports_ref->{'tcp'}{'6471'}{'name'} = 'lvision-lm'		; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'port'}{'udp'} = '2798'	; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'ports'}{'udp'}{'2798'}++	; 
#	$ports_ref->{'udp'}{'2798'}{'name'} = 'tmesis-upshot'		; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'port'}{'tcp'} = '2798'	; 
#	$srvcobjects_ref->{'tmesis-upshot'}{'ports'}{'tcp'}{'2798'}++	; 
#	$ports_ref->{'tcp'}{'2798'}{'name'} = 'tmesis-upshot'		; 
#	$srvcobjects_ref->{'fjmpss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjmpss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjmpss'}{'port'}{'udp'} = '2509'	; 
#	$srvcobjects_ref->{'fjmpss'}{'ports'}{'udp'}{'2509'}++	; 
#	$ports_ref->{'udp'}{'2509'}{'name'} = 'fjmpss'		; 
#	$srvcobjects_ref->{'fjmpss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjmpss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjmpss'}{'port'}{'tcp'} = '2509'	; 
#	$srvcobjects_ref->{'fjmpss'}{'ports'}{'tcp'}{'2509'}++	; 
#	$ports_ref->{'tcp'}{'2509'}{'name'} = 'fjmpss'		; 
#	$srvcobjects_ref->{'notify_srvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'notify_srvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'notify_srvr'}{'port'}{'udp'} = '3016'	; 
#	$srvcobjects_ref->{'notify_srvr'}{'ports'}{'udp'}{'3016'}++	; 
#	$ports_ref->{'udp'}{'3016'}{'name'} = 'notify_srvr'		; 
#	$srvcobjects_ref->{'notify_srvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'notify_srvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'notify_srvr'}{'port'}{'tcp'} = '3016'	; 
#	$srvcobjects_ref->{'notify_srvr'}{'ports'}{'tcp'}{'3016'}++	; 
#	$ports_ref->{'tcp'}{'3016'}{'name'} = 'notify_srvr'		; 
#	$srvcobjects_ref->{'multiling-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'multiling-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'multiling-http'}{'port'}{'udp'} = '777'	; 
#	$srvcobjects_ref->{'multiling-http'}{'ports'}{'udp'}{'777'}++	; 
#	$ports_ref->{'udp'}{'777'}{'name'} = 'multiling-http'		; 
#	$srvcobjects_ref->{'multiling-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'multiling-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'multiling-http'}{'port'}{'tcp'} = '777'	; 
#	$srvcobjects_ref->{'multiling-http'}{'ports'}{'tcp'}{'777'}++	; 
#	$ports_ref->{'tcp'}{'777'}{'name'} = 'multiling-http'		; 
#	$srvcobjects_ref->{'xtrms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xtrms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xtrms'}{'port'}{'udp'} = '3424'	; 
#	$srvcobjects_ref->{'xtrms'}{'ports'}{'udp'}{'3424'}++	; 
#	$ports_ref->{'udp'}{'3424'}{'name'} = 'xtrms'		; 
#	$srvcobjects_ref->{'xtrms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xtrms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xtrms'}{'port'}{'tcp'} = '3424'	; 
#	$srvcobjects_ref->{'xtrms'}{'ports'}{'tcp'}{'3424'}++	; 
#	$ports_ref->{'tcp'}{'3424'}{'name'} = 'xtrms'		; 
#	$srvcobjects_ref->{'compaq-wcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'compaq-wcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-wcp'}{'port'}{'udp'} = '2555'	; 
#	$srvcobjects_ref->{'compaq-wcp'}{'ports'}{'udp'}{'2555'}++	; 
#	$ports_ref->{'udp'}{'2555'}{'name'} = 'compaq-wcp'		; 
#	$srvcobjects_ref->{'compaq-wcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'compaq-wcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compaq-wcp'}{'port'}{'tcp'} = '2555'	; 
#	$srvcobjects_ref->{'compaq-wcp'}{'ports'}{'tcp'}{'2555'}++	; 
#	$ports_ref->{'tcp'}{'2555'}{'name'} = 'compaq-wcp'		; 
#	$srvcobjects_ref->{'netopia-vo1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netopia-vo1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo1'}{'port'}{'udp'} = '1839'	; 
#	$srvcobjects_ref->{'netopia-vo1'}{'ports'}{'udp'}{'1839'}++	; 
#	$ports_ref->{'udp'}{'1839'}{'name'} = 'netopia-vo1'		; 
#	$srvcobjects_ref->{'netopia-vo1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netopia-vo1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo1'}{'port'}{'tcp'} = '1839'	; 
#	$srvcobjects_ref->{'netopia-vo1'}{'ports'}{'tcp'}{'1839'}++	; 
#	$ports_ref->{'tcp'}{'1839'}{'name'} = 'netopia-vo1'		; 
#	$srvcobjects_ref->{'namp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'namp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'namp'}{'port'}{'udp'} = '167'	; 
#	$srvcobjects_ref->{'namp'}{'ports'}{'udp'}{'167'}++	; 
#	$ports_ref->{'udp'}{'167'}{'name'} = 'namp'		; 
#	$srvcobjects_ref->{'namp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'namp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'namp'}{'port'}{'tcp'} = '167'	; 
#	$srvcobjects_ref->{'namp'}{'ports'}{'tcp'}{'167'}++	; 
#	$ports_ref->{'tcp'}{'167'}{'name'} = 'namp'		; 
#	$srvcobjects_ref->{'aries-kfinder'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aries-kfinder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aries-kfinder'}{'port'}{'udp'} = '7570'	; 
#	$srvcobjects_ref->{'aries-kfinder'}{'ports'}{'udp'}{'7570'}++	; 
#	$ports_ref->{'udp'}{'7570'}{'name'} = 'aries-kfinder'		; 
#	$srvcobjects_ref->{'aries-kfinder'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aries-kfinder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aries-kfinder'}{'port'}{'tcp'} = '7570'	; 
#	$srvcobjects_ref->{'aries-kfinder'}{'ports'}{'tcp'}{'7570'}++	; 
#	$ports_ref->{'tcp'}{'7570'}{'name'} = 'aries-kfinder'		; 
#	$srvcobjects_ref->{'emsd-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emsd-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emsd-port'}{'port'}{'udp'} = '1928'	; 
#	$srvcobjects_ref->{'emsd-port'}{'ports'}{'udp'}{'1928'}++	; 
#	$ports_ref->{'udp'}{'1928'}{'name'} = 'emsd-port'		; 
#	$srvcobjects_ref->{'emsd-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emsd-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emsd-port'}{'port'}{'tcp'} = '1928'	; 
#	$srvcobjects_ref->{'emsd-port'}{'ports'}{'tcp'}{'1928'}++	; 
#	$ports_ref->{'tcp'}{'1928'}{'name'} = 'emsd-port'		; 
#	$srvcobjects_ref->{'t2-brm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'t2-brm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t2-brm'}{'port'}{'udp'} = '7933'	; 
#	$srvcobjects_ref->{'t2-brm'}{'ports'}{'udp'}{'7933'}++	; 
#	$ports_ref->{'udp'}{'7933'}{'name'} = 't2-brm'		; 
#	$srvcobjects_ref->{'t2-brm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'t2-brm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t2-brm'}{'port'}{'tcp'} = '7933'	; 
#	$srvcobjects_ref->{'t2-brm'}{'ports'}{'tcp'}{'7933'}++	; 
#	$ports_ref->{'tcp'}{'7933'}{'name'} = 't2-brm'		; 
#	$srvcobjects_ref->{'newlixengine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newlixengine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newlixengine'}{'port'}{'udp'} = '2075'	; 
#	$srvcobjects_ref->{'newlixengine'}{'ports'}{'udp'}{'2075'}++	; 
#	$ports_ref->{'udp'}{'2075'}{'name'} = 'newlixengine'		; 
#	$srvcobjects_ref->{'newlixengine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newlixengine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newlixengine'}{'port'}{'tcp'} = '2075'	; 
#	$srvcobjects_ref->{'newlixengine'}{'ports'}{'tcp'}{'2075'}++	; 
#	$ports_ref->{'tcp'}{'2075'}{'name'} = 'newlixengine'		; 
#	$srvcobjects_ref->{'webdata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webdata'}{'port'}{'udp'} = '3748'	; 
#	$srvcobjects_ref->{'webdata'}{'ports'}{'udp'}{'3748'}++	; 
#	$ports_ref->{'udp'}{'3748'}{'name'} = 'webdata'		; 
#	$srvcobjects_ref->{'webdata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webdata'}{'port'}{'tcp'} = '3748'	; 
#	$srvcobjects_ref->{'webdata'}{'ports'}{'tcp'}{'3748'}++	; 
#	$ports_ref->{'tcp'}{'3748'}{'name'} = 'webdata'		; 
#	$srvcobjects_ref->{'nmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmap'}{'port'}{'udp'} = '689'	; 
#	$srvcobjects_ref->{'nmap'}{'ports'}{'udp'}{'689'}++	; 
#	$ports_ref->{'udp'}{'689'}{'name'} = 'nmap'		; 
#	$srvcobjects_ref->{'nmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmap'}{'port'}{'tcp'} = '689'	; 
#	$srvcobjects_ref->{'nmap'}{'ports'}{'tcp'}{'689'}++	; 
#	$ports_ref->{'tcp'}{'689'}{'name'} = 'nmap'		; 
#	$srvcobjects_ref->{'webster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webster'}{'port'}{'udp'} = '765'	; 
#	$srvcobjects_ref->{'webster'}{'ports'}{'udp'}{'765'}++	; 
#	$ports_ref->{'udp'}{'765'}{'name'} = 'webster'		; 
#	$srvcobjects_ref->{'webster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webster'}{'port'}{'tcp'} = '765'	; 
#	$srvcobjects_ref->{'webster'}{'ports'}{'tcp'}{'765'}++	; 
#	$ports_ref->{'tcp'}{'765'}{'name'} = 'webster'		; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'port'}{'udp'} = '1272'	; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'ports'}{'udp'}{'1272'}++	; 
#	$ports_ref->{'udp'}{'1272'}{'name'} = 'cspmlockmgr'		; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'port'}{'tcp'} = '1272'	; 
#	$srvcobjects_ref->{'cspmlockmgr'}{'ports'}{'tcp'}{'1272'}++	; 
#	$ports_ref->{'tcp'}{'1272'}{'name'} = 'cspmlockmgr'		; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'port'}{'udp'} = '3715'	; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'ports'}{'udp'}{'3715'}++	; 
#	$ports_ref->{'udp'}{'3715'}{'name'} = 'anoto-rendezv'		; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'port'}{'tcp'} = '3715'	; 
#	$srvcobjects_ref->{'anoto-rendezv'}{'ports'}{'tcp'}{'3715'}++	; 
#	$ports_ref->{'tcp'}{'3715'}{'name'} = 'anoto-rendezv'		; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'port'}{'udp'} = '13822'	; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'ports'}{'udp'}{'13822'}++	; 
#	$ports_ref->{'udp'}{'13822'}{'name'} = 'dsmcc-ccp'		; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'port'}{'tcp'} = '13822'	; 
#	$srvcobjects_ref->{'dsmcc-ccp'}{'ports'}{'tcp'}{'13822'}++	; 
#	$ports_ref->{'tcp'}{'13822'}{'name'} = 'dsmcc-ccp'		; 
#	$srvcobjects_ref->{'cs-services'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cs-services'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-services'}{'port'}{'udp'} = '3631'	; 
#	$srvcobjects_ref->{'cs-services'}{'ports'}{'udp'}{'3631'}++	; 
#	$ports_ref->{'udp'}{'3631'}{'name'} = 'cs-services'		; 
#	$srvcobjects_ref->{'cs-services'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cs-services'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-services'}{'port'}{'tcp'} = '3631'	; 
#	$srvcobjects_ref->{'cs-services'}{'ports'}{'tcp'}{'3631'}++	; 
#	$ports_ref->{'tcp'}{'3631'}{'name'} = 'cs-services'		; 
#	$srvcobjects_ref->{'xingcsm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xingcsm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xingcsm'}{'port'}{'udp'} = '2327'	; 
#	$srvcobjects_ref->{'xingcsm'}{'ports'}{'udp'}{'2327'}++	; 
#	$ports_ref->{'udp'}{'2327'}{'name'} = 'xingcsm'		; 
#	$srvcobjects_ref->{'xingcsm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xingcsm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xingcsm'}{'port'}{'tcp'} = '2327'	; 
#	$srvcobjects_ref->{'xingcsm'}{'ports'}{'tcp'}{'2327'}++	; 
#	$ports_ref->{'tcp'}{'2327'}{'name'} = 'xingcsm'		; 
#	$srvcobjects_ref->{'xap-ha'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xap-ha'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xap-ha'}{'port'}{'udp'} = '3639'	; 
#	$srvcobjects_ref->{'xap-ha'}{'ports'}{'udp'}{'3639'}++	; 
#	$ports_ref->{'udp'}{'3639'}{'name'} = 'xap-ha'		; 
#	$srvcobjects_ref->{'xap-ha'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xap-ha'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xap-ha'}{'port'}{'tcp'} = '3639'	; 
#	$srvcobjects_ref->{'xap-ha'}{'ports'}{'tcp'}{'3639'}++	; 
#	$ports_ref->{'tcp'}{'3639'}{'name'} = 'xap-ha'		; 
#	$srvcobjects_ref->{'rtnt-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtnt-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtnt-1'}{'port'}{'udp'} = '3137'	; 
#	$srvcobjects_ref->{'rtnt-1'}{'ports'}{'udp'}{'3137'}++	; 
#	$ports_ref->{'udp'}{'3137'}{'name'} = 'rtnt-1'		; 
#	$srvcobjects_ref->{'rtnt-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtnt-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtnt-1'}{'port'}{'tcp'} = '3137'	; 
#	$srvcobjects_ref->{'rtnt-1'}{'ports'}{'tcp'}{'3137'}++	; 
#	$ports_ref->{'tcp'}{'3137'}{'name'} = 'rtnt-1'		; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'port'}{'udp'} = '541'	; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'ports'}{'udp'}{'541'}++	; 
#	$ports_ref->{'udp'}{'541'}{'name'} = 'uucp-rlogin'		; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'port'}{'tcp'} = '541'	; 
#	$srvcobjects_ref->{'uucp-rlogin'}{'ports'}{'tcp'}{'541'}++	; 
#	$ports_ref->{'tcp'}{'541'}{'name'} = 'uucp-rlogin'		; 
#	$srvcobjects_ref->{'ecp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ecp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecp'}{'port'}{'udp'} = '3134'	; 
#	$srvcobjects_ref->{'ecp'}{'ports'}{'udp'}{'3134'}++	; 
#	$ports_ref->{'udp'}{'3134'}{'name'} = 'ecp'		; 
#	$srvcobjects_ref->{'ecp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ecp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecp'}{'port'}{'tcp'} = '3134'	; 
#	$srvcobjects_ref->{'ecp'}{'ports'}{'tcp'}{'3134'}++	; 
#	$ports_ref->{'tcp'}{'3134'}{'name'} = 'ecp'		; 
#	$srvcobjects_ref->{'bullant-srap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bullant-srap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bullant-srap'}{'port'}{'udp'} = '2964'	; 
#	$srvcobjects_ref->{'bullant-srap'}{'ports'}{'udp'}{'2964'}++	; 
#	$ports_ref->{'udp'}{'2964'}{'name'} = 'bullant-srap'		; 
#	$srvcobjects_ref->{'bullant-srap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bullant-srap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bullant-srap'}{'port'}{'tcp'} = '2964'	; 
#	$srvcobjects_ref->{'bullant-srap'}{'ports'}{'tcp'}{'2964'}++	; 
#	$ports_ref->{'tcp'}{'2964'}{'name'} = 'bullant-srap'		; 
#	$srvcobjects_ref->{'rsc-robot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsc-robot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsc-robot'}{'port'}{'udp'} = '1793'	; 
#	$srvcobjects_ref->{'rsc-robot'}{'ports'}{'udp'}{'1793'}++	; 
#	$ports_ref->{'udp'}{'1793'}{'name'} = 'rsc-robot'		; 
#	$srvcobjects_ref->{'rsc-robot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsc-robot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsc-robot'}{'port'}{'tcp'} = '1793'	; 
#	$srvcobjects_ref->{'rsc-robot'}{'ports'}{'tcp'}{'1793'}++	; 
#	$ports_ref->{'tcp'}{'1793'}{'name'} = 'rsc-robot'		; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'port'}{'udp'} = '462'	; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'ports'}{'udp'}{'462'}++	; 
#	$ports_ref->{'udp'}{'462'}{'name'} = 'datasurfsrvsec'		; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'port'}{'tcp'} = '462'	; 
#	$srvcobjects_ref->{'datasurfsrvsec'}{'ports'}{'tcp'}{'462'}++	; 
#	$ports_ref->{'tcp'}{'462'}{'name'} = 'datasurfsrvsec'		; 
#	$srvcobjects_ref->{'ariel3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ariel3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariel3'}{'port'}{'udp'} = '422'	; 
#	$srvcobjects_ref->{'ariel3'}{'ports'}{'udp'}{'422'}++	; 
#	$ports_ref->{'udp'}{'422'}{'name'} = 'ariel3'		; 
#	$srvcobjects_ref->{'ariel3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ariel3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariel3'}{'port'}{'tcp'} = '422'	; 
#	$srvcobjects_ref->{'ariel3'}{'ports'}{'tcp'}{'422'}++	; 
#	$ports_ref->{'tcp'}{'422'}{'name'} = 'ariel3'		; 
#	$srvcobjects_ref->{'netserialext2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netserialext2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext2'}{'port'}{'udp'} = '16361'	; 
#	$srvcobjects_ref->{'netserialext2'}{'ports'}{'udp'}{'16361'}++	; 
#	$ports_ref->{'udp'}{'16361'}{'name'} = 'netserialext2'		; 
#	$srvcobjects_ref->{'netserialext2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netserialext2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext2'}{'port'}{'tcp'} = '16361'	; 
#	$srvcobjects_ref->{'netserialext2'}{'ports'}{'tcp'}{'16361'}++	; 
#	$ports_ref->{'tcp'}{'16361'}{'name'} = 'netserialext2'		; 
#	$srvcobjects_ref->{'rrisat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrisat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrisat'}{'port'}{'udp'} = '1697'	; 
#	$srvcobjects_ref->{'rrisat'}{'ports'}{'udp'}{'1697'}++	; 
#	$ports_ref->{'udp'}{'1697'}{'name'} = 'rrisat'		; 
#	$srvcobjects_ref->{'rrisat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrisat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrisat'}{'port'}{'tcp'} = '1697'	; 
#	$srvcobjects_ref->{'rrisat'}{'ports'}{'tcp'}{'1697'}++	; 
#	$ports_ref->{'tcp'}{'1697'}{'name'} = 'rrisat'		; 
#	$srvcobjects_ref->{'virtual-time'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'virtual-time'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtual-time'}{'port'}{'udp'} = '1852'	; 
#	$srvcobjects_ref->{'virtual-time'}{'ports'}{'udp'}{'1852'}++	; 
#	$ports_ref->{'udp'}{'1852'}{'name'} = 'virtual-time'		; 
#	$srvcobjects_ref->{'virtual-time'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'virtual-time'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtual-time'}{'port'}{'tcp'} = '1852'	; 
#	$srvcobjects_ref->{'virtual-time'}{'ports'}{'tcp'}{'1852'}++	; 
#	$ports_ref->{'tcp'}{'1852'}{'name'} = 'virtual-time'		; 
#	$srvcobjects_ref->{'ibm-db2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-db2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-db2'}{'port'}{'udp'} = '523'	; 
#	$srvcobjects_ref->{'ibm-db2'}{'ports'}{'udp'}{'523'}++	; 
#	$ports_ref->{'udp'}{'523'}{'name'} = 'ibm-db2'		; 
#	$srvcobjects_ref->{'ibm-db2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-db2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-db2'}{'port'}{'tcp'} = '523'	; 
#	$srvcobjects_ref->{'ibm-db2'}{'ports'}{'tcp'}{'523'}++	; 
#	$ports_ref->{'tcp'}{'523'}{'name'} = 'ibm-db2'		; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'port'}{'udp'} = '3569'	; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'ports'}{'udp'}{'3569'}++	; 
#	$ports_ref->{'udp'}{'3569'}{'name'} = 'mbg-ctrl'		; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'port'}{'tcp'} = '3569'	; 
#	$srvcobjects_ref->{'mbg-ctrl'}{'ports'}{'tcp'}{'3569'}++	; 
#	$ports_ref->{'tcp'}{'3569'}{'name'} = 'mbg-ctrl'		; 
#	$srvcobjects_ref->{'auris'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'auris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'auris'}{'port'}{'udp'} = '2772'	; 
#	$srvcobjects_ref->{'auris'}{'ports'}{'udp'}{'2772'}++	; 
#	$ports_ref->{'udp'}{'2772'}{'name'} = 'auris'		; 
#	$srvcobjects_ref->{'auris'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'auris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'auris'}{'port'}{'tcp'} = '2772'	; 
#	$srvcobjects_ref->{'auris'}{'ports'}{'tcp'}{'2772'}++	; 
#	$ports_ref->{'tcp'}{'2772'}{'name'} = 'auris'		; 
#	$srvcobjects_ref->{'qsnet-workst'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qsnet-workst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-workst'}{'port'}{'udp'} = '4355'	; 
#	$srvcobjects_ref->{'qsnet-workst'}{'ports'}{'udp'}{'4355'}++	; 
#	$ports_ref->{'udp'}{'4355'}{'name'} = 'qsnet-workst'		; 
#	$srvcobjects_ref->{'qsnet-workst'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qsnet-workst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-workst'}{'port'}{'tcp'} = '4355'	; 
#	$srvcobjects_ref->{'qsnet-workst'}{'ports'}{'tcp'}{'4355'}++	; 
#	$ports_ref->{'tcp'}{'4355'}{'name'} = 'qsnet-workst'		; 
#	$srvcobjects_ref->{'moldflow-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'moldflow-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'moldflow-lm'}{'port'}{'udp'} = '1576'	; 
#	$srvcobjects_ref->{'moldflow-lm'}{'ports'}{'udp'}{'1576'}++	; 
#	$ports_ref->{'udp'}{'1576'}{'name'} = 'moldflow-lm'		; 
#	$srvcobjects_ref->{'moldflow-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'moldflow-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'moldflow-lm'}{'port'}{'tcp'} = '1576'	; 
#	$srvcobjects_ref->{'moldflow-lm'}{'ports'}{'tcp'}{'1576'}++	; 
#	$ports_ref->{'tcp'}{'1576'}{'name'} = 'moldflow-lm'		; 
#	$srvcobjects_ref->{'creativeserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'creativeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativeserver'}{'port'}{'udp'} = '453'	; 
#	$srvcobjects_ref->{'creativeserver'}{'ports'}{'udp'}{'453'}++	; 
#	$ports_ref->{'udp'}{'453'}{'name'} = 'creativeserver'		; 
#	$srvcobjects_ref->{'creativeserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'creativeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativeserver'}{'port'}{'udp'} = '3364'	; 
#	$srvcobjects_ref->{'creativeserver'}{'ports'}{'udp'}{'3364'}++	; 
#	$ports_ref->{'udp'}{'3364'}{'name'} = 'creativeserver'		; 
#	$srvcobjects_ref->{'creativeserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'creativeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativeserver'}{'port'}{'tcp'} = '453'	; 
#	$srvcobjects_ref->{'creativeserver'}{'ports'}{'tcp'}{'453'}++	; 
#	$ports_ref->{'tcp'}{'453'}{'name'} = 'creativeserver'		; 
#	$srvcobjects_ref->{'creativeserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'creativeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativeserver'}{'port'}{'tcp'} = '3364'	; 
#	$srvcobjects_ref->{'creativeserver'}{'ports'}{'tcp'}{'3364'}++	; 
#	$ports_ref->{'tcp'}{'3364'}{'name'} = 'creativeserver'		; 
#	$srvcobjects_ref->{'atlinks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'atlinks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atlinks'}{'port'}{'udp'} = '4154'	; 
#	$srvcobjects_ref->{'atlinks'}{'ports'}{'udp'}{'4154'}++	; 
#	$ports_ref->{'udp'}{'4154'}{'name'} = 'atlinks'		; 
#	$srvcobjects_ref->{'atlinks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'atlinks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atlinks'}{'port'}{'tcp'} = '4154'	; 
#	$srvcobjects_ref->{'atlinks'}{'ports'}{'tcp'}{'4154'}++	; 
#	$ports_ref->{'tcp'}{'4154'}{'name'} = 'atlinks'		; 
#	$srvcobjects_ref->{'extensis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'extensis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'extensis'}{'port'}{'udp'} = '2666'	; 
#	$srvcobjects_ref->{'extensis'}{'ports'}{'udp'}{'2666'}++	; 
#	$ports_ref->{'udp'}{'2666'}{'name'} = 'extensis'		; 
#	$srvcobjects_ref->{'extensis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'extensis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'extensis'}{'port'}{'tcp'} = '2666'	; 
#	$srvcobjects_ref->{'extensis'}{'ports'}{'tcp'}{'2666'}++	; 
#	$ports_ref->{'tcp'}{'2666'}{'name'} = 'extensis'		; 
#	$srvcobjects_ref->{'sdhelp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdhelp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdhelp'}{'port'}{'udp'} = '2308'	; 
#	$srvcobjects_ref->{'sdhelp'}{'ports'}{'udp'}{'2308'}++	; 
#	$ports_ref->{'udp'}{'2308'}{'name'} = 'sdhelp'		; 
#	$srvcobjects_ref->{'sdhelp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdhelp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdhelp'}{'port'}{'tcp'} = '2308'	; 
#	$srvcobjects_ref->{'sdhelp'}{'ports'}{'tcp'}{'2308'}++	; 
#	$ports_ref->{'tcp'}{'2308'}{'name'} = 'sdhelp'		; 
#	$srvcobjects_ref->{'netrjs-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrjs-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-1'}{'port'}{'udp'} = '71'	; 
#	$srvcobjects_ref->{'netrjs-1'}{'ports'}{'udp'}{'71'}++	; 
#	$ports_ref->{'udp'}{'71'}{'name'} = 'netrjs-1'		; 
#	$srvcobjects_ref->{'netrjs-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrjs-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-1'}{'port'}{'tcp'} = '71'	; 
#	$srvcobjects_ref->{'netrjs-1'}{'ports'}{'tcp'}{'71'}++	; 
#	$ports_ref->{'tcp'}{'71'}{'name'} = 'netrjs-1'		; 
#	$srvcobjects_ref->{'dka'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dka'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dka'}{'port'}{'udp'} = '1263'	; 
#	$srvcobjects_ref->{'dka'}{'ports'}{'udp'}{'1263'}++	; 
#	$ports_ref->{'udp'}{'1263'}{'name'} = 'dka'		; 
#	$srvcobjects_ref->{'dka'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dka'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dka'}{'port'}{'tcp'} = '1263'	; 
#	$srvcobjects_ref->{'dka'}{'ports'}{'tcp'}{'1263'}++	; 
#	$ports_ref->{'tcp'}{'1263'}{'name'} = 'dka'		; 
#	$srvcobjects_ref->{'ewcappsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ewcappsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewcappsrv'}{'port'}{'udp'} = '1876'	; 
#	$srvcobjects_ref->{'ewcappsrv'}{'ports'}{'udp'}{'1876'}++	; 
#	$ports_ref->{'udp'}{'1876'}{'name'} = 'ewcappsrv'		; 
#	$srvcobjects_ref->{'ewcappsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ewcappsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewcappsrv'}{'port'}{'tcp'} = '1876'	; 
#	$srvcobjects_ref->{'ewcappsrv'}{'ports'}{'tcp'}{'1876'}++	; 
#	$ports_ref->{'tcp'}{'1876'}{'name'} = 'ewcappsrv'		; 
#	$srvcobjects_ref->{'cs-live'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cs-live'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-live'}{'port'}{'udp'} = '2129'	; 
#	$srvcobjects_ref->{'cs-live'}{'ports'}{'udp'}{'2129'}++	; 
#	$ports_ref->{'udp'}{'2129'}{'name'} = 'cs-live'		; 
#	$srvcobjects_ref->{'cs-live'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cs-live'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cs-live'}{'port'}{'tcp'} = '2129'	; 
#	$srvcobjects_ref->{'cs-live'}{'ports'}{'tcp'}{'2129'}++	; 
#	$ports_ref->{'tcp'}{'2129'}{'name'} = 'cs-live'		; 
#	$srvcobjects_ref->{'world-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'world-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'world-lm'}{'port'}{'udp'} = '1462'	; 
#	$srvcobjects_ref->{'world-lm'}{'ports'}{'udp'}{'1462'}++	; 
#	$ports_ref->{'udp'}{'1462'}{'name'} = 'world-lm'		; 
#	$srvcobjects_ref->{'world-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'world-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'world-lm'}{'port'}{'tcp'} = '1462'	; 
#	$srvcobjects_ref->{'world-lm'}{'ports'}{'tcp'}{'1462'}++	; 
#	$ports_ref->{'tcp'}{'1462'}{'name'} = 'world-lm'		; 
#	$srvcobjects_ref->{'mptn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mptn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mptn'}{'port'}{'udp'} = '397'	; 
#	$srvcobjects_ref->{'mptn'}{'ports'}{'udp'}{'397'}++	; 
#	$ports_ref->{'udp'}{'397'}{'name'} = 'mptn'		; 
#	$srvcobjects_ref->{'mptn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mptn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mptn'}{'port'}{'tcp'} = '397'	; 
#	$srvcobjects_ref->{'mptn'}{'ports'}{'tcp'}{'397'}++	; 
#	$ports_ref->{'tcp'}{'397'}{'name'} = 'mptn'		; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'port'}{'udp'} = '3650'	; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'ports'}{'udp'}{'3650'}++	; 
#	$ports_ref->{'udp'}{'3650'}{'name'} = 'prismiq-plugin'		; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'port'}{'tcp'} = '3650'	; 
#	$srvcobjects_ref->{'prismiq-plugin'}{'ports'}{'tcp'}{'3650'}++	; 
#	$ports_ref->{'tcp'}{'3650'}{'name'} = 'prismiq-plugin'		; 
#	$srvcobjects_ref->{'proxima-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proxima-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proxima-lm'}{'port'}{'udp'} = '1445'	; 
#	$srvcobjects_ref->{'proxima-lm'}{'ports'}{'udp'}{'1445'}++	; 
#	$ports_ref->{'udp'}{'1445'}{'name'} = 'proxima-lm'		; 
#	$srvcobjects_ref->{'proxima-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proxima-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proxima-lm'}{'port'}{'tcp'} = '1445'	; 
#	$srvcobjects_ref->{'proxima-lm'}{'ports'}{'tcp'}{'1445'}++	; 
#	$ports_ref->{'tcp'}{'1445'}{'name'} = 'proxima-lm'		; 
#	$srvcobjects_ref->{'ans-console'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ans-console'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ans-console'}{'port'}{'udp'} = '3440'	; 
#	$srvcobjects_ref->{'ans-console'}{'ports'}{'udp'}{'3440'}++	; 
#	$ports_ref->{'udp'}{'3440'}{'name'} = 'ans-console'		; 
#	$srvcobjects_ref->{'ans-console'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ans-console'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ans-console'}{'port'}{'tcp'} = '3440'	; 
#	$srvcobjects_ref->{'ans-console'}{'ports'}{'tcp'}{'3440'}++	; 
#	$ports_ref->{'tcp'}{'3440'}{'name'} = 'ans-console'		; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'port'}{'udp'} = '2476'	; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'ports'}{'udp'}{'2476'}++	; 
#	$ports_ref->{'udp'}{'2476'}{'name'} = 'ace-svr-prop'		; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'port'}{'tcp'} = '2476'	; 
#	$srvcobjects_ref->{'ace-svr-prop'}{'ports'}{'tcp'}{'2476'}++	; 
#	$ports_ref->{'tcp'}{'2476'}{'name'} = 'ace-svr-prop'		; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'port'}{'udp'} = '3468'	; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'ports'}{'udp'}{'3468'}++	; 
#	$ports_ref->{'udp'}{'3468'}{'name'} = 'ttcmremotectrl'		; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'port'}{'tcp'} = '3468'	; 
#	$srvcobjects_ref->{'ttcmremotectrl'}{'ports'}{'tcp'}{'3468'}++	; 
#	$ports_ref->{'tcp'}{'3468'}{'name'} = 'ttcmremotectrl'		; 
#	$srvcobjects_ref->{'slush'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slush'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slush'}{'port'}{'udp'} = '1966'	; 
#	$srvcobjects_ref->{'slush'}{'ports'}{'udp'}{'1966'}++	; 
#	$ports_ref->{'udp'}{'1966'}{'name'} = 'slush'		; 
#	$srvcobjects_ref->{'slush'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slush'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slush'}{'port'}{'tcp'} = '1966'	; 
#	$srvcobjects_ref->{'slush'}{'ports'}{'tcp'}{'1966'}++	; 
#	$ports_ref->{'tcp'}{'1966'}{'name'} = 'slush'		; 
#	$srvcobjects_ref->{'kiosk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kiosk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kiosk'}{'port'}{'udp'} = '1061'	; 
#	$srvcobjects_ref->{'kiosk'}{'ports'}{'udp'}{'1061'}++	; 
#	$ports_ref->{'udp'}{'1061'}{'name'} = 'kiosk'		; 
#	$srvcobjects_ref->{'kiosk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kiosk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kiosk'}{'port'}{'tcp'} = '1061'	; 
#	$srvcobjects_ref->{'kiosk'}{'ports'}{'tcp'}{'1061'}++	; 
#	$ports_ref->{'tcp'}{'1061'}{'name'} = 'kiosk'		; 
#	$srvcobjects_ref->{'nppmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nppmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nppmp'}{'port'}{'udp'} = '3476'	; 
#	$srvcobjects_ref->{'nppmp'}{'ports'}{'udp'}{'3476'}++	; 
#	$ports_ref->{'udp'}{'3476'}{'name'} = 'nppmp'		; 
#	$srvcobjects_ref->{'nppmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nppmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nppmp'}{'port'}{'tcp'} = '3476'	; 
#	$srvcobjects_ref->{'nppmp'}{'ports'}{'tcp'}{'3476'}++	; 
#	$ports_ref->{'tcp'}{'3476'}{'name'} = 'nppmp'		; 
#	$srvcobjects_ref->{'tip-app-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tip-app-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tip-app-server'}{'port'}{'udp'} = '3160'	; 
#	$srvcobjects_ref->{'tip-app-server'}{'ports'}{'udp'}{'3160'}++	; 
#	$ports_ref->{'udp'}{'3160'}{'name'} = 'tip-app-server'		; 
#	$srvcobjects_ref->{'tip-app-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tip-app-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tip-app-server'}{'port'}{'tcp'} = '3160'	; 
#	$srvcobjects_ref->{'tip-app-server'}{'ports'}{'tcp'}{'3160'}++	; 
#	$ports_ref->{'tcp'}{'3160'}{'name'} = 'tip-app-server'		; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'port'}{'udp'} = '3208'	; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'ports'}{'udp'}{'3208'}++	; 
#	$ports_ref->{'udp'}{'3208'}{'name'} = 'pfu-prcallback'		; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'port'}{'tcp'} = '3208'	; 
#	$srvcobjects_ref->{'pfu-prcallback'}{'ports'}{'tcp'}{'3208'}++	; 
#	$ports_ref->{'tcp'}{'3208'}{'name'} = 'pfu-prcallback'		; 
#	$srvcobjects_ref->{'ddi-udp-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddi-udp-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-udp-4'}{'port'}{'udp'} = '8891'	; 
#	$srvcobjects_ref->{'ddi-udp-4'}{'ports'}{'udp'}{'8891'}++	; 
#	$ports_ref->{'udp'}{'8891'}{'name'} = 'ddi-udp-4'		; 
#	$srvcobjects_ref->{'starquiz-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'starquiz-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'starquiz-port'}{'port'}{'udp'} = '3526'	; 
#	$srvcobjects_ref->{'starquiz-port'}{'ports'}{'udp'}{'3526'}++	; 
#	$ports_ref->{'udp'}{'3526'}{'name'} = 'starquiz-port'		; 
#	$srvcobjects_ref->{'starquiz-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'starquiz-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'starquiz-port'}{'port'}{'tcp'} = '3526'	; 
#	$srvcobjects_ref->{'starquiz-port'}{'ports'}{'tcp'}{'3526'}++	; 
#	$ports_ref->{'tcp'}{'3526'}{'name'} = 'starquiz-port'		; 
#	$srvcobjects_ref->{'smtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smtp'}{'port'}{'udp'} = '25'	; 
#	$srvcobjects_ref->{'smtp'}{'ports'}{'udp'}{'25'}++	; 
#	$ports_ref->{'udp'}{'25'}{'name'} = 'smtp'		; 
#	$srvcobjects_ref->{'smtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smtp'}{'port'}{'tcp'} = '25'	; 
#	$srvcobjects_ref->{'smtp'}{'ports'}{'tcp'}{'25'}++	; 
#	$ports_ref->{'tcp'}{'25'}{'name'} = 'smtp'		; 
#	$srvcobjects_ref->{'ocbinder'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ocbinder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocbinder'}{'port'}{'udp'} = '183'	; 
#	$srvcobjects_ref->{'ocbinder'}{'ports'}{'udp'}{'183'}++	; 
#	$ports_ref->{'udp'}{'183'}{'name'} = 'ocbinder'		; 
#	$srvcobjects_ref->{'ocbinder'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ocbinder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocbinder'}{'port'}{'tcp'} = '183'	; 
#	$srvcobjects_ref->{'ocbinder'}{'ports'}{'tcp'}{'183'}++	; 
#	$ports_ref->{'tcp'}{'183'}{'name'} = 'ocbinder'		; 
#	$srvcobjects_ref->{'ping-pong'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ping-pong'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ping-pong'}{'port'}{'udp'} = '3010'	; 
#	$srvcobjects_ref->{'ping-pong'}{'ports'}{'udp'}{'3010'}++	; 
#	$ports_ref->{'udp'}{'3010'}{'name'} = 'ping-pong'		; 
#	$srvcobjects_ref->{'clp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'clp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clp'}{'port'}{'udp'} = '2567'	; 
#	$srvcobjects_ref->{'clp'}{'ports'}{'udp'}{'2567'}++	; 
#	$ports_ref->{'udp'}{'2567'}{'name'} = 'clp'		; 
#	$srvcobjects_ref->{'clp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'clp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clp'}{'port'}{'tcp'} = '2567'	; 
#	$srvcobjects_ref->{'clp'}{'ports'}{'tcp'}{'2567'}++	; 
#	$ports_ref->{'tcp'}{'2567'}{'name'} = 'clp'		; 
#	$srvcobjects_ref->{'bgmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bgmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bgmp'}{'port'}{'udp'} = '264'	; 
#	$srvcobjects_ref->{'bgmp'}{'ports'}{'udp'}{'264'}++	; 
#	$ports_ref->{'udp'}{'264'}{'name'} = 'bgmp'		; 
#	$srvcobjects_ref->{'bgmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bgmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bgmp'}{'port'}{'tcp'} = '264'	; 
#	$srvcobjects_ref->{'bgmp'}{'ports'}{'tcp'}{'264'}++	; 
#	$ports_ref->{'tcp'}{'264'}{'name'} = 'bgmp'		; 
#	$srvcobjects_ref->{'ivs-video'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ivs-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivs-video'}{'port'}{'udp'} = '2232'	; 
#	$srvcobjects_ref->{'ivs-video'}{'ports'}{'udp'}{'2232'}++	; 
#	$ports_ref->{'udp'}{'2232'}{'name'} = 'ivs-video'		; 
#	$srvcobjects_ref->{'ivs-video'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ivs-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivs-video'}{'port'}{'tcp'} = '2232'	; 
#	$srvcobjects_ref->{'ivs-video'}{'ports'}{'tcp'}{'2232'}++	; 
#	$ports_ref->{'tcp'}{'2232'}{'name'} = 'ivs-video'		; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'port'}{'udp'} = '2101'	; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'ports'}{'udp'}{'2101'}++	; 
#	$ports_ref->{'udp'}{'2101'}{'name'} = 'rtcm-sc104'		; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'port'}{'tcp'} = '2101'	; 
#	$srvcobjects_ref->{'rtcm-sc104'}{'ports'}{'tcp'}{'2101'}++	; 
#	$ports_ref->{'tcp'}{'2101'}{'name'} = 'rtcm-sc104'		; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'port'}{'udp'} = '2074'	; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'ports'}{'udp'}{'2074'}++	; 
#	$ports_ref->{'udp'}{'2074'}{'name'} = 'vrtl-vmf-sa'		; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'port'}{'tcp'} = '2074'	; 
#	$srvcobjects_ref->{'vrtl-vmf-sa'}{'ports'}{'tcp'}{'2074'}++	; 
#	$ports_ref->{'tcp'}{'2074'}{'name'} = 'vrtl-vmf-sa'		; 
#	$srvcobjects_ref->{'sftsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sftsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftsrv'}{'port'}{'udp'} = '1303'	; 
#	$srvcobjects_ref->{'sftsrv'}{'ports'}{'udp'}{'1303'}++	; 
#	$ports_ref->{'udp'}{'1303'}{'name'} = 'sftsrv'		; 
#	$srvcobjects_ref->{'sftsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sftsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftsrv'}{'port'}{'tcp'} = '1303'	; 
#	$srvcobjects_ref->{'sftsrv'}{'ports'}{'tcp'}{'1303'}++	; 
#	$ports_ref->{'tcp'}{'1303'}{'name'} = 'sftsrv'		; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'port'}{'udp'} = '3347'	; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'ports'}{'udp'}{'3347'}++	; 
#	$ports_ref->{'udp'}{'3347'}{'name'} = 'phoenix-rpc'		; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'port'}{'tcp'} = '3347'	; 
#	$srvcobjects_ref->{'phoenix-rpc'}{'ports'}{'tcp'}{'3347'}++	; 
#	$ports_ref->{'tcp'}{'3347'}{'name'} = 'phoenix-rpc'		; 
#	$srvcobjects_ref->{'simp-all'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simp-all'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simp-all'}{'port'}{'udp'} = '1959'	; 
#	$srvcobjects_ref->{'simp-all'}{'ports'}{'udp'}{'1959'}++	; 
#	$ports_ref->{'udp'}{'1959'}{'name'} = 'simp-all'		; 
#	$srvcobjects_ref->{'simp-all'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simp-all'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simp-all'}{'port'}{'tcp'} = '1959'	; 
#	$srvcobjects_ref->{'simp-all'}{'ports'}{'tcp'}{'1959'}++	; 
#	$ports_ref->{'tcp'}{'1959'}{'name'} = 'simp-all'		; 
#	$srvcobjects_ref->{'ircs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ircs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ircs'}{'port'}{'udp'} = '994'	; 
#	$srvcobjects_ref->{'ircs'}{'ports'}{'udp'}{'994'}++	; 
#	$ports_ref->{'udp'}{'994'}{'name'} = 'ircs'		; 
#	$srvcobjects_ref->{'ircs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ircs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ircs'}{'port'}{'tcp'} = '994'	; 
#	$srvcobjects_ref->{'ircs'}{'ports'}{'tcp'}{'994'}++	; 
#	$ports_ref->{'tcp'}{'994'}{'name'} = 'ircs'		; 
#	$srvcobjects_ref->{'mc3ss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mc3ss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc3ss'}{'port'}{'udp'} = '3521'	; 
#	$srvcobjects_ref->{'mc3ss'}{'ports'}{'udp'}{'3521'}++	; 
#	$ports_ref->{'udp'}{'3521'}{'name'} = 'mc3ss'		; 
#	$srvcobjects_ref->{'mc3ss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mc3ss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc3ss'}{'port'}{'tcp'} = '3521'	; 
#	$srvcobjects_ref->{'mc3ss'}{'ports'}{'tcp'}{'3521'}++	; 
#	$ports_ref->{'tcp'}{'3521'}{'name'} = 'mc3ss'		; 
#	$srvcobjects_ref->{'v-one-spp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'v-one-spp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'v-one-spp'}{'port'}{'udp'} = '3845'	; 
#	$srvcobjects_ref->{'v-one-spp'}{'ports'}{'udp'}{'3845'}++	; 
#	$ports_ref->{'udp'}{'3845'}{'name'} = 'v-one-spp'		; 
#	$srvcobjects_ref->{'v-one-spp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'v-one-spp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'v-one-spp'}{'port'}{'tcp'} = '3845'	; 
#	$srvcobjects_ref->{'v-one-spp'}{'ports'}{'tcp'}{'3845'}++	; 
#	$ports_ref->{'tcp'}{'3845'}{'name'} = 'v-one-spp'		; 
#	$srvcobjects_ref->{'galileolog'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'galileolog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'galileolog'}{'port'}{'udp'} = '3520'	; 
#	$srvcobjects_ref->{'galileolog'}{'ports'}{'udp'}{'3520'}++	; 
#	$ports_ref->{'udp'}{'3520'}{'name'} = 'galileolog'		; 
#	$srvcobjects_ref->{'galileolog'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'galileolog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'galileolog'}{'port'}{'tcp'} = '3520'	; 
#	$srvcobjects_ref->{'galileolog'}{'ports'}{'tcp'}{'3520'}++	; 
#	$ports_ref->{'tcp'}{'3520'}{'name'} = 'galileolog'		; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'port'}{'udp'} = '3405'	; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'ports'}{'udp'}{'3405'}++	; 
#	$ports_ref->{'udp'}{'3405'}{'name'} = 'nokia-ann-ch1'		; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'port'}{'tcp'} = '3405'	; 
#	$srvcobjects_ref->{'nokia-ann-ch1'}{'ports'}{'tcp'}{'3405'}++	; 
#	$ports_ref->{'tcp'}{'3405'}{'name'} = 'nokia-ann-ch1'		; 
#	$srvcobjects_ref->{'kme-trap-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kme-trap-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kme-trap-port'}{'port'}{'udp'} = '2081'	; 
#	$srvcobjects_ref->{'kme-trap-port'}{'ports'}{'udp'}{'2081'}++	; 
#	$ports_ref->{'udp'}{'2081'}{'name'} = 'kme-trap-port'		; 
#	$srvcobjects_ref->{'kme-trap-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kme-trap-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kme-trap-port'}{'port'}{'tcp'} = '2081'	; 
#	$srvcobjects_ref->{'kme-trap-port'}{'ports'}{'tcp'}{'2081'}++	; 
#	$ports_ref->{'tcp'}{'2081'}{'name'} = 'kme-trap-port'		; 
#	$srvcobjects_ref->{'avian'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avian'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avian'}{'port'}{'udp'} = '486'	; 
#	$srvcobjects_ref->{'avian'}{'ports'}{'udp'}{'486'}++	; 
#	$ports_ref->{'udp'}{'486'}{'name'} = 'avian'		; 
#	$srvcobjects_ref->{'avian'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avian'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avian'}{'port'}{'tcp'} = '486'	; 
#	$srvcobjects_ref->{'avian'}{'ports'}{'tcp'}{'486'}++	; 
#	$ports_ref->{'tcp'}{'486'}{'name'} = 'avian'		; 
#	$srvcobjects_ref->{'digital-notary'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'digital-notary'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digital-notary'}{'port'}{'udp'} = '1335'	; 
#	$srvcobjects_ref->{'digital-notary'}{'ports'}{'udp'}{'1335'}++	; 
#	$ports_ref->{'udp'}{'1335'}{'name'} = 'digital-notary'		; 
#	$srvcobjects_ref->{'digital-notary'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'digital-notary'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digital-notary'}{'port'}{'tcp'} = '1335'	; 
#	$srvcobjects_ref->{'digital-notary'}{'ports'}{'tcp'}{'1335'}++	; 
#	$ports_ref->{'tcp'}{'1335'}{'name'} = 'digital-notary'		; 
#	$srvcobjects_ref->{'kpasswd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kpasswd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kpasswd'}{'port'}{'udp'} = '464'	; 
#	$srvcobjects_ref->{'kpasswd'}{'ports'}{'udp'}{'464'}++	; 
#	$ports_ref->{'udp'}{'464'}{'name'} = 'kpasswd'		; 
#	$srvcobjects_ref->{'kpasswd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kpasswd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kpasswd'}{'port'}{'tcp'} = '464'	; 
#	$srvcobjects_ref->{'kpasswd'}{'ports'}{'tcp'}{'464'}++	; 
#	$ports_ref->{'tcp'}{'464'}{'name'} = 'kpasswd'		; 
#	$srvcobjects_ref->{'ccs-software'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ccs-software'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccs-software'}{'port'}{'udp'} = '2734'	; 
#	$srvcobjects_ref->{'ccs-software'}{'ports'}{'udp'}{'2734'}++	; 
#	$ports_ref->{'udp'}{'2734'}{'name'} = 'ccs-software'		; 
#	$srvcobjects_ref->{'ccs-software'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ccs-software'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccs-software'}{'port'}{'tcp'} = '2734'	; 
#	$srvcobjects_ref->{'ccs-software'}{'ports'}{'tcp'}{'2734'}++	; 
#	$ports_ref->{'tcp'}{'2734'}{'name'} = 'ccs-software'		; 
#	$srvcobjects_ref->{'vs-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vs-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vs-server'}{'port'}{'udp'} = '3280'	; 
#	$srvcobjects_ref->{'vs-server'}{'ports'}{'udp'}{'3280'}++	; 
#	$ports_ref->{'udp'}{'3280'}{'name'} = 'vs-server'		; 
#	$srvcobjects_ref->{'vs-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vs-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vs-server'}{'port'}{'tcp'} = '3280'	; 
#	$srvcobjects_ref->{'vs-server'}{'ports'}{'tcp'}{'3280'}++	; 
#	$ports_ref->{'tcp'}{'3280'}{'name'} = 'vs-server'		; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'port'}{'udp'} = '3094'	; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'ports'}{'udp'}{'3094'}++	; 
#	$ports_ref->{'udp'}{'3094'}{'name'} = 'rapidmq-reg'		; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'port'}{'tcp'} = '3094'	; 
#	$srvcobjects_ref->{'rapidmq-reg'}{'ports'}{'tcp'}{'3094'}++	; 
#	$ports_ref->{'tcp'}{'3094'}{'name'} = 'rapidmq-reg'		; 
#	$srvcobjects_ref->{'websm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'websm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'websm'}{'port'}{'udp'} = '9090'	; 
#	$srvcobjects_ref->{'websm'}{'ports'}{'udp'}{'9090'}++	; 
#	$ports_ref->{'udp'}{'9090'}{'name'} = 'websm'		; 
#	$srvcobjects_ref->{'websm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'websm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'websm'}{'port'}{'tcp'} = '9090'	; 
#	$srvcobjects_ref->{'websm'}{'ports'}{'tcp'}{'9090'}++	; 
#	$ports_ref->{'tcp'}{'9090'}{'name'} = 'websm'		; 
#	$srvcobjects_ref->{'cognima'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cognima'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cognima'}{'port'}{'udp'} = '3779'	; 
#	$srvcobjects_ref->{'cognima'}{'ports'}{'udp'}{'3779'}++	; 
#	$ports_ref->{'udp'}{'3779'}{'name'} = 'cognima'		; 
#	$srvcobjects_ref->{'cognima'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cognima'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cognima'}{'port'}{'tcp'} = '3779'	; 
#	$srvcobjects_ref->{'cognima'}{'ports'}{'tcp'}{'3779'}++	; 
#	$ports_ref->{'tcp'}{'3779'}{'name'} = 'cognima'		; 
#	$srvcobjects_ref->{'ipulse-ics'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipulse-ics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipulse-ics'}{'port'}{'udp'} = '20222'	; 
#	$srvcobjects_ref->{'ipulse-ics'}{'ports'}{'udp'}{'20222'}++	; 
#	$ports_ref->{'udp'}{'20222'}{'name'} = 'ipulse-ics'		; 
#	$srvcobjects_ref->{'ipulse-ics'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipulse-ics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipulse-ics'}{'port'}{'tcp'} = '20222'	; 
#	$srvcobjects_ref->{'ipulse-ics'}{'ports'}{'tcp'}{'20222'}++	; 
#	$ports_ref->{'tcp'}{'20222'}{'name'} = 'ipulse-ics'		; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'port'}{'udp'} = '3750'	; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'ports'}{'udp'}{'3750'}++	; 
#	$ports_ref->{'udp'}{'3750'}{'name'} = 'cbos-ip-port'		; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'port'}{'tcp'} = '3750'	; 
#	$srvcobjects_ref->{'cbos-ip-port'}{'ports'}{'tcp'}{'3750'}++	; 
#	$ports_ref->{'tcp'}{'3750'}{'name'} = 'cbos-ip-port'		; 
#	$srvcobjects_ref->{'raven1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raven1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven1'}{'port'}{'udp'} = '2713'	; 
#	$srvcobjects_ref->{'raven1'}{'ports'}{'udp'}{'2713'}++	; 
#	$ports_ref->{'udp'}{'2713'}{'name'} = 'raven1'		; 
#	$srvcobjects_ref->{'raven1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raven1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven1'}{'port'}{'tcp'} = '2713'	; 
#	$srvcobjects_ref->{'raven1'}{'ports'}{'tcp'}{'2713'}++	; 
#	$ports_ref->{'tcp'}{'2713'}{'name'} = 'raven1'		; 
#	$srvcobjects_ref->{'config-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'config-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'config-port'}{'port'}{'udp'} = '3577'	; 
#	$srvcobjects_ref->{'config-port'}{'ports'}{'udp'}{'3577'}++	; 
#	$ports_ref->{'udp'}{'3577'}{'name'} = 'config-port'		; 
#	$srvcobjects_ref->{'config-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'config-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'config-port'}{'port'}{'tcp'} = '3577'	; 
#	$srvcobjects_ref->{'config-port'}{'ports'}{'tcp'}{'3577'}++	; 
#	$ports_ref->{'tcp'}{'3577'}{'name'} = 'config-port'		; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'port'}{'udp'} = '2697'	; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'ports'}{'udp'}{'2697'}++	; 
#	$ports_ref->{'udp'}{'2697'}{'name'} = 'oce-snmp-trap'		; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'port'}{'tcp'} = '2697'	; 
#	$srvcobjects_ref->{'oce-snmp-trap'}{'ports'}{'tcp'}{'2697'}++	; 
#	$ports_ref->{'tcp'}{'2697'}{'name'} = 'oce-snmp-trap'		; 
#	$srvcobjects_ref->{'srvc_registry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'srvc_registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srvc_registry'}{'port'}{'udp'} = '3018'	; 
#	$srvcobjects_ref->{'srvc_registry'}{'ports'}{'udp'}{'3018'}++	; 
#	$ports_ref->{'udp'}{'3018'}{'name'} = 'srvc_registry'		; 
#	$srvcobjects_ref->{'srvc_registry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'srvc_registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srvc_registry'}{'port'}{'tcp'} = '3018'	; 
#	$srvcobjects_ref->{'srvc_registry'}{'ports'}{'tcp'}{'3018'}++	; 
#	$ports_ref->{'tcp'}{'3018'}{'name'} = 'srvc_registry'		; 
#	$srvcobjects_ref->{'issd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'issd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'issd'}{'port'}{'udp'} = '1600'	; 
#	$srvcobjects_ref->{'issd'}{'ports'}{'udp'}{'1600'}++	; 
#	$ports_ref->{'udp'}{'1600'}{'name'} = 'issd'		; 
#	$srvcobjects_ref->{'issd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'issd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'issd'}{'port'}{'tcp'} = '1600'	; 
#	$srvcobjects_ref->{'issd'}{'ports'}{'tcp'}{'1600'}++	; 
#	$ports_ref->{'tcp'}{'1600'}{'name'} = 'issd'		; 
#	$srvcobjects_ref->{'voispeed-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'voispeed-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'voispeed-port'}{'port'}{'udp'} = '3541'	; 
#	$srvcobjects_ref->{'voispeed-port'}{'ports'}{'udp'}{'3541'}++	; 
#	$ports_ref->{'udp'}{'3541'}{'name'} = 'voispeed-port'		; 
#	$srvcobjects_ref->{'voispeed-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'voispeed-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'voispeed-port'}{'port'}{'tcp'} = '3541'	; 
#	$srvcobjects_ref->{'voispeed-port'}{'ports'}{'tcp'}{'3541'}++	; 
#	$ports_ref->{'tcp'}{'3541'}{'name'} = 'voispeed-port'		; 
#	$srvcobjects_ref->{'ci3-software-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ci3-software-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ci3-software-2'}{'port'}{'udp'} = '1302'	; 
#	$srvcobjects_ref->{'ci3-software-2'}{'ports'}{'udp'}{'1302'}++	; 
#	$ports_ref->{'udp'}{'1302'}{'name'} = 'ci3-software-2'		; 
#	$srvcobjects_ref->{'ci3-software-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ci3-software-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ci3-software-2'}{'port'}{'tcp'} = '1302'	; 
#	$srvcobjects_ref->{'ci3-software-2'}{'ports'}{'tcp'}{'1302'}++	; 
#	$ports_ref->{'tcp'}{'1302'}{'name'} = 'ci3-software-2'		; 
#	$srvcobjects_ref->{'livelan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'livelan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'livelan'}{'port'}{'udp'} = '1555'	; 
#	$srvcobjects_ref->{'livelan'}{'ports'}{'udp'}{'1555'}++	; 
#	$ports_ref->{'udp'}{'1555'}{'name'} = 'livelan'		; 
#	$srvcobjects_ref->{'livelan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'livelan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'livelan'}{'port'}{'tcp'} = '1555'	; 
#	$srvcobjects_ref->{'livelan'}{'ports'}{'tcp'}{'1555'}++	; 
#	$ports_ref->{'tcp'}{'1555'}{'name'} = 'livelan'		; 
#	$srvcobjects_ref->{'ncp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncp'}{'port'}{'udp'} = '524'	; 
#	$srvcobjects_ref->{'ncp'}{'ports'}{'udp'}{'524'}++	; 
#	$ports_ref->{'udp'}{'524'}{'name'} = 'ncp'		; 
#	$srvcobjects_ref->{'ncp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncp'}{'port'}{'tcp'} = '524'	; 
#	$srvcobjects_ref->{'ncp'}{'ports'}{'tcp'}{'524'}++	; 
#	$ports_ref->{'tcp'}{'524'}{'name'} = 'ncp'		; 
#	$srvcobjects_ref->{'nlogin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nlogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nlogin'}{'port'}{'udp'} = '758'	; 
#	$srvcobjects_ref->{'nlogin'}{'ports'}{'udp'}{'758'}++	; 
#	$ports_ref->{'udp'}{'758'}{'name'} = 'nlogin'		; 
#	$srvcobjects_ref->{'nlogin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nlogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nlogin'}{'port'}{'tcp'} = '758'	; 
#	$srvcobjects_ref->{'nlogin'}{'ports'}{'tcp'}{'758'}++	; 
#	$ports_ref->{'tcp'}{'758'}{'name'} = 'nlogin'		; 
#	$srvcobjects_ref->{'at-8'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-8'}{'port'}{'udp'} = '208'	; 
#	$srvcobjects_ref->{'at-8'}{'ports'}{'udp'}{'208'}++	; 
#	$ports_ref->{'udp'}{'208'}{'name'} = 'at-8'		; 
#	$srvcobjects_ref->{'at-8'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-8'}{'port'}{'tcp'} = '208'	; 
#	$srvcobjects_ref->{'at-8'}{'ports'}{'tcp'}{'208'}++	; 
#	$ports_ref->{'tcp'}{'208'}{'name'} = 'at-8'		; 
#	$srvcobjects_ref->{'crip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'crip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crip'}{'port'}{'udp'} = '6253'	; 
#	$srvcobjects_ref->{'crip'}{'ports'}{'udp'}{'6253'}++	; 
#	$ports_ref->{'udp'}{'6253'}{'name'} = 'crip'		; 
#	$srvcobjects_ref->{'crip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'crip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crip'}{'port'}{'tcp'} = '6253'	; 
#	$srvcobjects_ref->{'crip'}{'ports'}{'tcp'}{'6253'}++	; 
#	$ports_ref->{'tcp'}{'6253'}{'name'} = 'crip'		; 
#	$srvcobjects_ref->{'hippad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hippad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hippad'}{'port'}{'udp'} = '2988'	; 
#	$srvcobjects_ref->{'hippad'}{'ports'}{'udp'}{'2988'}++	; 
#	$ports_ref->{'udp'}{'2988'}{'name'} = 'hippad'		; 
#	$srvcobjects_ref->{'hippad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hippad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hippad'}{'port'}{'tcp'} = '2988'	; 
#	$srvcobjects_ref->{'hippad'}{'ports'}{'tcp'}{'2988'}++	; 
#	$ports_ref->{'tcp'}{'2988'}{'name'} = 'hippad'		; 
#	$srvcobjects_ref->{'dtp-dia'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dtp-dia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtp-dia'}{'port'}{'udp'} = '3489'	; 
#	$srvcobjects_ref->{'dtp-dia'}{'ports'}{'udp'}{'3489'}++	; 
#	$ports_ref->{'udp'}{'3489'}{'name'} = 'dtp-dia'		; 
#	$srvcobjects_ref->{'dtp-dia'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dtp-dia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtp-dia'}{'port'}{'tcp'} = '3489'	; 
#	$srvcobjects_ref->{'dtp-dia'}{'ports'}{'tcp'}{'3489'}++	; 
#	$ports_ref->{'tcp'}{'3489'}{'name'} = 'dtp-dia'		; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'port'}{'udp'} = '9899'	; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'ports'}{'udp'}{'9899'}++	; 
#	$ports_ref->{'udp'}{'9899'}{'name'} = 'sctp-tunneling'		; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'port'}{'tcp'} = '9899'	; 
#	$srvcobjects_ref->{'sctp-tunneling'}{'ports'}{'tcp'}{'9899'}++	; 
#	$ports_ref->{'tcp'}{'9899'}{'name'} = 'sctp-tunneling'		; 
#	$srvcobjects_ref->{'pcle-infex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcle-infex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcle-infex'}{'port'}{'udp'} = '3189'	; 
#	$srvcobjects_ref->{'pcle-infex'}{'ports'}{'udp'}{'3189'}++	; 
#	$ports_ref->{'udp'}{'3189'}{'name'} = 'pcle-infex'		; 
#	$srvcobjects_ref->{'pcle-infex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcle-infex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcle-infex'}{'port'}{'tcp'} = '3189'	; 
#	$srvcobjects_ref->{'pcle-infex'}{'ports'}{'tcp'}{'3189'}++	; 
#	$ports_ref->{'tcp'}{'3189'}{'name'} = 'pcle-infex'		; 
#	$srvcobjects_ref->{'aws-brf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aws-brf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aws-brf'}{'port'}{'udp'} = '22800'	; 
#	$srvcobjects_ref->{'aws-brf'}{'ports'}{'udp'}{'22800'}++	; 
#	$ports_ref->{'udp'}{'22800'}{'name'} = 'aws-brf'		; 
#	$srvcobjects_ref->{'aws-brf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aws-brf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aws-brf'}{'port'}{'tcp'} = '22800'	; 
#	$srvcobjects_ref->{'aws-brf'}{'ports'}{'tcp'}{'22800'}++	; 
#	$ports_ref->{'tcp'}{'22800'}{'name'} = 'aws-brf'		; 
#	$srvcobjects_ref->{'bears-02'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bears-02'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bears-02'}{'port'}{'udp'} = '3146'	; 
#	$srvcobjects_ref->{'bears-02'}{'ports'}{'udp'}{'3146'}++	; 
#	$ports_ref->{'udp'}{'3146'}{'name'} = 'bears-02'		; 
#	$srvcobjects_ref->{'bears-02'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bears-02'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bears-02'}{'port'}{'tcp'} = '3146'	; 
#	$srvcobjects_ref->{'bears-02'}{'ports'}{'tcp'}{'3146'}++	; 
#	$ports_ref->{'tcp'}{'3146'}{'name'} = 'bears-02'		; 
#	$srvcobjects_ref->{'down'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'down'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'down'}{'port'}{'tcp'} = '2022'	; 
#	$srvcobjects_ref->{'down'}{'ports'}{'tcp'}{'2022'}++	; 
#	$ports_ref->{'tcp'}{'2022'}{'name'} = 'down'		; 
#	$srvcobjects_ref->{'about'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'about'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'about'}{'port'}{'udp'} = '2019'	; 
#	$srvcobjects_ref->{'about'}{'ports'}{'udp'}{'2019'}++	; 
#	$ports_ref->{'udp'}{'2019'}{'name'} = 'about'		; 
#	$srvcobjects_ref->{'lhtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lhtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lhtp'}{'port'}{'udp'} = '1983'	; 
#	$srvcobjects_ref->{'lhtp'}{'ports'}{'udp'}{'1983'}++	; 
#	$ports_ref->{'udp'}{'1983'}{'name'} = 'lhtp'		; 
#	$srvcobjects_ref->{'lhtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lhtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lhtp'}{'port'}{'tcp'} = '1983'	; 
#	$srvcobjects_ref->{'lhtp'}{'ports'}{'tcp'}{'1983'}++	; 
#	$ports_ref->{'tcp'}{'1983'}{'name'} = 'lhtp'		; 
#	$srvcobjects_ref->{'brvread'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'brvread'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brvread'}{'port'}{'udp'} = '1054'	; 
#	$srvcobjects_ref->{'brvread'}{'ports'}{'udp'}{'1054'}++	; 
#	$ports_ref->{'udp'}{'1054'}{'name'} = 'brvread'		; 
#	$srvcobjects_ref->{'brvread'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'brvread'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brvread'}{'port'}{'tcp'} = '1054'	; 
#	$srvcobjects_ref->{'brvread'}{'ports'}{'tcp'}{'1054'}++	; 
#	$ports_ref->{'tcp'}{'1054'}{'name'} = 'brvread'		; 
#	$srvcobjects_ref->{'webphone'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webphone'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webphone'}{'port'}{'udp'} = '21845'	; 
#	$srvcobjects_ref->{'webphone'}{'ports'}{'udp'}{'21845'}++	; 
#	$ports_ref->{'udp'}{'21845'}{'name'} = 'webphone'		; 
#	$srvcobjects_ref->{'webphone'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webphone'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webphone'}{'port'}{'tcp'} = '21845'	; 
#	$srvcobjects_ref->{'webphone'}{'ports'}{'tcp'}{'21845'}++	; 
#	$ports_ref->{'tcp'}{'21845'}{'name'} = 'webphone'		; 
#	$srvcobjects_ref->{'at-7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-7'}{'port'}{'udp'} = '207'	; 
#	$srvcobjects_ref->{'at-7'}{'ports'}{'udp'}{'207'}++	; 
#	$ports_ref->{'udp'}{'207'}{'name'} = 'at-7'		; 
#	$srvcobjects_ref->{'at-7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-7'}{'port'}{'tcp'} = '207'	; 
#	$srvcobjects_ref->{'at-7'}{'ports'}{'tcp'}{'207'}++	; 
#	$ports_ref->{'tcp'}{'207'}{'name'} = 'at-7'		; 
#	$srvcobjects_ref->{'gss-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gss-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gss-http'}{'port'}{'udp'} = '488'	; 
#	$srvcobjects_ref->{'gss-http'}{'ports'}{'udp'}{'488'}++	; 
#	$ports_ref->{'udp'}{'488'}{'name'} = 'gss-http'		; 
#	$srvcobjects_ref->{'gss-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gss-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gss-http'}{'port'}{'tcp'} = '488'	; 
#	$srvcobjects_ref->{'gss-http'}{'ports'}{'tcp'}{'488'}++	; 
#	$ports_ref->{'tcp'}{'488'}{'name'} = 'gss-http'		; 
#	$srvcobjects_ref->{'supercell'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'supercell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'supercell'}{'port'}{'udp'} = '7967'	; 
#	$srvcobjects_ref->{'supercell'}{'ports'}{'udp'}{'7967'}++	; 
#	$ports_ref->{'udp'}{'7967'}{'name'} = 'supercell'		; 
#	$srvcobjects_ref->{'supercell'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'supercell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'supercell'}{'port'}{'tcp'} = '7967'	; 
#	$srvcobjects_ref->{'supercell'}{'ports'}{'tcp'}{'7967'}++	; 
#	$ports_ref->{'tcp'}{'7967'}{'name'} = 'supercell'		; 
#	$srvcobjects_ref->{'uaiact'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uaiact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uaiact'}{'port'}{'udp'} = '1470'	; 
#	$srvcobjects_ref->{'uaiact'}{'ports'}{'udp'}{'1470'}++	; 
#	$ports_ref->{'udp'}{'1470'}{'name'} = 'uaiact'		; 
#	$srvcobjects_ref->{'uaiact'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uaiact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uaiact'}{'port'}{'tcp'} = '1470'	; 
#	$srvcobjects_ref->{'uaiact'}{'ports'}{'tcp'}{'1470'}++	; 
#	$ports_ref->{'tcp'}{'1470'}{'name'} = 'uaiact'		; 
#	$srvcobjects_ref->{'networklens'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'networklens'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'networklens'}{'port'}{'udp'} = '3409'	; 
#	$srvcobjects_ref->{'networklens'}{'ports'}{'udp'}{'3409'}++	; 
#	$ports_ref->{'udp'}{'3409'}{'name'} = 'networklens'		; 
#	$srvcobjects_ref->{'networklens'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'networklens'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'networklens'}{'port'}{'tcp'} = '3409'	; 
#	$srvcobjects_ref->{'networklens'}{'ports'}{'tcp'}{'3409'}++	; 
#	$ports_ref->{'tcp'}{'3409'}{'name'} = 'networklens'		; 
#	$srvcobjects_ref->{'pdps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdps'}{'port'}{'udp'} = '1314'	; 
#	$srvcobjects_ref->{'pdps'}{'ports'}{'udp'}{'1314'}++	; 
#	$ports_ref->{'udp'}{'1314'}{'name'} = 'pdps'		; 
#	$srvcobjects_ref->{'pdps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdps'}{'port'}{'tcp'} = '1314'	; 
#	$srvcobjects_ref->{'pdps'}{'ports'}{'tcp'}{'1314'}++	; 
#	$ports_ref->{'tcp'}{'1314'}{'name'} = 'pdps'		; 
#	$srvcobjects_ref->{'fcmsys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcmsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcmsys'}{'port'}{'udp'} = '2344'	; 
#	$srvcobjects_ref->{'fcmsys'}{'ports'}{'udp'}{'2344'}++	; 
#	$ports_ref->{'udp'}{'2344'}{'name'} = 'fcmsys'		; 
#	$srvcobjects_ref->{'fcmsys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcmsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcmsys'}{'port'}{'tcp'} = '2344'	; 
#	$srvcobjects_ref->{'fcmsys'}{'ports'}{'tcp'}{'2344'}++	; 
#	$ports_ref->{'tcp'}{'2344'}{'name'} = 'fcmsys'		; 
#	$srvcobjects_ref->{'rs-rmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rs-rmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rs-rmi'}{'port'}{'udp'} = '3736'	; 
#	$srvcobjects_ref->{'rs-rmi'}{'ports'}{'udp'}{'3736'}++	; 
#	$ports_ref->{'udp'}{'3736'}{'name'} = 'rs-rmi'		; 
#	$srvcobjects_ref->{'rs-rmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rs-rmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rs-rmi'}{'port'}{'tcp'} = '3736'	; 
#	$srvcobjects_ref->{'rs-rmi'}{'ports'}{'tcp'}{'3736'}++	; 
#	$ports_ref->{'tcp'}{'3736'}{'name'} = 'rs-rmi'		; 
#	$srvcobjects_ref->{'skip-cert-recv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'skip-cert-recv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skip-cert-recv'}{'port'}{'tcp'} = '6455'	; 
#	$srvcobjects_ref->{'skip-cert-recv'}{'ports'}{'tcp'}{'6455'}++	; 
#	$ports_ref->{'tcp'}{'6455'}{'name'} = 'skip-cert-recv'		; 
#	$srvcobjects_ref->{'dyna-access'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dyna-access'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dyna-access'}{'port'}{'udp'} = '3310'	; 
#	$srvcobjects_ref->{'dyna-access'}{'ports'}{'udp'}{'3310'}++	; 
#	$ports_ref->{'udp'}{'3310'}{'name'} = 'dyna-access'		; 
#	$srvcobjects_ref->{'dyna-access'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dyna-access'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dyna-access'}{'port'}{'tcp'} = '3310'	; 
#	$srvcobjects_ref->{'dyna-access'}{'ports'}{'tcp'}{'3310'}++	; 
#	$ports_ref->{'tcp'}{'3310'}{'name'} = 'dyna-access'		; 
#	$srvcobjects_ref->{'dbbrowse'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbbrowse'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbbrowse'}{'port'}{'udp'} = '47557'	; 
#	$srvcobjects_ref->{'dbbrowse'}{'ports'}{'udp'}{'47557'}++	; 
#	$ports_ref->{'udp'}{'47557'}{'name'} = 'dbbrowse'		; 
#	$srvcobjects_ref->{'dbbrowse'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbbrowse'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbbrowse'}{'port'}{'tcp'} = '47557'	; 
#	$srvcobjects_ref->{'dbbrowse'}{'ports'}{'tcp'}{'47557'}++	; 
#	$ports_ref->{'tcp'}{'47557'}{'name'} = 'dbbrowse'		; 
#	$srvcobjects_ref->{'opalis-robot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opalis-robot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opalis-robot'}{'port'}{'udp'} = '314'	; 
#	$srvcobjects_ref->{'opalis-robot'}{'ports'}{'udp'}{'314'}++	; 
#	$ports_ref->{'udp'}{'314'}{'name'} = 'opalis-robot'		; 
#	$srvcobjects_ref->{'opalis-robot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opalis-robot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opalis-robot'}{'port'}{'tcp'} = '314'	; 
#	$srvcobjects_ref->{'opalis-robot'}{'ports'}{'tcp'}{'314'}++	; 
#	$ports_ref->{'tcp'}{'314'}{'name'} = 'opalis-robot'		; 
#	$srvcobjects_ref->{'quasar-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quasar-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quasar-server'}{'port'}{'udp'} = '3599'	; 
#	$srvcobjects_ref->{'quasar-server'}{'ports'}{'udp'}{'3599'}++	; 
#	$ports_ref->{'udp'}{'3599'}{'name'} = 'quasar-server'		; 
#	$srvcobjects_ref->{'quasar-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quasar-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quasar-server'}{'port'}{'tcp'} = '3599'	; 
#	$srvcobjects_ref->{'quasar-server'}{'ports'}{'tcp'}{'3599'}++	; 
#	$ports_ref->{'tcp'}{'3599'}{'name'} = 'quasar-server'		; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'port'}{'udp'} = '1414'	; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'ports'}{'udp'}{'1414'}++	; 
#	$ports_ref->{'udp'}{'1414'}{'name'} = 'ibm-mqseries'		; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'port'}{'tcp'} = '1414'	; 
#	$srvcobjects_ref->{'ibm-mqseries'}{'ports'}{'tcp'}{'1414'}++	; 
#	$ports_ref->{'tcp'}{'1414'}{'name'} = 'ibm-mqseries'		; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'port'}{'udp'} = '3302'	; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'ports'}{'udp'}{'3302'}++	; 
#	$ports_ref->{'udp'}{'3302'}{'name'} = 'mcs-fastmail'		; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'port'}{'tcp'} = '3302'	; 
#	$srvcobjects_ref->{'mcs-fastmail'}{'ports'}{'tcp'}{'3302'}++	; 
#	$ports_ref->{'tcp'}{'3302'}{'name'} = 'mcs-fastmail'		; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'port'}{'udp'} = '3198'	; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'ports'}{'udp'}{'3198'}++	; 
#	$ports_ref->{'udp'}{'3198'}{'name'} = 'embrace-dp-c'		; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'port'}{'tcp'} = '3198'	; 
#	$srvcobjects_ref->{'embrace-dp-c'}{'ports'}{'tcp'}{'3198'}++	; 
#	$ports_ref->{'tcp'}{'3198'}{'name'} = 'embrace-dp-c'		; 
#	$srvcobjects_ref->{'stone-design-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stone-design-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stone-design-1'}{'port'}{'udp'} = '1492'	; 
#	$srvcobjects_ref->{'stone-design-1'}{'ports'}{'udp'}{'1492'}++	; 
#	$ports_ref->{'udp'}{'1492'}{'name'} = 'stone-design-1'		; 
#	$srvcobjects_ref->{'stone-design-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stone-design-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stone-design-1'}{'port'}{'tcp'} = '1492'	; 
#	$srvcobjects_ref->{'stone-design-1'}{'ports'}{'tcp'}{'1492'}++	; 
#	$ports_ref->{'tcp'}{'1492'}{'name'} = 'stone-design-1'		; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'port'}{'udp'} = '496'	; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'ports'}{'udp'}{'496'}++	; 
#	$ports_ref->{'udp'}{'496'}{'name'} = 'pim-rp-disc'		; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'port'}{'tcp'} = '496'	; 
#	$srvcobjects_ref->{'pim-rp-disc'}{'ports'}{'tcp'}{'496'}++	; 
#	$ports_ref->{'tcp'}{'496'}{'name'} = 'pim-rp-disc'		; 
#	$srvcobjects_ref->{'device2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'device2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'device2'}{'port'}{'udp'} = '2030'	; 
#	$srvcobjects_ref->{'device2'}{'ports'}{'udp'}{'2030'}++	; 
#	$ports_ref->{'udp'}{'2030'}{'name'} = 'device2'		; 
#	$srvcobjects_ref->{'device2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'device2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'device2'}{'port'}{'tcp'} = '2030'	; 
#	$srvcobjects_ref->{'device2'}{'ports'}{'tcp'}{'2030'}++	; 
#	$ports_ref->{'tcp'}{'2030'}{'name'} = 'device2'		; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'port'}{'udp'} = '3446'	; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'ports'}{'udp'}{'3446'}++	; 
#	$ports_ref->{'udp'}{'3446'}{'name'} = '3comfaxrpc'		; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'port'}{'tcp'} = '3446'	; 
#	$srvcobjects_ref->{'3comfaxrpc'}{'ports'}{'tcp'}{'3446'}++	; 
#	$ports_ref->{'tcp'}{'3446'}{'name'} = '3comfaxrpc'		; 
#	$srvcobjects_ref->{'sent-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sent-lm'}{'port'}{'udp'} = '2316'	; 
#	$srvcobjects_ref->{'sent-lm'}{'ports'}{'udp'}{'2316'}++	; 
#	$ports_ref->{'udp'}{'2316'}{'name'} = 'sent-lm'		; 
#	$srvcobjects_ref->{'sent-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sent-lm'}{'port'}{'tcp'} = '2316'	; 
#	$srvcobjects_ref->{'sent-lm'}{'ports'}{'tcp'}{'2316'}++	; 
#	$ports_ref->{'tcp'}{'2316'}{'name'} = 'sent-lm'		; 
#	$srvcobjects_ref->{'caicci'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'caicci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caicci'}{'port'}{'udp'} = '1721'	; 
#	$srvcobjects_ref->{'caicci'}{'ports'}{'udp'}{'1721'}++	; 
#	$ports_ref->{'udp'}{'1721'}{'name'} = 'caicci'		; 
#	$srvcobjects_ref->{'caicci'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'caicci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caicci'}{'port'}{'tcp'} = '1721'	; 
#	$srvcobjects_ref->{'caicci'}{'ports'}{'tcp'}{'1721'}++	; 
#	$ports_ref->{'tcp'}{'1721'}{'name'} = 'caicci'		; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'port'}{'udp'} = '602'	; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'ports'}{'udp'}{'602'}++	; 
#	$ports_ref->{'udp'}{'602'}{'name'} = 'xmlrpc-beep'		; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'port'}{'tcp'} = '602'	; 
#	$srvcobjects_ref->{'xmlrpc-beep'}{'ports'}{'tcp'}{'602'}++	; 
#	$ports_ref->{'tcp'}{'602'}{'name'} = 'xmlrpc-beep'		; 
#	$srvcobjects_ref->{'wbem-rmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wbem-rmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wbem-rmi'}{'port'}{'udp'} = '5987'	; 
#	$srvcobjects_ref->{'wbem-rmi'}{'ports'}{'udp'}{'5987'}++	; 
#	$ports_ref->{'udp'}{'5987'}{'name'} = 'wbem-rmi'		; 
#	$srvcobjects_ref->{'wbem-rmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wbem-rmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wbem-rmi'}{'port'}{'tcp'} = '5987'	; 
#	$srvcobjects_ref->{'wbem-rmi'}{'ports'}{'tcp'}{'5987'}++	; 
#	$ports_ref->{'tcp'}{'5987'}{'name'} = 'wbem-rmi'		; 
#	$srvcobjects_ref->{'csd-monitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csd-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csd-monitor'}{'port'}{'udp'} = '3072'	; 
#	$srvcobjects_ref->{'csd-monitor'}{'ports'}{'udp'}{'3072'}++	; 
#	$ports_ref->{'udp'}{'3072'}{'name'} = 'csd-monitor'		; 
#	$srvcobjects_ref->{'csd-monitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csd-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csd-monitor'}{'port'}{'tcp'} = '3072'	; 
#	$srvcobjects_ref->{'csd-monitor'}{'ports'}{'tcp'}{'3072'}++	; 
#	$ports_ref->{'tcp'}{'3072'}{'name'} = 'csd-monitor'		; 
#	$srvcobjects_ref->{'wap-vcal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-vcal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcal'}{'port'}{'udp'} = '9205'	; 
#	$srvcobjects_ref->{'wap-vcal'}{'ports'}{'udp'}{'9205'}++	; 
#	$ports_ref->{'udp'}{'9205'}{'name'} = 'wap-vcal'		; 
#	$srvcobjects_ref->{'wap-vcal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-vcal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcal'}{'port'}{'tcp'} = '9205'	; 
#	$srvcobjects_ref->{'wap-vcal'}{'ports'}{'tcp'}{'9205'}++	; 
#	$ports_ref->{'tcp'}{'9205'}{'name'} = 'wap-vcal'		; 
#	$srvcobjects_ref->{'zephyr-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zephyr-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zephyr-srv'}{'port'}{'udp'} = '2102'	; 
#	$srvcobjects_ref->{'zephyr-srv'}{'ports'}{'udp'}{'2102'}++	; 
#	$ports_ref->{'udp'}{'2102'}{'name'} = 'zephyr-srv'		; 
#	$srvcobjects_ref->{'zephyr-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zephyr-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zephyr-srv'}{'port'}{'tcp'} = '2102'	; 
#	$srvcobjects_ref->{'zephyr-srv'}{'ports'}{'tcp'}{'2102'}++	; 
#	$ports_ref->{'tcp'}{'2102'}{'name'} = 'zephyr-srv'		; 
#	$srvcobjects_ref->{'decauth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'decauth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decauth'}{'port'}{'udp'} = '316'	; 
#	$srvcobjects_ref->{'decauth'}{'ports'}{'udp'}{'316'}++	; 
#	$ports_ref->{'udp'}{'316'}{'name'} = 'decauth'		; 
#	$srvcobjects_ref->{'decauth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'decauth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decauth'}{'port'}{'tcp'} = '316'	; 
#	$srvcobjects_ref->{'decauth'}{'ports'}{'tcp'}{'316'}++	; 
#	$ports_ref->{'tcp'}{'316'}{'name'} = 'decauth'		; 
#	$srvcobjects_ref->{'writesrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'writesrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'writesrv'}{'port'}{'udp'} = '1334'	; 
#	$srvcobjects_ref->{'writesrv'}{'ports'}{'udp'}{'1334'}++	; 
#	$ports_ref->{'udp'}{'1334'}{'name'} = 'writesrv'		; 
#	$srvcobjects_ref->{'writesrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'writesrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'writesrv'}{'port'}{'tcp'} = '1334'	; 
#	$srvcobjects_ref->{'writesrv'}{'ports'}{'tcp'}{'1334'}++	; 
#	$ports_ref->{'tcp'}{'1334'}{'name'} = 'writesrv'		; 
#	$srvcobjects_ref->{'esmmanager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esmmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esmmanager'}{'port'}{'udp'} = '5600'	; 
#	$srvcobjects_ref->{'esmmanager'}{'ports'}{'udp'}{'5600'}++	; 
#	$ports_ref->{'udp'}{'5600'}{'name'} = 'esmmanager'		; 
#	$srvcobjects_ref->{'esmmanager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esmmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esmmanager'}{'port'}{'tcp'} = '5600'	; 
#	$srvcobjects_ref->{'esmmanager'}{'ports'}{'tcp'}{'5600'}++	; 
#	$ports_ref->{'tcp'}{'5600'}{'name'} = 'esmmanager'		; 
#	$srvcobjects_ref->{'pafec-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pafec-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pafec-lm'}{'port'}{'udp'} = '7511'	; 
#	$srvcobjects_ref->{'pafec-lm'}{'ports'}{'udp'}{'7511'}++	; 
#	$ports_ref->{'udp'}{'7511'}{'name'} = 'pafec-lm'		; 
#	$srvcobjects_ref->{'pafec-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pafec-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pafec-lm'}{'port'}{'tcp'} = '7511'	; 
#	$srvcobjects_ref->{'pafec-lm'}{'ports'}{'tcp'}{'7511'}++	; 
#	$ports_ref->{'tcp'}{'7511'}{'name'} = 'pafec-lm'		; 
#	$srvcobjects_ref->{'konshus-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'konshus-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'konshus-lm'}{'port'}{'udp'} = '2294'	; 
#	$srvcobjects_ref->{'konshus-lm'}{'ports'}{'udp'}{'2294'}++	; 
#	$ports_ref->{'udp'}{'2294'}{'name'} = 'konshus-lm'		; 
#	$srvcobjects_ref->{'konshus-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'konshus-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'konshus-lm'}{'port'}{'tcp'} = '2294'	; 
#	$srvcobjects_ref->{'konshus-lm'}{'ports'}{'tcp'}{'2294'}++	; 
#	$ports_ref->{'tcp'}{'2294'}{'name'} = 'konshus-lm'		; 
#	$srvcobjects_ref->{'raid-cd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raid-cd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-cd'}{'port'}{'udp'} = '2013'	; 
#	$srvcobjects_ref->{'raid-cd'}{'ports'}{'udp'}{'2013'}++	; 
#	$ports_ref->{'udp'}{'2013'}{'name'} = 'raid-cd'		; 
#	$srvcobjects_ref->{'glogger'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'glogger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glogger'}{'port'}{'udp'} = '2033'	; 
#	$srvcobjects_ref->{'glogger'}{'ports'}{'udp'}{'2033'}++	; 
#	$ports_ref->{'udp'}{'2033'}{'name'} = 'glogger'		; 
#	$srvcobjects_ref->{'glogger'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'glogger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glogger'}{'port'}{'tcp'} = '2033'	; 
#	$srvcobjects_ref->{'glogger'}{'ports'}{'tcp'}{'2033'}++	; 
#	$ports_ref->{'tcp'}{'2033'}{'name'} = 'glogger'		; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'port'}{'udp'} = '1977'	; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'ports'}{'udp'}{'1977'}++	; 
#	$ports_ref->{'udp'}{'1977'}{'name'} = 'tcoaddressbook'		; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'port'}{'tcp'} = '1977'	; 
#	$srvcobjects_ref->{'tcoaddressbook'}{'ports'}{'tcp'}{'1977'}++	; 
#	$ports_ref->{'tcp'}{'1977'}{'name'} = 'tcoaddressbook'		; 
#	$srvcobjects_ref->{'borland-dsj'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'borland-dsj'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'borland-dsj'}{'port'}{'udp'} = '707'	; 
#	$srvcobjects_ref->{'borland-dsj'}{'ports'}{'udp'}{'707'}++	; 
#	$ports_ref->{'udp'}{'707'}{'name'} = 'borland-dsj'		; 
#	$srvcobjects_ref->{'borland-dsj'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'borland-dsj'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'borland-dsj'}{'port'}{'tcp'} = '707'	; 
#	$srvcobjects_ref->{'borland-dsj'}{'ports'}{'tcp'}{'707'}++	; 
#	$ports_ref->{'tcp'}{'707'}{'name'} = 'borland-dsj'		; 
#	$srvcobjects_ref->{'oracle'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oracle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle'}{'port'}{'udp'} = '2005'	; 
#	$srvcobjects_ref->{'oracle'}{'ports'}{'udp'}{'2005'}++	; 
#	$ports_ref->{'udp'}{'2005'}{'name'} = 'oracle'		; 
#	$srvcobjects_ref->{'udt_os'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'udt_os'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udt_os'}{'port'}{'udp'} = '1382'	; 
#	$srvcobjects_ref->{'udt_os'}{'ports'}{'udp'}{'1382'}++	; 
#	$ports_ref->{'udp'}{'1382'}{'name'} = 'udt_os'		; 
#	$srvcobjects_ref->{'udt_os'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'udt_os'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udt_os'}{'port'}{'udp'} = '3900'	; 
#	$srvcobjects_ref->{'udt_os'}{'ports'}{'udp'}{'3900'}++	; 
#	$ports_ref->{'udp'}{'3900'}{'name'} = 'udt_os'		; 
#	$srvcobjects_ref->{'udt_os'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'udt_os'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udt_os'}{'port'}{'tcp'} = '1382'	; 
#	$srvcobjects_ref->{'udt_os'}{'ports'}{'tcp'}{'1382'}++	; 
#	$ports_ref->{'tcp'}{'1382'}{'name'} = 'udt_os'		; 
#	$srvcobjects_ref->{'udt_os'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'udt_os'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udt_os'}{'port'}{'tcp'} = '3900'	; 
#	$srvcobjects_ref->{'udt_os'}{'ports'}{'tcp'}{'3900'}++	; 
#	$ports_ref->{'tcp'}{'3900'}{'name'} = 'udt_os'		; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'port'}{'udp'} = '9091'	; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'ports'}{'udp'}{'9091'}++	; 
#	$ports_ref->{'udp'}{'9091'}{'name'} = 'xmltec-xmlmail'		; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'port'}{'tcp'} = '9091'	; 
#	$srvcobjects_ref->{'xmltec-xmlmail'}{'ports'}{'tcp'}{'9091'}++	; 
#	$ports_ref->{'tcp'}{'9091'}{'name'} = 'xmltec-xmlmail'		; 
#	$srvcobjects_ref->{'rimsl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rimsl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rimsl'}{'port'}{'udp'} = '2044'	; 
#	$srvcobjects_ref->{'rimsl'}{'ports'}{'udp'}{'2044'}++	; 
#	$ports_ref->{'udp'}{'2044'}{'name'} = 'rimsl'		; 
#	$srvcobjects_ref->{'rimsl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rimsl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rimsl'}{'port'}{'tcp'} = '2044'	; 
#	$srvcobjects_ref->{'rimsl'}{'ports'}{'tcp'}{'2044'}++	; 
#	$ports_ref->{'tcp'}{'2044'}{'name'} = 'rimsl'		; 
#	$srvcobjects_ref->{'smsqp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smsqp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smsqp'}{'port'}{'udp'} = '11201'	; 
#	$srvcobjects_ref->{'smsqp'}{'ports'}{'udp'}{'11201'}++	; 
#	$ports_ref->{'udp'}{'11201'}{'name'} = 'smsqp'		; 
#	$srvcobjects_ref->{'smsqp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smsqp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smsqp'}{'port'}{'tcp'} = '11201'	; 
#	$srvcobjects_ref->{'smsqp'}{'ports'}{'tcp'}{'11201'}++	; 
#	$ports_ref->{'tcp'}{'11201'}{'name'} = 'smsqp'		; 
#	$srvcobjects_ref->{'rhp-iibp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rhp-iibp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rhp-iibp'}{'port'}{'udp'} = '1912'	; 
#	$srvcobjects_ref->{'rhp-iibp'}{'ports'}{'udp'}{'1912'}++	; 
#	$ports_ref->{'udp'}{'1912'}{'name'} = 'rhp-iibp'		; 
#	$srvcobjects_ref->{'rhp-iibp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rhp-iibp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rhp-iibp'}{'port'}{'tcp'} = '1912'	; 
#	$srvcobjects_ref->{'rhp-iibp'}{'ports'}{'tcp'}{'1912'}++	; 
#	$ports_ref->{'tcp'}{'1912'}{'name'} = 'rhp-iibp'		; 
#	$srvcobjects_ref->{'gwha'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gwha'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gwha'}{'port'}{'udp'} = '1383'	; 
#	$srvcobjects_ref->{'gwha'}{'ports'}{'udp'}{'1383'}++	; 
#	$ports_ref->{'udp'}{'1383'}{'name'} = 'gwha'		; 
#	$srvcobjects_ref->{'gwha'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gwha'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gwha'}{'port'}{'tcp'} = '1383'	; 
#	$srvcobjects_ref->{'gwha'}{'ports'}{'tcp'}{'1383'}++	; 
#	$ports_ref->{'tcp'}{'1383'}{'name'} = 'gwha'		; 
#	$srvcobjects_ref->{'ca-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ca-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ca-1'}{'port'}{'udp'} = '5064'	; 
#	$srvcobjects_ref->{'ca-1'}{'ports'}{'udp'}{'5064'}++	; 
#	$ports_ref->{'udp'}{'5064'}{'name'} = 'ca-1'		; 
#	$srvcobjects_ref->{'ca-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ca-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ca-1'}{'port'}{'tcp'} = '5064'	; 
#	$srvcobjects_ref->{'ca-1'}{'ports'}{'tcp'}{'5064'}++	; 
#	$ports_ref->{'tcp'}{'5064'}{'name'} = 'ca-1'		; 
#	$srvcobjects_ref->{'3link'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3link'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3link'}{'port'}{'udp'} = '15363'	; 
#	$srvcobjects_ref->{'3link'}{'ports'}{'udp'}{'15363'}++	; 
#	$ports_ref->{'udp'}{'15363'}{'name'} = '3link'		; 
#	$srvcobjects_ref->{'3link'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3link'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3link'}{'port'}{'tcp'} = '15363'	; 
#	$srvcobjects_ref->{'3link'}{'ports'}{'tcp'}{'15363'}++	; 
#	$ports_ref->{'tcp'}{'15363'}{'name'} = '3link'		; 
#	$srvcobjects_ref->{'simple-push-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simple-push-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simple-push-s'}{'port'}{'udp'} = '3688'	; 
#	$srvcobjects_ref->{'simple-push-s'}{'ports'}{'udp'}{'3688'}++	; 
#	$ports_ref->{'udp'}{'3688'}{'name'} = 'simple-push-s'		; 
#	$srvcobjects_ref->{'simple-push-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simple-push-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simple-push-s'}{'port'}{'tcp'} = '3688'	; 
#	$srvcobjects_ref->{'simple-push-s'}{'ports'}{'tcp'}{'3688'}++	; 
#	$ports_ref->{'tcp'}{'3688'}{'name'} = 'simple-push-s'		; 
#	$srvcobjects_ref->{'abcvoice-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abcvoice-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abcvoice-port'}{'port'}{'udp'} = '3781'	; 
#	$srvcobjects_ref->{'abcvoice-port'}{'ports'}{'udp'}{'3781'}++	; 
#	$ports_ref->{'udp'}{'3781'}{'name'} = 'abcvoice-port'		; 
#	$srvcobjects_ref->{'abcvoice-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abcvoice-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abcvoice-port'}{'port'}{'tcp'} = '3781'	; 
#	$srvcobjects_ref->{'abcvoice-port'}{'ports'}{'tcp'}{'3781'}++	; 
#	$ports_ref->{'tcp'}{'3781'}{'name'} = 'abcvoice-port'		; 
#	$srvcobjects_ref->{'idrs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idrs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idrs'}{'port'}{'udp'} = '2995'	; 
#	$srvcobjects_ref->{'idrs'}{'ports'}{'udp'}{'2995'}++	; 
#	$ports_ref->{'udp'}{'2995'}{'name'} = 'idrs'		; 
#	$srvcobjects_ref->{'idrs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idrs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idrs'}{'port'}{'tcp'} = '2995'	; 
#	$srvcobjects_ref->{'idrs'}{'ports'}{'tcp'}{'2995'}++	; 
#	$ports_ref->{'tcp'}{'2995'}{'name'} = 'idrs'		; 
#	$srvcobjects_ref->{'ms-sna-base'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-sna-base'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sna-base'}{'port'}{'udp'} = '1478'	; 
#	$srvcobjects_ref->{'ms-sna-base'}{'ports'}{'udp'}{'1478'}++	; 
#	$ports_ref->{'udp'}{'1478'}{'name'} = 'ms-sna-base'		; 
#	$srvcobjects_ref->{'ms-sna-base'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-sna-base'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sna-base'}{'port'}{'tcp'} = '1478'	; 
#	$srvcobjects_ref->{'ms-sna-base'}{'ports'}{'tcp'}{'1478'}++	; 
#	$ports_ref->{'tcp'}{'1478'}{'name'} = 'ms-sna-base'		; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'port'}{'udp'} = '7003'	; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'ports'}{'udp'}{'7003'}++	; 
#	$ports_ref->{'udp'}{'7003'}{'name'} = 'afs3-vlserver'		; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'port'}{'tcp'} = '7003'	; 
#	$srvcobjects_ref->{'afs3-vlserver'}{'ports'}{'tcp'}{'7003'}++	; 
#	$ports_ref->{'tcp'}{'7003'}{'name'} = 'afs3-vlserver'		; 
#	$srvcobjects_ref->{'netbios-ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbios-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbios-ns'}{'port'}{'udp'} = '137'	; 
#	$srvcobjects_ref->{'netbios-ns'}{'ports'}{'udp'}{'137'}++	; 
#	$ports_ref->{'udp'}{'137'}{'name'} = 'netbios-ns'		; 
#	$srvcobjects_ref->{'netbios-ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbios-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbios-ns'}{'port'}{'tcp'} = '137'	; 
#	$srvcobjects_ref->{'netbios-ns'}{'ports'}{'tcp'}{'137'}++	; 
#	$ports_ref->{'tcp'}{'137'}{'name'} = 'netbios-ns'		; 
#	$srvcobjects_ref->{'netx-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netx-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netx-agent'}{'port'}{'udp'} = '2586'	; 
#	$srvcobjects_ref->{'netx-agent'}{'ports'}{'udp'}{'2586'}++	; 
#	$ports_ref->{'udp'}{'2586'}{'name'} = 'netx-agent'		; 
#	$srvcobjects_ref->{'netx-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netx-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netx-agent'}{'port'}{'tcp'} = '2586'	; 
#	$srvcobjects_ref->{'netx-agent'}{'ports'}{'tcp'}{'2586'}++	; 
#	$ports_ref->{'tcp'}{'2586'}{'name'} = 'netx-agent'		; 
#	$srvcobjects_ref->{'oracle-em2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oracle-em2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-em2'}{'port'}{'udp'} = '1754'	; 
#	$srvcobjects_ref->{'oracle-em2'}{'ports'}{'udp'}{'1754'}++	; 
#	$ports_ref->{'udp'}{'1754'}{'name'} = 'oracle-em2'		; 
#	$srvcobjects_ref->{'oracle-em2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oracle-em2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-em2'}{'port'}{'tcp'} = '1754'	; 
#	$srvcobjects_ref->{'oracle-em2'}{'ports'}{'tcp'}{'1754'}++	; 
#	$ports_ref->{'tcp'}{'1754'}{'name'} = 'oracle-em2'		; 
#	$srvcobjects_ref->{'imdocsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imdocsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imdocsvc'}{'port'}{'udp'} = '2637'	; 
#	$srvcobjects_ref->{'imdocsvc'}{'ports'}{'udp'}{'2637'}++	; 
#	$ports_ref->{'udp'}{'2637'}{'name'} = 'imdocsvc'		; 
#	$srvcobjects_ref->{'imdocsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imdocsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imdocsvc'}{'port'}{'tcp'} = '2637'	; 
#	$srvcobjects_ref->{'imdocsvc'}{'ports'}{'tcp'}{'2637'}++	; 
#	$ports_ref->{'tcp'}{'2637'}{'name'} = 'imdocsvc'		; 
#	$srvcobjects_ref->{'mylex-mapd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mylex-mapd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mylex-mapd'}{'port'}{'udp'} = '467'	; 
#	$srvcobjects_ref->{'mylex-mapd'}{'ports'}{'udp'}{'467'}++	; 
#	$ports_ref->{'udp'}{'467'}{'name'} = 'mylex-mapd'		; 
#	$srvcobjects_ref->{'mylex-mapd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mylex-mapd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mylex-mapd'}{'port'}{'tcp'} = '467'	; 
#	$srvcobjects_ref->{'mylex-mapd'}{'ports'}{'tcp'}{'467'}++	; 
#	$ports_ref->{'tcp'}{'467'}{'name'} = 'mylex-mapd'		; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'port'}{'udp'} = '2923'	; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'ports'}{'udp'}{'2923'}++	; 
#	$ports_ref->{'udp'}{'2923'}{'name'} = 'wta-wsp-wtp-s'		; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'port'}{'tcp'} = '2923'	; 
#	$srvcobjects_ref->{'wta-wsp-wtp-s'}{'ports'}{'tcp'}{'2923'}++	; 
#	$ports_ref->{'tcp'}{'2923'}{'name'} = 'wta-wsp-wtp-s'		; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'port'}{'udp'} = '3079'	; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'ports'}{'udp'}{'3079'}++	; 
#	$ports_ref->{'udp'}{'3079'}{'name'} = 'lv-frontpanel'		; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'port'}{'tcp'} = '3079'	; 
#	$srvcobjects_ref->{'lv-frontpanel'}{'ports'}{'tcp'}{'3079'}++	; 
#	$ports_ref->{'tcp'}{'3079'}{'name'} = 'lv-frontpanel'		; 
#	$srvcobjects_ref->{'qft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qft'}{'port'}{'udp'} = '189'	; 
#	$srvcobjects_ref->{'qft'}{'ports'}{'udp'}{'189'}++	; 
#	$ports_ref->{'udp'}{'189'}{'name'} = 'qft'		; 
#	$srvcobjects_ref->{'qft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qft'}{'port'}{'tcp'} = '189'	; 
#	$srvcobjects_ref->{'qft'}{'ports'}{'tcp'}{'189'}++	; 
#	$ports_ref->{'tcp'}{'189'}{'name'} = 'qft'		; 
#	$srvcobjects_ref->{'otpatch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'otpatch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'otpatch'}{'port'}{'udp'} = '2936'	; 
#	$srvcobjects_ref->{'otpatch'}{'ports'}{'udp'}{'2936'}++	; 
#	$ports_ref->{'udp'}{'2936'}{'name'} = 'otpatch'		; 
#	$srvcobjects_ref->{'otpatch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'otpatch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'otpatch'}{'port'}{'tcp'} = '2936'	; 
#	$srvcobjects_ref->{'otpatch'}{'ports'}{'tcp'}{'2936'}++	; 
#	$ports_ref->{'tcp'}{'2936'}{'name'} = 'otpatch'		; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'port'}{'udp'} = '6768'	; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'ports'}{'udp'}{'6768'}++	; 
#	$ports_ref->{'udp'}{'6768'}{'name'} = 'bmc-perf-mgrd'		; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'port'}{'tcp'} = '6768'	; 
#	$srvcobjects_ref->{'bmc-perf-mgrd'}{'ports'}{'tcp'}{'6768'}++	; 
#	$ports_ref->{'tcp'}{'6768'}{'name'} = 'bmc-perf-mgrd'		; 
#	$srvcobjects_ref->{'elanlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elanlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elanlm'}{'port'}{'udp'} = '4346'	; 
#	$srvcobjects_ref->{'elanlm'}{'ports'}{'udp'}{'4346'}++	; 
#	$ports_ref->{'udp'}{'4346'}{'name'} = 'elanlm'		; 
#	$srvcobjects_ref->{'elanlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elanlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elanlm'}{'port'}{'tcp'} = '4346'	; 
#	$srvcobjects_ref->{'elanlm'}{'ports'}{'tcp'}{'4346'}++	; 
#	$ports_ref->{'tcp'}{'4346'}{'name'} = 'elanlm'		; 
#	$srvcobjects_ref->{'infocrypt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infocrypt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infocrypt'}{'port'}{'udp'} = '2233'	; 
#	$srvcobjects_ref->{'infocrypt'}{'ports'}{'udp'}{'2233'}++	; 
#	$ports_ref->{'udp'}{'2233'}{'name'} = 'infocrypt'		; 
#	$srvcobjects_ref->{'infocrypt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infocrypt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infocrypt'}{'port'}{'tcp'} = '2233'	; 
#	$srvcobjects_ref->{'infocrypt'}{'ports'}{'tcp'}{'2233'}++	; 
#	$ports_ref->{'tcp'}{'2233'}{'name'} = 'infocrypt'		; 
#	$srvcobjects_ref->{'nfa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nfa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nfa'}{'port'}{'udp'} = '1155'	; 
#	$srvcobjects_ref->{'nfa'}{'ports'}{'udp'}{'1155'}++	; 
#	$ports_ref->{'udp'}{'1155'}{'name'} = 'nfa'		; 
#	$srvcobjects_ref->{'nfa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nfa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nfa'}{'port'}{'tcp'} = '1155'	; 
#	$srvcobjects_ref->{'nfa'}{'ports'}{'tcp'}{'1155'}++	; 
#	$ports_ref->{'tcp'}{'1155'}{'name'} = 'nfa'		; 
#	$srvcobjects_ref->{'htcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'htcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'htcp'}{'port'}{'udp'} = '4827'	; 
#	$srvcobjects_ref->{'htcp'}{'ports'}{'udp'}{'4827'}++	; 
#	$ports_ref->{'udp'}{'4827'}{'name'} = 'htcp'		; 
#	$srvcobjects_ref->{'htcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'htcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'htcp'}{'port'}{'tcp'} = '4827'	; 
#	$srvcobjects_ref->{'htcp'}{'ports'}{'tcp'}{'4827'}++	; 
#	$ports_ref->{'tcp'}{'4827'}{'name'} = 'htcp'		; 
#	$srvcobjects_ref->{'d2000webserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d2000webserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2000webserver'}{'port'}{'udp'} = '3120'	; 
#	$srvcobjects_ref->{'d2000webserver'}{'ports'}{'udp'}{'3120'}++	; 
#	$ports_ref->{'udp'}{'3120'}{'name'} = 'd2000webserver'		; 
#	$srvcobjects_ref->{'d2000webserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d2000webserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2000webserver'}{'port'}{'tcp'} = '3120'	; 
#	$srvcobjects_ref->{'d2000webserver'}{'ports'}{'tcp'}{'3120'}++	; 
#	$ports_ref->{'tcp'}{'3120'}{'name'} = 'd2000webserver'		; 
#	$srvcobjects_ref->{'tdaccess'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tdaccess'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tdaccess'}{'port'}{'udp'} = '2910'	; 
#	$srvcobjects_ref->{'tdaccess'}{'ports'}{'udp'}{'2910'}++	; 
#	$ports_ref->{'udp'}{'2910'}{'name'} = 'tdaccess'		; 
#	$srvcobjects_ref->{'tdaccess'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tdaccess'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tdaccess'}{'port'}{'tcp'} = '2910'	; 
#	$srvcobjects_ref->{'tdaccess'}{'ports'}{'tcp'}{'2910'}++	; 
#	$ports_ref->{'tcp'}{'2910'}{'name'} = 'tdaccess'		; 
#	$srvcobjects_ref->{'codaauth2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'codaauth2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codaauth2'}{'port'}{'udp'} = '370'	; 
#	$srvcobjects_ref->{'codaauth2'}{'ports'}{'udp'}{'370'}++	; 
#	$ports_ref->{'udp'}{'370'}{'name'} = 'codaauth2'		; 
#	$srvcobjects_ref->{'codaauth2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'codaauth2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codaauth2'}{'port'}{'tcp'} = '370'	; 
#	$srvcobjects_ref->{'codaauth2'}{'ports'}{'tcp'}{'370'}++	; 
#	$ports_ref->{'tcp'}{'370'}{'name'} = 'codaauth2'		; 
#	$srvcobjects_ref->{'intersys-cache'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intersys-cache'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intersys-cache'}{'port'}{'udp'} = '1972'	; 
#	$srvcobjects_ref->{'intersys-cache'}{'ports'}{'udp'}{'1972'}++	; 
#	$ports_ref->{'udp'}{'1972'}{'name'} = 'intersys-cache'		; 
#	$srvcobjects_ref->{'intersys-cache'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intersys-cache'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intersys-cache'}{'port'}{'tcp'} = '1972'	; 
#	$srvcobjects_ref->{'intersys-cache'}{'ports'}{'tcp'}{'1972'}++	; 
#	$ports_ref->{'tcp'}{'1972'}{'name'} = 'intersys-cache'		; 
#	$srvcobjects_ref->{'here-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'here-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'here-lm'}{'port'}{'udp'} = '1409'	; 
#	$srvcobjects_ref->{'here-lm'}{'ports'}{'udp'}{'1409'}++	; 
#	$ports_ref->{'udp'}{'1409'}{'name'} = 'here-lm'		; 
#	$srvcobjects_ref->{'here-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'here-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'here-lm'}{'port'}{'tcp'} = '1409'	; 
#	$srvcobjects_ref->{'here-lm'}{'ports'}{'tcp'}{'1409'}++	; 
#	$ports_ref->{'tcp'}{'1409'}{'name'} = 'here-lm'		; 
#	$srvcobjects_ref->{'bytex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bytex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bytex'}{'port'}{'udp'} = '1375'	; 
#	$srvcobjects_ref->{'bytex'}{'ports'}{'udp'}{'1375'}++	; 
#	$ports_ref->{'udp'}{'1375'}{'name'} = 'bytex'		; 
#	$srvcobjects_ref->{'bytex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bytex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bytex'}{'port'}{'tcp'} = '1375'	; 
#	$srvcobjects_ref->{'bytex'}{'ports'}{'tcp'}{'1375'}++	; 
#	$ports_ref->{'tcp'}{'1375'}{'name'} = 'bytex'		; 
#	$srvcobjects_ref->{'visinet-gui'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'visinet-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visinet-gui'}{'port'}{'udp'} = '3601'	; 
#	$srvcobjects_ref->{'visinet-gui'}{'ports'}{'udp'}{'3601'}++	; 
#	$ports_ref->{'udp'}{'3601'}{'name'} = 'visinet-gui'		; 
#	$srvcobjects_ref->{'visinet-gui'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'visinet-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visinet-gui'}{'port'}{'tcp'} = '3601'	; 
#	$srvcobjects_ref->{'visinet-gui'}{'ports'}{'tcp'}{'3601'}++	; 
#	$ports_ref->{'tcp'}{'3601'}{'name'} = 'visinet-gui'		; 
#	$srvcobjects_ref->{'groove'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'groove'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'groove'}{'port'}{'udp'} = '2492'	; 
#	$srvcobjects_ref->{'groove'}{'ports'}{'udp'}{'2492'}++	; 
#	$ports_ref->{'udp'}{'2492'}{'name'} = 'groove'		; 
#	$srvcobjects_ref->{'groove'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'groove'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'groove'}{'port'}{'tcp'} = '2492'	; 
#	$srvcobjects_ref->{'groove'}{'ports'}{'tcp'}{'2492'}++	; 
#	$ports_ref->{'tcp'}{'2492'}{'name'} = 'groove'		; 
#	$srvcobjects_ref->{'maitrd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'maitrd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maitrd'}{'port'}{'udp'} = '997'	; 
#	$srvcobjects_ref->{'maitrd'}{'ports'}{'udp'}{'997'}++	; 
#	$ports_ref->{'udp'}{'997'}{'name'} = 'maitrd'		; 
#	$srvcobjects_ref->{'maitrd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'maitrd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maitrd'}{'port'}{'tcp'} = '997'	; 
#	$srvcobjects_ref->{'maitrd'}{'ports'}{'tcp'}{'997'}++	; 
#	$ports_ref->{'tcp'}{'997'}{'name'} = 'maitrd'		; 
#	$srvcobjects_ref->{'mfcobol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mfcobol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mfcobol'}{'port'}{'udp'} = '86'	; 
#	$srvcobjects_ref->{'mfcobol'}{'ports'}{'udp'}{'86'}++	; 
#	$ports_ref->{'udp'}{'86'}{'name'} = 'mfcobol'		; 
#	$srvcobjects_ref->{'mfcobol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mfcobol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mfcobol'}{'port'}{'tcp'} = '86'	; 
#	$srvcobjects_ref->{'mfcobol'}{'ports'}{'tcp'}{'86'}++	; 
#	$ports_ref->{'tcp'}{'86'}{'name'} = 'mfcobol'		; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'port'}{'udp'} = '2142'	; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'ports'}{'udp'}{'2142'}++	; 
#	$ports_ref->{'udp'}{'2142'}{'name'} = 'tdm-over-ip'		; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'port'}{'tcp'} = '2142'	; 
#	$srvcobjects_ref->{'tdm-over-ip'}{'ports'}{'tcp'}{'2142'}++	; 
#	$ports_ref->{'tcp'}{'2142'}{'name'} = 'tdm-over-ip'		; 
#	$srvcobjects_ref->{'hpppssvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpppssvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpppssvr'}{'port'}{'udp'} = '2448'	; 
#	$srvcobjects_ref->{'hpppssvr'}{'ports'}{'udp'}{'2448'}++	; 
#	$ports_ref->{'udp'}{'2448'}{'name'} = 'hpppssvr'		; 
#	$srvcobjects_ref->{'hpppssvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpppssvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpppssvr'}{'port'}{'tcp'} = '2448'	; 
#	$srvcobjects_ref->{'hpppssvr'}{'ports'}{'tcp'}{'2448'}++	; 
#	$ports_ref->{'tcp'}{'2448'}{'name'} = 'hpppssvr'		; 
#	$srvcobjects_ref->{'fjmpjps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjmpjps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjmpjps'}{'port'}{'udp'} = '1873'	; 
#	$srvcobjects_ref->{'fjmpjps'}{'ports'}{'udp'}{'1873'}++	; 
#	$ports_ref->{'udp'}{'1873'}{'name'} = 'fjmpjps'		; 
#	$srvcobjects_ref->{'fjmpjps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjmpjps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjmpjps'}{'port'}{'tcp'} = '1873'	; 
#	$srvcobjects_ref->{'fjmpjps'}{'ports'}{'tcp'}{'1873'}++	; 
#	$ports_ref->{'tcp'}{'1873'}{'name'} = 'fjmpjps'		; 
#	$srvcobjects_ref->{'ife_icorp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ife_icorp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ife_icorp'}{'port'}{'udp'} = '5165'	; 
#	$srvcobjects_ref->{'ife_icorp'}{'ports'}{'udp'}{'5165'}++	; 
#	$ports_ref->{'udp'}{'5165'}{'name'} = 'ife_icorp'		; 
#	$srvcobjects_ref->{'ife_icorp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ife_icorp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ife_icorp'}{'port'}{'tcp'} = '5165'	; 
#	$srvcobjects_ref->{'ife_icorp'}{'ports'}{'tcp'}{'5165'}++	; 
#	$ports_ref->{'tcp'}{'5165'}{'name'} = 'ife_icorp'		; 
#	$srvcobjects_ref->{'netobjects1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netobjects1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netobjects1'}{'port'}{'udp'} = '2485'	; 
#	$srvcobjects_ref->{'netobjects1'}{'ports'}{'udp'}{'2485'}++	; 
#	$ports_ref->{'udp'}{'2485'}{'name'} = 'netobjects1'		; 
#	$srvcobjects_ref->{'netobjects1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netobjects1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netobjects1'}{'port'}{'tcp'} = '2485'	; 
#	$srvcobjects_ref->{'netobjects1'}{'ports'}{'tcp'}{'2485'}++	; 
#	$ports_ref->{'tcp'}{'2485'}{'name'} = 'netobjects1'		; 
#	$srvcobjects_ref->{'bhoetty'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bhoetty'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhoetty'}{'port'}{'udp'} = '351'	; 
#	$srvcobjects_ref->{'bhoetty'}{'ports'}{'udp'}{'351'}++	; 
#	$ports_ref->{'udp'}{'351'}{'name'} = 'bhoetty'		; 
#	$srvcobjects_ref->{'bhoetty'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bhoetty'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhoetty'}{'port'}{'tcp'} = '351'	; 
#	$srvcobjects_ref->{'bhoetty'}{'ports'}{'tcp'}{'351'}++	; 
#	$ports_ref->{'tcp'}{'351'}{'name'} = 'bhoetty'		; 
#	$srvcobjects_ref->{'hlibmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hlibmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hlibmgr'}{'port'}{'udp'} = '3634'	; 
#	$srvcobjects_ref->{'hlibmgr'}{'ports'}{'udp'}{'3634'}++	; 
#	$ports_ref->{'udp'}{'3634'}{'name'} = 'hlibmgr'		; 
#	$srvcobjects_ref->{'hlibmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hlibmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hlibmgr'}{'port'}{'tcp'} = '3634'	; 
#	$srvcobjects_ref->{'hlibmgr'}{'ports'}{'tcp'}{'3634'}++	; 
#	$ports_ref->{'tcp'}{'3634'}{'name'} = 'hlibmgr'		; 
#	$srvcobjects_ref->{'vnsstr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vnsstr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnsstr'}{'port'}{'udp'} = '3321'	; 
#	$srvcobjects_ref->{'vnsstr'}{'ports'}{'udp'}{'3321'}++	; 
#	$ports_ref->{'udp'}{'3321'}{'name'} = 'vnsstr'		; 
#	$srvcobjects_ref->{'vnsstr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vnsstr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnsstr'}{'port'}{'tcp'} = '3321'	; 
#	$srvcobjects_ref->{'vnsstr'}{'ports'}{'tcp'}{'3321'}++	; 
#	$ports_ref->{'tcp'}{'3321'}{'name'} = 'vnsstr'		; 
#	$srvcobjects_ref->{'verismart'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'verismart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'verismart'}{'port'}{'udp'} = '3270'	; 
#	$srvcobjects_ref->{'verismart'}{'ports'}{'udp'}{'3270'}++	; 
#	$ports_ref->{'udp'}{'3270'}{'name'} = 'verismart'		; 
#	$srvcobjects_ref->{'verismart'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'verismart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'verismart'}{'port'}{'tcp'} = '3270'	; 
#	$srvcobjects_ref->{'verismart'}{'ports'}{'tcp'}{'3270'}++	; 
#	$ports_ref->{'tcp'}{'3270'}{'name'} = 'verismart'		; 
#	$srvcobjects_ref->{'ncu-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncu-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncu-1'}{'port'}{'udp'} = '3195'	; 
#	$srvcobjects_ref->{'ncu-1'}{'ports'}{'udp'}{'3195'}++	; 
#	$ports_ref->{'udp'}{'3195'}{'name'} = 'ncu-1'		; 
#	$srvcobjects_ref->{'ncu-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncu-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncu-1'}{'port'}{'tcp'} = '3195'	; 
#	$srvcobjects_ref->{'ncu-1'}{'ports'}{'tcp'}{'3195'}++	; 
#	$ports_ref->{'tcp'}{'3195'}{'name'} = 'ncu-1'		; 
#	$srvcobjects_ref->{'diagmond'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'diagmond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'diagmond'}{'port'}{'udp'} = '1508'	; 
#	$srvcobjects_ref->{'diagmond'}{'ports'}{'udp'}{'1508'}++	; 
#	$ports_ref->{'udp'}{'1508'}{'name'} = 'diagmond'		; 
#	$srvcobjects_ref->{'diagmond'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'diagmond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'diagmond'}{'port'}{'tcp'} = '1508'	; 
#	$srvcobjects_ref->{'diagmond'}{'ports'}{'tcp'}{'1508'}++	; 
#	$ports_ref->{'tcp'}{'1508'}{'name'} = 'diagmond'		; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'port'}{'udp'} = '1870'	; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'ports'}{'udp'}{'1870'}++	; 
#	$ports_ref->{'udp'}{'1870'}{'name'} = 'sunscalar-dns'		; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'port'}{'tcp'} = '1870'	; 
#	$srvcobjects_ref->{'sunscalar-dns'}{'ports'}{'tcp'}{'1870'}++	; 
#	$ports_ref->{'tcp'}{'1870'}{'name'} = 'sunscalar-dns'		; 
#	$srvcobjects_ref->{'abr-basic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abr-basic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abr-basic'}{'port'}{'udp'} = '1954'	; 
#	$srvcobjects_ref->{'abr-basic'}{'ports'}{'udp'}{'1954'}++	; 
#	$ports_ref->{'udp'}{'1954'}{'name'} = 'abr-basic'		; 
#	$srvcobjects_ref->{'abr-basic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abr-basic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abr-basic'}{'port'}{'tcp'} = '1954'	; 
#	$srvcobjects_ref->{'abr-basic'}{'ports'}{'tcp'}{'1954'}++	; 
#	$ports_ref->{'tcp'}{'1954'}{'name'} = 'abr-basic'		; 
#	$srvcobjects_ref->{'newlixconfig'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newlixconfig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newlixconfig'}{'port'}{'udp'} = '2076'	; 
#	$srvcobjects_ref->{'newlixconfig'}{'ports'}{'udp'}{'2076'}++	; 
#	$ports_ref->{'udp'}{'2076'}{'name'} = 'newlixconfig'		; 
#	$srvcobjects_ref->{'newlixconfig'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newlixconfig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newlixconfig'}{'port'}{'tcp'} = '2076'	; 
#	$srvcobjects_ref->{'newlixconfig'}{'ports'}{'tcp'}{'2076'}++	; 
#	$ports_ref->{'tcp'}{'2076'}{'name'} = 'newlixconfig'		; 
#	$srvcobjects_ref->{'ipcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcd'}{'port'}{'udp'} = '576'	; 
#	$srvcobjects_ref->{'ipcd'}{'ports'}{'udp'}{'576'}++	; 
#	$ports_ref->{'udp'}{'576'}{'name'} = 'ipcd'		; 
#	$srvcobjects_ref->{'ipcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcd'}{'port'}{'tcp'} = '576'	; 
#	$srvcobjects_ref->{'ipcd'}{'ports'}{'tcp'}{'576'}++	; 
#	$ports_ref->{'tcp'}{'576'}{'name'} = 'ipcd'		; 
#	$srvcobjects_ref->{'intrastar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intrastar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intrastar'}{'port'}{'udp'} = '1907'	; 
#	$srvcobjects_ref->{'intrastar'}{'ports'}{'udp'}{'1907'}++	; 
#	$ports_ref->{'udp'}{'1907'}{'name'} = 'intrastar'		; 
#	$srvcobjects_ref->{'intrastar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intrastar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intrastar'}{'port'}{'tcp'} = '1907'	; 
#	$srvcobjects_ref->{'intrastar'}{'ports'}{'tcp'}{'1907'}++	; 
#	$ports_ref->{'tcp'}{'1907'}{'name'} = 'intrastar'		; 
#	$srvcobjects_ref->{'nifty-hmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nifty-hmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nifty-hmi'}{'port'}{'udp'} = '4134'	; 
#	$srvcobjects_ref->{'nifty-hmi'}{'ports'}{'udp'}{'4134'}++	; 
#	$ports_ref->{'udp'}{'4134'}{'name'} = 'nifty-hmi'		; 
#	$srvcobjects_ref->{'nifty-hmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nifty-hmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nifty-hmi'}{'port'}{'tcp'} = '4134'	; 
#	$srvcobjects_ref->{'nifty-hmi'}{'ports'}{'tcp'}{'4134'}++	; 
#	$ports_ref->{'tcp'}{'4134'}{'name'} = 'nifty-hmi'		; 
#	$srvcobjects_ref->{'prospero'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prospero'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prospero'}{'port'}{'udp'} = '191'	; 
#	$srvcobjects_ref->{'prospero'}{'ports'}{'udp'}{'191'}++	; 
#	$ports_ref->{'udp'}{'191'}{'name'} = 'prospero'		; 
#	$srvcobjects_ref->{'prospero'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prospero'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prospero'}{'port'}{'tcp'} = '191'	; 
#	$srvcobjects_ref->{'prospero'}{'ports'}{'tcp'}{'191'}++	; 
#	$ports_ref->{'tcp'}{'191'}{'name'} = 'prospero'		; 
#	$srvcobjects_ref->{'creativepartnr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'port'}{'udp'} = '3366'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'ports'}{'udp'}{'3366'}++	; 
#	$ports_ref->{'udp'}{'3366'}{'name'} = 'creativepartnr'		; 
#	$srvcobjects_ref->{'creativepartnr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'port'}{'udp'} = '455'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'ports'}{'udp'}{'455'}++	; 
#	$ports_ref->{'udp'}{'455'}{'name'} = 'creativepartnr'		; 
#	$srvcobjects_ref->{'creativepartnr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'port'}{'tcp'} = '3366'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'ports'}{'tcp'}{'3366'}++	; 
#	$ports_ref->{'tcp'}{'3366'}{'name'} = 'creativepartnr'		; 
#	$srvcobjects_ref->{'creativepartnr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'port'}{'tcp'} = '455'	; 
#	$srvcobjects_ref->{'creativepartnr'}{'ports'}{'tcp'}{'455'}++	; 
#	$ports_ref->{'tcp'}{'455'}{'name'} = 'creativepartnr'		; 
#	$srvcobjects_ref->{'swiftnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swiftnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swiftnet'}{'port'}{'udp'} = '1751'	; 
#	$srvcobjects_ref->{'swiftnet'}{'ports'}{'udp'}{'1751'}++	; 
#	$ports_ref->{'udp'}{'1751'}{'name'} = 'swiftnet'		; 
#	$srvcobjects_ref->{'swiftnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swiftnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swiftnet'}{'port'}{'tcp'} = '1751'	; 
#	$srvcobjects_ref->{'swiftnet'}{'ports'}{'tcp'}{'1751'}++	; 
#	$ports_ref->{'tcp'}{'1751'}{'name'} = 'swiftnet'		; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'port'}{'udp'} = '2369'	; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'ports'}{'udp'}{'2369'}++	; 
#	$ports_ref->{'udp'}{'2369'}{'name'} = 'acs2000-dsp'		; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'port'}{'tcp'} = '2369'	; 
#	$srvcobjects_ref->{'acs2000-dsp'}{'ports'}{'tcp'}{'2369'}++	; 
#	$ports_ref->{'tcp'}{'2369'}{'name'} = 'acs2000-dsp'		; 
#	$srvcobjects_ref->{'sm-pas-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sm-pas-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-1'}{'port'}{'udp'} = '2938'	; 
#	$srvcobjects_ref->{'sm-pas-1'}{'ports'}{'udp'}{'2938'}++	; 
#	$ports_ref->{'udp'}{'2938'}{'name'} = 'sm-pas-1'		; 
#	$srvcobjects_ref->{'sm-pas-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sm-pas-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-1'}{'port'}{'tcp'} = '2938'	; 
#	$srvcobjects_ref->{'sm-pas-1'}{'ports'}{'tcp'}{'2938'}++	; 
#	$ports_ref->{'tcp'}{'2938'}{'name'} = 'sm-pas-1'		; 
#	$srvcobjects_ref->{'prm-nm-np'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prm-nm-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-nm-np'}{'port'}{'udp'} = '1403'	; 
#	$srvcobjects_ref->{'prm-nm-np'}{'ports'}{'udp'}{'1403'}++	; 
#	$ports_ref->{'udp'}{'1403'}{'name'} = 'prm-nm-np'		; 
#	$srvcobjects_ref->{'prm-nm-np'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prm-nm-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-nm-np'}{'port'}{'tcp'} = '1403'	; 
#	$srvcobjects_ref->{'prm-nm-np'}{'ports'}{'tcp'}{'1403'}++	; 
#	$ports_ref->{'tcp'}{'1403'}{'name'} = 'prm-nm-np'		; 
#	$srvcobjects_ref->{'eisport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eisport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eisport'}{'port'}{'udp'} = '3525'	; 
#	$srvcobjects_ref->{'eisport'}{'ports'}{'udp'}{'3525'}++	; 
#	$ports_ref->{'udp'}{'3525'}{'name'} = 'eisport'		; 
#	$srvcobjects_ref->{'eisport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eisport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eisport'}{'port'}{'tcp'} = '3525'	; 
#	$srvcobjects_ref->{'eisport'}{'ports'}{'tcp'}{'3525'}++	; 
#	$ports_ref->{'tcp'}{'3525'}{'name'} = 'eisport'		; 
#	$srvcobjects_ref->{'blockade'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'blockade'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blockade'}{'port'}{'udp'} = '2911'	; 
#	$srvcobjects_ref->{'blockade'}{'ports'}{'udp'}{'2911'}++	; 
#	$ports_ref->{'udp'}{'2911'}{'name'} = 'blockade'		; 
#	$srvcobjects_ref->{'blockade'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'blockade'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blockade'}{'port'}{'tcp'} = '2911'	; 
#	$srvcobjects_ref->{'blockade'}{'ports'}{'tcp'}{'2911'}++	; 
#	$ports_ref->{'tcp'}{'2911'}{'name'} = 'blockade'		; 
#	$srvcobjects_ref->{'interpathpanel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interpathpanel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interpathpanel'}{'port'}{'udp'} = '2652'	; 
#	$srvcobjects_ref->{'interpathpanel'}{'ports'}{'udp'}{'2652'}++	; 
#	$ports_ref->{'udp'}{'2652'}{'name'} = 'interpathpanel'		; 
#	$srvcobjects_ref->{'interpathpanel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interpathpanel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interpathpanel'}{'port'}{'tcp'} = '2652'	; 
#	$srvcobjects_ref->{'interpathpanel'}{'ports'}{'tcp'}{'2652'}++	; 
#	$ports_ref->{'tcp'}{'2652'}{'name'} = 'interpathpanel'		; 
#	$srvcobjects_ref->{'ftsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftsrv'}{'port'}{'udp'} = '1359'	; 
#	$srvcobjects_ref->{'ftsrv'}{'ports'}{'udp'}{'1359'}++	; 
#	$ports_ref->{'udp'}{'1359'}{'name'} = 'ftsrv'		; 
#	$srvcobjects_ref->{'ftsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftsrv'}{'port'}{'tcp'} = '1359'	; 
#	$srvcobjects_ref->{'ftsrv'}{'ports'}{'tcp'}{'1359'}++	; 
#	$ports_ref->{'tcp'}{'1359'}{'name'} = 'ftsrv'		; 
#	$srvcobjects_ref->{'mpfoncl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpfoncl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpfoncl'}{'port'}{'udp'} = '2579'	; 
#	$srvcobjects_ref->{'mpfoncl'}{'ports'}{'udp'}{'2579'}++	; 
#	$ports_ref->{'udp'}{'2579'}{'name'} = 'mpfoncl'		; 
#	$srvcobjects_ref->{'mpfoncl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpfoncl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpfoncl'}{'port'}{'tcp'} = '2579'	; 
#	$srvcobjects_ref->{'mpfoncl'}{'ports'}{'tcp'}{'2579'}++	; 
#	$ports_ref->{'tcp'}{'2579'}{'name'} = 'mpfoncl'		; 
#	$srvcobjects_ref->{'kazaa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kazaa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kazaa'}{'port'}{'udp'} = '1214'	; 
#	$srvcobjects_ref->{'kazaa'}{'ports'}{'udp'}{'1214'}++	; 
#	$ports_ref->{'udp'}{'1214'}{'name'} = 'kazaa'		; 
#	$srvcobjects_ref->{'kazaa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kazaa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kazaa'}{'port'}{'tcp'} = '1214'	; 
#	$srvcobjects_ref->{'kazaa'}{'ports'}{'tcp'}{'1214'}++	; 
#	$ports_ref->{'tcp'}{'1214'}{'name'} = 'kazaa'		; 
#	$srvcobjects_ref->{'messageasap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'messageasap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'messageasap'}{'port'}{'udp'} = '6070'	; 
#	$srvcobjects_ref->{'messageasap'}{'ports'}{'udp'}{'6070'}++	; 
#	$ports_ref->{'udp'}{'6070'}{'name'} = 'messageasap'		; 
#	$srvcobjects_ref->{'messageasap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'messageasap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'messageasap'}{'port'}{'tcp'} = '6070'	; 
#	$srvcobjects_ref->{'messageasap'}{'ports'}{'tcp'}{'6070'}++	; 
#	$ports_ref->{'tcp'}{'6070'}{'name'} = 'messageasap'		; 
#	$srvcobjects_ref->{'trellisagt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trellisagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trellisagt'}{'port'}{'udp'} = '2077'	; 
#	$srvcobjects_ref->{'trellisagt'}{'ports'}{'udp'}{'2077'}++	; 
#	$ports_ref->{'udp'}{'2077'}{'name'} = 'trellisagt'		; 
#	$srvcobjects_ref->{'trellisagt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trellisagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trellisagt'}{'port'}{'tcp'} = '2077'	; 
#	$srvcobjects_ref->{'trellisagt'}{'ports'}{'tcp'}{'2077'}++	; 
#	$ports_ref->{'tcp'}{'2077'}{'name'} = 'trellisagt'		; 
#	$srvcobjects_ref->{'seclayer-tls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'seclayer-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seclayer-tls'}{'port'}{'udp'} = '3496'	; 
#	$srvcobjects_ref->{'seclayer-tls'}{'ports'}{'udp'}{'3496'}++	; 
#	$ports_ref->{'udp'}{'3496'}{'name'} = 'seclayer-tls'		; 
#	$srvcobjects_ref->{'seclayer-tls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'seclayer-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seclayer-tls'}{'port'}{'tcp'} = '3496'	; 
#	$srvcobjects_ref->{'seclayer-tls'}{'ports'}{'tcp'}{'3496'}++	; 
#	$ports_ref->{'tcp'}{'3496'}{'name'} = 'seclayer-tls'		; 
#	$srvcobjects_ref->{'autocuetime'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'autocuetime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autocuetime'}{'port'}{'udp'} = '3104'	; 
#	$srvcobjects_ref->{'autocuetime'}{'ports'}{'udp'}{'3104'}++	; 
#	$ports_ref->{'udp'}{'3104'}{'name'} = 'autocuetime'		; 
#	$srvcobjects_ref->{'lnvconsole'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lnvconsole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvconsole'}{'port'}{'udp'} = '2281'	; 
#	$srvcobjects_ref->{'lnvconsole'}{'ports'}{'udp'}{'2281'}++	; 
#	$ports_ref->{'udp'}{'2281'}{'name'} = 'lnvconsole'		; 
#	$srvcobjects_ref->{'lnvconsole'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lnvconsole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvconsole'}{'port'}{'tcp'} = '2281'	; 
#	$srvcobjects_ref->{'lnvconsole'}{'ports'}{'tcp'}{'2281'}++	; 
#	$ports_ref->{'tcp'}{'2281'}{'name'} = 'lnvconsole'		; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'port'}{'udp'} = '6767'	; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'ports'}{'udp'}{'6767'}++	; 
#	$ports_ref->{'udp'}{'6767'}{'name'} = 'bmc-perf-agent'		; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'port'}{'tcp'} = '6767'	; 
#	$srvcobjects_ref->{'bmc-perf-agent'}{'ports'}{'tcp'}{'6767'}++	; 
#	$ports_ref->{'tcp'}{'6767'}{'name'} = 'bmc-perf-agent'		; 
#	$srvcobjects_ref->{'silkp4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'silkp4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp4'}{'port'}{'udp'} = '2832'	; 
#	$srvcobjects_ref->{'silkp4'}{'ports'}{'udp'}{'2832'}++	; 
#	$ports_ref->{'udp'}{'2832'}{'name'} = 'silkp4'		; 
#	$srvcobjects_ref->{'silkp4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'silkp4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp4'}{'port'}{'tcp'} = '2832'	; 
#	$srvcobjects_ref->{'silkp4'}{'ports'}{'tcp'}{'2832'}++	; 
#	$ports_ref->{'tcp'}{'2832'}{'name'} = 'silkp4'		; 
#	$srvcobjects_ref->{'ncdmirroring'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncdmirroring'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncdmirroring'}{'port'}{'udp'} = '2706'	; 
#	$srvcobjects_ref->{'ncdmirroring'}{'ports'}{'udp'}{'2706'}++	; 
#	$ports_ref->{'udp'}{'2706'}{'name'} = 'ncdmirroring'		; 
#	$srvcobjects_ref->{'ncdmirroring'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncdmirroring'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncdmirroring'}{'port'}{'tcp'} = '2706'	; 
#	$srvcobjects_ref->{'ncdmirroring'}{'ports'}{'tcp'}{'2706'}++	; 
#	$ports_ref->{'tcp'}{'2706'}{'name'} = 'ncdmirroring'		; 
#	$srvcobjects_ref->{'aci'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aci'}{'port'}{'udp'} = '187'	; 
#	$srvcobjects_ref->{'aci'}{'ports'}{'udp'}{'187'}++	; 
#	$ports_ref->{'udp'}{'187'}{'name'} = 'aci'		; 
#	$srvcobjects_ref->{'aci'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aci'}{'port'}{'tcp'} = '187'	; 
#	$srvcobjects_ref->{'aci'}{'ports'}{'tcp'}{'187'}++	; 
#	$ports_ref->{'tcp'}{'187'}{'name'} = 'aci'		; 
#	$srvcobjects_ref->{'kerberos-adm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kerberos-adm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kerberos-adm'}{'port'}{'udp'} = '749'	; 
#	$srvcobjects_ref->{'kerberos-adm'}{'ports'}{'udp'}{'749'}++	; 
#	$ports_ref->{'udp'}{'749'}{'name'} = 'kerberos-adm'		; 
#	$srvcobjects_ref->{'kerberos-adm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kerberos-adm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kerberos-adm'}{'port'}{'tcp'} = '749'	; 
#	$srvcobjects_ref->{'kerberos-adm'}{'ports'}{'tcp'}{'749'}++	; 
#	$ports_ref->{'tcp'}{'749'}{'name'} = 'kerberos-adm'		; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'port'}{'udp'} = '1218'	; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'ports'}{'udp'}{'1218'}++	; 
#	$ports_ref->{'udp'}{'1218'}{'name'} = 'aeroflight-ads'		; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'port'}{'tcp'} = '1218'	; 
#	$srvcobjects_ref->{'aeroflight-ads'}{'ports'}{'tcp'}{'1218'}++	; 
#	$ports_ref->{'tcp'}{'1218'}{'name'} = 'aeroflight-ads'		; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'port'}{'udp'} = '2657'	; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'ports'}{'udp'}{'2657'}++	; 
#	$ports_ref->{'udp'}{'2657'}{'name'} = 'sns-dispatcher'		; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'port'}{'tcp'} = '2657'	; 
#	$srvcobjects_ref->{'sns-dispatcher'}{'ports'}{'tcp'}{'2657'}++	; 
#	$ports_ref->{'tcp'}{'2657'}{'name'} = 'sns-dispatcher'		; 
#	$srvcobjects_ref->{'wago-io-system'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wago-io-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wago-io-system'}{'port'}{'udp'} = '2455'	; 
#	$srvcobjects_ref->{'wago-io-system'}{'ports'}{'udp'}{'2455'}++	; 
#	$ports_ref->{'udp'}{'2455'}{'name'} = 'wago-io-system'		; 
#	$srvcobjects_ref->{'wago-io-system'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wago-io-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wago-io-system'}{'port'}{'tcp'} = '2455'	; 
#	$srvcobjects_ref->{'wago-io-system'}{'ports'}{'tcp'}{'2455'}++	; 
#	$ports_ref->{'tcp'}{'2455'}{'name'} = 'wago-io-system'		; 
#	$srvcobjects_ref->{'cctv-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cctv-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cctv-port'}{'port'}{'udp'} = '3559'	; 
#	$srvcobjects_ref->{'cctv-port'}{'ports'}{'udp'}{'3559'}++	; 
#	$ports_ref->{'udp'}{'3559'}{'name'} = 'cctv-port'		; 
#	$srvcobjects_ref->{'cctv-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cctv-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cctv-port'}{'port'}{'tcp'} = '3559'	; 
#	$srvcobjects_ref->{'cctv-port'}{'ports'}{'tcp'}{'3559'}++	; 
#	$ports_ref->{'tcp'}{'3559'}{'name'} = 'cctv-port'		; 
#	$srvcobjects_ref->{'rtip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtip'}{'port'}{'udp'} = '771'	; 
#	$srvcobjects_ref->{'rtip'}{'ports'}{'udp'}{'771'}++	; 
#	$ports_ref->{'udp'}{'771'}{'name'} = 'rtip'		; 
#	$srvcobjects_ref->{'rtip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtip'}{'port'}{'tcp'} = '771'	; 
#	$srvcobjects_ref->{'rtip'}{'ports'}{'tcp'}{'771'}++	; 
#	$ports_ref->{'tcp'}{'771'}{'name'} = 'rtip'		; 
#	$srvcobjects_ref->{'optika-emedia'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'optika-emedia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optika-emedia'}{'port'}{'udp'} = '1829'	; 
#	$srvcobjects_ref->{'optika-emedia'}{'ports'}{'udp'}{'1829'}++	; 
#	$ports_ref->{'udp'}{'1829'}{'name'} = 'optika-emedia'		; 
#	$srvcobjects_ref->{'optika-emedia'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'optika-emedia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optika-emedia'}{'port'}{'tcp'} = '1829'	; 
#	$srvcobjects_ref->{'optika-emedia'}{'ports'}{'tcp'}{'1829'}++	; 
#	$ports_ref->{'tcp'}{'1829'}{'name'} = 'optika-emedia'		; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'port'}{'udp'} = '25793'	; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'ports'}{'udp'}{'25793'}++	; 
#	$ports_ref->{'udp'}{'25793'}{'name'} = 'vocaltec-hos'		; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'port'}{'tcp'} = '25793'	; 
#	$srvcobjects_ref->{'vocaltec-hos'}{'ports'}{'tcp'}{'25793'}++	; 
#	$ports_ref->{'tcp'}{'25793'}{'name'} = 'vocaltec-hos'		; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'port'}{'udp'} = '6670'	; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'ports'}{'udp'}{'6670'}++	; 
#	$ports_ref->{'udp'}{'6670'}{'name'} = 'vocaltec-gold'		; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'port'}{'tcp'} = '6670'	; 
#	$srvcobjects_ref->{'vocaltec-gold'}{'ports'}{'tcp'}{'6670'}++	; 
#	$ports_ref->{'tcp'}{'6670'}{'name'} = 'vocaltec-gold'		; 
#	$srvcobjects_ref->{'exlm-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'exlm-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exlm-agent'}{'port'}{'udp'} = '3002'	; 
#	$srvcobjects_ref->{'exlm-agent'}{'ports'}{'udp'}{'3002'}++	; 
#	$ports_ref->{'udp'}{'3002'}{'name'} = 'exlm-agent'		; 
#	$srvcobjects_ref->{'exlm-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'exlm-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exlm-agent'}{'port'}{'tcp'} = '3002'	; 
#	$srvcobjects_ref->{'exlm-agent'}{'ports'}{'tcp'}{'3002'}++	; 
#	$ports_ref->{'tcp'}{'3002'}{'name'} = 'exlm-agent'		; 
#	$srvcobjects_ref->{'capfast-lmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'capfast-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'capfast-lmd'}{'port'}{'udp'} = '1756'	; 
#	$srvcobjects_ref->{'capfast-lmd'}{'ports'}{'udp'}{'1756'}++	; 
#	$ports_ref->{'udp'}{'1756'}{'name'} = 'capfast-lmd'		; 
#	$srvcobjects_ref->{'capfast-lmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'capfast-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'capfast-lmd'}{'port'}{'tcp'} = '1756'	; 
#	$srvcobjects_ref->{'capfast-lmd'}{'ports'}{'tcp'}{'1756'}++	; 
#	$ports_ref->{'tcp'}{'1756'}{'name'} = 'capfast-lmd'		; 
#	$srvcobjects_ref->{'remoteware-un'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remoteware-un'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remoteware-un'}{'port'}{'udp'} = '2999'	; 
#	$srvcobjects_ref->{'remoteware-un'}{'ports'}{'udp'}{'2999'}++	; 
#	$ports_ref->{'udp'}{'2999'}{'name'} = 'remoteware-un'		; 
#	$srvcobjects_ref->{'remoteware-un'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remoteware-un'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remoteware-un'}{'port'}{'tcp'} = '2999'	; 
#	$srvcobjects_ref->{'remoteware-un'}{'ports'}{'tcp'}{'2999'}++	; 
#	$ports_ref->{'tcp'}{'2999'}{'name'} = 'remoteware-un'		; 
#	$srvcobjects_ref->{'obrpd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'obrpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'obrpd'}{'port'}{'udp'} = '1092'	; 
#	$srvcobjects_ref->{'obrpd'}{'ports'}{'udp'}{'1092'}++	; 
#	$ports_ref->{'udp'}{'1092'}{'name'} = 'obrpd'		; 
#	$srvcobjects_ref->{'obrpd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'obrpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'obrpd'}{'port'}{'tcp'} = '1092'	; 
#	$srvcobjects_ref->{'obrpd'}{'ports'}{'tcp'}{'1092'}++	; 
#	$ports_ref->{'tcp'}{'1092'}{'name'} = 'obrpd'		; 
#	$srvcobjects_ref->{'raid-ac'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raid-ac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raid-ac'}{'port'}{'udp'} = '2012'	; 
#	$srvcobjects_ref->{'raid-ac'}{'ports'}{'udp'}{'2012'}++	; 
#	$ports_ref->{'udp'}{'2012'}{'name'} = 'raid-ac'		; 
#	$srvcobjects_ref->{'uaac'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uaac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uaac'}{'port'}{'udp'} = '145'	; 
#	$srvcobjects_ref->{'uaac'}{'ports'}{'udp'}{'145'}++	; 
#	$ports_ref->{'udp'}{'145'}{'name'} = 'uaac'		; 
#	$srvcobjects_ref->{'uaac'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uaac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uaac'}{'port'}{'tcp'} = '145'	; 
#	$srvcobjects_ref->{'uaac'}{'ports'}{'tcp'}{'145'}++	; 
#	$ports_ref->{'tcp'}{'145'}{'name'} = 'uaac'		; 
#	$srvcobjects_ref->{'scoi2odialog'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scoi2odialog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scoi2odialog'}{'port'}{'udp'} = '360'	; 
#	$srvcobjects_ref->{'scoi2odialog'}{'ports'}{'udp'}{'360'}++	; 
#	$ports_ref->{'udp'}{'360'}{'name'} = 'scoi2odialog'		; 
#	$srvcobjects_ref->{'scoi2odialog'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scoi2odialog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scoi2odialog'}{'port'}{'tcp'} = '360'	; 
#	$srvcobjects_ref->{'scoi2odialog'}{'ports'}{'tcp'}{'360'}++	; 
#	$ports_ref->{'tcp'}{'360'}{'name'} = 'scoi2odialog'		; 
#	$srvcobjects_ref->{'iso-ill'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iso-ill'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-ill'}{'port'}{'udp'} = '499'	; 
#	$srvcobjects_ref->{'iso-ill'}{'ports'}{'udp'}{'499'}++	; 
#	$ports_ref->{'udp'}{'499'}{'name'} = 'iso-ill'		; 
#	$srvcobjects_ref->{'iso-ill'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iso-ill'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-ill'}{'port'}{'tcp'} = '499'	; 
#	$srvcobjects_ref->{'iso-ill'}{'ports'}{'tcp'}{'499'}++	; 
#	$ports_ref->{'tcp'}{'499'}{'name'} = 'iso-ill'		; 
#	$srvcobjects_ref->{'os-licman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'os-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'os-licman'}{'port'}{'udp'} = '1384'	; 
#	$srvcobjects_ref->{'os-licman'}{'ports'}{'udp'}{'1384'}++	; 
#	$ports_ref->{'udp'}{'1384'}{'name'} = 'os-licman'		; 
#	$srvcobjects_ref->{'os-licman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'os-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'os-licman'}{'port'}{'tcp'} = '1384'	; 
#	$srvcobjects_ref->{'os-licman'}{'ports'}{'tcp'}{'1384'}++	; 
#	$ports_ref->{'tcp'}{'1384'}{'name'} = 'os-licman'		; 
#	$srvcobjects_ref->{'singlept-mvs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'singlept-mvs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'singlept-mvs'}{'port'}{'udp'} = '2769'	; 
#	$srvcobjects_ref->{'singlept-mvs'}{'ports'}{'udp'}{'2769'}++	; 
#	$ports_ref->{'udp'}{'2769'}{'name'} = 'singlept-mvs'		; 
#	$srvcobjects_ref->{'singlept-mvs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'singlept-mvs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'singlept-mvs'}{'port'}{'tcp'} = '2769'	; 
#	$srvcobjects_ref->{'singlept-mvs'}{'ports'}{'tcp'}{'2769'}++	; 
#	$ports_ref->{'tcp'}{'2769'}{'name'} = 'singlept-mvs'		; 
#	$srvcobjects_ref->{'rds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rds'}{'port'}{'udp'} = '1540'	; 
#	$srvcobjects_ref->{'rds'}{'ports'}{'udp'}{'1540'}++	; 
#	$ports_ref->{'udp'}{'1540'}{'name'} = 'rds'		; 
#	$srvcobjects_ref->{'rds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rds'}{'port'}{'tcp'} = '1540'	; 
#	$srvcobjects_ref->{'rds'}{'ports'}{'tcp'}{'1540'}++	; 
#	$ports_ref->{'tcp'}{'1540'}{'name'} = 'rds'		; 
#	$srvcobjects_ref->{'qmqp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qmqp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qmqp'}{'port'}{'udp'} = '628'	; 
#	$srvcobjects_ref->{'qmqp'}{'ports'}{'udp'}{'628'}++	; 
#	$ports_ref->{'udp'}{'628'}{'name'} = 'qmqp'		; 
#	$srvcobjects_ref->{'qmqp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qmqp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qmqp'}{'port'}{'tcp'} = '628'	; 
#	$srvcobjects_ref->{'qmqp'}{'ports'}{'tcp'}{'628'}++	; 
#	$ports_ref->{'tcp'}{'628'}{'name'} = 'qmqp'		; 
#	$srvcobjects_ref->{'cruise-config'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cruise-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-config'}{'port'}{'udp'} = '8378'	; 
#	$srvcobjects_ref->{'cruise-config'}{'ports'}{'udp'}{'8378'}++	; 
#	$ports_ref->{'udp'}{'8378'}{'name'} = 'cruise-config'		; 
#	$srvcobjects_ref->{'cruise-config'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cruise-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-config'}{'port'}{'tcp'} = '8378'	; 
#	$srvcobjects_ref->{'cruise-config'}{'ports'}{'tcp'}{'8378'}++	; 
#	$ports_ref->{'tcp'}{'8378'}{'name'} = 'cruise-config'		; 
#	$srvcobjects_ref->{'univision'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'univision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'univision'}{'port'}{'udp'} = '2820'	; 
#	$srvcobjects_ref->{'univision'}{'ports'}{'udp'}{'2820'}++	; 
#	$ports_ref->{'udp'}{'2820'}{'name'} = 'univision'		; 
#	$srvcobjects_ref->{'univision'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'univision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'univision'}{'port'}{'tcp'} = '2820'	; 
#	$srvcobjects_ref->{'univision'}{'ports'}{'tcp'}{'2820'}++	; 
#	$ports_ref->{'tcp'}{'2820'}{'name'} = 'univision'		; 
#	$srvcobjects_ref->{'mon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mon'}{'port'}{'udp'} = '2583'	; 
#	$srvcobjects_ref->{'mon'}{'ports'}{'udp'}{'2583'}++	; 
#	$ports_ref->{'udp'}{'2583'}{'name'} = 'mon'		; 
#	$srvcobjects_ref->{'mon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mon'}{'port'}{'tcp'} = '2583'	; 
#	$srvcobjects_ref->{'mon'}{'ports'}{'tcp'}{'2583'}++	; 
#	$ports_ref->{'tcp'}{'2583'}{'name'} = 'mon'		; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'port'}{'udp'} = '3657'	; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'ports'}{'udp'}{'3657'}++	; 
#	$ports_ref->{'udp'}{'3657'}{'name'} = 'immedianet-bcn'		; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'port'}{'tcp'} = '3657'	; 
#	$srvcobjects_ref->{'immedianet-bcn'}{'ports'}{'tcp'}{'3657'}++	; 
#	$ports_ref->{'tcp'}{'3657'}{'name'} = 'immedianet-bcn'		; 
#	$srvcobjects_ref->{'nani'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nani'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nani'}{'port'}{'udp'} = '2236'	; 
#	$srvcobjects_ref->{'nani'}{'ports'}{'udp'}{'2236'}++	; 
#	$ports_ref->{'udp'}{'2236'}{'name'} = 'nani'		; 
#	$srvcobjects_ref->{'nani'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nani'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nani'}{'port'}{'tcp'} = '2236'	; 
#	$srvcobjects_ref->{'nani'}{'ports'}{'tcp'}{'2236'}++	; 
#	$ports_ref->{'tcp'}{'2236'}{'name'} = 'nani'		; 
#	$srvcobjects_ref->{'clearcase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'clearcase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clearcase'}{'port'}{'udp'} = '371'	; 
#	$srvcobjects_ref->{'clearcase'}{'ports'}{'udp'}{'371'}++	; 
#	$ports_ref->{'udp'}{'371'}{'name'} = 'clearcase'		; 
#	$srvcobjects_ref->{'clearcase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'clearcase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clearcase'}{'port'}{'tcp'} = '371'	; 
#	$srvcobjects_ref->{'clearcase'}{'ports'}{'tcp'}{'371'}++	; 
#	$ports_ref->{'tcp'}{'371'}{'name'} = 'clearcase'		; 
#	$srvcobjects_ref->{'everydayrc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'everydayrc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'everydayrc'}{'port'}{'udp'} = '2782'	; 
#	$srvcobjects_ref->{'everydayrc'}{'ports'}{'udp'}{'2782'}++	; 
#	$ports_ref->{'udp'}{'2782'}{'name'} = 'everydayrc'		; 
#	$srvcobjects_ref->{'everydayrc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'everydayrc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'everydayrc'}{'port'}{'tcp'} = '2782'	; 
#	$srvcobjects_ref->{'everydayrc'}{'ports'}{'tcp'}{'2782'}++	; 
#	$ports_ref->{'tcp'}{'2782'}{'name'} = 'everydayrc'		; 
#	$srvcobjects_ref->{'icl-twobase10'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase10'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase10'}{'port'}{'udp'} = '25009'	; 
#	$srvcobjects_ref->{'icl-twobase10'}{'ports'}{'udp'}{'25009'}++	; 
#	$ports_ref->{'udp'}{'25009'}{'name'} = 'icl-twobase10'		; 
#	$srvcobjects_ref->{'icl-twobase10'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase10'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase10'}{'port'}{'tcp'} = '25009'	; 
#	$srvcobjects_ref->{'icl-twobase10'}{'ports'}{'tcp'}{'25009'}++	; 
#	$ports_ref->{'tcp'}{'25009'}{'name'} = 'icl-twobase10'		; 
#	$srvcobjects_ref->{'infomover'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infomover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infomover'}{'port'}{'udp'} = '2854'	; 
#	$srvcobjects_ref->{'infomover'}{'ports'}{'udp'}{'2854'}++	; 
#	$ports_ref->{'udp'}{'2854'}{'name'} = 'infomover'		; 
#	$srvcobjects_ref->{'infomover'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infomover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infomover'}{'port'}{'tcp'} = '2854'	; 
#	$srvcobjects_ref->{'infomover'}{'ports'}{'tcp'}{'2854'}++	; 
#	$ports_ref->{'tcp'}{'2854'}{'name'} = 'infomover'		; 
#	$srvcobjects_ref->{'td-service'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'td-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'td-service'}{'port'}{'udp'} = '267'	; 
#	$srvcobjects_ref->{'td-service'}{'ports'}{'udp'}{'267'}++	; 
#	$ports_ref->{'udp'}{'267'}{'name'} = 'td-service'		; 
#	$srvcobjects_ref->{'td-service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'td-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'td-service'}{'port'}{'tcp'} = '267'	; 
#	$srvcobjects_ref->{'td-service'}{'ports'}{'tcp'}{'267'}++	; 
#	$ports_ref->{'tcp'}{'267'}{'name'} = 'td-service'		; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'port'}{'udp'} = '10101'	; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'ports'}{'udp'}{'10101'}++	; 
#	$ports_ref->{'udp'}{'10101'}{'name'} = 'ezmeeting-2'		; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'port'}{'tcp'} = '10101'	; 
#	$srvcobjects_ref->{'ezmeeting-2'}{'ports'}{'tcp'}{'10101'}++	; 
#	$ports_ref->{'tcp'}{'10101'}{'name'} = 'ezmeeting-2'		; 
#	$srvcobjects_ref->{'msgsrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msgsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msgsrvr'}{'port'}{'udp'} = '8787'	; 
#	$srvcobjects_ref->{'msgsrvr'}{'ports'}{'udp'}{'8787'}++	; 
#	$ports_ref->{'udp'}{'8787'}{'name'} = 'msgsrvr'		; 
#	$srvcobjects_ref->{'msgsrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msgsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msgsrvr'}{'port'}{'tcp'} = '8787'	; 
#	$srvcobjects_ref->{'msgsrvr'}{'ports'}{'tcp'}{'8787'}++	; 
#	$ports_ref->{'tcp'}{'8787'}{'name'} = 'msgsrvr'		; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'port'}{'udp'} = '547'	; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'ports'}{'udp'}{'547'}++	; 
#	$ports_ref->{'udp'}{'547'}{'name'} = 'dhcpv6-server'		; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'port'}{'tcp'} = '547'	; 
#	$srvcobjects_ref->{'dhcpv6-server'}{'ports'}{'tcp'}{'547'}++	; 
#	$ports_ref->{'tcp'}{'547'}{'name'} = 'dhcpv6-server'		; 
#	$srvcobjects_ref->{'vocaltec-wconf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vocaltec-wconf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-wconf'}{'port'}{'tcp'} = '22555'	; 
#	$srvcobjects_ref->{'vocaltec-wconf'}{'ports'}{'tcp'}{'22555'}++	; 
#	$ports_ref->{'tcp'}{'22555'}{'name'} = 'vocaltec-wconf'		; 
#	$srvcobjects_ref->{'lds-distrib'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lds-distrib'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lds-distrib'}{'port'}{'udp'} = '6543'	; 
#	$srvcobjects_ref->{'lds-distrib'}{'ports'}{'udp'}{'6543'}++	; 
#	$ports_ref->{'udp'}{'6543'}{'name'} = 'lds-distrib'		; 
#	$srvcobjects_ref->{'lds-distrib'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lds-distrib'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lds-distrib'}{'port'}{'tcp'} = '6543'	; 
#	$srvcobjects_ref->{'lds-distrib'}{'ports'}{'tcp'}{'6543'}++	; 
#	$ports_ref->{'tcp'}{'6543'}{'name'} = 'lds-distrib'		; 
#	$srvcobjects_ref->{'alta-smp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alta-smp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alta-smp'}{'port'}{'udp'} = '3433'	; 
#	$srvcobjects_ref->{'alta-smp'}{'ports'}{'udp'}{'3433'}++	; 
#	$ports_ref->{'udp'}{'3433'}{'name'} = 'alta-smp'		; 
#	$srvcobjects_ref->{'alta-smp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alta-smp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alta-smp'}{'port'}{'tcp'} = '3433'	; 
#	$srvcobjects_ref->{'alta-smp'}{'ports'}{'tcp'}{'3433'}++	; 
#	$ports_ref->{'tcp'}{'3433'}{'name'} = 'alta-smp'		; 
#	$srvcobjects_ref->{'itu-bicc-stc'}{'type'} = 'sctp'	; 
#	$srvcobjects_ref->{'itu-bicc-stc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itu-bicc-stc'}{'port'}{'sctp'} = '3097'	; 
#	$srvcobjects_ref->{'itu-bicc-stc'}{'ports'}{'sctp'}{'3097'}++	; 
#	$ports_ref->{'sctp'}{'3097'}{'name'} = 'itu-bicc-stc'		; 
#	$srvcobjects_ref->{'flukeserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'flukeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flukeserver'}{'port'}{'udp'} = '2359'	; 
#	$srvcobjects_ref->{'flukeserver'}{'ports'}{'udp'}{'2359'}++	; 
#	$ports_ref->{'udp'}{'2359'}{'name'} = 'flukeserver'		; 
#	$srvcobjects_ref->{'flukeserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'flukeserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flukeserver'}{'port'}{'tcp'} = '2359'	; 
#	$srvcobjects_ref->{'flukeserver'}{'ports'}{'tcp'}{'2359'}++	; 
#	$ports_ref->{'tcp'}{'2359'}{'name'} = 'flukeserver'		; 
#	$srvcobjects_ref->{'newacct'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newacct'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newacct'}{'port'}{'tcp'} = '100'	; 
#	$srvcobjects_ref->{'newacct'}{'ports'}{'tcp'}{'100'}++	; 
#	$ports_ref->{'tcp'}{'100'}{'name'} = 'newacct'		; 
#	$srvcobjects_ref->{'kentrox-prot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kentrox-prot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kentrox-prot'}{'port'}{'udp'} = '2502'	; 
#	$srvcobjects_ref->{'kentrox-prot'}{'ports'}{'udp'}{'2502'}++	; 
#	$ports_ref->{'udp'}{'2502'}{'name'} = 'kentrox-prot'		; 
#	$srvcobjects_ref->{'kentrox-prot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kentrox-prot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kentrox-prot'}{'port'}{'tcp'} = '2502'	; 
#	$srvcobjects_ref->{'kentrox-prot'}{'ports'}{'tcp'}{'2502'}++	; 
#	$ports_ref->{'tcp'}{'2502'}{'name'} = 'kentrox-prot'		; 
#	$srvcobjects_ref->{'eli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eli'}{'port'}{'udp'} = '2087'	; 
#	$srvcobjects_ref->{'eli'}{'ports'}{'udp'}{'2087'}++	; 
#	$ports_ref->{'udp'}{'2087'}{'name'} = 'eli'		; 
#	$srvcobjects_ref->{'eli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eli'}{'port'}{'tcp'} = '2087'	; 
#	$srvcobjects_ref->{'eli'}{'ports'}{'tcp'}{'2087'}++	; 
#	$ports_ref->{'tcp'}{'2087'}{'name'} = 'eli'		; 
#	$srvcobjects_ref->{'microsoft-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'microsoft-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microsoft-ds'}{'port'}{'udp'} = '445'	; 
#	$srvcobjects_ref->{'microsoft-ds'}{'ports'}{'udp'}{'445'}++	; 
#	$ports_ref->{'udp'}{'445'}{'name'} = 'microsoft-ds'		; 
#	$srvcobjects_ref->{'microsoft-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'microsoft-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microsoft-ds'}{'port'}{'tcp'} = '445'	; 
#	$srvcobjects_ref->{'microsoft-ds'}{'ports'}{'tcp'}{'445'}++	; 
#	$ports_ref->{'tcp'}{'445'}{'name'} = 'microsoft-ds'		; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'port'}{'udp'} = '3035'	; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'ports'}{'udp'}{'3035'}++	; 
#	$ports_ref->{'udp'}{'3035'}{'name'} = 'fjsv-gssagt'		; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'port'}{'tcp'} = '3035'	; 
#	$srvcobjects_ref->{'fjsv-gssagt'}{'ports'}{'tcp'}{'3035'}++	; 
#	$ports_ref->{'tcp'}{'3035'}{'name'} = 'fjsv-gssagt'		; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'port'}{'udp'} = '1828'	; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'ports'}{'udp'}{'1828'}++	; 
#	$ports_ref->{'udp'}{'1828'}{'name'} = 'itm-mcell-u'		; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'port'}{'tcp'} = '1828'	; 
#	$srvcobjects_ref->{'itm-mcell-u'}{'ports'}{'tcp'}{'1828'}++	; 
#	$ports_ref->{'tcp'}{'1828'}{'name'} = 'itm-mcell-u'		; 
#	$srvcobjects_ref->{'konspire2b'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'konspire2b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'konspire2b'}{'port'}{'udp'} = '6085'	; 
#	$srvcobjects_ref->{'konspire2b'}{'ports'}{'udp'}{'6085'}++	; 
#	$ports_ref->{'udp'}{'6085'}{'name'} = 'konspire2b'		; 
#	$srvcobjects_ref->{'konspire2b'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'konspire2b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'konspire2b'}{'port'}{'tcp'} = '6085'	; 
#	$srvcobjects_ref->{'konspire2b'}{'ports'}{'tcp'}{'6085'}++	; 
#	$ports_ref->{'tcp'}{'6085'}{'name'} = 'konspire2b'		; 
#	$srvcobjects_ref->{'combox-web-acc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'combox-web-acc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'combox-web-acc'}{'port'}{'udp'} = '2534'	; 
#	$srvcobjects_ref->{'combox-web-acc'}{'ports'}{'udp'}{'2534'}++	; 
#	$ports_ref->{'udp'}{'2534'}{'name'} = 'combox-web-acc'		; 
#	$srvcobjects_ref->{'combox-web-acc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'combox-web-acc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'combox-web-acc'}{'port'}{'tcp'} = '2534'	; 
#	$srvcobjects_ref->{'combox-web-acc'}{'ports'}{'tcp'}{'2534'}++	; 
#	$ports_ref->{'tcp'}{'2534'}{'name'} = 'combox-web-acc'		; 
#	$srvcobjects_ref->{'lnvmaps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lnvmaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvmaps'}{'port'}{'udp'} = '2284'	; 
#	$srvcobjects_ref->{'lnvmaps'}{'ports'}{'udp'}{'2284'}++	; 
#	$ports_ref->{'udp'}{'2284'}{'name'} = 'lnvmaps'		; 
#	$srvcobjects_ref->{'lnvmaps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lnvmaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvmaps'}{'port'}{'tcp'} = '2284'	; 
#	$srvcobjects_ref->{'lnvmaps'}{'ports'}{'tcp'}{'2284'}++	; 
#	$ports_ref->{'tcp'}{'2284'}{'name'} = 'lnvmaps'		; 
#	$srvcobjects_ref->{'advant-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'advant-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'advant-lm'}{'port'}{'udp'} = '2295'	; 
#	$srvcobjects_ref->{'advant-lm'}{'ports'}{'udp'}{'2295'}++	; 
#	$ports_ref->{'udp'}{'2295'}{'name'} = 'advant-lm'		; 
#	$srvcobjects_ref->{'advant-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'advant-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'advant-lm'}{'port'}{'tcp'} = '2295'	; 
#	$srvcobjects_ref->{'advant-lm'}{'ports'}{'tcp'}{'2295'}++	; 
#	$ports_ref->{'tcp'}{'2295'}{'name'} = 'advant-lm'		; 
#	$srvcobjects_ref->{'can-nds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'can-nds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-nds'}{'port'}{'udp'} = '1918'	; 
#	$srvcobjects_ref->{'can-nds'}{'ports'}{'udp'}{'1918'}++	; 
#	$ports_ref->{'udp'}{'1918'}{'name'} = 'can-nds'		; 
#	$srvcobjects_ref->{'can-nds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'can-nds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-nds'}{'port'}{'tcp'} = '1918'	; 
#	$srvcobjects_ref->{'can-nds'}{'ports'}{'tcp'}{'1918'}++	; 
#	$ports_ref->{'tcp'}{'1918'}{'name'} = 'can-nds'		; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'port'}{'udp'} = '2953'	; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'ports'}{'udp'}{'2953'}++	; 
#	$ports_ref->{'udp'}{'2953'}{'name'} = 'ovalarmsrv'		; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'port'}{'tcp'} = '2953'	; 
#	$srvcobjects_ref->{'ovalarmsrv'}{'ports'}{'tcp'}{'2953'}++	; 
#	$ports_ref->{'tcp'}{'2953'}{'name'} = 'ovalarmsrv'		; 
#	$srvcobjects_ref->{'nms-dpnss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nms-dpnss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nms-dpnss'}{'port'}{'udp'} = '2503'	; 
#	$srvcobjects_ref->{'nms-dpnss'}{'ports'}{'udp'}{'2503'}++	; 
#	$ports_ref->{'udp'}{'2503'}{'name'} = 'nms-dpnss'		; 
#	$srvcobjects_ref->{'nms-dpnss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nms-dpnss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nms-dpnss'}{'port'}{'tcp'} = '2503'	; 
#	$srvcobjects_ref->{'nms-dpnss'}{'ports'}{'tcp'}{'2503'}++	; 
#	$ports_ref->{'tcp'}{'2503'}{'name'} = 'nms-dpnss'		; 
#	$srvcobjects_ref->{'boosterware'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boosterware'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boosterware'}{'port'}{'udp'} = '2913'	; 
#	$srvcobjects_ref->{'boosterware'}{'ports'}{'udp'}{'2913'}++	; 
#	$ports_ref->{'udp'}{'2913'}{'name'} = 'boosterware'		; 
#	$srvcobjects_ref->{'boosterware'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boosterware'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boosterware'}{'port'}{'tcp'} = '2913'	; 
#	$srvcobjects_ref->{'boosterware'}{'ports'}{'tcp'}{'2913'}++	; 
#	$ports_ref->{'tcp'}{'2913'}{'name'} = 'boosterware'		; 
#	$srvcobjects_ref->{'checksum'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'checksum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'checksum'}{'port'}{'udp'} = '1386'	; 
#	$srvcobjects_ref->{'checksum'}{'ports'}{'udp'}{'1386'}++	; 
#	$ports_ref->{'udp'}{'1386'}{'name'} = 'checksum'		; 
#	$srvcobjects_ref->{'checksum'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'checksum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'checksum'}{'port'}{'tcp'} = '1386'	; 
#	$srvcobjects_ref->{'checksum'}{'ports'}{'tcp'}{'1386'}++	; 
#	$ports_ref->{'tcp'}{'1386'}{'name'} = 'checksum'		; 
#	$srvcobjects_ref->{'eicon-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eicon-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eicon-server'}{'port'}{'udp'} = '1438'	; 
#	$srvcobjects_ref->{'eicon-server'}{'ports'}{'udp'}{'1438'}++	; 
#	$ports_ref->{'udp'}{'1438'}{'name'} = 'eicon-server'		; 
#	$srvcobjects_ref->{'eicon-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eicon-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eicon-server'}{'port'}{'tcp'} = '1438'	; 
#	$srvcobjects_ref->{'eicon-server'}{'ports'}{'tcp'}{'1438'}++	; 
#	$ports_ref->{'tcp'}{'1438'}{'name'} = 'eicon-server'		; 
#	$srvcobjects_ref->{'lingwood'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lingwood'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lingwood'}{'port'}{'udp'} = '2480'	; 
#	$srvcobjects_ref->{'lingwood'}{'ports'}{'udp'}{'2480'}++	; 
#	$ports_ref->{'udp'}{'2480'}{'name'} = 'lingwood'		; 
#	$srvcobjects_ref->{'lingwood'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lingwood'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lingwood'}{'port'}{'tcp'} = '2480'	; 
#	$srvcobjects_ref->{'lingwood'}{'ports'}{'tcp'}{'2480'}++	; 
#	$ports_ref->{'tcp'}{'2480'}{'name'} = 'lingwood'		; 
#	$srvcobjects_ref->{'distinct'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'distinct'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'distinct'}{'port'}{'udp'} = '9999'	; 
#	$srvcobjects_ref->{'distinct'}{'ports'}{'udp'}{'9999'}++	; 
#	$ports_ref->{'udp'}{'9999'}{'name'} = 'distinct'		; 
#	$srvcobjects_ref->{'distinct'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'distinct'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'distinct'}{'port'}{'tcp'} = '9999'	; 
#	$srvcobjects_ref->{'distinct'}{'ports'}{'tcp'}{'9999'}++	; 
#	$ports_ref->{'tcp'}{'9999'}{'name'} = 'distinct'		; 
#	$srvcobjects_ref->{'h248-binary'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h248-binary'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h248-binary'}{'port'}{'udp'} = '2945'	; 
#	$srvcobjects_ref->{'h248-binary'}{'ports'}{'udp'}{'2945'}++	; 
#	$ports_ref->{'udp'}{'2945'}{'name'} = 'h248-binary'		; 
#	$srvcobjects_ref->{'h248-binary'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h248-binary'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h248-binary'}{'port'}{'tcp'} = '2945'	; 
#	$srvcobjects_ref->{'h248-binary'}{'ports'}{'tcp'}{'2945'}++	; 
#	$ports_ref->{'tcp'}{'2945'}{'name'} = 'h248-binary'		; 
#	$srvcobjects_ref->{'manyone-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'manyone-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'manyone-http'}{'port'}{'udp'} = '8910'	; 
#	$srvcobjects_ref->{'manyone-http'}{'ports'}{'udp'}{'8910'}++	; 
#	$ports_ref->{'udp'}{'8910'}{'name'} = 'manyone-http'		; 
#	$srvcobjects_ref->{'manyone-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'manyone-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'manyone-http'}{'port'}{'tcp'} = '8910'	; 
#	$srvcobjects_ref->{'manyone-http'}{'ports'}{'tcp'}{'8910'}++	; 
#	$ports_ref->{'tcp'}{'8910'}{'name'} = 'manyone-http'		; 
#	$srvcobjects_ref->{'fjdocdist'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjdocdist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjdocdist'}{'port'}{'udp'} = '1848'	; 
#	$srvcobjects_ref->{'fjdocdist'}{'ports'}{'udp'}{'1848'}++	; 
#	$ports_ref->{'udp'}{'1848'}{'name'} = 'fjdocdist'		; 
#	$srvcobjects_ref->{'fjdocdist'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjdocdist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjdocdist'}{'port'}{'tcp'} = '1848'	; 
#	$srvcobjects_ref->{'fjdocdist'}{'ports'}{'tcp'}{'1848'}++	; 
#	$ports_ref->{'tcp'}{'1848'}{'name'} = 'fjdocdist'		; 
#	$srvcobjects_ref->{'aes-discovery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aes-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aes-discovery'}{'port'}{'udp'} = '3224'	; 
#	$srvcobjects_ref->{'aes-discovery'}{'ports'}{'udp'}{'3224'}++	; 
#	$ports_ref->{'udp'}{'3224'}{'name'} = 'aes-discovery'		; 
#	$srvcobjects_ref->{'aes-discovery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aes-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aes-discovery'}{'port'}{'tcp'} = '3224'	; 
#	$srvcobjects_ref->{'aes-discovery'}{'ports'}{'tcp'}{'3224'}++	; 
#	$ports_ref->{'tcp'}{'3224'}{'name'} = 'aes-discovery'		; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'port'}{'udp'} = '903'	; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'ports'}{'udp'}{'903'}++	; 
#	$ports_ref->{'udp'}{'903'}{'name'} = 'ideafarm-catch'		; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'port'}{'tcp'} = '903'	; 
#	$srvcobjects_ref->{'ideafarm-catch'}{'ports'}{'tcp'}{'903'}++	; 
#	$ports_ref->{'tcp'}{'903'}{'name'} = 'ideafarm-catch'		; 
#	$srvcobjects_ref->{'biimenu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'biimenu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'biimenu'}{'port'}{'udp'} = '18000'	; 
#	$srvcobjects_ref->{'biimenu'}{'ports'}{'udp'}{'18000'}++	; 
#	$ports_ref->{'udp'}{'18000'}{'name'} = 'biimenu'		; 
#	$srvcobjects_ref->{'biimenu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'biimenu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'biimenu'}{'port'}{'tcp'} = '18000'	; 
#	$srvcobjects_ref->{'biimenu'}{'ports'}{'tcp'}{'18000'}++	; 
#	$ports_ref->{'tcp'}{'18000'}{'name'} = 'biimenu'		; 
#	$srvcobjects_ref->{'fsc-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fsc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fsc-port'}{'port'}{'udp'} = '9217'	; 
#	$srvcobjects_ref->{'fsc-port'}{'ports'}{'udp'}{'9217'}++	; 
#	$ports_ref->{'udp'}{'9217'}{'name'} = 'fsc-port'		; 
#	$srvcobjects_ref->{'fsc-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fsc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fsc-port'}{'port'}{'tcp'} = '9217'	; 
#	$srvcobjects_ref->{'fsc-port'}{'ports'}{'tcp'}{'9217'}++	; 
#	$ports_ref->{'tcp'}{'9217'}{'name'} = 'fsc-port'		; 
#	$srvcobjects_ref->{'snifferdata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snifferdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snifferdata'}{'port'}{'udp'} = '2892'	; 
#	$srvcobjects_ref->{'snifferdata'}{'ports'}{'udp'}{'2892'}++	; 
#	$ports_ref->{'udp'}{'2892'}{'name'} = 'snifferdata'		; 
#	$srvcobjects_ref->{'snifferdata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snifferdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snifferdata'}{'port'}{'tcp'} = '2892'	; 
#	$srvcobjects_ref->{'snifferdata'}{'ports'}{'tcp'}{'2892'}++	; 
#	$ports_ref->{'tcp'}{'2892'}{'name'} = 'snifferdata'		; 
#	$srvcobjects_ref->{'iso-tp0'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iso-tp0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tp0'}{'port'}{'udp'} = '146'	; 
#	$srvcobjects_ref->{'iso-tp0'}{'ports'}{'udp'}{'146'}++	; 
#	$ports_ref->{'udp'}{'146'}{'name'} = 'iso-tp0'		; 
#	$srvcobjects_ref->{'iso-tp0'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iso-tp0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tp0'}{'port'}{'tcp'} = '146'	; 
#	$srvcobjects_ref->{'iso-tp0'}{'ports'}{'tcp'}{'146'}++	; 
#	$ports_ref->{'tcp'}{'146'}{'name'} = 'iso-tp0'		; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'port'}{'udp'} = '684'	; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'ports'}{'udp'}{'684'}++	; 
#	$ports_ref->{'udp'}{'684'}{'name'} = 'corba-iiop-ssl'		; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'port'}{'tcp'} = '684'	; 
#	$srvcobjects_ref->{'corba-iiop-ssl'}{'ports'}{'tcp'}{'684'}++	; 
#	$ports_ref->{'tcp'}{'684'}{'name'} = 'corba-iiop-ssl'		; 
#	$srvcobjects_ref->{'p2plus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'p2plus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'p2plus'}{'port'}{'udp'} = '2037'	; 
#	$srvcobjects_ref->{'p2plus'}{'ports'}{'udp'}{'2037'}++	; 
#	$ports_ref->{'udp'}{'2037'}{'name'} = 'p2plus'		; 
#	$srvcobjects_ref->{'p2plus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'p2plus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'p2plus'}{'port'}{'tcp'} = '2037'	; 
#	$srvcobjects_ref->{'p2plus'}{'ports'}{'tcp'}{'2037'}++	; 
#	$ports_ref->{'tcp'}{'2037'}{'name'} = 'p2plus'		; 
#	$srvcobjects_ref->{'nced'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nced'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nced'}{'port'}{'udp'} = '404'	; 
#	$srvcobjects_ref->{'nced'}{'ports'}{'udp'}{'404'}++	; 
#	$ports_ref->{'udp'}{'404'}{'name'} = 'nced'		; 
#	$srvcobjects_ref->{'nced'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nced'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nced'}{'port'}{'tcp'} = '404'	; 
#	$srvcobjects_ref->{'nced'}{'ports'}{'tcp'}{'404'}++	; 
#	$ports_ref->{'tcp'}{'404'}{'name'} = 'nced'		; 
#	$srvcobjects_ref->{'privatewire'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'privatewire'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privatewire'}{'port'}{'udp'} = '4449'	; 
#	$srvcobjects_ref->{'privatewire'}{'ports'}{'udp'}{'4449'}++	; 
#	$ports_ref->{'udp'}{'4449'}{'name'} = 'privatewire'		; 
#	$srvcobjects_ref->{'privatewire'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'privatewire'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privatewire'}{'port'}{'tcp'} = '4449'	; 
#	$srvcobjects_ref->{'privatewire'}{'ports'}{'tcp'}{'4449'}++	; 
#	$ports_ref->{'tcp'}{'4449'}{'name'} = 'privatewire'		; 
#	$srvcobjects_ref->{'sixtrak'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sixtrak'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sixtrak'}{'port'}{'udp'} = '1594'	; 
#	$srvcobjects_ref->{'sixtrak'}{'ports'}{'udp'}{'1594'}++	; 
#	$ports_ref->{'udp'}{'1594'}{'name'} = 'sixtrak'		; 
#	$srvcobjects_ref->{'sixtrak'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sixtrak'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sixtrak'}{'port'}{'tcp'} = '1594'	; 
#	$srvcobjects_ref->{'sixtrak'}{'ports'}{'tcp'}{'1594'}++	; 
#	$ports_ref->{'tcp'}{'1594'}{'name'} = 'sixtrak'		; 
#	$srvcobjects_ref->{'keyshadow'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'keyshadow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'keyshadow'}{'port'}{'udp'} = '19315'	; 
#	$srvcobjects_ref->{'keyshadow'}{'ports'}{'udp'}{'19315'}++	; 
#	$ports_ref->{'udp'}{'19315'}{'name'} = 'keyshadow'		; 
#	$srvcobjects_ref->{'keyshadow'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'keyshadow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'keyshadow'}{'port'}{'tcp'} = '19315'	; 
#	$srvcobjects_ref->{'keyshadow'}{'ports'}{'tcp'}{'19315'}++	; 
#	$ports_ref->{'tcp'}{'19315'}{'name'} = 'keyshadow'		; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'port'}{'udp'} = '11751'	; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'ports'}{'udp'}{'11751'}++	; 
#	$ports_ref->{'udp'}{'11751'}{'name'} = 'intrepid-ssl'		; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'port'}{'tcp'} = '11751'	; 
#	$srvcobjects_ref->{'intrepid-ssl'}{'ports'}{'tcp'}{'11751'}++	; 
#	$ports_ref->{'tcp'}{'11751'}{'name'} = 'intrepid-ssl'		; 
#	$srvcobjects_ref->{'psbserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'psbserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psbserver'}{'port'}{'udp'} = '2350'	; 
#	$srvcobjects_ref->{'psbserver'}{'ports'}{'udp'}{'2350'}++	; 
#	$ports_ref->{'udp'}{'2350'}{'name'} = 'psbserver'		; 
#	$srvcobjects_ref->{'psbserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'psbserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psbserver'}{'port'}{'tcp'} = '2350'	; 
#	$srvcobjects_ref->{'psbserver'}{'ports'}{'tcp'}{'2350'}++	; 
#	$ports_ref->{'tcp'}{'2350'}{'name'} = 'psbserver'		; 
#	$srvcobjects_ref->{'fatserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fatserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fatserv'}{'port'}{'udp'} = '347'	; 
#	$srvcobjects_ref->{'fatserv'}{'ports'}{'udp'}{'347'}++	; 
#	$ports_ref->{'udp'}{'347'}{'name'} = 'fatserv'		; 
#	$srvcobjects_ref->{'fatserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fatserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fatserv'}{'port'}{'tcp'} = '347'	; 
#	$srvcobjects_ref->{'fatserv'}{'ports'}{'tcp'}{'347'}++	; 
#	$ports_ref->{'tcp'}{'347'}{'name'} = 'fatserv'		; 
#	$srvcobjects_ref->{'netplan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netplan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netplan'}{'port'}{'udp'} = '2983'	; 
#	$srvcobjects_ref->{'netplan'}{'ports'}{'udp'}{'2983'}++	; 
#	$ports_ref->{'udp'}{'2983'}{'name'} = 'netplan'		; 
#	$srvcobjects_ref->{'netplan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netplan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netplan'}{'port'}{'tcp'} = '2983'	; 
#	$srvcobjects_ref->{'netplan'}{'ports'}{'tcp'}{'2983'}++	; 
#	$ports_ref->{'tcp'}{'2983'}{'name'} = 'netplan'		; 
#	$srvcobjects_ref->{'admind'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'admind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'admind'}{'port'}{'udp'} = '8403'	; 
#	$srvcobjects_ref->{'admind'}{'ports'}{'udp'}{'8403'}++	; 
#	$ports_ref->{'udp'}{'8403'}{'name'} = 'admind'		; 
#	$srvcobjects_ref->{'admind'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'admind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'admind'}{'port'}{'udp'} = '3279'	; 
#	$srvcobjects_ref->{'admind'}{'ports'}{'udp'}{'3279'}++	; 
#	$ports_ref->{'udp'}{'3279'}{'name'} = 'admind'		; 
#	$srvcobjects_ref->{'admind'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'admind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'admind'}{'port'}{'tcp'} = '8403'	; 
#	$srvcobjects_ref->{'admind'}{'ports'}{'tcp'}{'8403'}++	; 
#	$ports_ref->{'tcp'}{'8403'}{'name'} = 'admind'		; 
#	$srvcobjects_ref->{'admind'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'admind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'admind'}{'port'}{'tcp'} = '3279'	; 
#	$srvcobjects_ref->{'admind'}{'ports'}{'tcp'}{'3279'}++	; 
#	$ports_ref->{'tcp'}{'3279'}{'name'} = 'admind'		; 
#	$srvcobjects_ref->{'netbios-ssn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbios-ssn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbios-ssn'}{'port'}{'udp'} = '139'	; 
#	$srvcobjects_ref->{'netbios-ssn'}{'ports'}{'udp'}{'139'}++	; 
#	$ports_ref->{'udp'}{'139'}{'name'} = 'netbios-ssn'		; 
#	$srvcobjects_ref->{'netbios-ssn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbios-ssn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbios-ssn'}{'port'}{'tcp'} = '139'	; 
#	$srvcobjects_ref->{'netbios-ssn'}{'ports'}{'tcp'}{'139'}++	; 
#	$ports_ref->{'tcp'}{'139'}{'name'} = 'netbios-ssn'		; 
#	$srvcobjects_ref->{'cnrprotocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cnrprotocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnrprotocol'}{'port'}{'udp'} = '1096'	; 
#	$srvcobjects_ref->{'cnrprotocol'}{'ports'}{'udp'}{'1096'}++	; 
#	$ports_ref->{'udp'}{'1096'}{'name'} = 'cnrprotocol'		; 
#	$srvcobjects_ref->{'cnrprotocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cnrprotocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnrprotocol'}{'port'}{'tcp'} = '1096'	; 
#	$srvcobjects_ref->{'cnrprotocol'}{'ports'}{'tcp'}{'1096'}++	; 
#	$ports_ref->{'tcp'}{'1096'}{'name'} = 'cnrprotocol'		; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'port'}{'udp'} = '3604'	; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'ports'}{'udp'}{'3604'}++	; 
#	$ports_ref->{'udp'}{'3604'}{'name'} = 'bmc-jmx-port'		; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'port'}{'tcp'} = '3604'	; 
#	$srvcobjects_ref->{'bmc-jmx-port'}{'ports'}{'tcp'}{'3604'}++	; 
#	$ports_ref->{'tcp'}{'3604'}{'name'} = 'bmc-jmx-port'		; 
#	$srvcobjects_ref->{'cddbp-alt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cddbp-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cddbp-alt'}{'port'}{'udp'} = '8880'	; 
#	$srvcobjects_ref->{'cddbp-alt'}{'ports'}{'udp'}{'8880'}++	; 
#	$ports_ref->{'udp'}{'8880'}{'name'} = 'cddbp-alt'		; 
#	$srvcobjects_ref->{'cddbp-alt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cddbp-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cddbp-alt'}{'port'}{'tcp'} = '8880'	; 
#	$srvcobjects_ref->{'cddbp-alt'}{'ports'}{'tcp'}{'8880'}++	; 
#	$ports_ref->{'tcp'}{'8880'}{'name'} = 'cddbp-alt'		; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'port'}{'udp'} = '10113'	; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'ports'}{'udp'}{'10113'}++	; 
#	$ports_ref->{'udp'}{'10113'}{'name'} = 'netiq-endpoint'		; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'port'}{'tcp'} = '10113'	; 
#	$srvcobjects_ref->{'netiq-endpoint'}{'ports'}{'tcp'}{'10113'}++	; 
#	$ports_ref->{'tcp'}{'10113'}{'name'} = 'netiq-endpoint'		; 
#	$srvcobjects_ref->{'grubd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'grubd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'grubd'}{'port'}{'udp'} = '3136'	; 
#	$srvcobjects_ref->{'grubd'}{'ports'}{'udp'}{'3136'}++	; 
#	$ports_ref->{'udp'}{'3136'}{'name'} = 'grubd'		; 
#	$srvcobjects_ref->{'grubd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'grubd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'grubd'}{'port'}{'tcp'} = '3136'	; 
#	$srvcobjects_ref->{'grubd'}{'ports'}{'tcp'}{'3136'}++	; 
#	$ports_ref->{'tcp'}{'3136'}{'name'} = 'grubd'		; 
#	$srvcobjects_ref->{'samsung-unidex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'samsung-unidex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'samsung-unidex'}{'port'}{'udp'} = '4010'	; 
#	$srvcobjects_ref->{'samsung-unidex'}{'ports'}{'udp'}{'4010'}++	; 
#	$ports_ref->{'udp'}{'4010'}{'name'} = 'samsung-unidex'		; 
#	$srvcobjects_ref->{'samsung-unidex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'samsung-unidex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'samsung-unidex'}{'port'}{'tcp'} = '4010'	; 
#	$srvcobjects_ref->{'samsung-unidex'}{'ports'}{'tcp'}{'4010'}++	; 
#	$ports_ref->{'tcp'}{'4010'}{'name'} = 'samsung-unidex'		; 
#	$srvcobjects_ref->{'syncserverssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'syncserverssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syncserverssl'}{'port'}{'udp'} = '2679'	; 
#	$srvcobjects_ref->{'syncserverssl'}{'ports'}{'udp'}{'2679'}++	; 
#	$ports_ref->{'udp'}{'2679'}{'name'} = 'syncserverssl'		; 
#	$srvcobjects_ref->{'syncserverssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'syncserverssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syncserverssl'}{'port'}{'tcp'} = '2679'	; 
#	$srvcobjects_ref->{'syncserverssl'}{'ports'}{'tcp'}{'2679'}++	; 
#	$ports_ref->{'tcp'}{'2679'}{'name'} = 'syncserverssl'		; 
#	$srvcobjects_ref->{'netview-aix-7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-7'}{'port'}{'udp'} = '1667'	; 
#	$srvcobjects_ref->{'netview-aix-7'}{'ports'}{'udp'}{'1667'}++	; 
#	$ports_ref->{'udp'}{'1667'}{'name'} = 'netview-aix-7'		; 
#	$srvcobjects_ref->{'netview-aix-7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-7'}{'port'}{'tcp'} = '1667'	; 
#	$srvcobjects_ref->{'netview-aix-7'}{'ports'}{'tcp'}{'1667'}++	; 
#	$ports_ref->{'tcp'}{'1667'}{'name'} = 'netview-aix-7'		; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'port'}{'udp'} = '3674'	; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'ports'}{'udp'}{'3674'}++	; 
#	$ports_ref->{'udp'}{'3674'}{'name'} = 'wininstall-ipc'		; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'port'}{'tcp'} = '3674'	; 
#	$srvcobjects_ref->{'wininstall-ipc'}{'ports'}{'tcp'}{'3674'}++	; 
#	$ports_ref->{'tcp'}{'3674'}{'name'} = 'wininstall-ipc'		; 
#	$srvcobjects_ref->{'svnetworks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'svnetworks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svnetworks'}{'port'}{'udp'} = '2973'	; 
#	$srvcobjects_ref->{'svnetworks'}{'ports'}{'udp'}{'2973'}++	; 
#	$ports_ref->{'udp'}{'2973'}{'name'} = 'svnetworks'		; 
#	$srvcobjects_ref->{'svnetworks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'svnetworks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svnetworks'}{'port'}{'tcp'} = '2973'	; 
#	$srvcobjects_ref->{'svnetworks'}{'ports'}{'tcp'}{'2973'}++	; 
#	$ports_ref->{'tcp'}{'2973'}{'name'} = 'svnetworks'		; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'port'}{'udp'} = '2677'	; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'ports'}{'udp'}{'2677'}++	; 
#	$ports_ref->{'udp'}{'2677'}{'name'} = 'gadgetgate1way'		; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'port'}{'tcp'} = '2677'	; 
#	$srvcobjects_ref->{'gadgetgate1way'}{'ports'}{'tcp'}{'2677'}++	; 
#	$ports_ref->{'tcp'}{'2677'}{'name'} = 'gadgetgate1way'		; 
#	$srvcobjects_ref->{'rcc-host'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rcc-host'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rcc-host'}{'port'}{'udp'} = '2332'	; 
#	$srvcobjects_ref->{'rcc-host'}{'ports'}{'udp'}{'2332'}++	; 
#	$ports_ref->{'udp'}{'2332'}{'name'} = 'rcc-host'		; 
#	$srvcobjects_ref->{'rcc-host'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rcc-host'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rcc-host'}{'port'}{'tcp'} = '2332'	; 
#	$srvcobjects_ref->{'rcc-host'}{'ports'}{'tcp'}{'2332'}++	; 
#	$ports_ref->{'tcp'}{'2332'}{'name'} = 'rcc-host'		; 
#	$srvcobjects_ref->{'pvsw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pvsw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pvsw'}{'port'}{'udp'} = '2520'	; 
#	$srvcobjects_ref->{'pvsw'}{'ports'}{'udp'}{'2520'}++	; 
#	$ports_ref->{'udp'}{'2520'}{'name'} = 'pvsw'		; 
#	$srvcobjects_ref->{'pvsw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pvsw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pvsw'}{'port'}{'tcp'} = '2520'	; 
#	$srvcobjects_ref->{'pvsw'}{'ports'}{'tcp'}{'2520'}++	; 
#	$ports_ref->{'tcp'}{'2520'}{'name'} = 'pvsw'		; 
#	$srvcobjects_ref->{'agentview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'agentview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agentview'}{'port'}{'udp'} = '2331'	; 
#	$srvcobjects_ref->{'agentview'}{'ports'}{'udp'}{'2331'}++	; 
#	$ports_ref->{'udp'}{'2331'}{'name'} = 'agentview'		; 
#	$srvcobjects_ref->{'agentview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'agentview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agentview'}{'port'}{'tcp'} = '2331'	; 
#	$srvcobjects_ref->{'agentview'}{'ports'}{'tcp'}{'2331'}++	; 
#	$ports_ref->{'tcp'}{'2331'}{'name'} = 'agentview'		; 
#	$srvcobjects_ref->{'maxim-asics'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'maxim-asics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maxim-asics'}{'port'}{'udp'} = '3276'	; 
#	$srvcobjects_ref->{'maxim-asics'}{'ports'}{'udp'}{'3276'}++	; 
#	$ports_ref->{'udp'}{'3276'}{'name'} = 'maxim-asics'		; 
#	$srvcobjects_ref->{'maxim-asics'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'maxim-asics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maxim-asics'}{'port'}{'tcp'} = '3276'	; 
#	$srvcobjects_ref->{'maxim-asics'}{'ports'}{'tcp'}{'3276'}++	; 
#	$ports_ref->{'tcp'}{'3276'}{'name'} = 'maxim-asics'		; 
#	$srvcobjects_ref->{'nec-raidplus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nec-raidplus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nec-raidplus'}{'port'}{'udp'} = '2730'	; 
#	$srvcobjects_ref->{'nec-raidplus'}{'ports'}{'udp'}{'2730'}++	; 
#	$ports_ref->{'udp'}{'2730'}{'name'} = 'nec-raidplus'		; 
#	$srvcobjects_ref->{'nec-raidplus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nec-raidplus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nec-raidplus'}{'port'}{'tcp'} = '2730'	; 
#	$srvcobjects_ref->{'nec-raidplus'}{'ports'}{'tcp'}{'2730'}++	; 
#	$ports_ref->{'tcp'}{'2730'}{'name'} = 'nec-raidplus'		; 
#	$srvcobjects_ref->{'twrpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'twrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'twrpc'}{'port'}{'udp'} = '3479'	; 
#	$srvcobjects_ref->{'twrpc'}{'ports'}{'udp'}{'3479'}++	; 
#	$ports_ref->{'udp'}{'3479'}{'name'} = 'twrpc'		; 
#	$srvcobjects_ref->{'twrpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'twrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'twrpc'}{'port'}{'tcp'} = '3479'	; 
#	$srvcobjects_ref->{'twrpc'}{'ports'}{'tcp'}{'3479'}++	; 
#	$ports_ref->{'tcp'}{'3479'}{'name'} = 'twrpc'		; 
#	$srvcobjects_ref->{'bluelance'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bluelance'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bluelance'}{'port'}{'udp'} = '2877'	; 
#	$srvcobjects_ref->{'bluelance'}{'ports'}{'udp'}{'2877'}++	; 
#	$ports_ref->{'udp'}{'2877'}{'name'} = 'bluelance'		; 
#	$srvcobjects_ref->{'bluelance'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bluelance'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bluelance'}{'port'}{'tcp'} = '2877'	; 
#	$srvcobjects_ref->{'bluelance'}{'ports'}{'tcp'}{'2877'}++	; 
#	$ports_ref->{'tcp'}{'2877'}{'name'} = 'bluelance'		; 
#	$srvcobjects_ref->{'novastorbakcup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'novastorbakcup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novastorbakcup'}{'port'}{'udp'} = '308'	; 
#	$srvcobjects_ref->{'novastorbakcup'}{'ports'}{'udp'}{'308'}++	; 
#	$ports_ref->{'udp'}{'308'}{'name'} = 'novastorbakcup'		; 
#	$srvcobjects_ref->{'novastorbakcup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'novastorbakcup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novastorbakcup'}{'port'}{'tcp'} = '308'	; 
#	$srvcobjects_ref->{'novastorbakcup'}{'ports'}{'tcp'}{'308'}++	; 
#	$ports_ref->{'tcp'}{'308'}{'name'} = 'novastorbakcup'		; 
#	$srvcobjects_ref->{'ocserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ocserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocserver'}{'port'}{'udp'} = '184'	; 
#	$srvcobjects_ref->{'ocserver'}{'ports'}{'udp'}{'184'}++	; 
#	$ports_ref->{'udp'}{'184'}{'name'} = 'ocserver'		; 
#	$srvcobjects_ref->{'ocserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ocserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocserver'}{'port'}{'tcp'} = '184'	; 
#	$srvcobjects_ref->{'ocserver'}{'ports'}{'tcp'}{'184'}++	; 
#	$ports_ref->{'tcp'}{'184'}{'name'} = 'ocserver'		; 
#	$srvcobjects_ref->{'and-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'and-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'and-lm'}{'port'}{'udp'} = '2646'	; 
#	$srvcobjects_ref->{'and-lm'}{'ports'}{'udp'}{'2646'}++	; 
#	$ports_ref->{'udp'}{'2646'}{'name'} = 'and-lm'		; 
#	$srvcobjects_ref->{'and-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'and-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'and-lm'}{'port'}{'tcp'} = '2646'	; 
#	$srvcobjects_ref->{'and-lm'}{'ports'}{'tcp'}{'2646'}++	; 
#	$ports_ref->{'tcp'}{'2646'}{'name'} = 'and-lm'		; 
#	$srvcobjects_ref->{'pclemultimedia'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pclemultimedia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pclemultimedia'}{'port'}{'udp'} = '2558'	; 
#	$srvcobjects_ref->{'pclemultimedia'}{'ports'}{'udp'}{'2558'}++	; 
#	$ports_ref->{'udp'}{'2558'}{'name'} = 'pclemultimedia'		; 
#	$srvcobjects_ref->{'pclemultimedia'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pclemultimedia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pclemultimedia'}{'port'}{'tcp'} = '2558'	; 
#	$srvcobjects_ref->{'pclemultimedia'}{'ports'}{'tcp'}{'2558'}++	; 
#	$ports_ref->{'tcp'}{'2558'}{'name'} = 'pclemultimedia'		; 
#	$srvcobjects_ref->{'netbill-cred'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbill-cred'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-cred'}{'port'}{'udp'} = '1614'	; 
#	$srvcobjects_ref->{'netbill-cred'}{'ports'}{'udp'}{'1614'}++	; 
#	$ports_ref->{'udp'}{'1614'}{'name'} = 'netbill-cred'		; 
#	$srvcobjects_ref->{'netbill-cred'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbill-cred'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-cred'}{'port'}{'tcp'} = '1614'	; 
#	$srvcobjects_ref->{'netbill-cred'}{'ports'}{'tcp'}{'1614'}++	; 
#	$ports_ref->{'tcp'}{'1614'}{'name'} = 'netbill-cred'		; 
#	$srvcobjects_ref->{'rcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rcp'}{'port'}{'udp'} = '469'	; 
#	$srvcobjects_ref->{'rcp'}{'ports'}{'udp'}{'469'}++	; 
#	$ports_ref->{'udp'}{'469'}{'name'} = 'rcp'		; 
#	$srvcobjects_ref->{'rcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rcp'}{'port'}{'tcp'} = '469'	; 
#	$srvcobjects_ref->{'rcp'}{'ports'}{'tcp'}{'469'}++	; 
#	$ports_ref->{'tcp'}{'469'}{'name'} = 'rcp'		; 
#	$srvcobjects_ref->{'icslap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icslap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icslap'}{'port'}{'udp'} = '2869'	; 
#	$srvcobjects_ref->{'icslap'}{'ports'}{'udp'}{'2869'}++	; 
#	$ports_ref->{'udp'}{'2869'}{'name'} = 'icslap'		; 
#	$srvcobjects_ref->{'icslap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icslap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icslap'}{'port'}{'tcp'} = '2869'	; 
#	$srvcobjects_ref->{'icslap'}{'ports'}{'tcp'}{'2869'}++	; 
#	$ports_ref->{'tcp'}{'2869'}{'name'} = 'icslap'		; 
#	$srvcobjects_ref->{'mice'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mice'}{'port'}{'udp'} = '5022'	; 
#	$srvcobjects_ref->{'mice'}{'ports'}{'udp'}{'5022'}++	; 
#	$ports_ref->{'udp'}{'5022'}{'name'} = 'mice'		; 
#	$srvcobjects_ref->{'mice'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mice'}{'port'}{'tcp'} = '5022'	; 
#	$srvcobjects_ref->{'mice'}{'ports'}{'tcp'}{'5022'}++	; 
#	$ports_ref->{'tcp'}{'5022'}{'name'} = 'mice'		; 
#	$srvcobjects_ref->{'sysorb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sysorb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysorb'}{'port'}{'udp'} = '3241'	; 
#	$srvcobjects_ref->{'sysorb'}{'ports'}{'udp'}{'3241'}++	; 
#	$ports_ref->{'udp'}{'3241'}{'name'} = 'sysorb'		; 
#	$srvcobjects_ref->{'sysorb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sysorb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysorb'}{'port'}{'tcp'} = '3241'	; 
#	$srvcobjects_ref->{'sysorb'}{'ports'}{'tcp'}{'3241'}++	; 
#	$ports_ref->{'tcp'}{'3241'}{'name'} = 'sysorb'		; 
#	$srvcobjects_ref->{'musiconline'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'musiconline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'musiconline'}{'port'}{'udp'} = '1806'	; 
#	$srvcobjects_ref->{'musiconline'}{'ports'}{'udp'}{'1806'}++	; 
#	$ports_ref->{'udp'}{'1806'}{'name'} = 'musiconline'		; 
#	$srvcobjects_ref->{'musiconline'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'musiconline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'musiconline'}{'port'}{'tcp'} = '1806'	; 
#	$srvcobjects_ref->{'musiconline'}{'ports'}{'tcp'}{'1806'}++	; 
#	$ports_ref->{'tcp'}{'1806'}{'name'} = 'musiconline'		; 
#	$srvcobjects_ref->{'isi-irp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isi-irp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isi-irp'}{'port'}{'udp'} = '3226'	; 
#	$srvcobjects_ref->{'isi-irp'}{'ports'}{'udp'}{'3226'}++	; 
#	$ports_ref->{'udp'}{'3226'}{'name'} = 'isi-irp'		; 
#	$srvcobjects_ref->{'isi-irp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isi-irp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isi-irp'}{'port'}{'tcp'} = '3226'	; 
#	$srvcobjects_ref->{'isi-irp'}{'ports'}{'tcp'}{'3226'}++	; 
#	$ports_ref->{'tcp'}{'3226'}{'name'} = 'isi-irp'		; 
#	$srvcobjects_ref->{'lv-auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lv-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-auth'}{'port'}{'udp'} = '2147'	; 
#	$srvcobjects_ref->{'lv-auth'}{'ports'}{'udp'}{'2147'}++	; 
#	$ports_ref->{'udp'}{'2147'}{'name'} = 'lv-auth'		; 
#	$srvcobjects_ref->{'lv-auth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lv-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-auth'}{'port'}{'tcp'} = '2147'	; 
#	$srvcobjects_ref->{'lv-auth'}{'ports'}{'tcp'}{'2147'}++	; 
#	$ports_ref->{'tcp'}{'2147'}{'name'} = 'lv-auth'		; 
#	$srvcobjects_ref->{'mngsuite'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mngsuite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mngsuite'}{'port'}{'udp'} = '9535'	; 
#	$srvcobjects_ref->{'mngsuite'}{'ports'}{'udp'}{'9535'}++	; 
#	$ports_ref->{'udp'}{'9535'}{'name'} = 'mngsuite'		; 
#	$srvcobjects_ref->{'mngsuite'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mngsuite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mngsuite'}{'port'}{'tcp'} = '9535'	; 
#	$srvcobjects_ref->{'mngsuite'}{'ports'}{'tcp'}{'9535'}++	; 
#	$ports_ref->{'tcp'}{'9535'}{'name'} = 'mngsuite'		; 
#	$srvcobjects_ref->{'fmpro-internal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fmpro-internal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fmpro-internal'}{'port'}{'udp'} = '5003'	; 
#	$srvcobjects_ref->{'fmpro-internal'}{'ports'}{'udp'}{'5003'}++	; 
#	$ports_ref->{'udp'}{'5003'}{'name'} = 'fmpro-internal'		; 
#	$srvcobjects_ref->{'fmpro-internal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fmpro-internal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fmpro-internal'}{'port'}{'tcp'} = '5003'	; 
#	$srvcobjects_ref->{'fmpro-internal'}{'ports'}{'tcp'}{'5003'}++	; 
#	$ports_ref->{'tcp'}{'5003'}{'name'} = 'fmpro-internal'		; 
#	$srvcobjects_ref->{'radio'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radio'}{'port'}{'udp'} = '1595'	; 
#	$srvcobjects_ref->{'radio'}{'ports'}{'udp'}{'1595'}++	; 
#	$ports_ref->{'udp'}{'1595'}{'name'} = 'radio'		; 
#	$srvcobjects_ref->{'radio'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radio'}{'port'}{'tcp'} = '1595'	; 
#	$srvcobjects_ref->{'radio'}{'ports'}{'tcp'}{'1595'}++	; 
#	$ports_ref->{'tcp'}{'1595'}{'name'} = 'radio'		; 
#	$srvcobjects_ref->{'k3software-svr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'k3software-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'k3software-svr'}{'port'}{'udp'} = '26262'	; 
#	$srvcobjects_ref->{'k3software-svr'}{'ports'}{'udp'}{'26262'}++	; 
#	$ports_ref->{'udp'}{'26262'}{'name'} = 'k3software-svr'		; 
#	$srvcobjects_ref->{'k3software-svr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'k3software-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'k3software-svr'}{'port'}{'tcp'} = '26262'	; 
#	$srvcobjects_ref->{'k3software-svr'}{'ports'}{'tcp'}{'26262'}++	; 
#	$ports_ref->{'tcp'}{'26262'}{'name'} = 'k3software-svr'		; 
#	$srvcobjects_ref->{'dttl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dttl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dttl'}{'port'}{'udp'} = '5435'	; 
#	$srvcobjects_ref->{'dttl'}{'ports'}{'udp'}{'5435'}++	; 
#	$ports_ref->{'udp'}{'5435'}{'name'} = 'dttl'		; 
#	$srvcobjects_ref->{'dttl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dttl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dttl'}{'port'}{'tcp'} = '5435'	; 
#	$srvcobjects_ref->{'dttl'}{'ports'}{'tcp'}{'5435'}++	; 
#	$ports_ref->{'tcp'}{'5435'}{'name'} = 'dttl'		; 
#	$srvcobjects_ref->{'dls-mon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dls-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls-mon'}{'port'}{'udp'} = '198'	; 
#	$srvcobjects_ref->{'dls-mon'}{'ports'}{'udp'}{'198'}++	; 
#	$ports_ref->{'udp'}{'198'}{'name'} = 'dls-mon'		; 
#	$srvcobjects_ref->{'dls-mon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dls-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls-mon'}{'port'}{'tcp'} = '198'	; 
#	$srvcobjects_ref->{'dls-mon'}{'ports'}{'tcp'}{'198'}++	; 
#	$ports_ref->{'tcp'}{'198'}{'name'} = 'dls-mon'		; 
#	$srvcobjects_ref->{'apc-5456'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-5456'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-5456'}{'port'}{'udp'} = '5456'	; 
#	$srvcobjects_ref->{'apc-5456'}{'ports'}{'udp'}{'5456'}++	; 
#	$ports_ref->{'udp'}{'5456'}{'name'} = 'apc-5456'		; 
#	$srvcobjects_ref->{'apc-5456'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-5456'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-5456'}{'port'}{'tcp'} = '5456'	; 
#	$srvcobjects_ref->{'apc-5456'}{'ports'}{'tcp'}{'5456'}++	; 
#	$ports_ref->{'tcp'}{'5456'}{'name'} = 'apc-5456'		; 
#	$srvcobjects_ref->{'802-11-iapp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'802-11-iapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'802-11-iapp'}{'port'}{'udp'} = '3517'	; 
#	$srvcobjects_ref->{'802-11-iapp'}{'ports'}{'udp'}{'3517'}++	; 
#	$ports_ref->{'udp'}{'3517'}{'name'} = '802-11-iapp'		; 
#	$srvcobjects_ref->{'802-11-iapp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'802-11-iapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'802-11-iapp'}{'port'}{'tcp'} = '3517'	; 
#	$srvcobjects_ref->{'802-11-iapp'}{'ports'}{'tcp'}{'3517'}++	; 
#	$ports_ref->{'tcp'}{'3517'}{'name'} = '802-11-iapp'		; 
#	$srvcobjects_ref->{'urd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'urd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'urd'}{'port'}{'tcp'} = '465'	; 
#	$srvcobjects_ref->{'urd'}{'ports'}{'tcp'}{'465'}++	; 
#	$ports_ref->{'tcp'}{'465'}{'name'} = 'urd'		; 
#	$srvcobjects_ref->{'mtrgtrans'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mtrgtrans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtrgtrans'}{'port'}{'udp'} = '19398'	; 
#	$srvcobjects_ref->{'mtrgtrans'}{'ports'}{'udp'}{'19398'}++	; 
#	$ports_ref->{'udp'}{'19398'}{'name'} = 'mtrgtrans'		; 
#	$srvcobjects_ref->{'mtrgtrans'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mtrgtrans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtrgtrans'}{'port'}{'tcp'} = '19398'	; 
#	$srvcobjects_ref->{'mtrgtrans'}{'ports'}{'tcp'}{'19398'}++	; 
#	$ports_ref->{'tcp'}{'19398'}{'name'} = 'mtrgtrans'		; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'port'}{'udp'} = '3755'	; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'ports'}{'udp'}{'3755'}++	; 
#	$ports_ref->{'udp'}{'3755'}{'name'} = 'sas-remote-hlp'		; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'port'}{'tcp'} = '3755'	; 
#	$srvcobjects_ref->{'sas-remote-hlp'}{'ports'}{'tcp'}{'3755'}++	; 
#	$ports_ref->{'tcp'}{'3755'}{'name'} = 'sas-remote-hlp'		; 
#	$srvcobjects_ref->{'opennl-voice'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opennl-voice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opennl-voice'}{'port'}{'udp'} = '1259'	; 
#	$srvcobjects_ref->{'opennl-voice'}{'ports'}{'udp'}{'1259'}++	; 
#	$ports_ref->{'udp'}{'1259'}{'name'} = 'opennl-voice'		; 
#	$srvcobjects_ref->{'opennl-voice'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opennl-voice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opennl-voice'}{'port'}{'tcp'} = '1259'	; 
#	$srvcobjects_ref->{'opennl-voice'}{'ports'}{'tcp'}{'1259'}++	; 
#	$ports_ref->{'tcp'}{'1259'}{'name'} = 'opennl-voice'		; 
#	$srvcobjects_ref->{'can-ferret'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'can-ferret'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-ferret'}{'port'}{'udp'} = '1920'	; 
#	$srvcobjects_ref->{'can-ferret'}{'ports'}{'udp'}{'1920'}++	; 
#	$ports_ref->{'udp'}{'1920'}{'name'} = 'can-ferret'		; 
#	$srvcobjects_ref->{'can-ferret'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'can-ferret'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-ferret'}{'port'}{'tcp'} = '1920'	; 
#	$srvcobjects_ref->{'can-ferret'}{'ports'}{'tcp'}{'1920'}++	; 
#	$ports_ref->{'tcp'}{'1920'}{'name'} = 'can-ferret'		; 
#	$srvcobjects_ref->{'ms-olap2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-olap2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap2'}{'port'}{'udp'} = '2394'	; 
#	$srvcobjects_ref->{'ms-olap2'}{'ports'}{'udp'}{'2394'}++	; 
#	$ports_ref->{'udp'}{'2394'}{'name'} = 'ms-olap2'		; 
#	$srvcobjects_ref->{'ms-olap2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-olap2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap2'}{'port'}{'tcp'} = '2394'	; 
#	$srvcobjects_ref->{'ms-olap2'}{'ports'}{'tcp'}{'2394'}++	; 
#	$ports_ref->{'tcp'}{'2394'}{'name'} = 'ms-olap2'		; 
#	$srvcobjects_ref->{'scan-change'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scan-change'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scan-change'}{'port'}{'udp'} = '2719'	; 
#	$srvcobjects_ref->{'scan-change'}{'ports'}{'udp'}{'2719'}++	; 
#	$ports_ref->{'udp'}{'2719'}{'name'} = 'scan-change'		; 
#	$srvcobjects_ref->{'scan-change'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scan-change'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scan-change'}{'port'}{'tcp'} = '2719'	; 
#	$srvcobjects_ref->{'scan-change'}{'ports'}{'tcp'}{'2719'}++	; 
#	$ports_ref->{'tcp'}{'2719'}{'name'} = 'scan-change'		; 
#	$srvcobjects_ref->{'nfsd-status'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nfsd-status'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nfsd-status'}{'port'}{'tcp'} = '1110'	; 
#	$srvcobjects_ref->{'nfsd-status'}{'ports'}{'tcp'}{'1110'}++	; 
#	$ports_ref->{'tcp'}{'1110'}{'name'} = 'nfsd-status'		; 
#	$srvcobjects_ref->{'vaultbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vaultbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vaultbase'}{'port'}{'udp'} = '1771'	; 
#	$srvcobjects_ref->{'vaultbase'}{'ports'}{'udp'}{'1771'}++	; 
#	$ports_ref->{'udp'}{'1771'}{'name'} = 'vaultbase'		; 
#	$srvcobjects_ref->{'vaultbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vaultbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vaultbase'}{'port'}{'tcp'} = '1771'	; 
#	$srvcobjects_ref->{'vaultbase'}{'ports'}{'tcp'}{'1771'}++	; 
#	$ports_ref->{'tcp'}{'1771'}{'name'} = 'vaultbase'		; 
#	$srvcobjects_ref->{'nnsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nnsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nnsp'}{'port'}{'udp'} = '433'	; 
#	$srvcobjects_ref->{'nnsp'}{'ports'}{'udp'}{'433'}++	; 
#	$ports_ref->{'udp'}{'433'}{'name'} = 'nnsp'		; 
#	$srvcobjects_ref->{'nnsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nnsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nnsp'}{'port'}{'tcp'} = '433'	; 
#	$srvcobjects_ref->{'nnsp'}{'ports'}{'tcp'}{'433'}++	; 
#	$ports_ref->{'tcp'}{'433'}{'name'} = 'nnsp'		; 
#	$srvcobjects_ref->{'stmf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stmf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stmf'}{'port'}{'udp'} = '501'	; 
#	$srvcobjects_ref->{'stmf'}{'ports'}{'udp'}{'501'}++	; 
#	$ports_ref->{'udp'}{'501'}{'name'} = 'stmf'		; 
#	$srvcobjects_ref->{'stmf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stmf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stmf'}{'port'}{'tcp'} = '501'	; 
#	$srvcobjects_ref->{'stmf'}{'ports'}{'tcp'}{'501'}++	; 
#	$ports_ref->{'tcp'}{'501'}{'name'} = 'stmf'		; 
#	$srvcobjects_ref->{'nssocketport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nssocketport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nssocketport'}{'port'}{'udp'} = '3522'	; 
#	$srvcobjects_ref->{'nssocketport'}{'ports'}{'udp'}{'3522'}++	; 
#	$ports_ref->{'udp'}{'3522'}{'name'} = 'nssocketport'		; 
#	$srvcobjects_ref->{'nssocketport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nssocketport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nssocketport'}{'port'}{'tcp'} = '3522'	; 
#	$srvcobjects_ref->{'nssocketport'}{'ports'}{'tcp'}{'3522'}++	; 
#	$ports_ref->{'tcp'}{'3522'}{'name'} = 'nssocketport'		; 
#	$srvcobjects_ref->{'vipremoteagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vipremoteagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vipremoteagent'}{'port'}{'udp'} = '3752'	; 
#	$srvcobjects_ref->{'vipremoteagent'}{'ports'}{'udp'}{'3752'}++	; 
#	$ports_ref->{'udp'}{'3752'}{'name'} = 'vipremoteagent'		; 
#	$srvcobjects_ref->{'vipremoteagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vipremoteagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vipremoteagent'}{'port'}{'tcp'} = '3752'	; 
#	$srvcobjects_ref->{'vipremoteagent'}{'ports'}{'tcp'}{'3752'}++	; 
#	$ports_ref->{'tcp'}{'3752'}{'name'} = 'vipremoteagent'		; 
#	$srvcobjects_ref->{'remoteware-cl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remoteware-cl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remoteware-cl'}{'port'}{'udp'} = '3000'	; 
#	$srvcobjects_ref->{'remoteware-cl'}{'ports'}{'udp'}{'3000'}++	; 
#	$ports_ref->{'udp'}{'3000'}{'name'} = 'remoteware-cl'		; 
#	$srvcobjects_ref->{'remoteware-cl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remoteware-cl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remoteware-cl'}{'port'}{'tcp'} = '3000'	; 
#	$srvcobjects_ref->{'remoteware-cl'}{'ports'}{'tcp'}{'3000'}++	; 
#	$ports_ref->{'tcp'}{'3000'}{'name'} = 'remoteware-cl'		; 
#	$srvcobjects_ref->{'netware-ip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netware-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netware-ip'}{'port'}{'udp'} = '396'	; 
#	$srvcobjects_ref->{'netware-ip'}{'ports'}{'udp'}{'396'}++	; 
#	$ports_ref->{'udp'}{'396'}{'name'} = 'netware-ip'		; 
#	$srvcobjects_ref->{'netware-ip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netware-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netware-ip'}{'port'}{'tcp'} = '396'	; 
#	$srvcobjects_ref->{'netware-ip'}{'ports'}{'tcp'}{'396'}++	; 
#	$ports_ref->{'tcp'}{'396'}{'name'} = 'netware-ip'		; 
#	$srvcobjects_ref->{'axon-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'axon-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'axon-lm'}{'port'}{'udp'} = '1548'	; 
#	$srvcobjects_ref->{'axon-lm'}{'ports'}{'udp'}{'1548'}++	; 
#	$ports_ref->{'udp'}{'1548'}{'name'} = 'axon-lm'		; 
#	$srvcobjects_ref->{'axon-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'axon-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'axon-lm'}{'port'}{'tcp'} = '1548'	; 
#	$srvcobjects_ref->{'axon-lm'}{'ports'}{'tcp'}{'1548'}++	; 
#	$ports_ref->{'tcp'}{'1548'}{'name'} = 'axon-lm'		; 
#	$srvcobjects_ref->{'binkp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'binkp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'binkp'}{'port'}{'udp'} = '24554'	; 
#	$srvcobjects_ref->{'binkp'}{'ports'}{'udp'}{'24554'}++	; 
#	$ports_ref->{'udp'}{'24554'}{'name'} = 'binkp'		; 
#	$srvcobjects_ref->{'binkp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'binkp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'binkp'}{'port'}{'tcp'} = '24554'	; 
#	$srvcobjects_ref->{'binkp'}{'ports'}{'tcp'}{'24554'}++	; 
#	$ports_ref->{'tcp'}{'24554'}{'name'} = 'binkp'		; 
#	$srvcobjects_ref->{'smntubootstrap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smntubootstrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smntubootstrap'}{'port'}{'udp'} = '2613'	; 
#	$srvcobjects_ref->{'smntubootstrap'}{'ports'}{'udp'}{'2613'}++	; 
#	$ports_ref->{'udp'}{'2613'}{'name'} = 'smntubootstrap'		; 
#	$srvcobjects_ref->{'smntubootstrap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smntubootstrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smntubootstrap'}{'port'}{'tcp'} = '2613'	; 
#	$srvcobjects_ref->{'smntubootstrap'}{'ports'}{'tcp'}{'2613'}++	; 
#	$ports_ref->{'tcp'}{'2613'}{'name'} = 'smntubootstrap'		; 
#	$srvcobjects_ref->{'mtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtp'}{'port'}{'udp'} = '1911'	; 
#	$srvcobjects_ref->{'mtp'}{'ports'}{'udp'}{'1911'}++	; 
#	$ports_ref->{'udp'}{'1911'}{'name'} = 'mtp'		; 
#	$srvcobjects_ref->{'mtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtp'}{'port'}{'tcp'} = '1911'	; 
#	$srvcobjects_ref->{'mtp'}{'ports'}{'tcp'}{'1911'}++	; 
#	$ports_ref->{'tcp'}{'1911'}{'name'} = 'mtp'		; 
#	$srvcobjects_ref->{'ivsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ivsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivsd'}{'port'}{'udp'} = '2241'	; 
#	$srvcobjects_ref->{'ivsd'}{'ports'}{'udp'}{'2241'}++	; 
#	$ports_ref->{'udp'}{'2241'}{'name'} = 'ivsd'		; 
#	$srvcobjects_ref->{'ivsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ivsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivsd'}{'port'}{'tcp'} = '2241'	; 
#	$srvcobjects_ref->{'ivsd'}{'ports'}{'tcp'}{'2241'}++	; 
#	$ports_ref->{'tcp'}{'2241'}{'name'} = 'ivsd'		; 
#	$srvcobjects_ref->{'3l-l1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3l-l1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3l-l1'}{'port'}{'udp'} = '1511'	; 
#	$srvcobjects_ref->{'3l-l1'}{'ports'}{'udp'}{'1511'}++	; 
#	$ports_ref->{'udp'}{'1511'}{'name'} = '3l-l1'		; 
#	$srvcobjects_ref->{'3l-l1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3l-l1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3l-l1'}{'port'}{'tcp'} = '1511'	; 
#	$srvcobjects_ref->{'3l-l1'}{'ports'}{'tcp'}{'1511'}++	; 
#	$ports_ref->{'tcp'}{'1511'}{'name'} = '3l-l1'		; 
#	$srvcobjects_ref->{'topx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'topx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'topx'}{'port'}{'udp'} = '2436'	; 
#	$srvcobjects_ref->{'topx'}{'ports'}{'udp'}{'2436'}++	; 
#	$ports_ref->{'udp'}{'2436'}{'name'} = 'topx'		; 
#	$srvcobjects_ref->{'topx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'topx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'topx'}{'port'}{'tcp'} = '2436'	; 
#	$srvcobjects_ref->{'topx'}{'ports'}{'tcp'}{'2436'}++	; 
#	$ports_ref->{'tcp'}{'2436'}{'name'} = 'topx'		; 
#	$srvcobjects_ref->{'cybercash'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cybercash'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cybercash'}{'port'}{'udp'} = '551'	; 
#	$srvcobjects_ref->{'cybercash'}{'ports'}{'udp'}{'551'}++	; 
#	$ports_ref->{'udp'}{'551'}{'name'} = 'cybercash'		; 
#	$srvcobjects_ref->{'cybercash'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cybercash'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cybercash'}{'port'}{'tcp'} = '551'	; 
#	$srvcobjects_ref->{'cybercash'}{'ports'}{'tcp'}{'551'}++	; 
#	$ports_ref->{'tcp'}{'551'}{'name'} = 'cybercash'		; 
#	$srvcobjects_ref->{'tl1-raw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tl1-raw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1-raw'}{'port'}{'udp'} = '3082'	; 
#	$srvcobjects_ref->{'tl1-raw'}{'ports'}{'udp'}{'3082'}++	; 
#	$ports_ref->{'udp'}{'3082'}{'name'} = 'tl1-raw'		; 
#	$srvcobjects_ref->{'tl1-raw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tl1-raw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1-raw'}{'port'}{'tcp'} = '3082'	; 
#	$srvcobjects_ref->{'tl1-raw'}{'ports'}{'tcp'}{'3082'}++	; 
#	$ports_ref->{'tcp'}{'3082'}{'name'} = 'tl1-raw'		; 
#	$srvcobjects_ref->{'emp-server2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emp-server2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emp-server2'}{'port'}{'udp'} = '6322'	; 
#	$srvcobjects_ref->{'emp-server2'}{'ports'}{'udp'}{'6322'}++	; 
#	$ports_ref->{'udp'}{'6322'}{'name'} = 'emp-server2'		; 
#	$srvcobjects_ref->{'emp-server2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emp-server2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emp-server2'}{'port'}{'tcp'} = '6322'	; 
#	$srvcobjects_ref->{'emp-server2'}{'ports'}{'tcp'}{'6322'}++	; 
#	$ports_ref->{'tcp'}{'6322'}{'name'} = 'emp-server2'		; 
#	$srvcobjects_ref->{'diagnose-proc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'diagnose-proc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'diagnose-proc'}{'port'}{'udp'} = '6072'	; 
#	$srvcobjects_ref->{'diagnose-proc'}{'ports'}{'udp'}{'6072'}++	; 
#	$ports_ref->{'udp'}{'6072'}{'name'} = 'diagnose-proc'		; 
#	$srvcobjects_ref->{'diagnose-proc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'diagnose-proc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'diagnose-proc'}{'port'}{'tcp'} = '6072'	; 
#	$srvcobjects_ref->{'diagnose-proc'}{'ports'}{'tcp'}{'6072'}++	; 
#	$ports_ref->{'tcp'}{'6072'}{'name'} = 'diagnose-proc'		; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'port'}{'udp'} = '2413'	; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'ports'}{'udp'}{'2413'}++	; 
#	$ports_ref->{'udp'}{'2413'}{'name'} = 'orion-rmi-reg'		; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'port'}{'tcp'} = '2413'	; 
#	$srvcobjects_ref->{'orion-rmi-reg'}{'ports'}{'tcp'}{'2413'}++	; 
#	$ports_ref->{'tcp'}{'2413'}{'name'} = 'orion-rmi-reg'		; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'port'}{'udp'} = '2701'	; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'ports'}{'udp'}{'2701'}++	; 
#	$ports_ref->{'udp'}{'2701'}{'name'} = 'sms-rcinfo'		; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'port'}{'tcp'} = '2701'	; 
#	$srvcobjects_ref->{'sms-rcinfo'}{'ports'}{'tcp'}{'2701'}++	; 
#	$ports_ref->{'tcp'}{'2701'}{'name'} = 'sms-rcinfo'		; 
#	$srvcobjects_ref->{'datasurfsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'datasurfsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datasurfsrv'}{'port'}{'udp'} = '461'	; 
#	$srvcobjects_ref->{'datasurfsrv'}{'ports'}{'udp'}{'461'}++	; 
#	$ports_ref->{'udp'}{'461'}{'name'} = 'datasurfsrv'		; 
#	$srvcobjects_ref->{'datasurfsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'datasurfsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datasurfsrv'}{'port'}{'tcp'} = '461'	; 
#	$srvcobjects_ref->{'datasurfsrv'}{'ports'}{'tcp'}{'461'}++	; 
#	$ports_ref->{'tcp'}{'461'}{'name'} = 'datasurfsrv'		; 
#	$srvcobjects_ref->{'dec-notes'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dec-notes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec-notes'}{'port'}{'udp'} = '3333'	; 
#	$srvcobjects_ref->{'dec-notes'}{'ports'}{'udp'}{'3333'}++	; 
#	$ports_ref->{'udp'}{'3333'}{'name'} = 'dec-notes'		; 
#	$srvcobjects_ref->{'dec-notes'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dec-notes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec-notes'}{'port'}{'tcp'} = '3333'	; 
#	$srvcobjects_ref->{'dec-notes'}{'ports'}{'tcp'}{'3333'}++	; 
#	$ports_ref->{'tcp'}{'3333'}{'name'} = 'dec-notes'		; 
#	$srvcobjects_ref->{'opsec-lea'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsec-lea'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-lea'}{'port'}{'udp'} = '18184'	; 
#	$srvcobjects_ref->{'opsec-lea'}{'ports'}{'udp'}{'18184'}++	; 
#	$ports_ref->{'udp'}{'18184'}{'name'} = 'opsec-lea'		; 
#	$srvcobjects_ref->{'opsec-lea'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsec-lea'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-lea'}{'port'}{'tcp'} = '18184'	; 
#	$srvcobjects_ref->{'opsec-lea'}{'ports'}{'tcp'}{'18184'}++	; 
#	$ports_ref->{'tcp'}{'18184'}{'name'} = 'opsec-lea'		; 
#	$srvcobjects_ref->{'targus-getdata2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'targus-getdata2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata2'}{'port'}{'udp'} = '5202'	; 
#	$srvcobjects_ref->{'targus-getdata2'}{'ports'}{'udp'}{'5202'}++	; 
#	$ports_ref->{'udp'}{'5202'}{'name'} = 'targus-getdata2'		; 
#	$srvcobjects_ref->{'targus-getdata2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'targus-getdata2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata2'}{'port'}{'tcp'} = '5202'	; 
#	$srvcobjects_ref->{'targus-getdata2'}{'ports'}{'tcp'}{'5202'}++	; 
#	$ports_ref->{'tcp'}{'5202'}{'name'} = 'targus-getdata2'		; 
#	$srvcobjects_ref->{'redwood-broker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'redwood-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redwood-broker'}{'port'}{'udp'} = '3001'	; 
#	$srvcobjects_ref->{'redwood-broker'}{'ports'}{'udp'}{'3001'}++	; 
#	$ports_ref->{'udp'}{'3001'}{'name'} = 'redwood-broker'		; 
#	$srvcobjects_ref->{'redwood-broker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'redwood-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redwood-broker'}{'port'}{'tcp'} = '3001'	; 
#	$srvcobjects_ref->{'redwood-broker'}{'ports'}{'tcp'}{'3001'}++	; 
#	$ports_ref->{'tcp'}{'3001'}{'name'} = 'redwood-broker'		; 
#	$srvcobjects_ref->{'ipether232port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipether232port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipether232port'}{'port'}{'udp'} = '3497'	; 
#	$srvcobjects_ref->{'ipether232port'}{'ports'}{'udp'}{'3497'}++	; 
#	$ports_ref->{'udp'}{'3497'}{'name'} = 'ipether232port'		; 
#	$srvcobjects_ref->{'ipether232port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipether232port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipether232port'}{'port'}{'tcp'} = '3497'	; 
#	$srvcobjects_ref->{'ipether232port'}{'ports'}{'tcp'}{'3497'}++	; 
#	$ports_ref->{'tcp'}{'3497'}{'name'} = 'ipether232port'		; 
#	$srvcobjects_ref->{'hnmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hnmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hnmp'}{'port'}{'udp'} = '6790'	; 
#	$srvcobjects_ref->{'hnmp'}{'ports'}{'udp'}{'6790'}++	; 
#	$ports_ref->{'udp'}{'6790'}{'name'} = 'hnmp'		; 
#	$srvcobjects_ref->{'hnmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hnmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hnmp'}{'port'}{'tcp'} = '6790'	; 
#	$srvcobjects_ref->{'hnmp'}{'ports'}{'tcp'}{'6790'}++	; 
#	$ports_ref->{'tcp'}{'6790'}{'name'} = 'hnmp'		; 
#	$srvcobjects_ref->{'translogic-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'translogic-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'translogic-lm'}{'port'}{'udp'} = '1753'	; 
#	$srvcobjects_ref->{'translogic-lm'}{'ports'}{'udp'}{'1753'}++	; 
#	$ports_ref->{'udp'}{'1753'}{'name'} = 'translogic-lm'		; 
#	$srvcobjects_ref->{'translogic-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'translogic-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'translogic-lm'}{'port'}{'tcp'} = '1753'	; 
#	$srvcobjects_ref->{'translogic-lm'}{'ports'}{'tcp'}{'1753'}++	; 
#	$ports_ref->{'tcp'}{'1753'}{'name'} = 'translogic-lm'		; 
#	$srvcobjects_ref->{'amiganetfs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amiganetfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amiganetfs'}{'port'}{'udp'} = '2100'	; 
#	$srvcobjects_ref->{'amiganetfs'}{'ports'}{'udp'}{'2100'}++	; 
#	$ports_ref->{'udp'}{'2100'}{'name'} = 'amiganetfs'		; 
#	$srvcobjects_ref->{'amiganetfs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amiganetfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amiganetfs'}{'port'}{'tcp'} = '2100'	; 
#	$srvcobjects_ref->{'amiganetfs'}{'ports'}{'tcp'}{'2100'}++	; 
#	$ports_ref->{'tcp'}{'2100'}{'name'} = 'amiganetfs'		; 
#	$srvcobjects_ref->{'dsfgw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsfgw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsfgw'}{'port'}{'udp'} = '438'	; 
#	$srvcobjects_ref->{'dsfgw'}{'ports'}{'udp'}{'438'}++	; 
#	$ports_ref->{'udp'}{'438'}{'name'} = 'dsfgw'		; 
#	$srvcobjects_ref->{'dsfgw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsfgw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsfgw'}{'port'}{'tcp'} = '438'	; 
#	$srvcobjects_ref->{'dsfgw'}{'ports'}{'tcp'}{'438'}++	; 
#	$ports_ref->{'tcp'}{'438'}{'name'} = 'dsfgw'		; 
#	$srvcobjects_ref->{'quotad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quotad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quotad'}{'port'}{'udp'} = '762'	; 
#	$srvcobjects_ref->{'quotad'}{'ports'}{'udp'}{'762'}++	; 
#	$ports_ref->{'udp'}{'762'}{'name'} = 'quotad'		; 
#	$srvcobjects_ref->{'quotad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quotad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quotad'}{'port'}{'tcp'} = '762'	; 
#	$srvcobjects_ref->{'quotad'}{'ports'}{'tcp'}{'762'}++	; 
#	$ports_ref->{'tcp'}{'762'}{'name'} = 'quotad'		; 
#	$srvcobjects_ref->{'firstcall42'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'firstcall42'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firstcall42'}{'port'}{'udp'} = '2673'	; 
#	$srvcobjects_ref->{'firstcall42'}{'ports'}{'udp'}{'2673'}++	; 
#	$ports_ref->{'udp'}{'2673'}{'name'} = 'firstcall42'		; 
#	$srvcobjects_ref->{'firstcall42'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'firstcall42'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firstcall42'}{'port'}{'tcp'} = '2673'	; 
#	$srvcobjects_ref->{'firstcall42'}{'ports'}{'tcp'}{'2673'}++	; 
#	$ports_ref->{'tcp'}{'2673'}{'name'} = 'firstcall42'		; 
#	$srvcobjects_ref->{'nxedit'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nxedit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nxedit'}{'port'}{'udp'} = '126'	; 
#	$srvcobjects_ref->{'nxedit'}{'ports'}{'udp'}{'126'}++	; 
#	$ports_ref->{'udp'}{'126'}{'name'} = 'nxedit'		; 
#	$srvcobjects_ref->{'nxedit'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nxedit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nxedit'}{'port'}{'tcp'} = '126'	; 
#	$srvcobjects_ref->{'nxedit'}{'ports'}{'tcp'}{'126'}++	; 
#	$ports_ref->{'tcp'}{'126'}{'name'} = 'nxedit'		; 
#	$srvcobjects_ref->{'stgxfws'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stgxfws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stgxfws'}{'port'}{'udp'} = '1226'	; 
#	$srvcobjects_ref->{'stgxfws'}{'ports'}{'udp'}{'1226'}++	; 
#	$ports_ref->{'udp'}{'1226'}{'name'} = 'stgxfws'		; 
#	$srvcobjects_ref->{'stgxfws'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stgxfws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stgxfws'}{'port'}{'tcp'} = '1226'	; 
#	$srvcobjects_ref->{'stgxfws'}{'ports'}{'tcp'}{'1226'}++	; 
#	$ports_ref->{'tcp'}{'1226'}{'name'} = 'stgxfws'		; 
#	$srvcobjects_ref->{'ampr-inter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ampr-inter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ampr-inter'}{'port'}{'udp'} = '1536'	; 
#	$srvcobjects_ref->{'ampr-inter'}{'ports'}{'udp'}{'1536'}++	; 
#	$ports_ref->{'udp'}{'1536'}{'name'} = 'ampr-inter'		; 
#	$srvcobjects_ref->{'ampr-inter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ampr-inter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ampr-inter'}{'port'}{'tcp'} = '1536'	; 
#	$srvcobjects_ref->{'ampr-inter'}{'ports'}{'tcp'}{'1536'}++	; 
#	$ports_ref->{'tcp'}{'1536'}{'name'} = 'ampr-inter'		; 
#	$srvcobjects_ref->{'gprs-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gprs-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gprs-data'}{'port'}{'tcp'} = '3386'	; 
#	$srvcobjects_ref->{'gprs-data'}{'ports'}{'tcp'}{'3386'}++	; 
#	$ports_ref->{'tcp'}{'3386'}{'name'} = 'gprs-data'		; 
#	$srvcobjects_ref->{'video-activmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'video-activmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'video-activmail'}{'port'}{'udp'} = '1398'	; 
#	$srvcobjects_ref->{'video-activmail'}{'ports'}{'udp'}{'1398'}++	; 
#	$ports_ref->{'udp'}{'1398'}{'name'} = 'video-activmail'		; 
#	$srvcobjects_ref->{'video-activmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'video-activmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'video-activmail'}{'port'}{'tcp'} = '1398'	; 
#	$srvcobjects_ref->{'video-activmail'}{'ports'}{'tcp'}{'1398'}++	; 
#	$ports_ref->{'tcp'}{'1398'}{'name'} = 'video-activmail'		; 
#	$srvcobjects_ref->{'canex-watch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'canex-watch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canex-watch'}{'port'}{'udp'} = '3583'	; 
#	$srvcobjects_ref->{'canex-watch'}{'ports'}{'udp'}{'3583'}++	; 
#	$ports_ref->{'udp'}{'3583'}{'name'} = 'canex-watch'		; 
#	$srvcobjects_ref->{'canex-watch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'canex-watch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canex-watch'}{'port'}{'tcp'} = '3583'	; 
#	$srvcobjects_ref->{'canex-watch'}{'ports'}{'tcp'}{'3583'}++	; 
#	$ports_ref->{'tcp'}{'3583'}{'name'} = 'canex-watch'		; 
#	$srvcobjects_ref->{'worldwire'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'worldwire'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldwire'}{'port'}{'udp'} = '2371'	; 
#	$srvcobjects_ref->{'worldwire'}{'ports'}{'udp'}{'2371'}++	; 
#	$ports_ref->{'udp'}{'2371'}{'name'} = 'worldwire'		; 
#	$srvcobjects_ref->{'worldwire'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'worldwire'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldwire'}{'port'}{'tcp'} = '2371'	; 
#	$srvcobjects_ref->{'worldwire'}{'ports'}{'tcp'}{'2371'}++	; 
#	$ports_ref->{'tcp'}{'2371'}{'name'} = 'worldwire'		; 
#	$srvcobjects_ref->{'continuus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'continuus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'continuus'}{'port'}{'udp'} = '5412'	; 
#	$srvcobjects_ref->{'continuus'}{'ports'}{'udp'}{'5412'}++	; 
#	$ports_ref->{'udp'}{'5412'}{'name'} = 'continuus'		; 
#	$srvcobjects_ref->{'continuus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'continuus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'continuus'}{'port'}{'tcp'} = '5412'	; 
#	$srvcobjects_ref->{'continuus'}{'ports'}{'tcp'}{'5412'}++	; 
#	$ports_ref->{'tcp'}{'5412'}{'name'} = 'continuus'		; 
#	$srvcobjects_ref->{'sitaramgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sitaramgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sitaramgmt'}{'port'}{'udp'} = '2630'	; 
#	$srvcobjects_ref->{'sitaramgmt'}{'ports'}{'udp'}{'2630'}++	; 
#	$ports_ref->{'udp'}{'2630'}{'name'} = 'sitaramgmt'		; 
#	$srvcobjects_ref->{'sitaramgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sitaramgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sitaramgmt'}{'port'}{'tcp'} = '2630'	; 
#	$srvcobjects_ref->{'sitaramgmt'}{'ports'}{'tcp'}{'2630'}++	; 
#	$ports_ref->{'tcp'}{'2630'}{'name'} = 'sitaramgmt'		; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'port'}{'udp'} = '2961'	; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'ports'}{'udp'}{'2961'}++	; 
#	$ports_ref->{'udp'}{'2961'}{'name'} = 'boldsoft-lm'		; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'port'}{'tcp'} = '2961'	; 
#	$srvcobjects_ref->{'boldsoft-lm'}{'ports'}{'tcp'}{'2961'}++	; 
#	$ports_ref->{'tcp'}{'2961'}{'name'} = 'boldsoft-lm'		; 
#	$srvcobjects_ref->{'noagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'noagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'noagent'}{'port'}{'udp'} = '1917'	; 
#	$srvcobjects_ref->{'noagent'}{'ports'}{'udp'}{'1917'}++	; 
#	$ports_ref->{'udp'}{'1917'}{'name'} = 'noagent'		; 
#	$srvcobjects_ref->{'noagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'noagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'noagent'}{'port'}{'tcp'} = '1917'	; 
#	$srvcobjects_ref->{'noagent'}{'ports'}{'tcp'}{'1917'}++	; 
#	$ports_ref->{'tcp'}{'1917'}{'name'} = 'noagent'		; 
#	$srvcobjects_ref->{'apc-9951'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-9951'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-9951'}{'port'}{'udp'} = '9951'	; 
#	$srvcobjects_ref->{'apc-9951'}{'ports'}{'udp'}{'9951'}++	; 
#	$ports_ref->{'udp'}{'9951'}{'name'} = 'apc-9951'		; 
#	$srvcobjects_ref->{'apc-9951'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-9951'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-9951'}{'port'}{'tcp'} = '9951'	; 
#	$srvcobjects_ref->{'apc-9951'}{'ports'}{'tcp'}{'9951'}++	; 
#	$ports_ref->{'tcp'}{'9951'}{'name'} = 'apc-9951'		; 
#	$srvcobjects_ref->{'xmpv7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xmpv7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmpv7'}{'port'}{'udp'} = '7430'	; 
#	$srvcobjects_ref->{'xmpv7'}{'ports'}{'udp'}{'7430'}++	; 
#	$ports_ref->{'udp'}{'7430'}{'name'} = 'xmpv7'		; 
#	$srvcobjects_ref->{'xmpv7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xmpv7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmpv7'}{'port'}{'tcp'} = '7430'	; 
#	$srvcobjects_ref->{'xmpv7'}{'ports'}{'tcp'}{'7430'}++	; 
#	$ports_ref->{'tcp'}{'7430'}{'name'} = 'xmpv7'		; 
#	$srvcobjects_ref->{'ovladmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovladmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovladmgr'}{'port'}{'udp'} = '7428'	; 
#	$srvcobjects_ref->{'ovladmgr'}{'ports'}{'udp'}{'7428'}++	; 
#	$ports_ref->{'udp'}{'7428'}{'name'} = 'ovladmgr'		; 
#	$srvcobjects_ref->{'ovladmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovladmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovladmgr'}{'port'}{'tcp'} = '7428'	; 
#	$srvcobjects_ref->{'ovladmgr'}{'ports'}{'tcp'}{'7428'}++	; 
#	$ports_ref->{'tcp'}{'7428'}{'name'} = 'ovladmgr'		; 
#	$srvcobjects_ref->{'monitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'monitor'}{'port'}{'udp'} = '561'	; 
#	$srvcobjects_ref->{'monitor'}{'ports'}{'udp'}{'561'}++	; 
#	$ports_ref->{'udp'}{'561'}{'name'} = 'monitor'		; 
#	$srvcobjects_ref->{'monitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'monitor'}{'port'}{'tcp'} = '561'	; 
#	$srvcobjects_ref->{'monitor'}{'ports'}{'tcp'}{'561'}++	; 
#	$ports_ref->{'tcp'}{'561'}{'name'} = 'monitor'		; 
#	$srvcobjects_ref->{'colubris'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'colubris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'colubris'}{'port'}{'udp'} = '3490'	; 
#	$srvcobjects_ref->{'colubris'}{'ports'}{'udp'}{'3490'}++	; 
#	$ports_ref->{'udp'}{'3490'}{'name'} = 'colubris'		; 
#	$srvcobjects_ref->{'colubris'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'colubris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'colubris'}{'port'}{'tcp'} = '3490'	; 
#	$srvcobjects_ref->{'colubris'}{'ports'}{'tcp'}{'3490'}++	; 
#	$ports_ref->{'tcp'}{'3490'}{'name'} = 'colubris'		; 
#	$srvcobjects_ref->{'ris-cm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ris-cm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ris-cm'}{'port'}{'udp'} = '748'	; 
#	$srvcobjects_ref->{'ris-cm'}{'ports'}{'udp'}{'748'}++	; 
#	$ports_ref->{'udp'}{'748'}{'name'} = 'ris-cm'		; 
#	$srvcobjects_ref->{'ris-cm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ris-cm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ris-cm'}{'port'}{'tcp'} = '748'	; 
#	$srvcobjects_ref->{'ris-cm'}{'ports'}{'tcp'}{'748'}++	; 
#	$ports_ref->{'tcp'}{'748'}{'name'} = 'ris-cm'		; 
#	$srvcobjects_ref->{'dfoxserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dfoxserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dfoxserver'}{'port'}{'udp'} = '2960'	; 
#	$srvcobjects_ref->{'dfoxserver'}{'ports'}{'udp'}{'2960'}++	; 
#	$ports_ref->{'udp'}{'2960'}{'name'} = 'dfoxserver'		; 
#	$srvcobjects_ref->{'dfoxserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dfoxserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dfoxserver'}{'port'}{'tcp'} = '2960'	; 
#	$srvcobjects_ref->{'dfoxserver'}{'ports'}{'tcp'}{'2960'}++	; 
#	$ports_ref->{'tcp'}{'2960'}{'name'} = 'dfoxserver'		; 
#	$srvcobjects_ref->{'catalyst'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'catalyst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'catalyst'}{'port'}{'udp'} = '2836'	; 
#	$srvcobjects_ref->{'catalyst'}{'ports'}{'udp'}{'2836'}++	; 
#	$ports_ref->{'udp'}{'2836'}{'name'} = 'catalyst'		; 
#	$srvcobjects_ref->{'catalyst'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'catalyst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'catalyst'}{'port'}{'tcp'} = '2836'	; 
#	$srvcobjects_ref->{'catalyst'}{'ports'}{'tcp'}{'2836'}++	; 
#	$ports_ref->{'tcp'}{'2836'}{'name'} = 'catalyst'		; 
#	$srvcobjects_ref->{'videte-cipc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'videte-cipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'videte-cipc'}{'port'}{'udp'} = '1927'	; 
#	$srvcobjects_ref->{'videte-cipc'}{'ports'}{'udp'}{'1927'}++	; 
#	$ports_ref->{'udp'}{'1927'}{'name'} = 'videte-cipc'		; 
#	$srvcobjects_ref->{'videte-cipc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'videte-cipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'videte-cipc'}{'port'}{'tcp'} = '1927'	; 
#	$srvcobjects_ref->{'videte-cipc'}{'ports'}{'tcp'}{'1927'}++	; 
#	$ports_ref->{'tcp'}{'1927'}{'name'} = 'videte-cipc'		; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'port'}{'udp'} = '1698'	; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'ports'}{'udp'}{'1698'}++	; 
#	$ports_ref->{'udp'}{'1698'}{'name'} = 'rsvp-encap-1'		; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'port'}{'tcp'} = '1698'	; 
#	$srvcobjects_ref->{'rsvp-encap-1'}{'ports'}{'tcp'}{'1698'}++	; 
#	$ports_ref->{'tcp'}{'1698'}{'name'} = 'rsvp-encap-1'		; 
#	$srvcobjects_ref->{'xsync'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xsync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xsync'}{'port'}{'udp'} = '3721'	; 
#	$srvcobjects_ref->{'xsync'}{'ports'}{'udp'}{'3721'}++	; 
#	$ports_ref->{'udp'}{'3721'}{'name'} = 'xsync'		; 
#	$srvcobjects_ref->{'xsync'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xsync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xsync'}{'port'}{'tcp'} = '3721'	; 
#	$srvcobjects_ref->{'xsync'}{'ports'}{'tcp'}{'3721'}++	; 
#	$ports_ref->{'tcp'}{'3721'}{'name'} = 'xsync'		; 
#	$srvcobjects_ref->{'xingmpeg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xingmpeg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xingmpeg'}{'port'}{'udp'} = '1558'	; 
#	$srvcobjects_ref->{'xingmpeg'}{'ports'}{'udp'}{'1558'}++	; 
#	$ports_ref->{'udp'}{'1558'}{'name'} = 'xingmpeg'		; 
#	$srvcobjects_ref->{'xingmpeg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xingmpeg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xingmpeg'}{'port'}{'tcp'} = '1558'	; 
#	$srvcobjects_ref->{'xingmpeg'}{'ports'}{'tcp'}{'1558'}++	; 
#	$ports_ref->{'tcp'}{'1558'}{'name'} = 'xingmpeg'		; 
#	$srvcobjects_ref->{'3d-nfsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3d-nfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3d-nfsd'}{'port'}{'udp'} = '2323'	; 
#	$srvcobjects_ref->{'3d-nfsd'}{'ports'}{'udp'}{'2323'}++	; 
#	$ports_ref->{'udp'}{'2323'}{'name'} = '3d-nfsd'		; 
#	$srvcobjects_ref->{'3d-nfsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3d-nfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3d-nfsd'}{'port'}{'tcp'} = '2323'	; 
#	$srvcobjects_ref->{'3d-nfsd'}{'ports'}{'tcp'}{'2323'}++	; 
#	$ports_ref->{'tcp'}{'2323'}{'name'} = '3d-nfsd'		; 
#	$srvcobjects_ref->{'kali'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kali'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kali'}{'port'}{'udp'} = '2213'	; 
#	$srvcobjects_ref->{'kali'}{'ports'}{'udp'}{'2213'}++	; 
#	$ports_ref->{'udp'}{'2213'}{'name'} = 'kali'		; 
#	$srvcobjects_ref->{'kali'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kali'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kali'}{'port'}{'tcp'} = '2213'	; 
#	$srvcobjects_ref->{'kali'}{'ports'}{'tcp'}{'2213'}++	; 
#	$ports_ref->{'tcp'}{'2213'}{'name'} = 'kali'		; 
#	$srvcobjects_ref->{'edm-manager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edm-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-manager'}{'port'}{'udp'} = '3460'	; 
#	$srvcobjects_ref->{'edm-manager'}{'ports'}{'udp'}{'3460'}++	; 
#	$ports_ref->{'udp'}{'3460'}{'name'} = 'edm-manager'		; 
#	$srvcobjects_ref->{'edm-manager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edm-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-manager'}{'port'}{'tcp'} = '3460'	; 
#	$srvcobjects_ref->{'edm-manager'}{'ports'}{'tcp'}{'3460'}++	; 
#	$ports_ref->{'tcp'}{'3460'}{'name'} = 'edm-manager'		; 
#	$srvcobjects_ref->{'instantia'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'instantia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'instantia'}{'port'}{'udp'} = '1240'	; 
#	$srvcobjects_ref->{'instantia'}{'ports'}{'udp'}{'1240'}++	; 
#	$ports_ref->{'udp'}{'1240'}{'name'} = 'instantia'		; 
#	$srvcobjects_ref->{'instantia'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'instantia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'instantia'}{'port'}{'tcp'} = '1240'	; 
#	$srvcobjects_ref->{'instantia'}{'ports'}{'tcp'}{'1240'}++	; 
#	$ports_ref->{'tcp'}{'1240'}{'name'} = 'instantia'		; 
#	$srvcobjects_ref->{'fjippol-port2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjippol-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-port2'}{'port'}{'udp'} = '2751'	; 
#	$srvcobjects_ref->{'fjippol-port2'}{'ports'}{'udp'}{'2751'}++	; 
#	$ports_ref->{'udp'}{'2751'}{'name'} = 'fjippol-port2'		; 
#	$srvcobjects_ref->{'fjippol-port2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjippol-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-port2'}{'port'}{'tcp'} = '2751'	; 
#	$srvcobjects_ref->{'fjippol-port2'}{'ports'}{'tcp'}{'2751'}++	; 
#	$ports_ref->{'tcp'}{'2751'}{'name'} = 'fjippol-port2'		; 
#	$srvcobjects_ref->{'pda-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pda-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pda-data'}{'port'}{'udp'} = '3253'	; 
#	$srvcobjects_ref->{'pda-data'}{'ports'}{'udp'}{'3253'}++	; 
#	$ports_ref->{'udp'}{'3253'}{'name'} = 'pda-data'		; 
#	$srvcobjects_ref->{'pda-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pda-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pda-data'}{'port'}{'tcp'} = '3253'	; 
#	$srvcobjects_ref->{'pda-data'}{'ports'}{'tcp'}{'3253'}++	; 
#	$ports_ref->{'tcp'}{'3253'}{'name'} = 'pda-data'		; 
#	$srvcobjects_ref->{'gxs-data-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gxs-data-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gxs-data-port'}{'port'}{'udp'} = '2073'	; 
#	$srvcobjects_ref->{'gxs-data-port'}{'ports'}{'udp'}{'2073'}++	; 
#	$ports_ref->{'udp'}{'2073'}{'name'} = 'gxs-data-port'		; 
#	$srvcobjects_ref->{'gxs-data-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gxs-data-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gxs-data-port'}{'port'}{'tcp'} = '2073'	; 
#	$srvcobjects_ref->{'gxs-data-port'}{'ports'}{'tcp'}{'2073'}++	; 
#	$ports_ref->{'tcp'}{'2073'}{'name'} = 'gxs-data-port'		; 
#	$srvcobjects_ref->{'atmtcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'atmtcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atmtcp'}{'port'}{'udp'} = '2812'	; 
#	$srvcobjects_ref->{'atmtcp'}{'ports'}{'udp'}{'2812'}++	; 
#	$ports_ref->{'udp'}{'2812'}{'name'} = 'atmtcp'		; 
#	$srvcobjects_ref->{'atmtcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'atmtcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atmtcp'}{'port'}{'tcp'} = '2812'	; 
#	$srvcobjects_ref->{'atmtcp'}{'ports'}{'tcp'}{'2812'}++	; 
#	$ports_ref->{'tcp'}{'2812'}{'name'} = 'atmtcp'		; 
#	$srvcobjects_ref->{'vergencecm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vergencecm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vergencecm'}{'port'}{'udp'} = '2771'	; 
#	$srvcobjects_ref->{'vergencecm'}{'ports'}{'udp'}{'2771'}++	; 
#	$ports_ref->{'udp'}{'2771'}{'name'} = 'vergencecm'		; 
#	$srvcobjects_ref->{'vergencecm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vergencecm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vergencecm'}{'port'}{'tcp'} = '2771'	; 
#	$srvcobjects_ref->{'vergencecm'}{'ports'}{'tcp'}{'2771'}++	; 
#	$ports_ref->{'tcp'}{'2771'}{'name'} = 'vergencecm'		; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'port'}{'udp'} = '886'	; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'ports'}{'udp'}{'886'}++	; 
#	$ports_ref->{'udp'}{'886'}{'name'} = 'iclcnet-locate'		; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'port'}{'tcp'} = '886'	; 
#	$srvcobjects_ref->{'iclcnet-locate'}{'ports'}{'tcp'}{'886'}++	; 
#	$ports_ref->{'tcp'}{'886'}{'name'} = 'iclcnet-locate'		; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'port'}{'udp'} = '1084'	; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'ports'}{'udp'}{'1084'}++	; 
#	$ports_ref->{'udp'}{'1084'}{'name'} = 'ansoft-lm-2'		; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'port'}{'tcp'} = '1084'	; 
#	$srvcobjects_ref->{'ansoft-lm-2'}{'ports'}{'tcp'}{'1084'}++	; 
#	$ports_ref->{'tcp'}{'1084'}{'name'} = 'ansoft-lm-2'		; 
#	$srvcobjects_ref->{'agriserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'agriserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agriserver'}{'port'}{'udp'} = '3021'	; 
#	$srvcobjects_ref->{'agriserver'}{'ports'}{'udp'}{'3021'}++	; 
#	$ports_ref->{'udp'}{'3021'}{'name'} = 'agriserver'		; 
#	$srvcobjects_ref->{'agriserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'agriserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agriserver'}{'port'}{'tcp'} = '3021'	; 
#	$srvcobjects_ref->{'agriserver'}{'ports'}{'tcp'}{'3021'}++	; 
#	$ports_ref->{'tcp'}{'3021'}{'name'} = 'agriserver'		; 
#	$srvcobjects_ref->{'es-elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'es-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'es-elmd'}{'port'}{'udp'} = '1822'	; 
#	$srvcobjects_ref->{'es-elmd'}{'ports'}{'udp'}{'1822'}++	; 
#	$ports_ref->{'udp'}{'1822'}{'name'} = 'es-elmd'		; 
#	$srvcobjects_ref->{'es-elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'es-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'es-elmd'}{'port'}{'tcp'} = '1822'	; 
#	$srvcobjects_ref->{'es-elmd'}{'ports'}{'tcp'}{'1822'}++	; 
#	$ports_ref->{'tcp'}{'1822'}{'name'} = 'es-elmd'		; 
#	$srvcobjects_ref->{'sd-elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sd-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd-elmd'}{'port'}{'udp'} = '1681'	; 
#	$srvcobjects_ref->{'sd-elmd'}{'ports'}{'udp'}{'1681'}++	; 
#	$ports_ref->{'udp'}{'1681'}{'name'} = 'sd-elmd'		; 
#	$srvcobjects_ref->{'sd-elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sd-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd-elmd'}{'port'}{'tcp'} = '1681'	; 
#	$srvcobjects_ref->{'sd-elmd'}{'ports'}{'tcp'}{'1681'}++	; 
#	$ports_ref->{'tcp'}{'1681'}{'name'} = 'sd-elmd'		; 
#	$srvcobjects_ref->{'wsynch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wsynch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsynch'}{'port'}{'udp'} = '3111'	; 
#	$srvcobjects_ref->{'wsynch'}{'ports'}{'udp'}{'3111'}++	; 
#	$ports_ref->{'udp'}{'3111'}{'name'} = 'wsynch'		; 
#	$srvcobjects_ref->{'wsynch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wsynch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsynch'}{'port'}{'tcp'} = '3111'	; 
#	$srvcobjects_ref->{'wsynch'}{'ports'}{'tcp'}{'3111'}++	; 
#	$ports_ref->{'tcp'}{'3111'}{'name'} = 'wsynch'		; 
#	$srvcobjects_ref->{'myrtle'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'myrtle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'myrtle'}{'port'}{'udp'} = '1831'	; 
#	$srvcobjects_ref->{'myrtle'}{'ports'}{'udp'}{'1831'}++	; 
#	$ports_ref->{'udp'}{'1831'}{'name'} = 'myrtle'		; 
#	$srvcobjects_ref->{'myrtle'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'myrtle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'myrtle'}{'port'}{'tcp'} = '1831'	; 
#	$srvcobjects_ref->{'myrtle'}{'ports'}{'tcp'}{'1831'}++	; 
#	$ports_ref->{'tcp'}{'1831'}{'name'} = 'myrtle'		; 
#	$srvcobjects_ref->{'aairnet-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aairnet-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aairnet-2'}{'port'}{'udp'} = '3619'	; 
#	$srvcobjects_ref->{'aairnet-2'}{'ports'}{'udp'}{'3619'}++	; 
#	$ports_ref->{'udp'}{'3619'}{'name'} = 'aairnet-2'		; 
#	$srvcobjects_ref->{'aairnet-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aairnet-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aairnet-2'}{'port'}{'tcp'} = '3619'	; 
#	$srvcobjects_ref->{'aairnet-2'}{'ports'}{'tcp'}{'3619'}++	; 
#	$ports_ref->{'tcp'}{'3619'}{'name'} = 'aairnet-2'		; 
#	$srvcobjects_ref->{'willy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'willy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'willy'}{'port'}{'udp'} = '2518'	; 
#	$srvcobjects_ref->{'willy'}{'ports'}{'udp'}{'2518'}++	; 
#	$ports_ref->{'udp'}{'2518'}{'name'} = 'willy'		; 
#	$srvcobjects_ref->{'willy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'willy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'willy'}{'port'}{'tcp'} = '2518'	; 
#	$srvcobjects_ref->{'willy'}{'ports'}{'tcp'}{'2518'}++	; 
#	$ports_ref->{'tcp'}{'2518'}{'name'} = 'willy'		; 
#	$srvcobjects_ref->{'panja-icsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'panja-icsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panja-icsp'}{'port'}{'udp'} = '1319'	; 
#	$srvcobjects_ref->{'panja-icsp'}{'ports'}{'udp'}{'1319'}++	; 
#	$ports_ref->{'udp'}{'1319'}{'name'} = 'panja-icsp'		; 
#	$srvcobjects_ref->{'panja-icsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'panja-icsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panja-icsp'}{'port'}{'tcp'} = '1319'	; 
#	$srvcobjects_ref->{'panja-icsp'}{'ports'}{'tcp'}{'1319'}++	; 
#	$ports_ref->{'tcp'}{'1319'}{'name'} = 'panja-icsp'		; 
#	$srvcobjects_ref->{'client-ctrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'client-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'client-ctrl'}{'port'}{'udp'} = '3730'	; 
#	$srvcobjects_ref->{'client-ctrl'}{'ports'}{'udp'}{'3730'}++	; 
#	$ports_ref->{'udp'}{'3730'}{'name'} = 'client-ctrl'		; 
#	$srvcobjects_ref->{'client-ctrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'client-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'client-ctrl'}{'port'}{'tcp'} = '3730'	; 
#	$srvcobjects_ref->{'client-ctrl'}{'ports'}{'tcp'}{'3730'}++	; 
#	$ports_ref->{'tcp'}{'3730'}{'name'} = 'client-ctrl'		; 
#	$srvcobjects_ref->{'syscomlan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'syscomlan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syscomlan'}{'port'}{'udp'} = '1065'	; 
#	$srvcobjects_ref->{'syscomlan'}{'ports'}{'udp'}{'1065'}++	; 
#	$ports_ref->{'udp'}{'1065'}{'name'} = 'syscomlan'		; 
#	$srvcobjects_ref->{'syscomlan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'syscomlan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'syscomlan'}{'port'}{'tcp'} = '1065'	; 
#	$srvcobjects_ref->{'syscomlan'}{'ports'}{'tcp'}{'1065'}++	; 
#	$ports_ref->{'tcp'}{'1065'}{'name'} = 'syscomlan'		; 
#	$srvcobjects_ref->{'pvuniwien'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pvuniwien'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pvuniwien'}{'port'}{'udp'} = '1081'	; 
#	$srvcobjects_ref->{'pvuniwien'}{'ports'}{'udp'}{'1081'}++	; 
#	$ports_ref->{'udp'}{'1081'}{'name'} = 'pvuniwien'		; 
#	$srvcobjects_ref->{'pvuniwien'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pvuniwien'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pvuniwien'}{'port'}{'tcp'} = '1081'	; 
#	$srvcobjects_ref->{'pvuniwien'}{'ports'}{'tcp'}{'1081'}++	; 
#	$ports_ref->{'tcp'}{'1081'}{'name'} = 'pvuniwien'		; 
#	$srvcobjects_ref->{'vsat-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsat-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsat-control'}{'port'}{'udp'} = '1880'	; 
#	$srvcobjects_ref->{'vsat-control'}{'ports'}{'udp'}{'1880'}++	; 
#	$ports_ref->{'udp'}{'1880'}{'name'} = 'vsat-control'		; 
#	$srvcobjects_ref->{'vsat-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsat-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsat-control'}{'port'}{'tcp'} = '1880'	; 
#	$srvcobjects_ref->{'vsat-control'}{'ports'}{'tcp'}{'1880'}++	; 
#	$ports_ref->{'tcp'}{'1880'}{'name'} = 'vsat-control'		; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'port'}{'udp'} = '1980'	; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'ports'}{'udp'}{'1980'}++	; 
#	$ports_ref->{'udp'}{'1980'}{'name'} = 'pearldoc-xact'		; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'port'}{'tcp'} = '1980'	; 
#	$srvcobjects_ref->{'pearldoc-xact'}{'ports'}{'tcp'}{'1980'}++	; 
#	$ports_ref->{'tcp'}{'1980'}{'name'} = 'pearldoc-xact'		; 
#	$srvcobjects_ref->{'bhfhs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bhfhs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhfhs'}{'port'}{'udp'} = '248'	; 
#	$srvcobjects_ref->{'bhfhs'}{'ports'}{'udp'}{'248'}++	; 
#	$ports_ref->{'udp'}{'248'}{'name'} = 'bhfhs'		; 
#	$srvcobjects_ref->{'bhfhs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bhfhs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhfhs'}{'port'}{'tcp'} = '248'	; 
#	$srvcobjects_ref->{'bhfhs'}{'ports'}{'tcp'}{'248'}++	; 
#	$ports_ref->{'tcp'}{'248'}{'name'} = 'bhfhs'		; 
#	$srvcobjects_ref->{'xyplex-mux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xyplex-mux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xyplex-mux'}{'port'}{'udp'} = '173'	; 
#	$srvcobjects_ref->{'xyplex-mux'}{'ports'}{'udp'}{'173'}++	; 
#	$ports_ref->{'udp'}{'173'}{'name'} = 'xyplex-mux'		; 
#	$srvcobjects_ref->{'xyplex-mux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xyplex-mux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xyplex-mux'}{'port'}{'tcp'} = '173'	; 
#	$srvcobjects_ref->{'xyplex-mux'}{'ports'}{'tcp'}{'173'}++	; 
#	$ports_ref->{'tcp'}{'173'}{'name'} = 'xyplex-mux'		; 
#	$srvcobjects_ref->{'partimage'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'partimage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'partimage'}{'port'}{'udp'} = '4025'	; 
#	$srvcobjects_ref->{'partimage'}{'ports'}{'udp'}{'4025'}++	; 
#	$ports_ref->{'udp'}{'4025'}{'name'} = 'partimage'		; 
#	$srvcobjects_ref->{'partimage'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'partimage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'partimage'}{'port'}{'tcp'} = '4025'	; 
#	$srvcobjects_ref->{'partimage'}{'ports'}{'tcp'}{'4025'}++	; 
#	$ports_ref->{'tcp'}{'4025'}{'name'} = 'partimage'		; 
#	$srvcobjects_ref->{'splitlock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'splitlock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'splitlock'}{'port'}{'udp'} = '3606'	; 
#	$srvcobjects_ref->{'splitlock'}{'ports'}{'udp'}{'3606'}++	; 
#	$ports_ref->{'udp'}{'3606'}{'name'} = 'splitlock'		; 
#	$srvcobjects_ref->{'splitlock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'splitlock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'splitlock'}{'port'}{'tcp'} = '3606'	; 
#	$srvcobjects_ref->{'splitlock'}{'ports'}{'tcp'}{'3606'}++	; 
#	$ports_ref->{'tcp'}{'3606'}{'name'} = 'splitlock'		; 
#	$srvcobjects_ref->{'netbill-auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbill-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-auth'}{'port'}{'udp'} = '1615'	; 
#	$srvcobjects_ref->{'netbill-auth'}{'ports'}{'udp'}{'1615'}++	; 
#	$ports_ref->{'udp'}{'1615'}{'name'} = 'netbill-auth'		; 
#	$srvcobjects_ref->{'netbill-auth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbill-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-auth'}{'port'}{'tcp'} = '1615'	; 
#	$srvcobjects_ref->{'netbill-auth'}{'ports'}{'tcp'}{'1615'}++	; 
#	$ports_ref->{'tcp'}{'1615'}{'name'} = 'netbill-auth'		; 
#	$srvcobjects_ref->{'cosmocall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cosmocall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cosmocall'}{'port'}{'udp'} = '2324'	; 
#	$srvcobjects_ref->{'cosmocall'}{'ports'}{'udp'}{'2324'}++	; 
#	$ports_ref->{'udp'}{'2324'}{'name'} = 'cosmocall'		; 
#	$srvcobjects_ref->{'cosmocall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cosmocall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cosmocall'}{'port'}{'tcp'} = '2324'	; 
#	$srvcobjects_ref->{'cosmocall'}{'ports'}{'tcp'}{'2324'}++	; 
#	$ports_ref->{'tcp'}{'2324'}{'name'} = 'cosmocall'		; 
#	$srvcobjects_ref->{'semantix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'semantix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'semantix'}{'port'}{'udp'} = '361'	; 
#	$srvcobjects_ref->{'semantix'}{'ports'}{'udp'}{'361'}++	; 
#	$ports_ref->{'udp'}{'361'}{'name'} = 'semantix'		; 
#	$srvcobjects_ref->{'semantix'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'semantix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'semantix'}{'port'}{'tcp'} = '361'	; 
#	$srvcobjects_ref->{'semantix'}{'ports'}{'tcp'}{'361'}++	; 
#	$ports_ref->{'tcp'}{'361'}{'name'} = 'semantix'		; 
#	$srvcobjects_ref->{'parsec-game'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'parsec-game'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parsec-game'}{'port'}{'udp'} = '6582'	; 
#	$srvcobjects_ref->{'parsec-game'}{'ports'}{'udp'}{'6582'}++	; 
#	$ports_ref->{'udp'}{'6582'}{'name'} = 'parsec-game'		; 
#	$srvcobjects_ref->{'parsec-game'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'parsec-game'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parsec-game'}{'port'}{'tcp'} = '6582'	; 
#	$srvcobjects_ref->{'parsec-game'}{'ports'}{'tcp'}{'6582'}++	; 
#	$ports_ref->{'tcp'}{'6582'}{'name'} = 'parsec-game'		; 
#	$srvcobjects_ref->{'deskview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'deskview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'deskview'}{'port'}{'udp'} = '3298'	; 
#	$srvcobjects_ref->{'deskview'}{'ports'}{'udp'}{'3298'}++	; 
#	$ports_ref->{'udp'}{'3298'}{'name'} = 'deskview'		; 
#	$srvcobjects_ref->{'deskview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'deskview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'deskview'}{'port'}{'tcp'} = '3298'	; 
#	$srvcobjects_ref->{'deskview'}{'ports'}{'tcp'}{'3298'}++	; 
#	$ports_ref->{'tcp'}{'3298'}{'name'} = 'deskview'		; 
#	$srvcobjects_ref->{'winddlb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'winddlb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winddlb'}{'port'}{'udp'} = '1565'	; 
#	$srvcobjects_ref->{'winddlb'}{'ports'}{'udp'}{'1565'}++	; 
#	$ports_ref->{'udp'}{'1565'}{'name'} = 'winddlb'		; 
#	$srvcobjects_ref->{'winddlb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'winddlb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winddlb'}{'port'}{'tcp'} = '1565'	; 
#	$srvcobjects_ref->{'winddlb'}{'ports'}{'tcp'}{'1565'}++	; 
#	$ports_ref->{'tcp'}{'1565'}{'name'} = 'winddlb'		; 
#	$srvcobjects_ref->{'tvpm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tvpm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tvpm'}{'port'}{'udp'} = '21800'	; 
#	$srvcobjects_ref->{'tvpm'}{'ports'}{'udp'}{'21800'}++	; 
#	$ports_ref->{'udp'}{'21800'}{'name'} = 'tvpm'		; 
#	$srvcobjects_ref->{'tvpm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tvpm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tvpm'}{'port'}{'tcp'} = '21800'	; 
#	$srvcobjects_ref->{'tvpm'}{'ports'}{'tcp'}{'21800'}++	; 
#	$ports_ref->{'tcp'}{'21800'}{'name'} = 'tvpm'		; 
#	$srvcobjects_ref->{'servserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'servserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servserv'}{'port'}{'udp'} = '2011'	; 
#	$srvcobjects_ref->{'servserv'}{'ports'}{'udp'}{'2011'}++	; 
#	$ports_ref->{'udp'}{'2011'}{'name'} = 'servserv'		; 
#	$srvcobjects_ref->{'lam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lam'}{'port'}{'udp'} = '2040'	; 
#	$srvcobjects_ref->{'lam'}{'ports'}{'udp'}{'2040'}++	; 
#	$ports_ref->{'udp'}{'2040'}{'name'} = 'lam'		; 
#	$srvcobjects_ref->{'lam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lam'}{'port'}{'tcp'} = '2040'	; 
#	$srvcobjects_ref->{'lam'}{'ports'}{'tcp'}{'2040'}++	; 
#	$ports_ref->{'tcp'}{'2040'}{'name'} = 'lam'		; 
#	$srvcobjects_ref->{'innosys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'innosys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'innosys'}{'port'}{'udp'} = '1412'	; 
#	$srvcobjects_ref->{'innosys'}{'ports'}{'udp'}{'1412'}++	; 
#	$ports_ref->{'udp'}{'1412'}{'name'} = 'innosys'		; 
#	$srvcobjects_ref->{'innosys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'innosys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'innosys'}{'port'}{'tcp'} = '1412'	; 
#	$srvcobjects_ref->{'innosys'}{'ports'}{'tcp'}{'1412'}++	; 
#	$ports_ref->{'tcp'}{'1412'}{'name'} = 'innosys'		; 
#	$srvcobjects_ref->{'loaprobe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'loaprobe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'loaprobe'}{'port'}{'udp'} = '1634'	; 
#	$srvcobjects_ref->{'loaprobe'}{'ports'}{'udp'}{'1634'}++	; 
#	$ports_ref->{'udp'}{'1634'}{'name'} = 'loaprobe'		; 
#	$srvcobjects_ref->{'loaprobe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'loaprobe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'loaprobe'}{'port'}{'tcp'} = '1634'	; 
#	$srvcobjects_ref->{'loaprobe'}{'ports'}{'tcp'}{'1634'}++	; 
#	$ports_ref->{'tcp'}{'1634'}{'name'} = 'loaprobe'		; 
#	$srvcobjects_ref->{'login'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'login'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'login'}{'port'}{'tcp'} = '513'	; 
#	$srvcobjects_ref->{'login'}{'ports'}{'tcp'}{'513'}++	; 
#	$ports_ref->{'tcp'}{'513'}{'name'} = 'login'		; 
#	$srvcobjects_ref->{'magaya-network'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'magaya-network'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magaya-network'}{'port'}{'udp'} = '3691'	; 
#	$srvcobjects_ref->{'magaya-network'}{'ports'}{'udp'}{'3691'}++	; 
#	$ports_ref->{'udp'}{'3691'}{'name'} = 'magaya-network'		; 
#	$srvcobjects_ref->{'magaya-network'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'magaya-network'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magaya-network'}{'port'}{'tcp'} = '3691'	; 
#	$srvcobjects_ref->{'magaya-network'}{'ports'}{'tcp'}{'3691'}++	; 
#	$ports_ref->{'tcp'}{'3691'}{'name'} = 'magaya-network'		; 
#	$srvcobjects_ref->{'rmonitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmonitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmonitor'}{'port'}{'udp'} = '560'	; 
#	$srvcobjects_ref->{'rmonitor'}{'ports'}{'udp'}{'560'}++	; 
#	$ports_ref->{'udp'}{'560'}{'name'} = 'rmonitor'		; 
#	$srvcobjects_ref->{'rmonitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmonitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmonitor'}{'port'}{'tcp'} = '560'	; 
#	$srvcobjects_ref->{'rmonitor'}{'ports'}{'tcp'}{'560'}++	; 
#	$ports_ref->{'tcp'}{'560'}{'name'} = 'rmonitor'		; 
#	$srvcobjects_ref->{'screencast'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'screencast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'screencast'}{'port'}{'udp'} = '1368'	; 
#	$srvcobjects_ref->{'screencast'}{'ports'}{'udp'}{'1368'}++	; 
#	$ports_ref->{'udp'}{'1368'}{'name'} = 'screencast'		; 
#	$srvcobjects_ref->{'screencast'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'screencast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'screencast'}{'port'}{'tcp'} = '1368'	; 
#	$srvcobjects_ref->{'screencast'}{'ports'}{'tcp'}{'1368'}++	; 
#	$ports_ref->{'tcp'}{'1368'}{'name'} = 'screencast'		; 
#	$srvcobjects_ref->{'panja-axbnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'panja-axbnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panja-axbnet'}{'port'}{'udp'} = '1320'	; 
#	$srvcobjects_ref->{'panja-axbnet'}{'ports'}{'udp'}{'1320'}++	; 
#	$ports_ref->{'udp'}{'1320'}{'name'} = 'panja-axbnet'		; 
#	$srvcobjects_ref->{'panja-axbnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'panja-axbnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panja-axbnet'}{'port'}{'tcp'} = '1320'	; 
#	$srvcobjects_ref->{'panja-axbnet'}{'ports'}{'tcp'}{'1320'}++	; 
#	$ports_ref->{'tcp'}{'1320'}{'name'} = 'panja-axbnet'		; 
#	$srvcobjects_ref->{'cyborg-systems'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cyborg-systems'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cyborg-systems'}{'port'}{'udp'} = '9888'	; 
#	$srvcobjects_ref->{'cyborg-systems'}{'ports'}{'udp'}{'9888'}++	; 
#	$ports_ref->{'udp'}{'9888'}{'name'} = 'cyborg-systems'		; 
#	$srvcobjects_ref->{'cyborg-systems'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cyborg-systems'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cyborg-systems'}{'port'}{'tcp'} = '9888'	; 
#	$srvcobjects_ref->{'cyborg-systems'}{'ports'}{'tcp'}{'9888'}++	; 
#	$ports_ref->{'tcp'}{'9888'}{'name'} = 'cyborg-systems'		; 
#	$srvcobjects_ref->{'appserv-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appserv-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appserv-http'}{'port'}{'udp'} = '4848'	; 
#	$srvcobjects_ref->{'appserv-http'}{'ports'}{'udp'}{'4848'}++	; 
#	$ports_ref->{'udp'}{'4848'}{'name'} = 'appserv-http'		; 
#	$srvcobjects_ref->{'appserv-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appserv-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appserv-http'}{'port'}{'tcp'} = '4848'	; 
#	$srvcobjects_ref->{'appserv-http'}{'ports'}{'tcp'}{'4848'}++	; 
#	$ports_ref->{'tcp'}{'4848'}{'name'} = 'appserv-http'		; 
#	$srvcobjects_ref->{'hks-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hks-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hks-lm'}{'port'}{'udp'} = '1722'	; 
#	$srvcobjects_ref->{'hks-lm'}{'ports'}{'udp'}{'1722'}++	; 
#	$ports_ref->{'udp'}{'1722'}{'name'} = 'hks-lm'		; 
#	$srvcobjects_ref->{'hks-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hks-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hks-lm'}{'port'}{'tcp'} = '1722'	; 
#	$srvcobjects_ref->{'hks-lm'}{'ports'}{'tcp'}{'1722'}++	; 
#	$ports_ref->{'tcp'}{'1722'}{'name'} = 'hks-lm'		; 
#	$srvcobjects_ref->{'xss-srv-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xss-srv-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xss-srv-port'}{'port'}{'udp'} = '3646'	; 
#	$srvcobjects_ref->{'xss-srv-port'}{'ports'}{'udp'}{'3646'}++	; 
#	$ports_ref->{'udp'}{'3646'}{'name'} = 'xss-srv-port'		; 
#	$srvcobjects_ref->{'xss-srv-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xss-srv-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xss-srv-port'}{'port'}{'tcp'} = '3646'	; 
#	$srvcobjects_ref->{'xss-srv-port'}{'ports'}{'tcp'}{'3646'}++	; 
#	$ports_ref->{'tcp'}{'3646'}{'name'} = 'xss-srv-port'		; 
#	$srvcobjects_ref->{'avocent-proxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avocent-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avocent-proxy'}{'port'}{'udp'} = '1078'	; 
#	$srvcobjects_ref->{'avocent-proxy'}{'ports'}{'udp'}{'1078'}++	; 
#	$ports_ref->{'udp'}{'1078'}{'name'} = 'avocent-proxy'		; 
#	$srvcobjects_ref->{'avocent-proxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avocent-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avocent-proxy'}{'port'}{'tcp'} = '1078'	; 
#	$srvcobjects_ref->{'avocent-proxy'}{'ports'}{'tcp'}{'1078'}++	; 
#	$ports_ref->{'tcp'}{'1078'}{'name'} = 'avocent-proxy'		; 
#	$srvcobjects_ref->{'e-mdu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'e-mdu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e-mdu'}{'port'}{'udp'} = '3727'	; 
#	$srvcobjects_ref->{'e-mdu'}{'ports'}{'udp'}{'3727'}++	; 
#	$ports_ref->{'udp'}{'3727'}{'name'} = 'e-mdu'		; 
#	$srvcobjects_ref->{'e-mdu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'e-mdu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e-mdu'}{'port'}{'tcp'} = '3727'	; 
#	$srvcobjects_ref->{'e-mdu'}{'ports'}{'tcp'}{'3727'}++	; 
#	$ports_ref->{'tcp'}{'3727'}{'name'} = 'e-mdu'		; 
#	$srvcobjects_ref->{'rapido-ip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rapido-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapido-ip'}{'port'}{'udp'} = '2457'	; 
#	$srvcobjects_ref->{'rapido-ip'}{'ports'}{'udp'}{'2457'}++	; 
#	$ports_ref->{'udp'}{'2457'}{'name'} = 'rapido-ip'		; 
#	$srvcobjects_ref->{'rapido-ip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rapido-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapido-ip'}{'port'}{'tcp'} = '2457'	; 
#	$srvcobjects_ref->{'rapido-ip'}{'ports'}{'tcp'}{'2457'}++	; 
#	$ports_ref->{'tcp'}{'2457'}{'name'} = 'rapido-ip'		; 
#	$srvcobjects_ref->{'insitu-conf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'insitu-conf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'insitu-conf'}{'port'}{'udp'} = '1490'	; 
#	$srvcobjects_ref->{'insitu-conf'}{'ports'}{'udp'}{'1490'}++	; 
#	$ports_ref->{'udp'}{'1490'}{'name'} = 'insitu-conf'		; 
#	$srvcobjects_ref->{'insitu-conf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'insitu-conf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'insitu-conf'}{'port'}{'tcp'} = '1490'	; 
#	$srvcobjects_ref->{'insitu-conf'}{'ports'}{'tcp'}{'1490'}++	; 
#	$ports_ref->{'tcp'}{'1490'}{'name'} = 'insitu-conf'		; 
#	$srvcobjects_ref->{'timbuktu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timbuktu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu'}{'port'}{'udp'} = '407'	; 
#	$srvcobjects_ref->{'timbuktu'}{'ports'}{'udp'}{'407'}++	; 
#	$ports_ref->{'udp'}{'407'}{'name'} = 'timbuktu'		; 
#	$srvcobjects_ref->{'timbuktu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timbuktu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu'}{'port'}{'tcp'} = '407'	; 
#	$srvcobjects_ref->{'timbuktu'}{'ports'}{'tcp'}{'407'}++	; 
#	$ports_ref->{'tcp'}{'407'}{'name'} = 'timbuktu'		; 
#	$srvcobjects_ref->{'upnp-discovery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'upnp-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upnp-discovery'}{'port'}{'udp'} = '3702'	; 
#	$srvcobjects_ref->{'upnp-discovery'}{'ports'}{'udp'}{'3702'}++	; 
#	$ports_ref->{'udp'}{'3702'}{'name'} = 'upnp-discovery'		; 
#	$srvcobjects_ref->{'upnp-discovery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'upnp-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upnp-discovery'}{'port'}{'tcp'} = '3702'	; 
#	$srvcobjects_ref->{'upnp-discovery'}{'ports'}{'tcp'}{'3702'}++	; 
#	$ports_ref->{'tcp'}{'3702'}{'name'} = 'upnp-discovery'		; 
#	$srvcobjects_ref->{'netplay-port1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netplay-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netplay-port1'}{'port'}{'udp'} = '3640'	; 
#	$srvcobjects_ref->{'netplay-port1'}{'ports'}{'udp'}{'3640'}++	; 
#	$ports_ref->{'udp'}{'3640'}{'name'} = 'netplay-port1'		; 
#	$srvcobjects_ref->{'netplay-port1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netplay-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netplay-port1'}{'port'}{'tcp'} = '3640'	; 
#	$srvcobjects_ref->{'netplay-port1'}{'ports'}{'tcp'}{'3640'}++	; 
#	$ports_ref->{'tcp'}{'3640'}{'name'} = 'netplay-port1'		; 
#	$srvcobjects_ref->{'rrac'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrac'}{'port'}{'udp'} = '5678'	; 
#	$srvcobjects_ref->{'rrac'}{'ports'}{'udp'}{'5678'}++	; 
#	$ports_ref->{'udp'}{'5678'}{'name'} = 'rrac'		; 
#	$srvcobjects_ref->{'rrac'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrac'}{'port'}{'tcp'} = '5678'	; 
#	$srvcobjects_ref->{'rrac'}{'ports'}{'tcp'}{'5678'}++	; 
#	$ports_ref->{'tcp'}{'5678'}{'name'} = 'rrac'		; 
#	$srvcobjects_ref->{'topflow'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'topflow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'topflow'}{'port'}{'udp'} = '2885'	; 
#	$srvcobjects_ref->{'topflow'}{'ports'}{'udp'}{'2885'}++	; 
#	$ports_ref->{'udp'}{'2885'}{'name'} = 'topflow'		; 
#	$srvcobjects_ref->{'topflow'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'topflow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'topflow'}{'port'}{'tcp'} = '2885'	; 
#	$srvcobjects_ref->{'topflow'}{'ports'}{'tcp'}{'2885'}++	; 
#	$ports_ref->{'tcp'}{'2885'}{'name'} = 'topflow'		; 
#	$srvcobjects_ref->{'eristwoguns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eristwoguns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eristwoguns'}{'port'}{'udp'} = '2650'	; 
#	$srvcobjects_ref->{'eristwoguns'}{'ports'}{'udp'}{'2650'}++	; 
#	$ports_ref->{'udp'}{'2650'}{'name'} = 'eristwoguns'		; 
#	$srvcobjects_ref->{'eristwoguns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eristwoguns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eristwoguns'}{'port'}{'tcp'} = '2650'	; 
#	$srvcobjects_ref->{'eristwoguns'}{'ports'}{'tcp'}{'2650'}++	; 
#	$ports_ref->{'tcp'}{'2650'}{'name'} = 'eristwoguns'		; 
#	$srvcobjects_ref->{'ha-cluster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ha-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ha-cluster'}{'port'}{'udp'} = '694'	; 
#	$srvcobjects_ref->{'ha-cluster'}{'ports'}{'udp'}{'694'}++	; 
#	$ports_ref->{'udp'}{'694'}{'name'} = 'ha-cluster'		; 
#	$srvcobjects_ref->{'ha-cluster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ha-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ha-cluster'}{'port'}{'tcp'} = '694'	; 
#	$srvcobjects_ref->{'ha-cluster'}{'ports'}{'tcp'}{'694'}++	; 
#	$ports_ref->{'tcp'}{'694'}{'name'} = 'ha-cluster'		; 
#	$srvcobjects_ref->{'eims-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eims-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eims-admin'}{'port'}{'udp'} = '4199'	; 
#	$srvcobjects_ref->{'eims-admin'}{'ports'}{'udp'}{'4199'}++	; 
#	$ports_ref->{'udp'}{'4199'}{'name'} = 'eims-admin'		; 
#	$srvcobjects_ref->{'eims-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eims-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eims-admin'}{'port'}{'tcp'} = '4199'	; 
#	$srvcobjects_ref->{'eims-admin'}{'ports'}{'tcp'}{'4199'}++	; 
#	$ports_ref->{'tcp'}{'4199'}{'name'} = 'eims-admin'		; 
#	$srvcobjects_ref->{'rnmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rnmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rnmap'}{'port'}{'udp'} = '3418'	; 
#	$srvcobjects_ref->{'rnmap'}{'ports'}{'udp'}{'3418'}++	; 
#	$ports_ref->{'udp'}{'3418'}{'name'} = 'rnmap'		; 
#	$srvcobjects_ref->{'rnmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rnmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rnmap'}{'port'}{'tcp'} = '3418'	; 
#	$srvcobjects_ref->{'rnmap'}{'ports'}{'tcp'}{'3418'}++	; 
#	$ports_ref->{'tcp'}{'3418'}{'name'} = 'rnmap'		; 
#	$srvcobjects_ref->{'newton-dock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newton-dock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newton-dock'}{'port'}{'udp'} = '3679'	; 
#	$srvcobjects_ref->{'newton-dock'}{'ports'}{'udp'}{'3679'}++	; 
#	$ports_ref->{'udp'}{'3679'}{'name'} = 'newton-dock'		; 
#	$srvcobjects_ref->{'newton-dock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newton-dock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newton-dock'}{'port'}{'tcp'} = '3679'	; 
#	$srvcobjects_ref->{'newton-dock'}{'ports'}{'tcp'}{'3679'}++	; 
#	$ports_ref->{'tcp'}{'3679'}{'name'} = 'newton-dock'		; 
#	$srvcobjects_ref->{'qadmifevent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qadmifevent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qadmifevent'}{'port'}{'udp'} = '2462'	; 
#	$srvcobjects_ref->{'qadmifevent'}{'ports'}{'udp'}{'2462'}++	; 
#	$ports_ref->{'udp'}{'2462'}{'name'} = 'qadmifevent'		; 
#	$srvcobjects_ref->{'qadmifevent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qadmifevent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qadmifevent'}{'port'}{'tcp'} = '2462'	; 
#	$srvcobjects_ref->{'qadmifevent'}{'ports'}{'tcp'}{'2462'}++	; 
#	$ports_ref->{'tcp'}{'2462'}{'name'} = 'qadmifevent'		; 
#	$srvcobjects_ref->{'ulistproc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ulistproc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ulistproc'}{'port'}{'udp'} = '372'	; 
#	$srvcobjects_ref->{'ulistproc'}{'ports'}{'udp'}{'372'}++	; 
#	$ports_ref->{'udp'}{'372'}{'name'} = 'ulistproc'		; 
#	$srvcobjects_ref->{'ulistproc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ulistproc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ulistproc'}{'port'}{'tcp'} = '372'	; 
#	$srvcobjects_ref->{'ulistproc'}{'ports'}{'tcp'}{'372'}++	; 
#	$ports_ref->{'tcp'}{'372'}{'name'} = 'ulistproc'		; 
#	$srvcobjects_ref->{'obex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'obex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'obex'}{'port'}{'udp'} = '650'	; 
#	$srvcobjects_ref->{'obex'}{'ports'}{'udp'}{'650'}++	; 
#	$ports_ref->{'udp'}{'650'}{'name'} = 'obex'		; 
#	$srvcobjects_ref->{'obex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'obex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'obex'}{'port'}{'tcp'} = '650'	; 
#	$srvcobjects_ref->{'obex'}{'ports'}{'tcp'}{'650'}++	; 
#	$ports_ref->{'tcp'}{'650'}{'name'} = 'obex'		; 
#	$srvcobjects_ref->{'directv-catlg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directv-catlg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-catlg'}{'port'}{'udp'} = '3337'	; 
#	$srvcobjects_ref->{'directv-catlg'}{'ports'}{'udp'}{'3337'}++	; 
#	$ports_ref->{'udp'}{'3337'}{'name'} = 'directv-catlg'		; 
#	$srvcobjects_ref->{'directv-catlg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directv-catlg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-catlg'}{'port'}{'tcp'} = '3337'	; 
#	$srvcobjects_ref->{'directv-catlg'}{'ports'}{'tcp'}{'3337'}++	; 
#	$ports_ref->{'tcp'}{'3337'}{'name'} = 'directv-catlg'		; 
#	$srvcobjects_ref->{'eye2eye'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eye2eye'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eye2eye'}{'port'}{'udp'} = '1948'	; 
#	$srvcobjects_ref->{'eye2eye'}{'ports'}{'udp'}{'1948'}++	; 
#	$ports_ref->{'udp'}{'1948'}{'name'} = 'eye2eye'		; 
#	$srvcobjects_ref->{'eye2eye'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eye2eye'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eye2eye'}{'port'}{'tcp'} = '1948'	; 
#	$srvcobjects_ref->{'eye2eye'}{'ports'}{'tcp'}{'1948'}++	; 
#	$ports_ref->{'tcp'}{'1948'}{'name'} = 'eye2eye'		; 
#	$srvcobjects_ref->{'apparenet-ui'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apparenet-ui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-ui'}{'port'}{'udp'} = '3239'	; 
#	$srvcobjects_ref->{'apparenet-ui'}{'ports'}{'udp'}{'3239'}++	; 
#	$ports_ref->{'udp'}{'3239'}{'name'} = 'apparenet-ui'		; 
#	$srvcobjects_ref->{'apparenet-ui'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apparenet-ui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-ui'}{'port'}{'tcp'} = '3239'	; 
#	$srvcobjects_ref->{'apparenet-ui'}{'ports'}{'tcp'}{'3239'}++	; 
#	$ports_ref->{'tcp'}{'3239'}{'name'} = 'apparenet-ui'		; 
#	$srvcobjects_ref->{'interserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interserver'}{'port'}{'udp'} = '3060'	; 
#	$srvcobjects_ref->{'interserver'}{'ports'}{'udp'}{'3060'}++	; 
#	$ports_ref->{'udp'}{'3060'}{'name'} = 'interserver'		; 
#	$srvcobjects_ref->{'interserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interserver'}{'port'}{'tcp'} = '3060'	; 
#	$srvcobjects_ref->{'interserver'}{'ports'}{'tcp'}{'3060'}++	; 
#	$ports_ref->{'tcp'}{'3060'}{'name'} = 'interserver'		; 
#	$srvcobjects_ref->{'netcheque'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netcheque'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcheque'}{'port'}{'udp'} = '4008'	; 
#	$srvcobjects_ref->{'netcheque'}{'ports'}{'udp'}{'4008'}++	; 
#	$ports_ref->{'udp'}{'4008'}{'name'} = 'netcheque'		; 
#	$srvcobjects_ref->{'netcheque'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netcheque'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcheque'}{'port'}{'tcp'} = '4008'	; 
#	$srvcobjects_ref->{'netcheque'}{'ports'}{'tcp'}{'4008'}++	; 
#	$ports_ref->{'tcp'}{'4008'}{'name'} = 'netcheque'		; 
#	$srvcobjects_ref->{'liberty-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'liberty-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'liberty-lm'}{'port'}{'udp'} = '1496'	; 
#	$srvcobjects_ref->{'liberty-lm'}{'ports'}{'udp'}{'1496'}++	; 
#	$ports_ref->{'udp'}{'1496'}{'name'} = 'liberty-lm'		; 
#	$srvcobjects_ref->{'liberty-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'liberty-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'liberty-lm'}{'port'}{'tcp'} = '1496'	; 
#	$srvcobjects_ref->{'liberty-lm'}{'ports'}{'tcp'}{'1496'}++	; 
#	$ports_ref->{'tcp'}{'1496'}{'name'} = 'liberty-lm'		; 
#	$srvcobjects_ref->{'cr-websystems'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cr-websystems'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cr-websystems'}{'port'}{'udp'} = '2314'	; 
#	$srvcobjects_ref->{'cr-websystems'}{'ports'}{'udp'}{'2314'}++	; 
#	$ports_ref->{'udp'}{'2314'}{'name'} = 'cr-websystems'		; 
#	$srvcobjects_ref->{'cr-websystems'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cr-websystems'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cr-websystems'}{'port'}{'tcp'} = '2314'	; 
#	$srvcobjects_ref->{'cr-websystems'}{'ports'}{'tcp'}{'2314'}++	; 
#	$ports_ref->{'tcp'}{'2314'}{'name'} = 'cr-websystems'		; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'port'}{'udp'} = '18241'	; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'ports'}{'udp'}{'18241'}++	; 
#	$ports_ref->{'udp'}{'18241'}{'name'} = 'checkpoint-rtm'		; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'port'}{'tcp'} = '18241'	; 
#	$srvcobjects_ref->{'checkpoint-rtm'}{'ports'}{'tcp'}{'18241'}++	; 
#	$ports_ref->{'tcp'}{'18241'}{'name'} = 'checkpoint-rtm'		; 
#	$srvcobjects_ref->{'cvsup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cvsup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvsup'}{'port'}{'udp'} = '5999'	; 
#	$srvcobjects_ref->{'cvsup'}{'ports'}{'udp'}{'5999'}++	; 
#	$ports_ref->{'udp'}{'5999'}{'name'} = 'cvsup'		; 
#	$srvcobjects_ref->{'cvsup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cvsup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvsup'}{'port'}{'tcp'} = '5999'	; 
#	$srvcobjects_ref->{'cvsup'}{'ports'}{'tcp'}{'5999'}++	; 
#	$ports_ref->{'tcp'}{'5999'}{'name'} = 'cvsup'		; 
#	$srvcobjects_ref->{'sstsys-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sstsys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sstsys-lm'}{'port'}{'udp'} = '1692'	; 
#	$srvcobjects_ref->{'sstsys-lm'}{'ports'}{'udp'}{'1692'}++	; 
#	$ports_ref->{'udp'}{'1692'}{'name'} = 'sstsys-lm'		; 
#	$srvcobjects_ref->{'sstsys-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sstsys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sstsys-lm'}{'port'}{'tcp'} = '1692'	; 
#	$srvcobjects_ref->{'sstsys-lm'}{'ports'}{'tcp'}{'1692'}++	; 
#	$ports_ref->{'tcp'}{'1692'}{'name'} = 'sstsys-lm'		; 
#	$srvcobjects_ref->{'xfer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xfer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xfer'}{'port'}{'udp'} = '82'	; 
#	$srvcobjects_ref->{'xfer'}{'ports'}{'udp'}{'82'}++	; 
#	$ports_ref->{'udp'}{'82'}{'name'} = 'xfer'		; 
#	$srvcobjects_ref->{'xfer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xfer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xfer'}{'port'}{'tcp'} = '82'	; 
#	$srvcobjects_ref->{'xfer'}{'ports'}{'tcp'}{'82'}++	; 
#	$ports_ref->{'tcp'}{'82'}{'name'} = 'xfer'		; 
#	$srvcobjects_ref->{'palace-6'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'palace-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-6'}{'port'}{'udp'} = '9997'	; 
#	$srvcobjects_ref->{'palace-6'}{'ports'}{'udp'}{'9997'}++	; 
#	$ports_ref->{'udp'}{'9997'}{'name'} = 'palace-6'		; 
#	$srvcobjects_ref->{'palace-6'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'palace-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-6'}{'port'}{'tcp'} = '9997'	; 
#	$srvcobjects_ref->{'palace-6'}{'ports'}{'tcp'}{'9997'}++	; 
#	$ports_ref->{'tcp'}{'9997'}{'name'} = 'palace-6'		; 
#	$srvcobjects_ref->{'omnisky'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'omnisky'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'omnisky'}{'port'}{'udp'} = '2056'	; 
#	$srvcobjects_ref->{'omnisky'}{'ports'}{'udp'}{'2056'}++	; 
#	$ports_ref->{'udp'}{'2056'}{'name'} = 'omnisky'		; 
#	$srvcobjects_ref->{'omnisky'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'omnisky'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'omnisky'}{'port'}{'tcp'} = '2056'	; 
#	$srvcobjects_ref->{'omnisky'}{'ports'}{'tcp'}{'2056'}++	; 
#	$ports_ref->{'tcp'}{'2056'}{'name'} = 'omnisky'		; 
#	$srvcobjects_ref->{'entextlow'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entextlow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextlow'}{'port'}{'udp'} = '12004'	; 
#	$srvcobjects_ref->{'entextlow'}{'ports'}{'udp'}{'12004'}++	; 
#	$ports_ref->{'udp'}{'12004'}{'name'} = 'entextlow'		; 
#	$srvcobjects_ref->{'entextlow'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entextlow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextlow'}{'port'}{'tcp'} = '12004'	; 
#	$srvcobjects_ref->{'entextlow'}{'ports'}{'tcp'}{'12004'}++	; 
#	$ports_ref->{'tcp'}{'12004'}{'name'} = 'entextlow'		; 
#	$srvcobjects_ref->{'cft-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-3'}{'port'}{'udp'} = '1764'	; 
#	$srvcobjects_ref->{'cft-3'}{'ports'}{'udp'}{'1764'}++	; 
#	$ports_ref->{'udp'}{'1764'}{'name'} = 'cft-3'		; 
#	$srvcobjects_ref->{'cft-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-3'}{'port'}{'tcp'} = '1764'	; 
#	$srvcobjects_ref->{'cft-3'}{'ports'}{'tcp'}{'1764'}++	; 
#	$ports_ref->{'tcp'}{'1764'}{'name'} = 'cft-3'		; 
#	$srvcobjects_ref->{'global-wlink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'global-wlink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'global-wlink'}{'port'}{'udp'} = '1909'	; 
#	$srvcobjects_ref->{'global-wlink'}{'ports'}{'udp'}{'1909'}++	; 
#	$ports_ref->{'udp'}{'1909'}{'name'} = 'global-wlink'		; 
#	$srvcobjects_ref->{'global-wlink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'global-wlink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'global-wlink'}{'port'}{'tcp'} = '1909'	; 
#	$srvcobjects_ref->{'global-wlink'}{'ports'}{'tcp'}{'1909'}++	; 
#	$ports_ref->{'tcp'}{'1909'}{'name'} = 'global-wlink'		; 
#	$srvcobjects_ref->{'sns-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-gateway'}{'port'}{'udp'} = '5416'	; 
#	$srvcobjects_ref->{'sns-gateway'}{'ports'}{'udp'}{'5416'}++	; 
#	$ports_ref->{'udp'}{'5416'}{'name'} = 'sns-gateway'		; 
#	$srvcobjects_ref->{'sns-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-gateway'}{'port'}{'tcp'} = '5416'	; 
#	$srvcobjects_ref->{'sns-gateway'}{'ports'}{'tcp'}{'5416'}++	; 
#	$ports_ref->{'tcp'}{'5416'}{'name'} = 'sns-gateway'		; 
#	$srvcobjects_ref->{'tsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsp'}{'port'}{'udp'} = '3653'	; 
#	$srvcobjects_ref->{'tsp'}{'ports'}{'udp'}{'3653'}++	; 
#	$ports_ref->{'udp'}{'3653'}{'name'} = 'tsp'		; 
#	$srvcobjects_ref->{'tsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsp'}{'port'}{'tcp'} = '3653'	; 
#	$srvcobjects_ref->{'tsp'}{'ports'}{'tcp'}{'3653'}++	; 
#	$ports_ref->{'tcp'}{'3653'}{'name'} = 'tsp'		; 
#	$srvcobjects_ref->{'esinstall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esinstall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esinstall'}{'port'}{'udp'} = '5599'	; 
#	$srvcobjects_ref->{'esinstall'}{'ports'}{'udp'}{'5599'}++	; 
#	$ports_ref->{'udp'}{'5599'}{'name'} = 'esinstall'		; 
#	$srvcobjects_ref->{'esinstall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esinstall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esinstall'}{'port'}{'tcp'} = '5599'	; 
#	$srvcobjects_ref->{'esinstall'}{'ports'}{'tcp'}{'5599'}++	; 
#	$ports_ref->{'tcp'}{'5599'}{'name'} = 'esinstall'		; 
#	$srvcobjects_ref->{'itscomm-ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itscomm-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itscomm-ns'}{'port'}{'udp'} = '1573'	; 
#	$srvcobjects_ref->{'itscomm-ns'}{'ports'}{'udp'}{'1573'}++	; 
#	$ports_ref->{'udp'}{'1573'}{'name'} = 'itscomm-ns'		; 
#	$srvcobjects_ref->{'itscomm-ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itscomm-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itscomm-ns'}{'port'}{'tcp'} = '1573'	; 
#	$srvcobjects_ref->{'itscomm-ns'}{'ports'}{'tcp'}{'1573'}++	; 
#	$ports_ref->{'tcp'}{'1573'}{'name'} = 'itscomm-ns'		; 
#	$srvcobjects_ref->{'dtk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dtk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtk'}{'port'}{'udp'} = '365'	; 
#	$srvcobjects_ref->{'dtk'}{'ports'}{'udp'}{'365'}++	; 
#	$ports_ref->{'udp'}{'365'}{'name'} = 'dtk'		; 
#	$srvcobjects_ref->{'dtk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dtk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtk'}{'port'}{'tcp'} = '365'	; 
#	$srvcobjects_ref->{'dtk'}{'ports'}{'tcp'}{'365'}++	; 
#	$ports_ref->{'tcp'}{'365'}{'name'} = 'dtk'		; 
#	$srvcobjects_ref->{'cdc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cdc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdc'}{'port'}{'udp'} = '223'	; 
#	$srvcobjects_ref->{'cdc'}{'ports'}{'udp'}{'223'}++	; 
#	$ports_ref->{'udp'}{'223'}{'name'} = 'cdc'		; 
#	$srvcobjects_ref->{'cdc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cdc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdc'}{'port'}{'tcp'} = '223'	; 
#	$srvcobjects_ref->{'cdc'}{'ports'}{'tcp'}{'223'}++	; 
#	$ports_ref->{'tcp'}{'223'}{'name'} = 'cdc'		; 
#	$srvcobjects_ref->{'jdmn-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jdmn-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jdmn-port'}{'port'}{'udp'} = '4030'	; 
#	$srvcobjects_ref->{'jdmn-port'}{'ports'}{'udp'}{'4030'}++	; 
#	$ports_ref->{'udp'}{'4030'}{'name'} = 'jdmn-port'		; 
#	$srvcobjects_ref->{'jdmn-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jdmn-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jdmn-port'}{'port'}{'tcp'} = '4030'	; 
#	$srvcobjects_ref->{'jdmn-port'}{'ports'}{'tcp'}{'4030'}++	; 
#	$ports_ref->{'tcp'}{'4030'}{'name'} = 'jdmn-port'		; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'port'}{'udp'} = '2223'	; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'ports'}{'udp'}{'2223'}++	; 
#	$ports_ref->{'udp'}{'2223'}{'name'} = 'rockwell-csp3'		; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'port'}{'tcp'} = '2223'	; 
#	$srvcobjects_ref->{'rockwell-csp3'}{'ports'}{'tcp'}{'2223'}++	; 
#	$ports_ref->{'tcp'}{'2223'}{'name'} = 'rockwell-csp3'		; 
#	$srvcobjects_ref->{'personal-link'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'personal-link'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personal-link'}{'port'}{'udp'} = '281'	; 
#	$srvcobjects_ref->{'personal-link'}{'ports'}{'udp'}{'281'}++	; 
#	$ports_ref->{'udp'}{'281'}{'name'} = 'personal-link'		; 
#	$srvcobjects_ref->{'personal-link'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'personal-link'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personal-link'}{'port'}{'tcp'} = '281'	; 
#	$srvcobjects_ref->{'personal-link'}{'ports'}{'tcp'}{'281'}++	; 
#	$ports_ref->{'tcp'}{'281'}{'name'} = 'personal-link'		; 
#	$srvcobjects_ref->{'sip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sip'}{'port'}{'udp'} = '5060'	; 
#	$srvcobjects_ref->{'sip'}{'ports'}{'udp'}{'5060'}++	; 
#	$ports_ref->{'udp'}{'5060'}{'name'} = 'sip'		; 
#	$srvcobjects_ref->{'sip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sip'}{'port'}{'tcp'} = '5060'	; 
#	$srvcobjects_ref->{'sip'}{'ports'}{'tcp'}{'5060'}++	; 
#	$ports_ref->{'tcp'}{'5060'}{'name'} = 'sip'		; 
#	$srvcobjects_ref->{'bgs-nsi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bgs-nsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bgs-nsi'}{'port'}{'udp'} = '482'	; 
#	$srvcobjects_ref->{'bgs-nsi'}{'ports'}{'udp'}{'482'}++	; 
#	$ports_ref->{'udp'}{'482'}{'name'} = 'bgs-nsi'		; 
#	$srvcobjects_ref->{'bgs-nsi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bgs-nsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bgs-nsi'}{'port'}{'tcp'} = '482'	; 
#	$srvcobjects_ref->{'bgs-nsi'}{'ports'}{'tcp'}{'482'}++	; 
#	$ports_ref->{'tcp'}{'482'}{'name'} = 'bgs-nsi'		; 
#	$srvcobjects_ref->{'dbsa-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbsa-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbsa-lm'}{'port'}{'udp'} = '1407'	; 
#	$srvcobjects_ref->{'dbsa-lm'}{'ports'}{'udp'}{'1407'}++	; 
#	$ports_ref->{'udp'}{'1407'}{'name'} = 'dbsa-lm'		; 
#	$srvcobjects_ref->{'dbsa-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbsa-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbsa-lm'}{'port'}{'tcp'} = '1407'	; 
#	$srvcobjects_ref->{'dbsa-lm'}{'ports'}{'tcp'}{'1407'}++	; 
#	$ports_ref->{'tcp'}{'1407'}{'name'} = 'dbsa-lm'		; 
#	$srvcobjects_ref->{'interwise'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interwise'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interwise'}{'port'}{'udp'} = '7778'	; 
#	$srvcobjects_ref->{'interwise'}{'ports'}{'udp'}{'7778'}++	; 
#	$ports_ref->{'udp'}{'7778'}{'name'} = 'interwise'		; 
#	$srvcobjects_ref->{'interwise'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interwise'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interwise'}{'port'}{'tcp'} = '7778'	; 
#	$srvcobjects_ref->{'interwise'}{'ports'}{'tcp'}{'7778'}++	; 
#	$ports_ref->{'tcp'}{'7778'}{'name'} = 'interwise'		; 
#	$srvcobjects_ref->{'badm_priv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'badm_priv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'badm_priv'}{'port'}{'udp'} = '6505'	; 
#	$srvcobjects_ref->{'badm_priv'}{'ports'}{'udp'}{'6505'}++	; 
#	$ports_ref->{'udp'}{'6505'}{'name'} = 'badm_priv'		; 
#	$srvcobjects_ref->{'badm_priv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'badm_priv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'badm_priv'}{'port'}{'tcp'} = '6505'	; 
#	$srvcobjects_ref->{'badm_priv'}{'ports'}{'tcp'}{'6505'}++	; 
#	$ports_ref->{'tcp'}{'6505'}{'name'} = 'badm_priv'		; 
#	$srvcobjects_ref->{'uarps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uarps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uarps'}{'port'}{'udp'} = '219'	; 
#	$srvcobjects_ref->{'uarps'}{'ports'}{'udp'}{'219'}++	; 
#	$ports_ref->{'udp'}{'219'}{'name'} = 'uarps'		; 
#	$srvcobjects_ref->{'uarps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uarps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uarps'}{'port'}{'tcp'} = '219'	; 
#	$srvcobjects_ref->{'uarps'}{'ports'}{'tcp'}{'219'}++	; 
#	$ports_ref->{'tcp'}{'219'}{'name'} = 'uarps'		; 
#	$srvcobjects_ref->{'arcisdms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arcisdms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arcisdms'}{'port'}{'udp'} = '262'	; 
#	$srvcobjects_ref->{'arcisdms'}{'ports'}{'udp'}{'262'}++	; 
#	$ports_ref->{'udp'}{'262'}{'name'} = 'arcisdms'		; 
#	$srvcobjects_ref->{'arcisdms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arcisdms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arcisdms'}{'port'}{'tcp'} = '262'	; 
#	$srvcobjects_ref->{'arcisdms'}{'ports'}{'tcp'}{'262'}++	; 
#	$ports_ref->{'tcp'}{'262'}{'name'} = 'arcisdms'		; 
#	$srvcobjects_ref->{'webmail-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webmail-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webmail-2'}{'port'}{'udp'} = '3511'	; 
#	$srvcobjects_ref->{'webmail-2'}{'ports'}{'udp'}{'3511'}++	; 
#	$ports_ref->{'udp'}{'3511'}{'name'} = 'webmail-2'		; 
#	$srvcobjects_ref->{'webmail-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webmail-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webmail-2'}{'port'}{'tcp'} = '3511'	; 
#	$srvcobjects_ref->{'webmail-2'}{'ports'}{'tcp'}{'3511'}++	; 
#	$ports_ref->{'tcp'}{'3511'}{'name'} = 'webmail-2'		; 
#	$srvcobjects_ref->{'rprt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rprt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rprt'}{'port'}{'udp'} = '3064'	; 
#	$srvcobjects_ref->{'rprt'}{'ports'}{'udp'}{'3064'}++	; 
#	$ports_ref->{'udp'}{'3064'}{'name'} = 'rprt'		; 
#	$srvcobjects_ref->{'rprt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rprt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rprt'}{'port'}{'tcp'} = '3064'	; 
#	$srvcobjects_ref->{'rprt'}{'ports'}{'tcp'}{'3064'}++	; 
#	$ports_ref->{'tcp'}{'3064'}{'name'} = 'rprt'		; 
#	$srvcobjects_ref->{'quartus-tcl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quartus-tcl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quartus-tcl'}{'port'}{'udp'} = '2589'	; 
#	$srvcobjects_ref->{'quartus-tcl'}{'ports'}{'udp'}{'2589'}++	; 
#	$ports_ref->{'udp'}{'2589'}{'name'} = 'quartus-tcl'		; 
#	$srvcobjects_ref->{'quartus-tcl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quartus-tcl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quartus-tcl'}{'port'}{'tcp'} = '2589'	; 
#	$srvcobjects_ref->{'quartus-tcl'}{'ports'}{'tcp'}{'2589'}++	; 
#	$ports_ref->{'tcp'}{'2589'}{'name'} = 'quartus-tcl'		; 
#	$srvcobjects_ref->{'bruce'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bruce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bruce'}{'port'}{'udp'} = '2619'	; 
#	$srvcobjects_ref->{'bruce'}{'ports'}{'udp'}{'2619'}++	; 
#	$ports_ref->{'udp'}{'2619'}{'name'} = 'bruce'		; 
#	$srvcobjects_ref->{'bruce'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bruce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bruce'}{'port'}{'tcp'} = '2619'	; 
#	$srvcobjects_ref->{'bruce'}{'ports'}{'tcp'}{'2619'}++	; 
#	$ports_ref->{'tcp'}{'2619'}{'name'} = 'bruce'		; 
#	$srvcobjects_ref->{'cleanerliverc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cleanerliverc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cleanerliverc'}{'port'}{'udp'} = '3481'	; 
#	$srvcobjects_ref->{'cleanerliverc'}{'ports'}{'udp'}{'3481'}++	; 
#	$ports_ref->{'udp'}{'3481'}{'name'} = 'cleanerliverc'		; 
#	$srvcobjects_ref->{'cleanerliverc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cleanerliverc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cleanerliverc'}{'port'}{'tcp'} = '3481'	; 
#	$srvcobjects_ref->{'cleanerliverc'}{'ports'}{'tcp'}{'3481'}++	; 
#	$ports_ref->{'tcp'}{'3481'}{'name'} = 'cleanerliverc'		; 
#	$srvcobjects_ref->{'pov-ray'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pov-ray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pov-ray'}{'port'}{'udp'} = '494'	; 
#	$srvcobjects_ref->{'pov-ray'}{'ports'}{'udp'}{'494'}++	; 
#	$ports_ref->{'udp'}{'494'}{'name'} = 'pov-ray'		; 
#	$srvcobjects_ref->{'pov-ray'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pov-ray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pov-ray'}{'port'}{'tcp'} = '494'	; 
#	$srvcobjects_ref->{'pov-ray'}{'ports'}{'tcp'}{'494'}++	; 
#	$ports_ref->{'tcp'}{'494'}{'name'} = 'pov-ray'		; 
#	$srvcobjects_ref->{'nnp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nnp'}{'port'}{'udp'} = '3780'	; 
#	$srvcobjects_ref->{'nnp'}{'ports'}{'udp'}{'3780'}++	; 
#	$ports_ref->{'udp'}{'3780'}{'name'} = 'nnp'		; 
#	$srvcobjects_ref->{'nnp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nnp'}{'port'}{'tcp'} = '3780'	; 
#	$srvcobjects_ref->{'nnp'}{'ports'}{'tcp'}{'3780'}++	; 
#	$ports_ref->{'tcp'}{'3780'}{'name'} = 'nnp'		; 
#	$srvcobjects_ref->{'pxc-pin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-pin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-pin'}{'port'}{'udp'} = '4005'	; 
#	$srvcobjects_ref->{'pxc-pin'}{'ports'}{'udp'}{'4005'}++	; 
#	$ports_ref->{'udp'}{'4005'}{'name'} = 'pxc-pin'		; 
#	$srvcobjects_ref->{'pxc-pin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-pin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-pin'}{'port'}{'tcp'} = '4005'	; 
#	$srvcobjects_ref->{'pxc-pin'}{'ports'}{'tcp'}{'4005'}++	; 
#	$ports_ref->{'tcp'}{'4005'}{'name'} = 'pxc-pin'		; 
#	$srvcobjects_ref->{'hacl-test'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-test'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-test'}{'port'}{'udp'} = '5305'	; 
#	$srvcobjects_ref->{'hacl-test'}{'ports'}{'udp'}{'5305'}++	; 
#	$ports_ref->{'udp'}{'5305'}{'name'} = 'hacl-test'		; 
#	$srvcobjects_ref->{'hacl-test'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-test'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-test'}{'port'}{'tcp'} = '5305'	; 
#	$srvcobjects_ref->{'hacl-test'}{'ports'}{'tcp'}{'5305'}++	; 
#	$ports_ref->{'tcp'}{'5305'}{'name'} = 'hacl-test'		; 
#	$srvcobjects_ref->{'pictrography'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pictrography'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pictrography'}{'port'}{'udp'} = '1280'	; 
#	$srvcobjects_ref->{'pictrography'}{'ports'}{'udp'}{'1280'}++	; 
#	$ports_ref->{'udp'}{'1280'}{'name'} = 'pictrography'		; 
#	$srvcobjects_ref->{'pictrography'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pictrography'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pictrography'}{'port'}{'tcp'} = '1280'	; 
#	$srvcobjects_ref->{'pictrography'}{'ports'}{'tcp'}{'1280'}++	; 
#	$ports_ref->{'tcp'}{'1280'}{'name'} = 'pictrography'		; 
#	$srvcobjects_ref->{'rets-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rets-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rets-ssl'}{'port'}{'udp'} = '12109'	; 
#	$srvcobjects_ref->{'rets-ssl'}{'ports'}{'udp'}{'12109'}++	; 
#	$ports_ref->{'udp'}{'12109'}{'name'} = 'rets-ssl'		; 
#	$srvcobjects_ref->{'rets-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rets-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rets-ssl'}{'port'}{'tcp'} = '12109'	; 
#	$srvcobjects_ref->{'rets-ssl'}{'ports'}{'tcp'}{'12109'}++	; 
#	$ports_ref->{'tcp'}{'12109'}{'name'} = 'rets-ssl'		; 
#	$srvcobjects_ref->{'qsoft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qsoft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsoft'}{'port'}{'udp'} = '3059'	; 
#	$srvcobjects_ref->{'qsoft'}{'ports'}{'udp'}{'3059'}++	; 
#	$ports_ref->{'udp'}{'3059'}{'name'} = 'qsoft'		; 
#	$srvcobjects_ref->{'qsoft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qsoft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsoft'}{'port'}{'tcp'} = '3059'	; 
#	$srvcobjects_ref->{'qsoft'}{'ports'}{'tcp'}{'3059'}++	; 
#	$ports_ref->{'tcp'}{'3059'}{'name'} = 'qsoft'		; 
#	$srvcobjects_ref->{'workflow'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'workflow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'workflow'}{'port'}{'udp'} = '3466'	; 
#	$srvcobjects_ref->{'workflow'}{'ports'}{'udp'}{'3466'}++	; 
#	$ports_ref->{'udp'}{'3466'}{'name'} = 'workflow'		; 
#	$srvcobjects_ref->{'workflow'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'workflow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'workflow'}{'port'}{'tcp'} = '3466'	; 
#	$srvcobjects_ref->{'workflow'}{'ports'}{'tcp'}{'3466'}++	; 
#	$ports_ref->{'tcp'}{'3466'}{'name'} = 'workflow'		; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'port'}{'udp'} = '546'	; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'ports'}{'udp'}{'546'}++	; 
#	$ports_ref->{'udp'}{'546'}{'name'} = 'dhcpv6-client'		; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'port'}{'tcp'} = '546'	; 
#	$srvcobjects_ref->{'dhcpv6-client'}{'ports'}{'tcp'}{'546'}++	; 
#	$ports_ref->{'tcp'}{'546'}{'name'} = 'dhcpv6-client'		; 
#	$srvcobjects_ref->{'cluster-disc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cluster-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cluster-disc'}{'port'}{'udp'} = '3374'	; 
#	$srvcobjects_ref->{'cluster-disc'}{'ports'}{'udp'}{'3374'}++	; 
#	$ports_ref->{'udp'}{'3374'}{'name'} = 'cluster-disc'		; 
#	$srvcobjects_ref->{'cluster-disc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cluster-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cluster-disc'}{'port'}{'tcp'} = '3374'	; 
#	$srvcobjects_ref->{'cluster-disc'}{'ports'}{'tcp'}{'3374'}++	; 
#	$ports_ref->{'tcp'}{'3374'}{'name'} = 'cluster-disc'		; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'port'}{'udp'} = '2978'	; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'ports'}{'udp'}{'2978'}++	; 
#	$ports_ref->{'udp'}{'2978'}{'name'} = 'ttc-etap-ds'		; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'port'}{'tcp'} = '2978'	; 
#	$srvcobjects_ref->{'ttc-etap-ds'}{'ports'}{'tcp'}{'2978'}++	; 
#	$ports_ref->{'tcp'}{'2978'}{'name'} = 'ttc-etap-ds'		; 
#	$srvcobjects_ref->{'banyan-rpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'banyan-rpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'banyan-rpc'}{'port'}{'udp'} = '567'	; 
#	$srvcobjects_ref->{'banyan-rpc'}{'ports'}{'udp'}{'567'}++	; 
#	$ports_ref->{'udp'}{'567'}{'name'} = 'banyan-rpc'		; 
#	$srvcobjects_ref->{'banyan-rpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'banyan-rpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'banyan-rpc'}{'port'}{'tcp'} = '567'	; 
#	$srvcobjects_ref->{'banyan-rpc'}{'ports'}{'tcp'}{'567'}++	; 
#	$ports_ref->{'tcp'}{'567'}{'name'} = 'banyan-rpc'		; 
#	$srvcobjects_ref->{'virprot-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'virprot-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virprot-lm'}{'port'}{'udp'} = '7121'	; 
#	$srvcobjects_ref->{'virprot-lm'}{'ports'}{'udp'}{'7121'}++	; 
#	$ports_ref->{'udp'}{'7121'}{'name'} = 'virprot-lm'		; 
#	$srvcobjects_ref->{'virprot-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'virprot-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virprot-lm'}{'port'}{'tcp'} = '7121'	; 
#	$srvcobjects_ref->{'virprot-lm'}{'ports'}{'tcp'}{'7121'}++	; 
#	$ports_ref->{'tcp'}{'7121'}{'name'} = 'virprot-lm'		; 
#	$srvcobjects_ref->{'vpps-qua'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpps-qua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpps-qua'}{'port'}{'udp'} = '672'	; 
#	$srvcobjects_ref->{'vpps-qua'}{'ports'}{'udp'}{'672'}++	; 
#	$ports_ref->{'udp'}{'672'}{'name'} = 'vpps-qua'		; 
#	$srvcobjects_ref->{'vpps-qua'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpps-qua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpps-qua'}{'port'}{'tcp'} = '672'	; 
#	$srvcobjects_ref->{'vpps-qua'}{'ports'}{'tcp'}{'672'}++	; 
#	$ports_ref->{'tcp'}{'672'}{'name'} = 'vpps-qua'		; 
#	$srvcobjects_ref->{'pacerforum'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pacerforum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pacerforum'}{'port'}{'udp'} = '1480'	; 
#	$srvcobjects_ref->{'pacerforum'}{'ports'}{'udp'}{'1480'}++	; 
#	$ports_ref->{'udp'}{'1480'}{'name'} = 'pacerforum'		; 
#	$srvcobjects_ref->{'pacerforum'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pacerforum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pacerforum'}{'port'}{'tcp'} = '1480'	; 
#	$srvcobjects_ref->{'pacerforum'}{'ports'}{'tcp'}{'1480'}++	; 
#	$ports_ref->{'tcp'}{'1480'}{'name'} = 'pacerforum'		; 
#	$srvcobjects_ref->{'blackjack'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'blackjack'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blackjack'}{'port'}{'udp'} = '1025'	; 
#	$srvcobjects_ref->{'blackjack'}{'ports'}{'udp'}{'1025'}++	; 
#	$ports_ref->{'udp'}{'1025'}{'name'} = 'blackjack'		; 
#	$srvcobjects_ref->{'blackjack'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'blackjack'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blackjack'}{'port'}{'tcp'} = '1025'	; 
#	$srvcobjects_ref->{'blackjack'}{'ports'}{'tcp'}{'1025'}++	; 
#	$ports_ref->{'tcp'}{'1025'}{'name'} = 'blackjack'		; 
#	$srvcobjects_ref->{'boks_servc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boks_servc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks_servc'}{'port'}{'udp'} = '6501'	; 
#	$srvcobjects_ref->{'boks_servc'}{'ports'}{'udp'}{'6501'}++	; 
#	$ports_ref->{'udp'}{'6501'}{'name'} = 'boks_servc'		; 
#	$srvcobjects_ref->{'boks_servc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boks_servc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks_servc'}{'port'}{'tcp'} = '6501'	; 
#	$srvcobjects_ref->{'boks_servc'}{'ports'}{'tcp'}{'6501'}++	; 
#	$ports_ref->{'tcp'}{'6501'}{'name'} = 'boks_servc'		; 
#	$srvcobjects_ref->{'responsenet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'responsenet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'responsenet'}{'port'}{'udp'} = '3045'	; 
#	$srvcobjects_ref->{'responsenet'}{'ports'}{'udp'}{'3045'}++	; 
#	$ports_ref->{'udp'}{'3045'}{'name'} = 'responsenet'		; 
#	$srvcobjects_ref->{'responsenet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'responsenet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'responsenet'}{'port'}{'tcp'} = '3045'	; 
#	$srvcobjects_ref->{'responsenet'}{'ports'}{'tcp'}{'3045'}++	; 
#	$ports_ref->{'tcp'}{'3045'}{'name'} = 'responsenet'		; 
#	$srvcobjects_ref->{'csoftragent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csoftragent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoftragent'}{'port'}{'udp'} = '3004'	; 
#	$srvcobjects_ref->{'csoftragent'}{'ports'}{'udp'}{'3004'}++	; 
#	$ports_ref->{'udp'}{'3004'}{'name'} = 'csoftragent'		; 
#	$srvcobjects_ref->{'csoftragent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csoftragent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoftragent'}{'port'}{'tcp'} = '3004'	; 
#	$srvcobjects_ref->{'csoftragent'}{'ports'}{'tcp'}{'3004'}++	; 
#	$ports_ref->{'tcp'}{'3004'}{'name'} = 'csoftragent'		; 
#	$srvcobjects_ref->{'biolink-auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'biolink-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'biolink-auth'}{'port'}{'udp'} = '3411'	; 
#	$srvcobjects_ref->{'biolink-auth'}{'ports'}{'udp'}{'3411'}++	; 
#	$ports_ref->{'udp'}{'3411'}{'name'} = 'biolink-auth'		; 
#	$srvcobjects_ref->{'biolink-auth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'biolink-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'biolink-auth'}{'port'}{'tcp'} = '3411'	; 
#	$srvcobjects_ref->{'biolink-auth'}{'ports'}{'tcp'}{'3411'}++	; 
#	$ports_ref->{'tcp'}{'3411'}{'name'} = 'biolink-auth'		; 
#	$srvcobjects_ref->{'aria'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aria'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aria'}{'port'}{'udp'} = '2624'	; 
#	$srvcobjects_ref->{'aria'}{'ports'}{'udp'}{'2624'}++	; 
#	$ports_ref->{'udp'}{'2624'}{'name'} = 'aria'		; 
#	$srvcobjects_ref->{'aria'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aria'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aria'}{'port'}{'tcp'} = '2624'	; 
#	$srvcobjects_ref->{'aria'}{'ports'}{'tcp'}{'2624'}++	; 
#	$ports_ref->{'tcp'}{'2624'}{'name'} = 'aria'		; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'port'}{'udp'} = '3984'	; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'ports'}{'udp'}{'3984'}++	; 
#	$ports_ref->{'udp'}{'3984'}{'name'} = 'mapper-nodemgr'		; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'port'}{'tcp'} = '3984'	; 
#	$srvcobjects_ref->{'mapper-nodemgr'}{'ports'}{'tcp'}{'3984'}++	; 
#	$ports_ref->{'tcp'}{'3984'}{'name'} = 'mapper-nodemgr'		; 
#	$srvcobjects_ref->{'ltcudp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ltcudp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ltcudp'}{'port'}{'udp'} = '3487'	; 
#	$srvcobjects_ref->{'ltcudp'}{'ports'}{'udp'}{'3487'}++	; 
#	$ports_ref->{'udp'}{'3487'}{'name'} = 'ltcudp'		; 
#	$srvcobjects_ref->{'gacp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gacp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gacp'}{'port'}{'udp'} = '190'	; 
#	$srvcobjects_ref->{'gacp'}{'ports'}{'udp'}{'190'}++	; 
#	$ports_ref->{'udp'}{'190'}{'name'} = 'gacp'		; 
#	$srvcobjects_ref->{'gacp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gacp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gacp'}{'port'}{'tcp'} = '190'	; 
#	$srvcobjects_ref->{'gacp'}{'ports'}{'tcp'}{'190'}++	; 
#	$ports_ref->{'tcp'}{'190'}{'name'} = 'gacp'		; 
#	$srvcobjects_ref->{'auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'auth'}{'port'}{'udp'} = '113'	; 
#	$srvcobjects_ref->{'auth'}{'ports'}{'udp'}{'113'}++	; 
#	$ports_ref->{'udp'}{'113'}{'name'} = 'auth'		; 
#	$srvcobjects_ref->{'transmit-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'transmit-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'transmit-port'}{'port'}{'udp'} = '5282'	; 
#	$srvcobjects_ref->{'transmit-port'}{'ports'}{'udp'}{'5282'}++	; 
#	$ports_ref->{'udp'}{'5282'}{'name'} = 'transmit-port'		; 
#	$srvcobjects_ref->{'transmit-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'transmit-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'transmit-port'}{'port'}{'tcp'} = '5282'	; 
#	$srvcobjects_ref->{'transmit-port'}{'ports'}{'tcp'}{'5282'}++	; 
#	$ports_ref->{'tcp'}{'5282'}{'name'} = 'transmit-port'		; 
#	$srvcobjects_ref->{'ff-lr-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ff-lr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-lr-port'}{'port'}{'udp'} = '3622'	; 
#	$srvcobjects_ref->{'ff-lr-port'}{'ports'}{'udp'}{'3622'}++	; 
#	$ports_ref->{'udp'}{'3622'}{'name'} = 'ff-lr-port'		; 
#	$srvcobjects_ref->{'ff-lr-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ff-lr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-lr-port'}{'port'}{'tcp'} = '3622'	; 
#	$srvcobjects_ref->{'ff-lr-port'}{'ports'}{'tcp'}{'3622'}++	; 
#	$ports_ref->{'tcp'}{'3622'}{'name'} = 'ff-lr-port'		; 
#	$srvcobjects_ref->{'alaris-disc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alaris-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alaris-disc'}{'port'}{'udp'} = '3613'	; 
#	$srvcobjects_ref->{'alaris-disc'}{'ports'}{'udp'}{'3613'}++	; 
#	$ports_ref->{'udp'}{'3613'}{'name'} = 'alaris-disc'		; 
#	$srvcobjects_ref->{'alaris-disc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alaris-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alaris-disc'}{'port'}{'tcp'} = '3613'	; 
#	$srvcobjects_ref->{'alaris-disc'}{'ports'}{'tcp'}{'3613'}++	; 
#	$ports_ref->{'tcp'}{'3613'}{'name'} = 'alaris-disc'		; 
#	$srvcobjects_ref->{'lsp-ping'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lsp-ping'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lsp-ping'}{'port'}{'udp'} = '3503'	; 
#	$srvcobjects_ref->{'lsp-ping'}{'ports'}{'udp'}{'3503'}++	; 
#	$ports_ref->{'udp'}{'3503'}{'name'} = 'lsp-ping'		; 
#	$srvcobjects_ref->{'lsp-ping'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lsp-ping'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lsp-ping'}{'port'}{'tcp'} = '3503'	; 
#	$srvcobjects_ref->{'lsp-ping'}{'ports'}{'tcp'}{'3503'}++	; 
#	$ports_ref->{'tcp'}{'3503'}{'name'} = 'lsp-ping'		; 
#	$srvcobjects_ref->{'naap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'naap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'naap'}{'port'}{'udp'} = '1340'	; 
#	$srvcobjects_ref->{'naap'}{'ports'}{'udp'}{'1340'}++	; 
#	$ports_ref->{'udp'}{'1340'}{'name'} = 'naap'		; 
#	$srvcobjects_ref->{'naap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'naap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'naap'}{'port'}{'tcp'} = '1340'	; 
#	$srvcobjects_ref->{'naap'}{'ports'}{'tcp'}{'1340'}++	; 
#	$ports_ref->{'tcp'}{'1340'}{'name'} = 'naap'		; 
#	$srvcobjects_ref->{'afesc-mc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afesc-mc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afesc-mc'}{'port'}{'udp'} = '6628'	; 
#	$srvcobjects_ref->{'afesc-mc'}{'ports'}{'udp'}{'6628'}++	; 
#	$ports_ref->{'udp'}{'6628'}{'name'} = 'afesc-mc'		; 
#	$srvcobjects_ref->{'afesc-mc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afesc-mc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afesc-mc'}{'port'}{'tcp'} = '6628'	; 
#	$srvcobjects_ref->{'afesc-mc'}{'ports'}{'tcp'}{'6628'}++	; 
#	$ports_ref->{'tcp'}{'6628'}{'name'} = 'afesc-mc'		; 
#	$srvcobjects_ref->{'acptsys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acptsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acptsys'}{'port'}{'udp'} = '2149'	; 
#	$srvcobjects_ref->{'acptsys'}{'ports'}{'udp'}{'2149'}++	; 
#	$ports_ref->{'udp'}{'2149'}{'name'} = 'acptsys'		; 
#	$srvcobjects_ref->{'acptsys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acptsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acptsys'}{'port'}{'tcp'} = '2149'	; 
#	$srvcobjects_ref->{'acptsys'}{'ports'}{'tcp'}{'2149'}++	; 
#	$ports_ref->{'tcp'}{'2149'}{'name'} = 'acptsys'		; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'port'}{'udp'} = '3581'	; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'ports'}{'udp'}{'3581'}++	; 
#	$ports_ref->{'udp'}{'3581'}{'name'} = 'kfxaclicensing'		; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'port'}{'tcp'} = '3581'	; 
#	$srvcobjects_ref->{'kfxaclicensing'}{'ports'}{'tcp'}{'3581'}++	; 
#	$ports_ref->{'tcp'}{'3581'}{'name'} = 'kfxaclicensing'		; 
#	$srvcobjects_ref->{'coord-svr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'coord-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'coord-svr'}{'port'}{'udp'} = '2565'	; 
#	$srvcobjects_ref->{'coord-svr'}{'ports'}{'udp'}{'2565'}++	; 
#	$ports_ref->{'udp'}{'2565'}{'name'} = 'coord-svr'		; 
#	$srvcobjects_ref->{'coord-svr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'coord-svr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'coord-svr'}{'port'}{'tcp'} = '2565'	; 
#	$srvcobjects_ref->{'coord-svr'}{'ports'}{'tcp'}{'2565'}++	; 
#	$ports_ref->{'tcp'}{'2565'}{'name'} = 'coord-svr'		; 
#	$srvcobjects_ref->{'ndm-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndm-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndm-server'}{'port'}{'udp'} = '1364'	; 
#	$srvcobjects_ref->{'ndm-server'}{'ports'}{'udp'}{'1364'}++	; 
#	$ports_ref->{'udp'}{'1364'}{'name'} = 'ndm-server'		; 
#	$srvcobjects_ref->{'ndm-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndm-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndm-server'}{'port'}{'tcp'} = '1364'	; 
#	$srvcobjects_ref->{'ndm-server'}{'ports'}{'tcp'}{'1364'}++	; 
#	$ports_ref->{'tcp'}{'1364'}{'name'} = 'ndm-server'		; 
#	$srvcobjects_ref->{'hiq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hiq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hiq'}{'port'}{'udp'} = '1410'	; 
#	$srvcobjects_ref->{'hiq'}{'ports'}{'udp'}{'1410'}++	; 
#	$ports_ref->{'udp'}{'1410'}{'name'} = 'hiq'		; 
#	$srvcobjects_ref->{'hiq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hiq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hiq'}{'port'}{'tcp'} = '1410'	; 
#	$srvcobjects_ref->{'hiq'}{'ports'}{'tcp'}{'1410'}++	; 
#	$ports_ref->{'tcp'}{'1410'}{'name'} = 'hiq'		; 
#	$srvcobjects_ref->{'terminaldb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'terminaldb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'terminaldb'}{'port'}{'udp'} = '2008'	; 
#	$srvcobjects_ref->{'terminaldb'}{'ports'}{'udp'}{'2008'}++	; 
#	$ports_ref->{'udp'}{'2008'}{'name'} = 'terminaldb'		; 
#	$srvcobjects_ref->{'terminaldb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'terminaldb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'terminaldb'}{'port'}{'tcp'} = '2018'	; 
#	$srvcobjects_ref->{'terminaldb'}{'ports'}{'tcp'}{'2018'}++	; 
#	$ports_ref->{'tcp'}{'2018'}{'name'} = 'terminaldb'		; 
#	$srvcobjects_ref->{'ups'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ups'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ups'}{'port'}{'udp'} = '401'	; 
#	$srvcobjects_ref->{'ups'}{'ports'}{'udp'}{'401'}++	; 
#	$ports_ref->{'udp'}{'401'}{'name'} = 'ups'		; 
#	$srvcobjects_ref->{'ups'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ups'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ups'}{'port'}{'tcp'} = '401'	; 
#	$srvcobjects_ref->{'ups'}{'ports'}{'tcp'}{'401'}++	; 
#	$ports_ref->{'tcp'}{'401'}{'name'} = 'ups'		; 
#	$srvcobjects_ref->{'sage-best-com1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sage-best-com1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sage-best-com1'}{'port'}{'udp'} = '14033'	; 
#	$srvcobjects_ref->{'sage-best-com1'}{'ports'}{'udp'}{'14033'}++	; 
#	$ports_ref->{'udp'}{'14033'}{'name'} = 'sage-best-com1'		; 
#	$srvcobjects_ref->{'sage-best-com1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sage-best-com1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sage-best-com1'}{'port'}{'tcp'} = '14033'	; 
#	$srvcobjects_ref->{'sage-best-com1'}{'ports'}{'tcp'}{'14033'}++	; 
#	$ports_ref->{'tcp'}{'14033'}{'name'} = 'sage-best-com1'		; 
#	$srvcobjects_ref->{'apc-6549'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-6549'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-6549'}{'port'}{'udp'} = '6549'	; 
#	$srvcobjects_ref->{'apc-6549'}{'ports'}{'udp'}{'6549'}++	; 
#	$ports_ref->{'udp'}{'6549'}{'name'} = 'apc-6549'		; 
#	$srvcobjects_ref->{'apc-6549'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-6549'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-6549'}{'port'}{'tcp'} = '6549'	; 
#	$srvcobjects_ref->{'apc-6549'}{'ports'}{'tcp'}{'6549'}++	; 
#	$ports_ref->{'tcp'}{'6549'}{'name'} = 'apc-6549'		; 
#	$srvcobjects_ref->{'mit-dov'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mit-dov'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mit-dov'}{'port'}{'udp'} = '91'	; 
#	$srvcobjects_ref->{'mit-dov'}{'ports'}{'udp'}{'91'}++	; 
#	$ports_ref->{'udp'}{'91'}{'name'} = 'mit-dov'		; 
#	$srvcobjects_ref->{'mit-dov'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mit-dov'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mit-dov'}{'port'}{'tcp'} = '91'	; 
#	$srvcobjects_ref->{'mit-dov'}{'ports'}{'tcp'}{'91'}++	; 
#	$ports_ref->{'tcp'}{'91'}{'name'} = 'mit-dov'		; 
#	$srvcobjects_ref->{'can-dch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'can-dch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-dch'}{'port'}{'udp'} = '1919'	; 
#	$srvcobjects_ref->{'can-dch'}{'ports'}{'udp'}{'1919'}++	; 
#	$ports_ref->{'udp'}{'1919'}{'name'} = 'can-dch'		; 
#	$srvcobjects_ref->{'can-dch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'can-dch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-dch'}{'port'}{'tcp'} = '1919'	; 
#	$srvcobjects_ref->{'can-dch'}{'ports'}{'tcp'}{'1919'}++	; 
#	$ports_ref->{'tcp'}{'1919'}{'name'} = 'can-dch'		; 
#	$srvcobjects_ref->{'mshnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mshnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mshnet'}{'port'}{'udp'} = '1989'	; 
#	$srvcobjects_ref->{'mshnet'}{'ports'}{'udp'}{'1989'}++	; 
#	$ports_ref->{'udp'}{'1989'}{'name'} = 'mshnet'		; 
#	$srvcobjects_ref->{'mshnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mshnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mshnet'}{'port'}{'tcp'} = '1989'	; 
#	$srvcobjects_ref->{'mshnet'}{'ports'}{'tcp'}{'1989'}++	; 
#	$ports_ref->{'tcp'}{'1989'}{'name'} = 'mshnet'		; 
#	$srvcobjects_ref->{'geneous'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'geneous'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'geneous'}{'port'}{'udp'} = '3381'	; 
#	$srvcobjects_ref->{'geneous'}{'ports'}{'udp'}{'3381'}++	; 
#	$ports_ref->{'udp'}{'3381'}{'name'} = 'geneous'		; 
#	$srvcobjects_ref->{'geneous'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'geneous'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'geneous'}{'port'}{'tcp'} = '3381'	; 
#	$srvcobjects_ref->{'geneous'}{'ports'}{'tcp'}{'3381'}++	; 
#	$ports_ref->{'tcp'}{'3381'}{'name'} = 'geneous'		; 
#	$srvcobjects_ref->{'gbjd816'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gbjd816'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gbjd816'}{'port'}{'udp'} = '2626'	; 
#	$srvcobjects_ref->{'gbjd816'}{'ports'}{'udp'}{'2626'}++	; 
#	$ports_ref->{'udp'}{'2626'}{'name'} = 'gbjd816'		; 
#	$srvcobjects_ref->{'gbjd816'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gbjd816'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gbjd816'}{'port'}{'tcp'} = '2626'	; 
#	$srvcobjects_ref->{'gbjd816'}{'ports'}{'tcp'}{'2626'}++	; 
#	$ports_ref->{'tcp'}{'2626'}{'name'} = 'gbjd816'		; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'port'}{'udp'} = '1486'	; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'ports'}{'udp'}{'1486'}++	; 
#	$ports_ref->{'udp'}{'1486'}{'name'} = 'nms_topo_serv'		; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'port'}{'tcp'} = '1486'	; 
#	$srvcobjects_ref->{'nms_topo_serv'}{'ports'}{'tcp'}{'1486'}++	; 
#	$ports_ref->{'tcp'}{'1486'}{'name'} = 'nms_topo_serv'		; 
#	$srvcobjects_ref->{'rtmp'}{'type'} = 'ddp'	; 
#	$srvcobjects_ref->{'rtmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtmp'}{'port'}{'ddp'} = '1'	; 
#	$srvcobjects_ref->{'rtmp'}{'ports'}{'ddp'}{'1'}++	; 
#	$ports_ref->{'ddp'}{'1'}{'name'} = 'rtmp'		; 
#	$srvcobjects_ref->{'veritas-ucl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'veritas-ucl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-ucl'}{'port'}{'udp'} = '2148'	; 
#	$srvcobjects_ref->{'veritas-ucl'}{'ports'}{'udp'}{'2148'}++	; 
#	$ports_ref->{'udp'}{'2148'}{'name'} = 'veritas-ucl'		; 
#	$srvcobjects_ref->{'veritas-ucl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'veritas-ucl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-ucl'}{'port'}{'tcp'} = '2148'	; 
#	$srvcobjects_ref->{'veritas-ucl'}{'ports'}{'tcp'}{'2148'}++	; 
#	$ports_ref->{'tcp'}{'2148'}{'name'} = 'veritas-ucl'		; 
#	$srvcobjects_ref->{'ott'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ott'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ott'}{'port'}{'udp'} = '2428'	; 
#	$srvcobjects_ref->{'ott'}{'ports'}{'udp'}{'2428'}++	; 
#	$ports_ref->{'udp'}{'2428'}{'name'} = 'ott'		; 
#	$srvcobjects_ref->{'ott'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ott'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ott'}{'port'}{'tcp'} = '2428'	; 
#	$srvcobjects_ref->{'ott'}{'ports'}{'tcp'}{'2428'}++	; 
#	$ports_ref->{'tcp'}{'2428'}{'name'} = 'ott'		; 
#	$srvcobjects_ref->{'sm-pas-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sm-pas-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-4'}{'port'}{'udp'} = '2941'	; 
#	$srvcobjects_ref->{'sm-pas-4'}{'ports'}{'udp'}{'2941'}++	; 
#	$ports_ref->{'udp'}{'2941'}{'name'} = 'sm-pas-4'		; 
#	$srvcobjects_ref->{'sm-pas-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sm-pas-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-4'}{'port'}{'tcp'} = '2941'	; 
#	$srvcobjects_ref->{'sm-pas-4'}{'ports'}{'tcp'}{'2941'}++	; 
#	$ports_ref->{'tcp'}{'2941'}{'name'} = 'sm-pas-4'		; 
#	$srvcobjects_ref->{'ncconfig'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncconfig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncconfig'}{'port'}{'udp'} = '1888'	; 
#	$srvcobjects_ref->{'ncconfig'}{'ports'}{'udp'}{'1888'}++	; 
#	$ports_ref->{'udp'}{'1888'}{'name'} = 'ncconfig'		; 
#	$srvcobjects_ref->{'ncconfig'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncconfig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncconfig'}{'port'}{'tcp'} = '1888'	; 
#	$srvcobjects_ref->{'ncconfig'}{'ports'}{'tcp'}{'1888'}++	; 
#	$ports_ref->{'tcp'}{'1888'}{'name'} = 'ncconfig'		; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'port'}{'udp'} = '1682'	; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'ports'}{'udp'}{'1682'}++	; 
#	$ports_ref->{'udp'}{'1682'}{'name'} = 'lanyon-lantern'		; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'port'}{'tcp'} = '1682'	; 
#	$srvcobjects_ref->{'lanyon-lantern'}{'ports'}{'tcp'}{'1682'}++	; 
#	$ports_ref->{'tcp'}{'1682'}{'name'} = 'lanyon-lantern'		; 
#	$srvcobjects_ref->{'apc-2161'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-2161'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-2161'}{'port'}{'udp'} = '2161'	; 
#	$srvcobjects_ref->{'apc-2161'}{'ports'}{'udp'}{'2161'}++	; 
#	$ports_ref->{'udp'}{'2161'}{'name'} = 'apc-2161'		; 
#	$srvcobjects_ref->{'apc-2161'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-2161'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-2161'}{'port'}{'tcp'} = '2161'	; 
#	$srvcobjects_ref->{'apc-2161'}{'ports'}{'tcp'}{'2161'}++	; 
#	$ports_ref->{'tcp'}{'2161'}{'name'} = 'apc-2161'		; 
#	$srvcobjects_ref->{'qsnet-trans'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qsnet-trans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-trans'}{'port'}{'udp'} = '4354'	; 
#	$srvcobjects_ref->{'qsnet-trans'}{'ports'}{'udp'}{'4354'}++	; 
#	$ports_ref->{'udp'}{'4354'}{'name'} = 'qsnet-trans'		; 
#	$srvcobjects_ref->{'qsnet-trans'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qsnet-trans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-trans'}{'port'}{'tcp'} = '4354'	; 
#	$srvcobjects_ref->{'qsnet-trans'}{'ports'}{'tcp'}{'4354'}++	; 
#	$ports_ref->{'tcp'}{'4354'}{'name'} = 'qsnet-trans'		; 
#	$srvcobjects_ref->{'smar-se-port1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smar-se-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smar-se-port1'}{'port'}{'udp'} = '4987'	; 
#	$srvcobjects_ref->{'smar-se-port1'}{'ports'}{'udp'}{'4987'}++	; 
#	$ports_ref->{'udp'}{'4987'}{'name'} = 'smar-se-port1'		; 
#	$srvcobjects_ref->{'smar-se-port1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smar-se-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smar-se-port1'}{'port'}{'tcp'} = '4987'	; 
#	$srvcobjects_ref->{'smar-se-port1'}{'ports'}{'tcp'}{'4987'}++	; 
#	$ports_ref->{'tcp'}{'4987'}{'name'} = 'smar-se-port1'		; 
#	$srvcobjects_ref->{'ssrip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssrip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssrip'}{'port'}{'udp'} = '3318'	; 
#	$srvcobjects_ref->{'ssrip'}{'ports'}{'udp'}{'3318'}++	; 
#	$ports_ref->{'udp'}{'3318'}{'name'} = 'ssrip'		; 
#	$srvcobjects_ref->{'ssrip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssrip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssrip'}{'port'}{'tcp'} = '3318'	; 
#	$srvcobjects_ref->{'ssrip'}{'ports'}{'tcp'}{'3318'}++	; 
#	$ports_ref->{'tcp'}{'3318'}{'name'} = 'ssrip'		; 
#	$srvcobjects_ref->{'ttc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc'}{'port'}{'udp'} = '2483'	; 
#	$srvcobjects_ref->{'ttc'}{'ports'}{'udp'}{'2483'}++	; 
#	$ports_ref->{'udp'}{'2483'}{'name'} = 'ttc'		; 
#	$srvcobjects_ref->{'ttc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc'}{'port'}{'tcp'} = '2483'	; 
#	$srvcobjects_ref->{'ttc'}{'ports'}{'tcp'}{'2483'}++	; 
#	$ports_ref->{'tcp'}{'2483'}{'name'} = 'ttc'		; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'port'}{'udp'} = '3488'	; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'ports'}{'udp'}{'3488'}++	; 
#	$ports_ref->{'udp'}{'3488'}{'name'} = 'fs-rh-srv'		; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'port'}{'tcp'} = '3488'	; 
#	$srvcobjects_ref->{'fs-rh-srv'}{'ports'}{'tcp'}{'3488'}++	; 
#	$ports_ref->{'tcp'}{'3488'}{'name'} = 'fs-rh-srv'		; 
#	$srvcobjects_ref->{'mpshrsv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpshrsv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpshrsv'}{'port'}{'udp'} = '1261'	; 
#	$srvcobjects_ref->{'mpshrsv'}{'ports'}{'udp'}{'1261'}++	; 
#	$ports_ref->{'udp'}{'1261'}{'name'} = 'mpshrsv'		; 
#	$srvcobjects_ref->{'mpshrsv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpshrsv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpshrsv'}{'port'}{'tcp'} = '1261'	; 
#	$srvcobjects_ref->{'mpshrsv'}{'ports'}{'tcp'}{'1261'}++	; 
#	$ports_ref->{'tcp'}{'1261'}{'name'} = 'mpshrsv'		; 
#	$srvcobjects_ref->{'lrp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lrp'}{'port'}{'udp'} = '2090'	; 
#	$srvcobjects_ref->{'lrp'}{'ports'}{'udp'}{'2090'}++	; 
#	$ports_ref->{'udp'}{'2090'}{'name'} = 'lrp'		; 
#	$srvcobjects_ref->{'lrp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lrp'}{'port'}{'tcp'} = '2090'	; 
#	$srvcobjects_ref->{'lrp'}{'ports'}{'tcp'}{'2090'}++	; 
#	$ports_ref->{'tcp'}{'2090'}{'name'} = 'lrp'		; 
#	$srvcobjects_ref->{'iso-tsap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iso-tsap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tsap'}{'port'}{'udp'} = '102'	; 
#	$srvcobjects_ref->{'iso-tsap'}{'ports'}{'udp'}{'102'}++	; 
#	$ports_ref->{'udp'}{'102'}{'name'} = 'iso-tsap'		; 
#	$srvcobjects_ref->{'iso-tsap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iso-tsap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tsap'}{'port'}{'tcp'} = '102'	; 
#	$srvcobjects_ref->{'iso-tsap'}{'ports'}{'tcp'}{'102'}++	; 
#	$ports_ref->{'tcp'}{'102'}{'name'} = 'iso-tsap'		; 
#	$srvcobjects_ref->{'prchat-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prchat-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prchat-server'}{'port'}{'udp'} = '4456'	; 
#	$srvcobjects_ref->{'prchat-server'}{'ports'}{'udp'}{'4456'}++	; 
#	$ports_ref->{'udp'}{'4456'}{'name'} = 'prchat-server'		; 
#	$srvcobjects_ref->{'prchat-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prchat-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prchat-server'}{'port'}{'tcp'} = '4456'	; 
#	$srvcobjects_ref->{'prchat-server'}{'ports'}{'tcp'}{'4456'}++	; 
#	$ports_ref->{'tcp'}{'4456'}{'name'} = 'prchat-server'		; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'port'}{'udp'} = '4114'	; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'ports'}{'udp'}{'4114'}++	; 
#	$ports_ref->{'udp'}{'4114'}{'name'} = 'jomamqmonitor'		; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'port'}{'tcp'} = '4114'	; 
#	$srvcobjects_ref->{'jomamqmonitor'}{'ports'}{'tcp'}{'4114'}++	; 
#	$ports_ref->{'tcp'}{'4114'}{'name'} = 'jomamqmonitor'		; 
#	$srvcobjects_ref->{'must-backplane'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'must-backplane'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'must-backplane'}{'port'}{'udp'} = '3515'	; 
#	$srvcobjects_ref->{'must-backplane'}{'ports'}{'udp'}{'3515'}++	; 
#	$ports_ref->{'udp'}{'3515'}{'name'} = 'must-backplane'		; 
#	$srvcobjects_ref->{'must-backplane'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'must-backplane'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'must-backplane'}{'port'}{'tcp'} = '3515'	; 
#	$srvcobjects_ref->{'must-backplane'}{'ports'}{'tcp'}{'3515'}++	; 
#	$ports_ref->{'tcp'}{'3515'}{'name'} = 'must-backplane'		; 
#	$srvcobjects_ref->{'prosharerequest'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prosharerequest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharerequest'}{'port'}{'udp'} = '5716'	; 
#	$srvcobjects_ref->{'prosharerequest'}{'ports'}{'udp'}{'5716'}++	; 
#	$ports_ref->{'udp'}{'5716'}{'name'} = 'prosharerequest'		; 
#	$srvcobjects_ref->{'prosharerequest'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prosharerequest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharerequest'}{'port'}{'tcp'} = '5716'	; 
#	$srvcobjects_ref->{'prosharerequest'}{'ports'}{'tcp'}{'5716'}++	; 
#	$ports_ref->{'tcp'}{'5716'}{'name'} = 'prosharerequest'		; 
#	$srvcobjects_ref->{'ttyinfo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttyinfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttyinfo'}{'port'}{'tcp'} = '2012'	; 
#	$srvcobjects_ref->{'ttyinfo'}{'ports'}{'tcp'}{'2012'}++	; 
#	$ports_ref->{'tcp'}{'2012'}{'name'} = 'ttyinfo'		; 
#	$srvcobjects_ref->{'hybrid-pop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hybrid-pop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hybrid-pop'}{'port'}{'udp'} = '473'	; 
#	$srvcobjects_ref->{'hybrid-pop'}{'ports'}{'udp'}{'473'}++	; 
#	$ports_ref->{'udp'}{'473'}{'name'} = 'hybrid-pop'		; 
#	$srvcobjects_ref->{'hybrid-pop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hybrid-pop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hybrid-pop'}{'port'}{'tcp'} = '473'	; 
#	$srvcobjects_ref->{'hybrid-pop'}{'ports'}{'tcp'}{'473'}++	; 
#	$ports_ref->{'tcp'}{'473'}{'name'} = 'hybrid-pop'		; 
#	$srvcobjects_ref->{'giga-pocket'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'giga-pocket'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'giga-pocket'}{'port'}{'udp'} = '3862'	; 
#	$srvcobjects_ref->{'giga-pocket'}{'ports'}{'udp'}{'3862'}++	; 
#	$ports_ref->{'udp'}{'3862'}{'name'} = 'giga-pocket'		; 
#	$srvcobjects_ref->{'giga-pocket'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'giga-pocket'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'giga-pocket'}{'port'}{'tcp'} = '3862'	; 
#	$srvcobjects_ref->{'giga-pocket'}{'ports'}{'tcp'}{'3862'}++	; 
#	$ports_ref->{'tcp'}{'3862'}{'name'} = 'giga-pocket'		; 
#	$srvcobjects_ref->{'ddi-tcp-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddi-tcp-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-tcp-2'}{'port'}{'tcp'} = '8889'	; 
#	$srvcobjects_ref->{'ddi-tcp-2'}{'ports'}{'tcp'}{'8889'}++	; 
#	$ports_ref->{'tcp'}{'8889'}{'name'} = 'ddi-tcp-2'		; 
#	$srvcobjects_ref->{'servergraph'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'servergraph'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servergraph'}{'port'}{'udp'} = '1251'	; 
#	$srvcobjects_ref->{'servergraph'}{'ports'}{'udp'}{'1251'}++	; 
#	$ports_ref->{'udp'}{'1251'}{'name'} = 'servergraph'		; 
#	$srvcobjects_ref->{'servergraph'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'servergraph'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servergraph'}{'port'}{'tcp'} = '1251'	; 
#	$srvcobjects_ref->{'servergraph'}{'ports'}{'tcp'}{'1251'}++	; 
#	$ports_ref->{'tcp'}{'1251'}{'name'} = 'servergraph'		; 
#	$srvcobjects_ref->{'apollo-cc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apollo-cc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apollo-cc'}{'port'}{'udp'} = '2754'	; 
#	$srvcobjects_ref->{'apollo-cc'}{'ports'}{'udp'}{'2754'}++	; 
#	$ports_ref->{'udp'}{'2754'}{'name'} = 'apollo-cc'		; 
#	$srvcobjects_ref->{'apollo-cc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apollo-cc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apollo-cc'}{'port'}{'tcp'} = '2754'	; 
#	$srvcobjects_ref->{'apollo-cc'}{'ports'}{'tcp'}{'2754'}++	; 
#	$ports_ref->{'tcp'}{'2754'}{'name'} = 'apollo-cc'		; 
#	$srvcobjects_ref->{'varadero-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'varadero-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'varadero-1'}{'port'}{'udp'} = '4838'	; 
#	$srvcobjects_ref->{'varadero-1'}{'ports'}{'udp'}{'4838'}++	; 
#	$ports_ref->{'udp'}{'4838'}{'name'} = 'varadero-1'		; 
#	$srvcobjects_ref->{'varadero-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'varadero-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'varadero-1'}{'port'}{'tcp'} = '4838'	; 
#	$srvcobjects_ref->{'varadero-1'}{'ports'}{'tcp'}{'4838'}++	; 
#	$ports_ref->{'tcp'}{'4838'}{'name'} = 'varadero-1'		; 
#	$srvcobjects_ref->{'netmo-default'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netmo-default'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmo-default'}{'port'}{'udp'} = '6841'	; 
#	$srvcobjects_ref->{'netmo-default'}{'ports'}{'udp'}{'6841'}++	; 
#	$ports_ref->{'udp'}{'6841'}{'name'} = 'netmo-default'		; 
#	$srvcobjects_ref->{'netmo-default'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netmo-default'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmo-default'}{'port'}{'tcp'} = '6841'	; 
#	$srvcobjects_ref->{'netmo-default'}{'ports'}{'tcp'}{'6841'}++	; 
#	$ports_ref->{'tcp'}{'6841'}{'name'} = 'netmo-default'		; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'port'}{'udp'} = '5553'	; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'ports'}{'udp'}{'5553'}++	; 
#	$ports_ref->{'udp'}{'5553'}{'name'} = 'sgi-eventmond'		; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'port'}{'tcp'} = '5553'	; 
#	$srvcobjects_ref->{'sgi-eventmond'}{'ports'}{'tcp'}{'5553'}++	; 
#	$ports_ref->{'tcp'}{'5553'}{'name'} = 'sgi-eventmond'		; 
#	$srvcobjects_ref->{'adtempusclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adtempusclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adtempusclient'}{'port'}{'udp'} = '3760'	; 
#	$srvcobjects_ref->{'adtempusclient'}{'ports'}{'udp'}{'3760'}++	; 
#	$ports_ref->{'udp'}{'3760'}{'name'} = 'adtempusclient'		; 
#	$srvcobjects_ref->{'adtempusclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adtempusclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adtempusclient'}{'port'}{'tcp'} = '3760'	; 
#	$srvcobjects_ref->{'adtempusclient'}{'ports'}{'tcp'}{'3760'}++	; 
#	$ports_ref->{'tcp'}{'3760'}{'name'} = 'adtempusclient'		; 
#	$srvcobjects_ref->{'mcer-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcer-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcer-port'}{'port'}{'udp'} = '6510'	; 
#	$srvcobjects_ref->{'mcer-port'}{'ports'}{'udp'}{'6510'}++	; 
#	$ports_ref->{'udp'}{'6510'}{'name'} = 'mcer-port'		; 
#	$srvcobjects_ref->{'mcer-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcer-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcer-port'}{'port'}{'tcp'} = '6510'	; 
#	$srvcobjects_ref->{'mcer-port'}{'ports'}{'tcp'}{'6510'}++	; 
#	$ports_ref->{'tcp'}{'6510'}{'name'} = 'mcer-port'		; 
#	$srvcobjects_ref->{'gf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gf'}{'port'}{'udp'} = '3530'	; 
#	$srvcobjects_ref->{'gf'}{'ports'}{'udp'}{'3530'}++	; 
#	$ports_ref->{'udp'}{'3530'}{'name'} = 'gf'		; 
#	$srvcobjects_ref->{'gf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gf'}{'port'}{'tcp'} = '3530'	; 
#	$srvcobjects_ref->{'gf'}{'ports'}{'tcp'}{'3530'}++	; 
#	$ports_ref->{'tcp'}{'3530'}{'name'} = 'gf'		; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'port'}{'udp'} = '3182'	; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'ports'}{'udp'}{'3182'}++	; 
#	$ports_ref->{'udp'}{'3182'}{'name'} = 'bmcpatrolrnvu'		; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'port'}{'tcp'} = '3182'	; 
#	$srvcobjects_ref->{'bmcpatrolrnvu'}{'ports'}{'tcp'}{'3182'}++	; 
#	$ports_ref->{'tcp'}{'3182'}{'name'} = 'bmcpatrolrnvu'		; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'port'}{'udp'} = '2699'	; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'ports'}{'udp'}{'2699'}++	; 
#	$ports_ref->{'udp'}{'2699'}{'name'} = 'csoft-plusclnt'		; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'port'}{'tcp'} = '2699'	; 
#	$srvcobjects_ref->{'csoft-plusclnt'}{'ports'}{'tcp'}{'2699'}++	; 
#	$ports_ref->{'tcp'}{'2699'}{'name'} = 'csoft-plusclnt'		; 
#	$srvcobjects_ref->{'netcomm2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netcomm2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcomm2'}{'port'}{'udp'} = '1676'	; 
#	$srvcobjects_ref->{'netcomm2'}{'ports'}{'udp'}{'1676'}++	; 
#	$ports_ref->{'udp'}{'1676'}{'name'} = 'netcomm2'		; 
#	$srvcobjects_ref->{'odmr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'odmr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odmr'}{'port'}{'udp'} = '366'	; 
#	$srvcobjects_ref->{'odmr'}{'ports'}{'udp'}{'366'}++	; 
#	$ports_ref->{'udp'}{'366'}{'name'} = 'odmr'		; 
#	$srvcobjects_ref->{'odmr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'odmr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odmr'}{'port'}{'tcp'} = '366'	; 
#	$srvcobjects_ref->{'odmr'}{'ports'}{'tcp'}{'366'}++	; 
#	$ports_ref->{'tcp'}{'366'}{'name'} = 'odmr'		; 
#	$srvcobjects_ref->{'edm-std-notify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edm-std-notify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-std-notify'}{'port'}{'udp'} = '3462'	; 
#	$srvcobjects_ref->{'edm-std-notify'}{'ports'}{'udp'}{'3462'}++	; 
#	$ports_ref->{'udp'}{'3462'}{'name'} = 'edm-std-notify'		; 
#	$srvcobjects_ref->{'edm-std-notify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edm-std-notify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-std-notify'}{'port'}{'tcp'} = '3462'	; 
#	$srvcobjects_ref->{'edm-std-notify'}{'ports'}{'tcp'}{'3462'}++	; 
#	$ports_ref->{'tcp'}{'3462'}{'name'} = 'edm-std-notify'		; 
#	$srvcobjects_ref->{'cypress-stat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cypress-stat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cypress-stat'}{'port'}{'tcp'} = '2017'	; 
#	$srvcobjects_ref->{'cypress-stat'}{'ports'}{'tcp'}{'2017'}++	; 
#	$ports_ref->{'tcp'}{'2017'}{'name'} = 'cypress-stat'		; 
#	$srvcobjects_ref->{'odn-castraq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'odn-castraq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odn-castraq'}{'port'}{'udp'} = '2498'	; 
#	$srvcobjects_ref->{'odn-castraq'}{'ports'}{'udp'}{'2498'}++	; 
#	$ports_ref->{'udp'}{'2498'}{'name'} = 'odn-castraq'		; 
#	$srvcobjects_ref->{'odn-castraq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'odn-castraq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odn-castraq'}{'port'}{'tcp'} = '2498'	; 
#	$srvcobjects_ref->{'odn-castraq'}{'ports'}{'tcp'}{'2498'}++	; 
#	$ports_ref->{'tcp'}{'2498'}{'name'} = 'odn-castraq'		; 
#	$srvcobjects_ref->{'radio-bc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radio-bc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radio-bc'}{'port'}{'udp'} = '1596'	; 
#	$srvcobjects_ref->{'radio-bc'}{'ports'}{'udp'}{'1596'}++	; 
#	$ports_ref->{'udp'}{'1596'}{'name'} = 'radio-bc'		; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'port'}{'udp'} = '3150'	; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'ports'}{'udp'}{'3150'}++	; 
#	$ports_ref->{'udp'}{'3150'}{'name'} = 'nm-asses-admin'		; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'port'}{'tcp'} = '3150'	; 
#	$srvcobjects_ref->{'nm-asses-admin'}{'ports'}{'tcp'}{'3150'}++	; 
#	$ports_ref->{'tcp'}{'3150'}{'name'} = 'nm-asses-admin'		; 
#	$srvcobjects_ref->{'dtspcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dtspcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtspcd'}{'port'}{'udp'} = '6112'	; 
#	$srvcobjects_ref->{'dtspcd'}{'ports'}{'udp'}{'6112'}++	; 
#	$ports_ref->{'udp'}{'6112'}{'name'} = 'dtspcd'		; 
#	$srvcobjects_ref->{'dtspcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dtspcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtspcd'}{'port'}{'tcp'} = '6112'	; 
#	$srvcobjects_ref->{'dtspcd'}{'ports'}{'tcp'}{'6112'}++	; 
#	$ports_ref->{'tcp'}{'6112'}{'name'} = 'dtspcd'		; 
#	$srvcobjects_ref->{'acr-nema'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acr-nema'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acr-nema'}{'port'}{'udp'} = '104'	; 
#	$srvcobjects_ref->{'acr-nema'}{'ports'}{'udp'}{'104'}++	; 
#	$ports_ref->{'udp'}{'104'}{'name'} = 'acr-nema'		; 
#	$srvcobjects_ref->{'acr-nema'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acr-nema'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acr-nema'}{'port'}{'tcp'} = '104'	; 
#	$srvcobjects_ref->{'acr-nema'}{'ports'}{'tcp'}{'104'}++	; 
#	$ports_ref->{'tcp'}{'104'}{'name'} = 'acr-nema'		; 
#	$srvcobjects_ref->{'whosells'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'whosells'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whosells'}{'port'}{'udp'} = '2781'	; 
#	$srvcobjects_ref->{'whosells'}{'ports'}{'udp'}{'2781'}++	; 
#	$ports_ref->{'udp'}{'2781'}{'name'} = 'whosells'		; 
#	$srvcobjects_ref->{'whosells'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'whosells'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whosells'}{'port'}{'tcp'} = '2781'	; 
#	$srvcobjects_ref->{'whosells'}{'ports'}{'tcp'}{'2781'}++	; 
#	$ports_ref->{'tcp'}{'2781'}{'name'} = 'whosells'		; 
#	$srvcobjects_ref->{'nds_sso'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nds_sso'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nds_sso'}{'port'}{'udp'} = '3024'	; 
#	$srvcobjects_ref->{'nds_sso'}{'ports'}{'udp'}{'3024'}++	; 
#	$ports_ref->{'udp'}{'3024'}{'name'} = 'nds_sso'		; 
#	$srvcobjects_ref->{'nds_sso'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nds_sso'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nds_sso'}{'port'}{'tcp'} = '3024'	; 
#	$srvcobjects_ref->{'nds_sso'}{'ports'}{'tcp'}{'3024'}++	; 
#	$ports_ref->{'tcp'}{'3024'}{'name'} = 'nds_sso'		; 
#	$srvcobjects_ref->{'gdomap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gdomap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdomap'}{'port'}{'udp'} = '538'	; 
#	$srvcobjects_ref->{'gdomap'}{'ports'}{'udp'}{'538'}++	; 
#	$ports_ref->{'udp'}{'538'}{'name'} = 'gdomap'		; 
#	$srvcobjects_ref->{'gdomap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gdomap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdomap'}{'port'}{'tcp'} = '538'	; 
#	$srvcobjects_ref->{'gdomap'}{'ports'}{'tcp'}{'538'}++	; 
#	$ports_ref->{'tcp'}{'538'}{'name'} = 'gdomap'		; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'port'}{'udp'} = '3695'	; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'ports'}{'udp'}{'3695'}++	; 
#	$ports_ref->{'udp'}{'3695'}{'name'} = 'bmc-data-coll'		; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'port'}{'tcp'} = '3695'	; 
#	$srvcobjects_ref->{'bmc-data-coll'}{'ports'}{'tcp'}{'3695'}++	; 
#	$ports_ref->{'tcp'}{'3695'}{'name'} = 'bmc-data-coll'		; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'port'}{'udp'} = '2526'	; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'ports'}{'udp'}{'2526'}++	; 
#	$ports_ref->{'udp'}{'2526'}{'name'} = 'ema-sent-lm'		; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'port'}{'tcp'} = '2526'	; 
#	$srvcobjects_ref->{'ema-sent-lm'}{'ports'}{'tcp'}{'2526'}++	; 
#	$ports_ref->{'tcp'}{'2526'}{'name'} = 'ema-sent-lm'		; 
#	$srvcobjects_ref->{'bmc-ea'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-ea'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-ea'}{'port'}{'udp'} = '3683'	; 
#	$srvcobjects_ref->{'bmc-ea'}{'ports'}{'udp'}{'3683'}++	; 
#	$ports_ref->{'udp'}{'3683'}{'name'} = 'bmc-ea'		; 
#	$srvcobjects_ref->{'bmc-ea'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-ea'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-ea'}{'port'}{'tcp'} = '3683'	; 
#	$srvcobjects_ref->{'bmc-ea'}{'ports'}{'tcp'}{'3683'}++	; 
#	$ports_ref->{'tcp'}{'3683'}{'name'} = 'bmc-ea'		; 
#	$srvcobjects_ref->{'sabams'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sabams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sabams'}{'port'}{'udp'} = '2760'	; 
#	$srvcobjects_ref->{'sabams'}{'ports'}{'udp'}{'2760'}++	; 
#	$ports_ref->{'udp'}{'2760'}{'name'} = 'sabams'		; 
#	$srvcobjects_ref->{'sabams'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sabams'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sabams'}{'port'}{'tcp'} = '2760'	; 
#	$srvcobjects_ref->{'sabams'}{'ports'}{'tcp'}{'2760'}++	; 
#	$ports_ref->{'tcp'}{'2760'}{'name'} = 'sabams'		; 
#	$srvcobjects_ref->{'signet-ctf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'signet-ctf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'signet-ctf'}{'port'}{'udp'} = '2733'	; 
#	$srvcobjects_ref->{'signet-ctf'}{'ports'}{'udp'}{'2733'}++	; 
#	$ports_ref->{'udp'}{'2733'}{'name'} = 'signet-ctf'		; 
#	$srvcobjects_ref->{'signet-ctf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'signet-ctf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'signet-ctf'}{'port'}{'tcp'} = '2733'	; 
#	$srvcobjects_ref->{'signet-ctf'}{'ports'}{'tcp'}{'2733'}++	; 
#	$ports_ref->{'tcp'}{'2733'}{'name'} = 'signet-ctf'		; 
#	$srvcobjects_ref->{'interactionweb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interactionweb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interactionweb'}{'port'}{'udp'} = '3508'	; 
#	$srvcobjects_ref->{'interactionweb'}{'ports'}{'udp'}{'3508'}++	; 
#	$ports_ref->{'udp'}{'3508'}{'name'} = 'interactionweb'		; 
#	$srvcobjects_ref->{'interactionweb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interactionweb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interactionweb'}{'port'}{'tcp'} = '3508'	; 
#	$srvcobjects_ref->{'interactionweb'}{'ports'}{'tcp'}{'3508'}++	; 
#	$ports_ref->{'tcp'}{'3508'}{'name'} = 'interactionweb'		; 
#	$srvcobjects_ref->{'tsb2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tsb2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsb2'}{'port'}{'udp'} = '2742'	; 
#	$srvcobjects_ref->{'tsb2'}{'ports'}{'udp'}{'2742'}++	; 
#	$ports_ref->{'udp'}{'2742'}{'name'} = 'tsb2'		; 
#	$srvcobjects_ref->{'tsb2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tsb2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsb2'}{'port'}{'tcp'} = '2742'	; 
#	$srvcobjects_ref->{'tsb2'}{'ports'}{'tcp'}{'2742'}++	; 
#	$ports_ref->{'tcp'}{'2742'}{'name'} = 'tsb2'		; 
#	$srvcobjects_ref->{'suitcase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'suitcase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'suitcase'}{'port'}{'udp'} = '2903'	; 
#	$srvcobjects_ref->{'suitcase'}{'ports'}{'udp'}{'2903'}++	; 
#	$ports_ref->{'udp'}{'2903'}{'name'} = 'suitcase'		; 
#	$srvcobjects_ref->{'suitcase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'suitcase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'suitcase'}{'port'}{'tcp'} = '2903'	; 
#	$srvcobjects_ref->{'suitcase'}{'ports'}{'tcp'}{'2903'}++	; 
#	$ports_ref->{'tcp'}{'2903'}{'name'} = 'suitcase'		; 
#	$srvcobjects_ref->{'tclprodebugger'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tclprodebugger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tclprodebugger'}{'port'}{'udp'} = '2576'	; 
#	$srvcobjects_ref->{'tclprodebugger'}{'ports'}{'udp'}{'2576'}++	; 
#	$ports_ref->{'udp'}{'2576'}{'name'} = 'tclprodebugger'		; 
#	$srvcobjects_ref->{'tclprodebugger'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tclprodebugger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tclprodebugger'}{'port'}{'tcp'} = '2576'	; 
#	$srvcobjects_ref->{'tclprodebugger'}{'ports'}{'tcp'}{'2576'}++	; 
#	$ports_ref->{'tcp'}{'2576'}{'name'} = 'tclprodebugger'		; 
#	$srvcobjects_ref->{'qbikgdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qbikgdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qbikgdp'}{'port'}{'udp'} = '368'	; 
#	$srvcobjects_ref->{'qbikgdp'}{'ports'}{'udp'}{'368'}++	; 
#	$ports_ref->{'udp'}{'368'}{'name'} = 'qbikgdp'		; 
#	$srvcobjects_ref->{'qbikgdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qbikgdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qbikgdp'}{'port'}{'tcp'} = '368'	; 
#	$srvcobjects_ref->{'qbikgdp'}{'ports'}{'tcp'}{'368'}++	; 
#	$ports_ref->{'tcp'}{'368'}{'name'} = 'qbikgdp'		; 
#	$srvcobjects_ref->{'servstat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'servstat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servstat'}{'port'}{'udp'} = '633'	; 
#	$srvcobjects_ref->{'servstat'}{'ports'}{'udp'}{'633'}++	; 
#	$ports_ref->{'udp'}{'633'}{'name'} = 'servstat'		; 
#	$srvcobjects_ref->{'servstat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'servstat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servstat'}{'port'}{'tcp'} = '633'	; 
#	$srvcobjects_ref->{'servstat'}{'ports'}{'tcp'}{'633'}++	; 
#	$ports_ref->{'tcp'}{'633'}{'name'} = 'servstat'		; 
#	$srvcobjects_ref->{'ace-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ace-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-server'}{'port'}{'udp'} = '2475'	; 
#	$srvcobjects_ref->{'ace-server'}{'ports'}{'udp'}{'2475'}++	; 
#	$ports_ref->{'udp'}{'2475'}{'name'} = 'ace-server'		; 
#	$srvcobjects_ref->{'ace-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ace-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ace-server'}{'port'}{'tcp'} = '2475'	; 
#	$srvcobjects_ref->{'ace-server'}{'ports'}{'tcp'}{'2475'}++	; 
#	$ports_ref->{'tcp'}{'2475'}{'name'} = 'ace-server'		; 
#	$srvcobjects_ref->{'decap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'decap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decap'}{'port'}{'udp'} = '403'	; 
#	$srvcobjects_ref->{'decap'}{'ports'}{'udp'}{'403'}++	; 
#	$ports_ref->{'udp'}{'403'}{'name'} = 'decap'		; 
#	$srvcobjects_ref->{'decap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'decap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decap'}{'port'}{'tcp'} = '403'	; 
#	$srvcobjects_ref->{'decap'}{'ports'}{'tcp'}{'403'}++	; 
#	$ports_ref->{'tcp'}{'403'}{'name'} = 'decap'		; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'port'}{'udp'} = '3037'	; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'ports'}{'udp'}{'3037'}++	; 
#	$ports_ref->{'udp'}{'3037'}{'name'} = 'hp-san-mgmt'		; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'port'}{'tcp'} = '3037'	; 
#	$srvcobjects_ref->{'hp-san-mgmt'}{'ports'}{'tcp'}{'3037'}++	; 
#	$ports_ref->{'tcp'}{'3037'}{'name'} = 'hp-san-mgmt'		; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'port'}{'udp'} = '2690'	; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'ports'}{'udp'}{'2690'}++	; 
#	$ports_ref->{'udp'}{'2690'}{'name'} = 'hp-nnm-data'		; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'port'}{'tcp'} = '2690'	; 
#	$srvcobjects_ref->{'hp-nnm-data'}{'ports'}{'tcp'}{'2690'}++	; 
#	$ports_ref->{'tcp'}{'2690'}{'name'} = 'hp-nnm-data'		; 
#	$srvcobjects_ref->{'icap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icap'}{'port'}{'udp'} = '1344'	; 
#	$srvcobjects_ref->{'icap'}{'ports'}{'udp'}{'1344'}++	; 
#	$ports_ref->{'udp'}{'1344'}{'name'} = 'icap'		; 
#	$srvcobjects_ref->{'icap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icap'}{'port'}{'tcp'} = '1344'	; 
#	$srvcobjects_ref->{'icap'}{'ports'}{'tcp'}{'1344'}++	; 
#	$ports_ref->{'tcp'}{'1344'}{'name'} = 'icap'		; 
#	$srvcobjects_ref->{'wap-wsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-wsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp'}{'port'}{'udp'} = '9200'	; 
#	$srvcobjects_ref->{'wap-wsp'}{'ports'}{'udp'}{'9200'}++	; 
#	$ports_ref->{'udp'}{'9200'}{'name'} = 'wap-wsp'		; 
#	$srvcobjects_ref->{'wap-wsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-wsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-wsp'}{'port'}{'tcp'} = '9200'	; 
#	$srvcobjects_ref->{'wap-wsp'}{'ports'}{'tcp'}{'9200'}++	; 
#	$ports_ref->{'tcp'}{'9200'}{'name'} = 'wap-wsp'		; 
#	$srvcobjects_ref->{'hlserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hlserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hlserver'}{'port'}{'udp'} = '3047'	; 
#	$srvcobjects_ref->{'hlserver'}{'ports'}{'udp'}{'3047'}++	; 
#	$ports_ref->{'udp'}{'3047'}{'name'} = 'hlserver'		; 
#	$srvcobjects_ref->{'hlserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hlserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hlserver'}{'port'}{'udp'} = '1947'	; 
#	$srvcobjects_ref->{'hlserver'}{'ports'}{'udp'}{'1947'}++	; 
#	$ports_ref->{'udp'}{'1947'}{'name'} = 'hlserver'		; 
#	$srvcobjects_ref->{'hlserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hlserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hlserver'}{'port'}{'tcp'} = '3047'	; 
#	$srvcobjects_ref->{'hlserver'}{'ports'}{'tcp'}{'3047'}++	; 
#	$ports_ref->{'tcp'}{'3047'}{'name'} = 'hlserver'		; 
#	$srvcobjects_ref->{'hlserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hlserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hlserver'}{'port'}{'tcp'} = '1947'	; 
#	$srvcobjects_ref->{'hlserver'}{'ports'}{'tcp'}{'1947'}++	; 
#	$ports_ref->{'tcp'}{'1947'}{'name'} = 'hlserver'		; 
#	$srvcobjects_ref->{'csms2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csms2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csms2'}{'port'}{'udp'} = '3400'	; 
#	$srvcobjects_ref->{'csms2'}{'ports'}{'udp'}{'3400'}++	; 
#	$ports_ref->{'udp'}{'3400'}{'name'} = 'csms2'		; 
#	$srvcobjects_ref->{'csms2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csms2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csms2'}{'port'}{'tcp'} = '3400'	; 
#	$srvcobjects_ref->{'csms2'}{'ports'}{'tcp'}{'3400'}++	; 
#	$ports_ref->{'tcp'}{'3400'}{'name'} = 'csms2'		; 
#	$srvcobjects_ref->{'router'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'router'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'router'}{'port'}{'udp'} = '520'	; 
#	$srvcobjects_ref->{'router'}{'ports'}{'udp'}{'520'}++	; 
#	$ports_ref->{'udp'}{'520'}{'name'} = 'router'		; 
#	$srvcobjects_ref->{'apogeex-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apogeex-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apogeex-port'}{'port'}{'udp'} = '3184'	; 
#	$srvcobjects_ref->{'apogeex-port'}{'ports'}{'udp'}{'3184'}++	; 
#	$ports_ref->{'udp'}{'3184'}{'name'} = 'apogeex-port'		; 
#	$srvcobjects_ref->{'apogeex-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apogeex-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apogeex-port'}{'port'}{'tcp'} = '3184'	; 
#	$srvcobjects_ref->{'apogeex-port'}{'ports'}{'tcp'}{'3184'}++	; 
#	$ports_ref->{'tcp'}{'3184'}{'name'} = 'apogeex-port'		; 
#	$srvcobjects_ref->{'ddi-udp-6'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddi-udp-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-udp-6'}{'port'}{'udp'} = '8893'	; 
#	$srvcobjects_ref->{'ddi-udp-6'}{'ports'}{'udp'}{'8893'}++	; 
#	$ports_ref->{'udp'}{'8893'}{'name'} = 'ddi-udp-6'		; 
#	$srvcobjects_ref->{'cdid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cdid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdid'}{'port'}{'udp'} = '3315'	; 
#	$srvcobjects_ref->{'cdid'}{'ports'}{'udp'}{'3315'}++	; 
#	$ports_ref->{'udp'}{'3315'}{'name'} = 'cdid'		; 
#	$srvcobjects_ref->{'cdid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cdid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdid'}{'port'}{'tcp'} = '3315'	; 
#	$srvcobjects_ref->{'cdid'}{'ports'}{'tcp'}{'3315'}++	; 
#	$ports_ref->{'tcp'}{'3315'}{'name'} = 'cdid'		; 
#	$srvcobjects_ref->{'llsurfup-https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'llsurfup-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llsurfup-https'}{'port'}{'udp'} = '1184'	; 
#	$srvcobjects_ref->{'llsurfup-https'}{'ports'}{'udp'}{'1184'}++	; 
#	$ports_ref->{'udp'}{'1184'}{'name'} = 'llsurfup-https'		; 
#	$srvcobjects_ref->{'llsurfup-https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'llsurfup-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llsurfup-https'}{'port'}{'tcp'} = '1184'	; 
#	$srvcobjects_ref->{'llsurfup-https'}{'ports'}{'tcp'}{'1184'}++	; 
#	$ports_ref->{'tcp'}{'1184'}{'name'} = 'llsurfup-https'		; 
#	$srvcobjects_ref->{'tcoflashagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tcoflashagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcoflashagent'}{'port'}{'udp'} = '1975'	; 
#	$srvcobjects_ref->{'tcoflashagent'}{'ports'}{'udp'}{'1975'}++	; 
#	$ports_ref->{'udp'}{'1975'}{'name'} = 'tcoflashagent'		; 
#	$srvcobjects_ref->{'tcoflashagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcoflashagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcoflashagent'}{'port'}{'tcp'} = '1975'	; 
#	$srvcobjects_ref->{'tcoflashagent'}{'ports'}{'tcp'}{'1975'}++	; 
#	$ports_ref->{'tcp'}{'1975'}{'name'} = 'tcoflashagent'		; 
#	$srvcobjects_ref->{'proshare1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proshare1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare1'}{'port'}{'udp'} = '1459'	; 
#	$srvcobjects_ref->{'proshare1'}{'ports'}{'udp'}{'1459'}++	; 
#	$ports_ref->{'udp'}{'1459'}{'name'} = 'proshare1'		; 
#	$srvcobjects_ref->{'proshare1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proshare1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare1'}{'port'}{'tcp'} = '1459'	; 
#	$srvcobjects_ref->{'proshare1'}{'ports'}{'tcp'}{'1459'}++	; 
#	$ports_ref->{'tcp'}{'1459'}{'name'} = 'proshare1'		; 
#	$srvcobjects_ref->{'trap-daemon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trap-daemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trap-daemon'}{'port'}{'udp'} = '3600'	; 
#	$srvcobjects_ref->{'trap-daemon'}{'ports'}{'udp'}{'3600'}++	; 
#	$ports_ref->{'udp'}{'3600'}{'name'} = 'trap-daemon'		; 
#	$srvcobjects_ref->{'trap-daemon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trap-daemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trap-daemon'}{'port'}{'tcp'} = '3600'	; 
#	$srvcobjects_ref->{'trap-daemon'}{'ports'}{'tcp'}{'3600'}++	; 
#	$ports_ref->{'tcp'}{'3600'}{'name'} = 'trap-daemon'		; 
#	$srvcobjects_ref->{'remote-kis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remote-kis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-kis'}{'port'}{'udp'} = '185'	; 
#	$srvcobjects_ref->{'remote-kis'}{'ports'}{'udp'}{'185'}++	; 
#	$ports_ref->{'udp'}{'185'}{'name'} = 'remote-kis'		; 
#	$srvcobjects_ref->{'remote-kis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remote-kis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-kis'}{'port'}{'tcp'} = '185'	; 
#	$srvcobjects_ref->{'remote-kis'}{'ports'}{'tcp'}{'185'}++	; 
#	$ports_ref->{'tcp'}{'185'}{'name'} = 'remote-kis'		; 
#	$srvcobjects_ref->{'fxp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fxp'}{'port'}{'udp'} = '2849'	; 
#	$srvcobjects_ref->{'fxp'}{'ports'}{'udp'}{'2849'}++	; 
#	$ports_ref->{'udp'}{'2849'}{'name'} = 'fxp'		; 
#	$srvcobjects_ref->{'fxp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fxp'}{'port'}{'tcp'} = '2849'	; 
#	$srvcobjects_ref->{'fxp'}{'ports'}{'tcp'}{'2849'}++	; 
#	$ports_ref->{'tcp'}{'2849'}{'name'} = 'fxp'		; 
#	$srvcobjects_ref->{'rapidbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rapidbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapidbase'}{'port'}{'udp'} = '1953'	; 
#	$srvcobjects_ref->{'rapidbase'}{'ports'}{'udp'}{'1953'}++	; 
#	$ports_ref->{'udp'}{'1953'}{'name'} = 'rapidbase'		; 
#	$srvcobjects_ref->{'rapidbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rapidbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapidbase'}{'port'}{'tcp'} = '1953'	; 
#	$srvcobjects_ref->{'rapidbase'}{'ports'}{'tcp'}{'1953'}++	; 
#	$ports_ref->{'tcp'}{'1953'}{'name'} = 'rapidbase'		; 
#	$srvcobjects_ref->{'dsmcc-config'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsmcc-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-config'}{'port'}{'udp'} = '13818'	; 
#	$srvcobjects_ref->{'dsmcc-config'}{'ports'}{'udp'}{'13818'}++	; 
#	$ports_ref->{'udp'}{'13818'}{'name'} = 'dsmcc-config'		; 
#	$srvcobjects_ref->{'dsmcc-config'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsmcc-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-config'}{'port'}{'tcp'} = '13818'	; 
#	$srvcobjects_ref->{'dsmcc-config'}{'ports'}{'tcp'}{'13818'}++	; 
#	$ports_ref->{'tcp'}{'13818'}{'name'} = 'dsmcc-config'		; 
#	$srvcobjects_ref->{'ipx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipx'}{'port'}{'udp'} = '213'	; 
#	$srvcobjects_ref->{'ipx'}{'ports'}{'udp'}{'213'}++	; 
#	$ports_ref->{'udp'}{'213'}{'name'} = 'ipx'		; 
#	$srvcobjects_ref->{'ipx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipx'}{'port'}{'tcp'} = '213'	; 
#	$srvcobjects_ref->{'ipx'}{'ports'}{'tcp'}{'213'}++	; 
#	$ports_ref->{'tcp'}{'213'}{'name'} = 'ipx'		; 
#	$srvcobjects_ref->{'vid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vid'}{'port'}{'udp'} = '769'	; 
#	$srvcobjects_ref->{'vid'}{'ports'}{'udp'}{'769'}++	; 
#	$ports_ref->{'udp'}{'769'}{'name'} = 'vid'		; 
#	$srvcobjects_ref->{'vid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vid'}{'port'}{'tcp'} = '769'	; 
#	$srvcobjects_ref->{'vid'}{'ports'}{'tcp'}{'769'}++	; 
#	$ports_ref->{'tcp'}{'769'}{'name'} = 'vid'		; 
#	$srvcobjects_ref->{'i-zipqd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'i-zipqd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'i-zipqd'}{'port'}{'udp'} = '13160'	; 
#	$srvcobjects_ref->{'i-zipqd'}{'ports'}{'udp'}{'13160'}++	; 
#	$ports_ref->{'udp'}{'13160'}{'name'} = 'i-zipqd'		; 
#	$srvcobjects_ref->{'i-zipqd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'i-zipqd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'i-zipqd'}{'port'}{'tcp'} = '13160'	; 
#	$srvcobjects_ref->{'i-zipqd'}{'ports'}{'tcp'}{'13160'}++	; 
#	$ports_ref->{'tcp'}{'13160'}{'name'} = 'i-zipqd'		; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'port'}{'udp'} = '2121'	; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'ports'}{'udp'}{'2121'}++	; 
#	$ports_ref->{'udp'}{'2121'}{'name'} = 'scientia-ssdb'		; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'port'}{'tcp'} = '2121'	; 
#	$srvcobjects_ref->{'scientia-ssdb'}{'ports'}{'tcp'}{'2121'}++	; 
#	$ports_ref->{'tcp'}{'2121'}{'name'} = 'scientia-ssdb'		; 
#	$srvcobjects_ref->{'garcon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'garcon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'garcon'}{'port'}{'tcp'} = '999'	; 
#	$srvcobjects_ref->{'garcon'}{'ports'}{'tcp'}{'999'}++	; 
#	$ports_ref->{'tcp'}{'999'}{'name'} = 'garcon'		; 
#	$srvcobjects_ref->{'afs3-errors'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-errors'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-errors'}{'port'}{'udp'} = '7006'	; 
#	$srvcobjects_ref->{'afs3-errors'}{'ports'}{'udp'}{'7006'}++	; 
#	$ports_ref->{'udp'}{'7006'}{'name'} = 'afs3-errors'		; 
#	$srvcobjects_ref->{'afs3-errors'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-errors'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-errors'}{'port'}{'tcp'} = '7006'	; 
#	$srvcobjects_ref->{'afs3-errors'}{'ports'}{'tcp'}{'7006'}++	; 
#	$ports_ref->{'tcp'}{'7006'}{'name'} = 'afs3-errors'		; 
#	$srvcobjects_ref->{'oi-2000'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oi-2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oi-2000'}{'port'}{'udp'} = '2364'	; 
#	$srvcobjects_ref->{'oi-2000'}{'ports'}{'udp'}{'2364'}++	; 
#	$ports_ref->{'udp'}{'2364'}{'name'} = 'oi-2000'		; 
#	$srvcobjects_ref->{'oi-2000'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oi-2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oi-2000'}{'port'}{'tcp'} = '2364'	; 
#	$srvcobjects_ref->{'oi-2000'}{'ports'}{'tcp'}{'2364'}++	; 
#	$ports_ref->{'tcp'}{'2364'}{'name'} = 'oi-2000'		; 
#	$srvcobjects_ref->{'irc-serv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'irc-serv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irc-serv'}{'port'}{'udp'} = '529'	; 
#	$srvcobjects_ref->{'irc-serv'}{'ports'}{'udp'}{'529'}++	; 
#	$ports_ref->{'udp'}{'529'}{'name'} = 'irc-serv'		; 
#	$srvcobjects_ref->{'irc-serv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'irc-serv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irc-serv'}{'port'}{'tcp'} = '529'	; 
#	$srvcobjects_ref->{'irc-serv'}{'ports'}{'tcp'}{'529'}++	; 
#	$ports_ref->{'tcp'}{'529'}{'name'} = 'irc-serv'		; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'port'}{'udp'} = '3717'	; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'ports'}{'udp'}{'3717'}++	; 
#	$ports_ref->{'udp'}{'3717'}{'name'} = 'wv-csp-udp-cir'		; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'port'}{'tcp'} = '3717'	; 
#	$srvcobjects_ref->{'wv-csp-udp-cir'}{'ports'}{'tcp'}{'3717'}++	; 
#	$ports_ref->{'tcp'}{'3717'}{'name'} = 'wv-csp-udp-cir'		; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'port'}{'udp'} = '2847'	; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'ports'}{'udp'}{'2847'}++	; 
#	$ports_ref->{'udp'}{'2847'}{'name'} = 'aimpp-port-req'		; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'port'}{'tcp'} = '2847'	; 
#	$srvcobjects_ref->{'aimpp-port-req'}{'ports'}{'tcp'}{'2847'}++	; 
#	$ports_ref->{'tcp'}{'2847'}{'name'} = 'aimpp-port-req'		; 
#	$srvcobjects_ref->{'vatp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vatp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vatp'}{'port'}{'udp'} = '690'	; 
#	$srvcobjects_ref->{'vatp'}{'ports'}{'udp'}{'690'}++	; 
#	$ports_ref->{'udp'}{'690'}{'name'} = 'vatp'		; 
#	$srvcobjects_ref->{'vatp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vatp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vatp'}{'port'}{'tcp'} = '690'	; 
#	$srvcobjects_ref->{'vatp'}{'ports'}{'tcp'}{'690'}++	; 
#	$ports_ref->{'tcp'}{'690'}{'name'} = 'vatp'		; 
#	$srvcobjects_ref->{'vsixml'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsixml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsixml'}{'port'}{'udp'} = '2996'	; 
#	$srvcobjects_ref->{'vsixml'}{'ports'}{'udp'}{'2996'}++	; 
#	$ports_ref->{'udp'}{'2996'}{'name'} = 'vsixml'		; 
#	$srvcobjects_ref->{'vsixml'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsixml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsixml'}{'port'}{'tcp'} = '2996'	; 
#	$srvcobjects_ref->{'vsixml'}{'ports'}{'tcp'}{'2996'}++	; 
#	$ports_ref->{'tcp'}{'2996'}{'name'} = 'vsixml'		; 
#	$srvcobjects_ref->{'cisco-tna'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cisco-tna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-tna'}{'port'}{'udp'} = '131'	; 
#	$srvcobjects_ref->{'cisco-tna'}{'ports'}{'udp'}{'131'}++	; 
#	$ports_ref->{'udp'}{'131'}{'name'} = 'cisco-tna'		; 
#	$srvcobjects_ref->{'cisco-tna'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cisco-tna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-tna'}{'port'}{'tcp'} = '131'	; 
#	$srvcobjects_ref->{'cisco-tna'}{'ports'}{'tcp'}{'131'}++	; 
#	$ports_ref->{'tcp'}{'131'}{'name'} = 'cisco-tna'		; 
#	$srvcobjects_ref->{'uuidgen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uuidgen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uuidgen'}{'port'}{'udp'} = '697'	; 
#	$srvcobjects_ref->{'uuidgen'}{'ports'}{'udp'}{'697'}++	; 
#	$ports_ref->{'udp'}{'697'}{'name'} = 'uuidgen'		; 
#	$srvcobjects_ref->{'uuidgen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uuidgen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uuidgen'}{'port'}{'tcp'} = '697'	; 
#	$srvcobjects_ref->{'uuidgen'}{'ports'}{'tcp'}{'697'}++	; 
#	$ports_ref->{'tcp'}{'697'}{'name'} = 'uuidgen'		; 
#	$srvcobjects_ref->{'netarx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netarx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netarx'}{'port'}{'udp'} = '1040'	; 
#	$srvcobjects_ref->{'netarx'}{'ports'}{'udp'}{'1040'}++	; 
#	$ports_ref->{'udp'}{'1040'}{'name'} = 'netarx'		; 
#	$srvcobjects_ref->{'netarx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netarx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netarx'}{'port'}{'tcp'} = '1040'	; 
#	$srvcobjects_ref->{'netarx'}{'ports'}{'tcp'}{'1040'}++	; 
#	$ports_ref->{'tcp'}{'1040'}{'name'} = 'netarx'		; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'port'}{'udp'} = '1416'	; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'ports'}{'udp'}{'1416'}++	; 
#	$ports_ref->{'udp'}{'1416'}{'name'} = 'novell-lu6.2'		; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'port'}{'tcp'} = '1416'	; 
#	$srvcobjects_ref->{'novell-lu6.2'}{'ports'}{'tcp'}{'1416'}++	; 
#	$ports_ref->{'tcp'}{'1416'}{'name'} = 'novell-lu6.2'		; 
#	$srvcobjects_ref->{'t1distproc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'t1distproc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t1distproc'}{'port'}{'udp'} = '1274'	; 
#	$srvcobjects_ref->{'t1distproc'}{'ports'}{'udp'}{'1274'}++	; 
#	$ports_ref->{'udp'}{'1274'}{'name'} = 't1distproc'		; 
#	$srvcobjects_ref->{'t1distproc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'t1distproc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t1distproc'}{'port'}{'tcp'} = '1274'	; 
#	$srvcobjects_ref->{'t1distproc'}{'ports'}{'tcp'}{'1274'}++	; 
#	$ports_ref->{'tcp'}{'1274'}{'name'} = 't1distproc'		; 
#	$srvcobjects_ref->{'ddi-tcp-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddi-tcp-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-tcp-4'}{'port'}{'tcp'} = '8891'	; 
#	$srvcobjects_ref->{'ddi-tcp-4'}{'ports'}{'tcp'}{'8891'}++	; 
#	$ports_ref->{'tcp'}{'8891'}{'name'} = 'ddi-tcp-4'		; 
#	$srvcobjects_ref->{'aimpp-hello'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aimpp-hello'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aimpp-hello'}{'port'}{'udp'} = '2846'	; 
#	$srvcobjects_ref->{'aimpp-hello'}{'ports'}{'udp'}{'2846'}++	; 
#	$ports_ref->{'udp'}{'2846'}{'name'} = 'aimpp-hello'		; 
#	$srvcobjects_ref->{'aimpp-hello'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aimpp-hello'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aimpp-hello'}{'port'}{'tcp'} = '2846'	; 
#	$srvcobjects_ref->{'aimpp-hello'}{'ports'}{'tcp'}{'2846'}++	; 
#	$ports_ref->{'tcp'}{'2846'}{'name'} = 'aimpp-hello'		; 
#	$srvcobjects_ref->{'smux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smux'}{'port'}{'udp'} = '199'	; 
#	$srvcobjects_ref->{'smux'}{'ports'}{'udp'}{'199'}++	; 
#	$ports_ref->{'udp'}{'199'}{'name'} = 'smux'		; 
#	$srvcobjects_ref->{'smux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smux'}{'port'}{'tcp'} = '199'	; 
#	$srvcobjects_ref->{'smux'}{'ports'}{'tcp'}{'199'}++	; 
#	$ports_ref->{'tcp'}{'199'}{'name'} = 'smux'		; 
#	$srvcobjects_ref->{'interworld'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interworld'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interworld'}{'port'}{'udp'} = '3548'	; 
#	$srvcobjects_ref->{'interworld'}{'ports'}{'udp'}{'3548'}++	; 
#	$ports_ref->{'udp'}{'3548'}{'name'} = 'interworld'		; 
#	$srvcobjects_ref->{'interworld'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interworld'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interworld'}{'port'}{'tcp'} = '3548'	; 
#	$srvcobjects_ref->{'interworld'}{'ports'}{'tcp'}{'3548'}++	; 
#	$ports_ref->{'tcp'}{'3548'}{'name'} = 'interworld'		; 
#	$srvcobjects_ref->{'lnvmailmon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lnvmailmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvmailmon'}{'port'}{'udp'} = '2285'	; 
#	$srvcobjects_ref->{'lnvmailmon'}{'ports'}{'udp'}{'2285'}++	; 
#	$ports_ref->{'udp'}{'2285'}{'name'} = 'lnvmailmon'		; 
#	$srvcobjects_ref->{'lnvmailmon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lnvmailmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvmailmon'}{'port'}{'tcp'} = '2285'	; 
#	$srvcobjects_ref->{'lnvmailmon'}{'ports'}{'tcp'}{'2285'}++	; 
#	$ports_ref->{'tcp'}{'2285'}{'name'} = 'lnvmailmon'		; 
#	$srvcobjects_ref->{'src'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'src'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'src'}{'port'}{'udp'} = '200'	; 
#	$srvcobjects_ref->{'src'}{'ports'}{'udp'}{'200'}++	; 
#	$ports_ref->{'udp'}{'200'}{'name'} = 'src'		; 
#	$srvcobjects_ref->{'src'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'src'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'src'}{'port'}{'tcp'} = '200'	; 
#	$srvcobjects_ref->{'src'}{'ports'}{'tcp'}{'200'}++	; 
#	$ports_ref->{'tcp'}{'200'}{'name'} = 'src'		; 
#	$srvcobjects_ref->{'supdup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'supdup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'supdup'}{'port'}{'udp'} = '95'	; 
#	$srvcobjects_ref->{'supdup'}{'ports'}{'udp'}{'95'}++	; 
#	$ports_ref->{'udp'}{'95'}{'name'} = 'supdup'		; 
#	$srvcobjects_ref->{'supdup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'supdup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'supdup'}{'port'}{'tcp'} = '95'	; 
#	$srvcobjects_ref->{'supdup'}{'ports'}{'tcp'}{'95'}++	; 
#	$ports_ref->{'tcp'}{'95'}{'name'} = 'supdup'		; 
#	$srvcobjects_ref->{'canocentral1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'canocentral1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canocentral1'}{'port'}{'udp'} = '1872'	; 
#	$srvcobjects_ref->{'canocentral1'}{'ports'}{'udp'}{'1872'}++	; 
#	$ports_ref->{'udp'}{'1872'}{'name'} = 'canocentral1'		; 
#	$srvcobjects_ref->{'canocentral1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'canocentral1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canocentral1'}{'port'}{'tcp'} = '1872'	; 
#	$srvcobjects_ref->{'canocentral1'}{'ports'}{'tcp'}{'1872'}++	; 
#	$ports_ref->{'tcp'}{'1872'}{'name'} = 'canocentral1'		; 
#	$srvcobjects_ref->{'citriximaclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'citriximaclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citriximaclient'}{'port'}{'udp'} = '2598'	; 
#	$srvcobjects_ref->{'citriximaclient'}{'ports'}{'udp'}{'2598'}++	; 
#	$ports_ref->{'udp'}{'2598'}{'name'} = 'citriximaclient'		; 
#	$srvcobjects_ref->{'citriximaclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'citriximaclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citriximaclient'}{'port'}{'tcp'} = '2598'	; 
#	$srvcobjects_ref->{'citriximaclient'}{'ports'}{'tcp'}{'2598'}++	; 
#	$ports_ref->{'tcp'}{'2598'}{'name'} = 'citriximaclient'		; 
#	$srvcobjects_ref->{'olsr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'olsr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'olsr'}{'port'}{'udp'} = '698'	; 
#	$srvcobjects_ref->{'olsr'}{'ports'}{'udp'}{'698'}++	; 
#	$ports_ref->{'udp'}{'698'}{'name'} = 'olsr'		; 
#	$srvcobjects_ref->{'olsr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'olsr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'olsr'}{'port'}{'tcp'} = '698'	; 
#	$srvcobjects_ref->{'olsr'}{'ports'}{'tcp'}{'698'}++	; 
#	$ports_ref->{'tcp'}{'698'}{'name'} = 'olsr'		; 
#	$srvcobjects_ref->{'lrs-paging'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lrs-paging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lrs-paging'}{'port'}{'udp'} = '3700'	; 
#	$srvcobjects_ref->{'lrs-paging'}{'ports'}{'udp'}{'3700'}++	; 
#	$ports_ref->{'udp'}{'3700'}{'name'} = 'lrs-paging'		; 
#	$srvcobjects_ref->{'lrs-paging'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lrs-paging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lrs-paging'}{'port'}{'tcp'} = '3700'	; 
#	$srvcobjects_ref->{'lrs-paging'}{'ports'}{'tcp'}{'3700'}++	; 
#	$ports_ref->{'tcp'}{'3700'}{'name'} = 'lrs-paging'		; 
#	$srvcobjects_ref->{'mvx-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mvx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mvx-lm'}{'port'}{'udp'} = '1510'	; 
#	$srvcobjects_ref->{'mvx-lm'}{'ports'}{'udp'}{'1510'}++	; 
#	$ports_ref->{'udp'}{'1510'}{'name'} = 'mvx-lm'		; 
#	$srvcobjects_ref->{'mvx-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mvx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mvx-lm'}{'port'}{'tcp'} = '1510'	; 
#	$srvcobjects_ref->{'mvx-lm'}{'ports'}{'tcp'}{'1510'}++	; 
#	$ports_ref->{'tcp'}{'1510'}{'name'} = 'mvx-lm'		; 
#	$srvcobjects_ref->{'watchdognt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'watchdognt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watchdognt'}{'port'}{'udp'} = '2723'	; 
#	$srvcobjects_ref->{'watchdognt'}{'ports'}{'udp'}{'2723'}++	; 
#	$ports_ref->{'udp'}{'2723'}{'name'} = 'watchdognt'		; 
#	$srvcobjects_ref->{'watchdognt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'watchdognt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watchdognt'}{'port'}{'tcp'} = '2723'	; 
#	$srvcobjects_ref->{'watchdognt'}{'ports'}{'tcp'}{'2723'}++	; 
#	$ports_ref->{'tcp'}{'2723'}{'name'} = 'watchdognt'		; 
#	$srvcobjects_ref->{'scanstat-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scanstat-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scanstat-1'}{'port'}{'udp'} = '1215'	; 
#	$srvcobjects_ref->{'scanstat-1'}{'ports'}{'udp'}{'1215'}++	; 
#	$ports_ref->{'udp'}{'1215'}{'name'} = 'scanstat-1'		; 
#	$srvcobjects_ref->{'scanstat-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scanstat-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scanstat-1'}{'port'}{'tcp'} = '1215'	; 
#	$srvcobjects_ref->{'scanstat-1'}{'ports'}{'tcp'}{'1215'}++	; 
#	$ports_ref->{'tcp'}{'1215'}{'name'} = 'scanstat-1'		; 
#	$srvcobjects_ref->{'impera'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'impera'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'impera'}{'port'}{'udp'} = '1710'	; 
#	$srvcobjects_ref->{'impera'}{'ports'}{'udp'}{'1710'}++	; 
#	$ports_ref->{'udp'}{'1710'}{'name'} = 'impera'		; 
#	$srvcobjects_ref->{'impera'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'impera'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'impera'}{'port'}{'tcp'} = '1710'	; 
#	$srvcobjects_ref->{'impera'}{'ports'}{'tcp'}{'1710'}++	; 
#	$ports_ref->{'tcp'}{'1710'}{'name'} = 'impera'		; 
#	$srvcobjects_ref->{'send'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'send'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'send'}{'port'}{'udp'} = '169'	; 
#	$srvcobjects_ref->{'send'}{'ports'}{'udp'}{'169'}++	; 
#	$ports_ref->{'udp'}{'169'}{'name'} = 'send'		; 
#	$srvcobjects_ref->{'send'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'send'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'send'}{'port'}{'tcp'} = '169'	; 
#	$srvcobjects_ref->{'send'}{'ports'}{'tcp'}{'169'}++	; 
#	$ports_ref->{'tcp'}{'169'}{'name'} = 'send'		; 
#	$srvcobjects_ref->{'kastenxpipe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kastenxpipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kastenxpipe'}{'port'}{'udp'} = '36865'	; 
#	$srvcobjects_ref->{'kastenxpipe'}{'ports'}{'udp'}{'36865'}++	; 
#	$ports_ref->{'udp'}{'36865'}{'name'} = 'kastenxpipe'		; 
#	$srvcobjects_ref->{'kastenxpipe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kastenxpipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kastenxpipe'}{'port'}{'tcp'} = '36865'	; 
#	$srvcobjects_ref->{'kastenxpipe'}{'ports'}{'tcp'}{'36865'}++	; 
#	$ports_ref->{'tcp'}{'36865'}{'name'} = 'kastenxpipe'		; 
#	$srvcobjects_ref->{'npp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'npp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npp'}{'port'}{'udp'} = '92'	; 
#	$srvcobjects_ref->{'npp'}{'ports'}{'udp'}{'92'}++	; 
#	$ports_ref->{'udp'}{'92'}{'name'} = 'npp'		; 
#	$srvcobjects_ref->{'npp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'npp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npp'}{'port'}{'tcp'} = '92'	; 
#	$srvcobjects_ref->{'npp'}{'ports'}{'tcp'}{'92'}++	; 
#	$ports_ref->{'tcp'}{'92'}{'name'} = 'npp'		; 
#	$srvcobjects_ref->{'slm-api'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slm-api'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slm-api'}{'port'}{'udp'} = '1606'	; 
#	$srvcobjects_ref->{'slm-api'}{'ports'}{'udp'}{'1606'}++	; 
#	$ports_ref->{'udp'}{'1606'}{'name'} = 'slm-api'		; 
#	$srvcobjects_ref->{'slm-api'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slm-api'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slm-api'}{'port'}{'tcp'} = '1606'	; 
#	$srvcobjects_ref->{'slm-api'}{'ports'}{'tcp'}{'1606'}++	; 
#	$ports_ref->{'tcp'}{'1606'}{'name'} = 'slm-api'		; 
#	$srvcobjects_ref->{'xgrid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xgrid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xgrid'}{'port'}{'udp'} = '4111'	; 
#	$srvcobjects_ref->{'xgrid'}{'ports'}{'udp'}{'4111'}++	; 
#	$ports_ref->{'udp'}{'4111'}{'name'} = 'xgrid'		; 
#	$srvcobjects_ref->{'xgrid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xgrid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xgrid'}{'port'}{'tcp'} = '4111'	; 
#	$srvcobjects_ref->{'xgrid'}{'ports'}{'tcp'}{'4111'}++	; 
#	$ports_ref->{'tcp'}{'4111'}{'name'} = 'xgrid'		; 
#	$srvcobjects_ref->{'backroomnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'backroomnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'backroomnet'}{'port'}{'udp'} = '3387'	; 
#	$srvcobjects_ref->{'backroomnet'}{'ports'}{'udp'}{'3387'}++	; 
#	$ports_ref->{'udp'}{'3387'}{'name'} = 'backroomnet'		; 
#	$srvcobjects_ref->{'backroomnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'backroomnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'backroomnet'}{'port'}{'tcp'} = '3387'	; 
#	$srvcobjects_ref->{'backroomnet'}{'ports'}{'tcp'}{'3387'}++	; 
#	$ports_ref->{'tcp'}{'3387'}{'name'} = 'backroomnet'		; 
#	$srvcobjects_ref->{'jmevt2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmevt2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmevt2'}{'port'}{'udp'} = '6962'	; 
#	$srvcobjects_ref->{'jmevt2'}{'ports'}{'udp'}{'6962'}++	; 
#	$ports_ref->{'udp'}{'6962'}{'name'} = 'jmevt2'		; 
#	$srvcobjects_ref->{'jmevt2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmevt2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmevt2'}{'port'}{'tcp'} = '6962'	; 
#	$srvcobjects_ref->{'jmevt2'}{'ports'}{'tcp'}{'6962'}++	; 
#	$ports_ref->{'tcp'}{'6962'}{'name'} = 'jmevt2'		; 
#	$srvcobjects_ref->{'silverplatter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'silverplatter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silverplatter'}{'port'}{'udp'} = '416'	; 
#	$srvcobjects_ref->{'silverplatter'}{'ports'}{'udp'}{'416'}++	; 
#	$ports_ref->{'udp'}{'416'}{'name'} = 'silverplatter'		; 
#	$srvcobjects_ref->{'silverplatter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'silverplatter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silverplatter'}{'port'}{'tcp'} = '416'	; 
#	$srvcobjects_ref->{'silverplatter'}{'ports'}{'tcp'}{'416'}++	; 
#	$ports_ref->{'tcp'}{'416'}{'name'} = 'silverplatter'		; 
#	$srvcobjects_ref->{'nuts_dem'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nuts_dem'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nuts_dem'}{'port'}{'udp'} = '4132'	; 
#	$srvcobjects_ref->{'nuts_dem'}{'ports'}{'udp'}{'4132'}++	; 
#	$ports_ref->{'udp'}{'4132'}{'name'} = 'nuts_dem'		; 
#	$srvcobjects_ref->{'nuts_dem'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nuts_dem'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nuts_dem'}{'port'}{'tcp'} = '4132'	; 
#	$srvcobjects_ref->{'nuts_dem'}{'ports'}{'tcp'}{'4132'}++	; 
#	$ports_ref->{'tcp'}{'4132'}{'name'} = 'nuts_dem'		; 
#	$srvcobjects_ref->{'d2000kernel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d2000kernel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2000kernel'}{'port'}{'udp'} = '3119'	; 
#	$srvcobjects_ref->{'d2000kernel'}{'ports'}{'udp'}{'3119'}++	; 
#	$ports_ref->{'udp'}{'3119'}{'name'} = 'd2000kernel'		; 
#	$srvcobjects_ref->{'d2000kernel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d2000kernel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2000kernel'}{'port'}{'tcp'} = '3119'	; 
#	$srvcobjects_ref->{'d2000kernel'}{'ports'}{'tcp'}{'3119'}++	; 
#	$ports_ref->{'tcp'}{'3119'}{'name'} = 'd2000kernel'		; 
#	$srvcobjects_ref->{'sip-tls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sip-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sip-tls'}{'port'}{'udp'} = '5061'	; 
#	$srvcobjects_ref->{'sip-tls'}{'ports'}{'udp'}{'5061'}++	; 
#	$ports_ref->{'udp'}{'5061'}{'name'} = 'sip-tls'		; 
#	$srvcobjects_ref->{'sip-tls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sip-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sip-tls'}{'port'}{'tcp'} = '5061'	; 
#	$srvcobjects_ref->{'sip-tls'}{'ports'}{'tcp'}{'5061'}++	; 
#	$ports_ref->{'tcp'}{'5061'}{'name'} = 'sip-tls'		; 
#	$srvcobjects_ref->{'gttp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gttp'}{'port'}{'udp'} = '3693'	; 
#	$srvcobjects_ref->{'gttp'}{'ports'}{'udp'}{'3693'}++	; 
#	$ports_ref->{'udp'}{'3693'}{'name'} = 'gttp'		; 
#	$srvcobjects_ref->{'gttp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gttp'}{'port'}{'tcp'} = '3693'	; 
#	$srvcobjects_ref->{'gttp'}{'ports'}{'tcp'}{'3693'}++	; 
#	$ports_ref->{'tcp'}{'3693'}{'name'} = 'gttp'		; 
#	$srvcobjects_ref->{'connlcli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'connlcli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connlcli'}{'port'}{'udp'} = '1358'	; 
#	$srvcobjects_ref->{'connlcli'}{'ports'}{'udp'}{'1358'}++	; 
#	$ports_ref->{'udp'}{'1358'}{'name'} = 'connlcli'		; 
#	$srvcobjects_ref->{'connlcli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'connlcli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connlcli'}{'port'}{'tcp'} = '1358'	; 
#	$srvcobjects_ref->{'connlcli'}{'ports'}{'tcp'}{'1358'}++	; 
#	$ports_ref->{'tcp'}{'1358'}{'name'} = 'connlcli'		; 
#	$srvcobjects_ref->{'jms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jms'}{'port'}{'udp'} = '5673'	; 
#	$srvcobjects_ref->{'jms'}{'ports'}{'udp'}{'5673'}++	; 
#	$ports_ref->{'udp'}{'5673'}{'name'} = 'jms'		; 
#	$srvcobjects_ref->{'jms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jms'}{'port'}{'tcp'} = '5673'	; 
#	$srvcobjects_ref->{'jms'}{'ports'}{'tcp'}{'5673'}++	; 
#	$ports_ref->{'tcp'}{'5673'}{'name'} = 'jms'		; 
#	$srvcobjects_ref->{'rrp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrp'}{'port'}{'udp'} = '648'	; 
#	$srvcobjects_ref->{'rrp'}{'ports'}{'udp'}{'648'}++	; 
#	$ports_ref->{'udp'}{'648'}{'name'} = 'rrp'		; 
#	$srvcobjects_ref->{'rrp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrp'}{'port'}{'tcp'} = '648'	; 
#	$srvcobjects_ref->{'rrp'}{'ports'}{'tcp'}{'648'}++	; 
#	$ports_ref->{'tcp'}{'648'}{'name'} = 'rrp'		; 
#	$srvcobjects_ref->{'netcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcp'}{'port'}{'udp'} = '395'	; 
#	$srvcobjects_ref->{'netcp'}{'ports'}{'udp'}{'395'}++	; 
#	$ports_ref->{'udp'}{'395'}{'name'} = 'netcp'		; 
#	$srvcobjects_ref->{'netcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcp'}{'port'}{'tcp'} = '395'	; 
#	$srvcobjects_ref->{'netcp'}{'ports'}{'tcp'}{'395'}++	; 
#	$ports_ref->{'tcp'}{'395'}{'name'} = 'netcp'		; 
#	$srvcobjects_ref->{'res-sap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'res-sap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'res-sap'}{'port'}{'udp'} = '3163'	; 
#	$srvcobjects_ref->{'res-sap'}{'ports'}{'udp'}{'3163'}++	; 
#	$ports_ref->{'udp'}{'3163'}{'name'} = 'res-sap'		; 
#	$srvcobjects_ref->{'res-sap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'res-sap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'res-sap'}{'port'}{'tcp'} = '3163'	; 
#	$srvcobjects_ref->{'res-sap'}{'ports'}{'tcp'}{'3163'}++	; 
#	$ports_ref->{'tcp'}{'3163'}{'name'} = 'res-sap'		; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'port'}{'udp'} = '2099'	; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'ports'}{'udp'}{'2099'}++	; 
#	$ports_ref->{'udp'}{'2099'}{'name'} = 'h2250-annex-g'		; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'port'}{'tcp'} = '2099'	; 
#	$srvcobjects_ref->{'h2250-annex-g'}{'ports'}{'tcp'}{'2099'}++	; 
#	$ports_ref->{'tcp'}{'2099'}{'name'} = 'h2250-annex-g'		; 
#	$srvcobjects_ref->{'cpudpencap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cpudpencap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpudpencap'}{'port'}{'udp'} = '2746'	; 
#	$srvcobjects_ref->{'cpudpencap'}{'ports'}{'udp'}{'2746'}++	; 
#	$ports_ref->{'udp'}{'2746'}{'name'} = 'cpudpencap'		; 
#	$srvcobjects_ref->{'cpudpencap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cpudpencap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpudpencap'}{'port'}{'tcp'} = '2746'	; 
#	$srvcobjects_ref->{'cpudpencap'}{'ports'}{'tcp'}{'2746'}++	; 
#	$ports_ref->{'tcp'}{'2746'}{'name'} = 'cpudpencap'		; 
#	$srvcobjects_ref->{'x25-svc-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'x25-svc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x25-svc-port'}{'port'}{'udp'} = '1998'	; 
#	$srvcobjects_ref->{'x25-svc-port'}{'ports'}{'udp'}{'1998'}++	; 
#	$ports_ref->{'udp'}{'1998'}{'name'} = 'x25-svc-port'		; 
#	$srvcobjects_ref->{'x25-svc-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'x25-svc-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x25-svc-port'}{'port'}{'tcp'} = '1998'	; 
#	$srvcobjects_ref->{'x25-svc-port'}{'ports'}{'tcp'}{'1998'}++	; 
#	$ports_ref->{'tcp'}{'1998'}{'name'} = 'x25-svc-port'		; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'port'}{'udp'} = '1656'	; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'ports'}{'udp'}{'1656'}++	; 
#	$ports_ref->{'udp'}{'1656'}{'name'} = 'dec-mbadmin-h'		; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'port'}{'tcp'} = '1656'	; 
#	$srvcobjects_ref->{'dec-mbadmin-h'}{'ports'}{'tcp'}{'1656'}++	; 
#	$ports_ref->{'tcp'}{'1656'}{'name'} = 'dec-mbadmin-h'		; 
#	$srvcobjects_ref->{'rellpack'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rellpack'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rellpack'}{'port'}{'udp'} = '2018'	; 
#	$srvcobjects_ref->{'rellpack'}{'ports'}{'udp'}{'2018'}++	; 
#	$ports_ref->{'udp'}{'2018'}{'name'} = 'rellpack'		; 
#	$srvcobjects_ref->{'sixnetudr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sixnetudr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sixnetudr'}{'port'}{'udp'} = '1658'	; 
#	$srvcobjects_ref->{'sixnetudr'}{'ports'}{'udp'}{'1658'}++	; 
#	$ports_ref->{'udp'}{'1658'}{'name'} = 'sixnetudr'		; 
#	$srvcobjects_ref->{'sixnetudr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sixnetudr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sixnetudr'}{'port'}{'tcp'} = '1658'	; 
#	$srvcobjects_ref->{'sixnetudr'}{'ports'}{'tcp'}{'1658'}++	; 
#	$ports_ref->{'tcp'}{'1658'}{'name'} = 'sixnetudr'		; 
#	$srvcobjects_ref->{'mdns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mdns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdns'}{'port'}{'udp'} = '5353'	; 
#	$srvcobjects_ref->{'mdns'}{'ports'}{'udp'}{'5353'}++	; 
#	$ports_ref->{'udp'}{'5353'}{'name'} = 'mdns'		; 
#	$srvcobjects_ref->{'mdns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mdns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdns'}{'port'}{'tcp'} = '5353'	; 
#	$srvcobjects_ref->{'mdns'}{'ports'}{'tcp'}{'5353'}++	; 
#	$ports_ref->{'tcp'}{'5353'}{'name'} = 'mdns'		; 
#	$srvcobjects_ref->{'molly'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'molly'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'molly'}{'port'}{'udp'} = '1374'	; 
#	$srvcobjects_ref->{'molly'}{'ports'}{'udp'}{'1374'}++	; 
#	$ports_ref->{'udp'}{'1374'}{'name'} = 'molly'		; 
#	$srvcobjects_ref->{'molly'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'molly'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'molly'}{'port'}{'tcp'} = '1374'	; 
#	$srvcobjects_ref->{'molly'}{'ports'}{'tcp'}{'1374'}++	; 
#	$ports_ref->{'tcp'}{'1374'}{'name'} = 'molly'		; 
#	$srvcobjects_ref->{'jwalkserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jwalkserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jwalkserver'}{'port'}{'udp'} = '1289'	; 
#	$srvcobjects_ref->{'jwalkserver'}{'ports'}{'udp'}{'1289'}++	; 
#	$ports_ref->{'udp'}{'1289'}{'name'} = 'jwalkserver'		; 
#	$srvcobjects_ref->{'jwalkserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jwalkserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jwalkserver'}{'port'}{'tcp'} = '1289'	; 
#	$srvcobjects_ref->{'jwalkserver'}{'ports'}{'tcp'}{'1289'}++	; 
#	$ports_ref->{'tcp'}{'1289'}{'name'} = 'jwalkserver'		; 
#	$srvcobjects_ref->{'officelink2000'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'officelink2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'officelink2000'}{'port'}{'udp'} = '3320'	; 
#	$srvcobjects_ref->{'officelink2000'}{'ports'}{'udp'}{'3320'}++	; 
#	$ports_ref->{'udp'}{'3320'}{'name'} = 'officelink2000'		; 
#	$srvcobjects_ref->{'officelink2000'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'officelink2000'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'officelink2000'}{'port'}{'tcp'} = '3320'	; 
#	$srvcobjects_ref->{'officelink2000'}{'ports'}{'tcp'}{'3320'}++	; 
#	$ports_ref->{'tcp'}{'3320'}{'name'} = 'officelink2000'		; 
#	$srvcobjects_ref->{'ls3bcast'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ls3bcast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ls3bcast'}{'port'}{'udp'} = '3068'	; 
#	$srvcobjects_ref->{'ls3bcast'}{'ports'}{'udp'}{'3068'}++	; 
#	$ports_ref->{'udp'}{'3068'}{'name'} = 'ls3bcast'		; 
#	$srvcobjects_ref->{'ls3bcast'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ls3bcast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ls3bcast'}{'port'}{'tcp'} = '3068'	; 
#	$srvcobjects_ref->{'ls3bcast'}{'ports'}{'tcp'}{'3068'}++	; 
#	$ports_ref->{'tcp'}{'3068'}{'name'} = 'ls3bcast'		; 
#	$srvcobjects_ref->{'srp-feedback'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'srp-feedback'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srp-feedback'}{'port'}{'udp'} = '2737'	; 
#	$srvcobjects_ref->{'srp-feedback'}{'ports'}{'udp'}{'2737'}++	; 
#	$ports_ref->{'udp'}{'2737'}{'name'} = 'srp-feedback'		; 
#	$srvcobjects_ref->{'srp-feedback'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'srp-feedback'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srp-feedback'}{'port'}{'tcp'} = '2737'	; 
#	$srvcobjects_ref->{'srp-feedback'}{'ports'}{'tcp'}{'2737'}++	; 
#	$ports_ref->{'tcp'}{'2737'}{'name'} = 'srp-feedback'		; 
#	$srvcobjects_ref->{'k-block'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'k-block'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'k-block'}{'port'}{'udp'} = '287'	; 
#	$srvcobjects_ref->{'k-block'}{'ports'}{'udp'}{'287'}++	; 
#	$ports_ref->{'udp'}{'287'}{'name'} = 'k-block'		; 
#	$srvcobjects_ref->{'k-block'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'k-block'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'k-block'}{'port'}{'tcp'} = '287'	; 
#	$srvcobjects_ref->{'k-block'}{'ports'}{'tcp'}{'287'}++	; 
#	$ports_ref->{'tcp'}{'287'}{'name'} = 'k-block'		; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'port'}{'udp'} = '1107'	; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'ports'}{'udp'}{'1107'}++	; 
#	$ports_ref->{'udp'}{'1107'}{'name'} = 'isoipsigport-2'		; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'port'}{'tcp'} = '1107'	; 
#	$srvcobjects_ref->{'isoipsigport-2'}{'ports'}{'tcp'}{'1107'}++	; 
#	$ports_ref->{'tcp'}{'1107'}{'name'} = 'isoipsigport-2'		; 
#	$srvcobjects_ref->{'wrs_registry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wrs_registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wrs_registry'}{'port'}{'udp'} = '2340'	; 
#	$srvcobjects_ref->{'wrs_registry'}{'ports'}{'udp'}{'2340'}++	; 
#	$ports_ref->{'udp'}{'2340'}{'name'} = 'wrs_registry'		; 
#	$srvcobjects_ref->{'wrs_registry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wrs_registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wrs_registry'}{'port'}{'tcp'} = '2340'	; 
#	$srvcobjects_ref->{'wrs_registry'}{'ports'}{'tcp'}{'2340'}++	; 
#	$ports_ref->{'tcp'}{'2340'}{'name'} = 'wrs_registry'		; 
#	$srvcobjects_ref->{'websphere-snmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'websphere-snmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'websphere-snmp'}{'port'}{'udp'} = '3427'	; 
#	$srvcobjects_ref->{'websphere-snmp'}{'ports'}{'udp'}{'3427'}++	; 
#	$ports_ref->{'udp'}{'3427'}{'name'} = 'websphere-snmp'		; 
#	$srvcobjects_ref->{'websphere-snmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'websphere-snmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'websphere-snmp'}{'port'}{'tcp'} = '3427'	; 
#	$srvcobjects_ref->{'websphere-snmp'}{'ports'}{'tcp'}{'3427'}++	; 
#	$ports_ref->{'tcp'}{'3427'}{'name'} = 'websphere-snmp'		; 
#	$srvcobjects_ref->{'mailbox-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mailbox-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mailbox-lm'}{'port'}{'udp'} = '505'	; 
#	$srvcobjects_ref->{'mailbox-lm'}{'ports'}{'udp'}{'505'}++	; 
#	$ports_ref->{'udp'}{'505'}{'name'} = 'mailbox-lm'		; 
#	$srvcobjects_ref->{'mailbox-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mailbox-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mailbox-lm'}{'port'}{'tcp'} = '505'	; 
#	$srvcobjects_ref->{'mailbox-lm'}{'ports'}{'tcp'}{'505'}++	; 
#	$ports_ref->{'tcp'}{'505'}{'name'} = 'mailbox-lm'		; 
#	$srvcobjects_ref->{'npmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'npmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp'}{'port'}{'udp'} = '8450'	; 
#	$srvcobjects_ref->{'npmp'}{'ports'}{'udp'}{'8450'}++	; 
#	$ports_ref->{'udp'}{'8450'}{'name'} = 'npmp'		; 
#	$srvcobjects_ref->{'npmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'npmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp'}{'port'}{'tcp'} = '8450'	; 
#	$srvcobjects_ref->{'npmp'}{'ports'}{'tcp'}{'8450'}++	; 
#	$ports_ref->{'tcp'}{'8450'}{'name'} = 'npmp'		; 
#	$srvcobjects_ref->{'ttg-protocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttg-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttg-protocol'}{'port'}{'udp'} = '2862'	; 
#	$srvcobjects_ref->{'ttg-protocol'}{'ports'}{'udp'}{'2862'}++	; 
#	$ports_ref->{'udp'}{'2862'}{'name'} = 'ttg-protocol'		; 
#	$srvcobjects_ref->{'ttg-protocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttg-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttg-protocol'}{'port'}{'tcp'} = '2862'	; 
#	$srvcobjects_ref->{'ttg-protocol'}{'ports'}{'tcp'}{'2862'}++	; 
#	$ports_ref->{'tcp'}{'2862'}{'name'} = 'ttg-protocol'		; 
#	$srvcobjects_ref->{'vsiadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsiadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsiadmin'}{'port'}{'udp'} = '2539'	; 
#	$srvcobjects_ref->{'vsiadmin'}{'ports'}{'udp'}{'2539'}++	; 
#	$ports_ref->{'udp'}{'2539'}{'name'} = 'vsiadmin'		; 
#	$srvcobjects_ref->{'vsiadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsiadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsiadmin'}{'port'}{'tcp'} = '2539'	; 
#	$srvcobjects_ref->{'vsiadmin'}{'ports'}{'tcp'}{'2539'}++	; 
#	$ports_ref->{'tcp'}{'2539'}{'name'} = 'vsiadmin'		; 
#	$srvcobjects_ref->{'beeyond-media'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'beeyond-media'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beeyond-media'}{'port'}{'udp'} = '1943'	; 
#	$srvcobjects_ref->{'beeyond-media'}{'ports'}{'udp'}{'1943'}++	; 
#	$ports_ref->{'udp'}{'1943'}{'name'} = 'beeyond-media'		; 
#	$srvcobjects_ref->{'beeyond-media'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'beeyond-media'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beeyond-media'}{'port'}{'tcp'} = '1943'	; 
#	$srvcobjects_ref->{'beeyond-media'}{'ports'}{'tcp'}{'1943'}++	; 
#	$ports_ref->{'tcp'}{'1943'}{'name'} = 'beeyond-media'		; 
#	$srvcobjects_ref->{'vpncpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpncpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpncpp'}{'port'}{'udp'} = '3694'	; 
#	$srvcobjects_ref->{'vpncpp'}{'ports'}{'udp'}{'3694'}++	; 
#	$ports_ref->{'udp'}{'3694'}{'name'} = 'vpncpp'		; 
#	$srvcobjects_ref->{'vpncpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpncpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpncpp'}{'port'}{'tcp'} = '3694'	; 
#	$srvcobjects_ref->{'vpncpp'}{'ports'}{'tcp'}{'3694'}++	; 
#	$ports_ref->{'tcp'}{'3694'}{'name'} = 'vpncpp'		; 
#	$srvcobjects_ref->{'vspread'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vspread'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vspread'}{'port'}{'udp'} = '2695'	; 
#	$srvcobjects_ref->{'vspread'}{'ports'}{'udp'}{'2695'}++	; 
#	$ports_ref->{'udp'}{'2695'}{'name'} = 'vspread'		; 
#	$srvcobjects_ref->{'vspread'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vspread'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vspread'}{'port'}{'tcp'} = '2695'	; 
#	$srvcobjects_ref->{'vspread'}{'ports'}{'tcp'}{'2695'}++	; 
#	$ports_ref->{'tcp'}{'2695'}{'name'} = 'vspread'		; 
#	$srvcobjects_ref->{'finger'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'finger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'finger'}{'port'}{'udp'} = '79'	; 
#	$srvcobjects_ref->{'finger'}{'ports'}{'udp'}{'79'}++	; 
#	$ports_ref->{'udp'}{'79'}{'name'} = 'finger'		; 
#	$srvcobjects_ref->{'finger'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'finger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'finger'}{'port'}{'tcp'} = '79'	; 
#	$srvcobjects_ref->{'finger'}{'ports'}{'tcp'}{'79'}++	; 
#	$ports_ref->{'tcp'}{'79'}{'name'} = 'finger'		; 
#	$srvcobjects_ref->{'gdoi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gdoi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdoi'}{'port'}{'udp'} = '848'	; 
#	$srvcobjects_ref->{'gdoi'}{'ports'}{'udp'}{'848'}++	; 
#	$ports_ref->{'udp'}{'848'}{'name'} = 'gdoi'		; 
#	$srvcobjects_ref->{'gdoi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gdoi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdoi'}{'port'}{'tcp'} = '848'	; 
#	$srvcobjects_ref->{'gdoi'}{'ports'}{'tcp'}{'848'}++	; 
#	$ports_ref->{'tcp'}{'848'}{'name'} = 'gdoi'		; 
#	$srvcobjects_ref->{'talon-disc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talon-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talon-disc'}{'port'}{'udp'} = '7011'	; 
#	$srvcobjects_ref->{'talon-disc'}{'ports'}{'udp'}{'7011'}++	; 
#	$ports_ref->{'udp'}{'7011'}{'name'} = 'talon-disc'		; 
#	$srvcobjects_ref->{'talon-disc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talon-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talon-disc'}{'port'}{'tcp'} = '7011'	; 
#	$srvcobjects_ref->{'talon-disc'}{'ports'}{'tcp'}{'7011'}++	; 
#	$ports_ref->{'tcp'}{'7011'}{'name'} = 'talon-disc'		; 
#	$srvcobjects_ref->{'pcmail-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcmail-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcmail-srv'}{'port'}{'udp'} = '158'	; 
#	$srvcobjects_ref->{'pcmail-srv'}{'ports'}{'udp'}{'158'}++	; 
#	$ports_ref->{'udp'}{'158'}{'name'} = 'pcmail-srv'		; 
#	$srvcobjects_ref->{'pcmail-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcmail-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcmail-srv'}{'port'}{'tcp'} = '158'	; 
#	$srvcobjects_ref->{'pcmail-srv'}{'ports'}{'tcp'}{'158'}++	; 
#	$ports_ref->{'tcp'}{'158'}{'name'} = 'pcmail-srv'		; 
#	$srvcobjects_ref->{'event_listener'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'event_listener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'event_listener'}{'port'}{'udp'} = '3017'	; 
#	$srvcobjects_ref->{'event_listener'}{'ports'}{'udp'}{'3017'}++	; 
#	$ports_ref->{'udp'}{'3017'}{'name'} = 'event_listener'		; 
#	$srvcobjects_ref->{'event_listener'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'event_listener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'event_listener'}{'port'}{'tcp'} = '3017'	; 
#	$srvcobjects_ref->{'event_listener'}{'ports'}{'tcp'}{'3017'}++	; 
#	$ports_ref->{'tcp'}{'3017'}{'name'} = 'event_listener'		; 
#	$srvcobjects_ref->{'muse'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'muse'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'muse'}{'port'}{'udp'} = '6888'	; 
#	$srvcobjects_ref->{'muse'}{'ports'}{'udp'}{'6888'}++	; 
#	$ports_ref->{'udp'}{'6888'}{'name'} = 'muse'		; 
#	$srvcobjects_ref->{'muse'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'muse'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'muse'}{'port'}{'tcp'} = '6888'	; 
#	$srvcobjects_ref->{'muse'}{'ports'}{'tcp'}{'6888'}++	; 
#	$ports_ref->{'tcp'}{'6888'}{'name'} = 'muse'		; 
#	$srvcobjects_ref->{'tsb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tsb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsb'}{'port'}{'udp'} = '2741'	; 
#	$srvcobjects_ref->{'tsb'}{'ports'}{'udp'}{'2741'}++	; 
#	$ports_ref->{'udp'}{'2741'}{'name'} = 'tsb'		; 
#	$srvcobjects_ref->{'tsb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tsb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsb'}{'port'}{'tcp'} = '2741'	; 
#	$srvcobjects_ref->{'tsb'}{'ports'}{'tcp'}{'2741'}++	; 
#	$ports_ref->{'tcp'}{'2741'}{'name'} = 'tsb'		; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'port'}{'udp'} = '3181'	; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'ports'}{'udp'}{'3181'}++	; 
#	$ports_ref->{'udp'}{'3181'}{'name'} = 'bmcpatrolagent'		; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'port'}{'tcp'} = '3181'	; 
#	$srvcobjects_ref->{'bmcpatrolagent'}{'ports'}{'tcp'}{'3181'}++	; 
#	$ports_ref->{'tcp'}{'3181'}{'name'} = 'bmcpatrolagent'		; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'port'}{'udp'} = '2873'	; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'ports'}{'udp'}{'2873'}++	; 
#	$ports_ref->{'udp'}{'2873'}{'name'} = 'paspar2-zoomin'		; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'port'}{'tcp'} = '2873'	; 
#	$srvcobjects_ref->{'paspar2-zoomin'}{'ports'}{'tcp'}{'2873'}++	; 
#	$ports_ref->{'tcp'}{'2873'}{'name'} = 'paspar2-zoomin'		; 
#	$srvcobjects_ref->{'iec-104'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iec-104'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iec-104'}{'port'}{'udp'} = '2404'	; 
#	$srvcobjects_ref->{'iec-104'}{'ports'}{'udp'}{'2404'}++	; 
#	$ports_ref->{'udp'}{'2404'}{'name'} = 'iec-104'		; 
#	$srvcobjects_ref->{'iec-104'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iec-104'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iec-104'}{'port'}{'tcp'} = '2404'	; 
#	$srvcobjects_ref->{'iec-104'}{'ports'}{'tcp'}{'2404'}++	; 
#	$ports_ref->{'tcp'}{'2404'}{'name'} = 'iec-104'		; 
#	$srvcobjects_ref->{'dx-instrument'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dx-instrument'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dx-instrument'}{'port'}{'udp'} = '1325'	; 
#	$srvcobjects_ref->{'dx-instrument'}{'ports'}{'udp'}{'1325'}++	; 
#	$ports_ref->{'udp'}{'1325'}{'name'} = 'dx-instrument'		; 
#	$srvcobjects_ref->{'dx-instrument'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dx-instrument'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dx-instrument'}{'port'}{'tcp'} = '1325'	; 
#	$srvcobjects_ref->{'dx-instrument'}{'ports'}{'tcp'}{'1325'}++	; 
#	$ports_ref->{'tcp'}{'1325'}{'name'} = 'dx-instrument'		; 
#	$srvcobjects_ref->{'etc-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'etc-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etc-control'}{'port'}{'udp'} = '6107'	; 
#	$srvcobjects_ref->{'etc-control'}{'ports'}{'udp'}{'6107'}++	; 
#	$ports_ref->{'udp'}{'6107'}{'name'} = 'etc-control'		; 
#	$srvcobjects_ref->{'etc-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'etc-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etc-control'}{'port'}{'tcp'} = '6107'	; 
#	$srvcobjects_ref->{'etc-control'}{'ports'}{'tcp'}{'6107'}++	; 
#	$ports_ref->{'tcp'}{'6107'}{'name'} = 'etc-control'		; 
#	$srvcobjects_ref->{'iop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iop'}{'port'}{'udp'} = '2055'	; 
#	$srvcobjects_ref->{'iop'}{'ports'}{'udp'}{'2055'}++	; 
#	$ports_ref->{'udp'}{'2055'}{'name'} = 'iop'		; 
#	$srvcobjects_ref->{'iop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iop'}{'port'}{'tcp'} = '2055'	; 
#	$srvcobjects_ref->{'iop'}{'ports'}{'tcp'}{'2055'}++	; 
#	$ports_ref->{'tcp'}{'2055'}{'name'} = 'iop'		; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'port'}{'udp'} = '3394'	; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'ports'}{'udp'}{'3394'}++	; 
#	$ports_ref->{'udp'}{'3394'}{'name'} = 'd2k-tapestry2'		; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'port'}{'tcp'} = '3394'	; 
#	$srvcobjects_ref->{'d2k-tapestry2'}{'ports'}{'tcp'}{'3394'}++	; 
#	$ports_ref->{'tcp'}{'3394'}{'name'} = 'd2k-tapestry2'		; 
#	$srvcobjects_ref->{'print-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'print-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'print-srv'}{'port'}{'udp'} = '170'	; 
#	$srvcobjects_ref->{'print-srv'}{'ports'}{'udp'}{'170'}++	; 
#	$ports_ref->{'udp'}{'170'}{'name'} = 'print-srv'		; 
#	$srvcobjects_ref->{'print-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'print-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'print-srv'}{'port'}{'tcp'} = '170'	; 
#	$srvcobjects_ref->{'print-srv'}{'ports'}{'tcp'}{'170'}++	; 
#	$ports_ref->{'tcp'}{'170'}{'name'} = 'print-srv'		; 
#	$srvcobjects_ref->{'orbix-config'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orbix-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-config'}{'port'}{'udp'} = '3076'	; 
#	$srvcobjects_ref->{'orbix-config'}{'ports'}{'udp'}{'3076'}++	; 
#	$ports_ref->{'udp'}{'3076'}{'name'} = 'orbix-config'		; 
#	$srvcobjects_ref->{'orbix-config'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orbix-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-config'}{'port'}{'tcp'} = '3076'	; 
#	$srvcobjects_ref->{'orbix-config'}{'ports'}{'tcp'}{'3076'}++	; 
#	$ports_ref->{'tcp'}{'3076'}{'name'} = 'orbix-config'		; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'port'}{'udp'} = '557'	; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'ports'}{'udp'}{'557'}++	; 
#	$ports_ref->{'udp'}{'557'}{'name'} = 'openvms-sysipc'		; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'port'}{'tcp'} = '557'	; 
#	$srvcobjects_ref->{'openvms-sysipc'}{'ports'}{'tcp'}{'557'}++	; 
#	$ports_ref->{'tcp'}{'557'}{'name'} = 'openvms-sysipc'		; 
#	$srvcobjects_ref->{'trc-netpoll'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trc-netpoll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trc-netpoll'}{'port'}{'udp'} = '2405'	; 
#	$srvcobjects_ref->{'trc-netpoll'}{'ports'}{'udp'}{'2405'}++	; 
#	$ports_ref->{'udp'}{'2405'}{'name'} = 'trc-netpoll'		; 
#	$srvcobjects_ref->{'trc-netpoll'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trc-netpoll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trc-netpoll'}{'port'}{'tcp'} = '2405'	; 
#	$srvcobjects_ref->{'trc-netpoll'}{'ports'}{'tcp'}{'2405'}++	; 
#	$ports_ref->{'tcp'}{'2405'}{'name'} = 'trc-netpoll'		; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'port'}{'udp'} = '7392'	; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'ports'}{'udp'}{'7392'}++	; 
#	$ports_ref->{'udp'}{'7392'}{'name'} = 'mrssrendezvous'		; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'port'}{'tcp'} = '7392'	; 
#	$srvcobjects_ref->{'mrssrendezvous'}{'ports'}{'tcp'}{'7392'}++	; 
#	$ports_ref->{'tcp'}{'7392'}{'name'} = 'mrssrendezvous'		; 
#	$srvcobjects_ref->{'aises'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aises'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aises'}{'port'}{'udp'} = '2783'	; 
#	$srvcobjects_ref->{'aises'}{'ports'}{'udp'}{'2783'}++	; 
#	$ports_ref->{'udp'}{'2783'}{'name'} = 'aises'		; 
#	$srvcobjects_ref->{'aises'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aises'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aises'}{'port'}{'tcp'} = '2783'	; 
#	$srvcobjects_ref->{'aises'}{'ports'}{'tcp'}{'2783'}++	; 
#	$ports_ref->{'tcp'}{'2783'}{'name'} = 'aises'		; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'port'}{'udp'} = '3142'	; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'ports'}{'udp'}{'3142'}++	; 
#	$ports_ref->{'udp'}{'3142'}{'name'} = 'rdc-wh-eos'		; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'port'}{'tcp'} = '3142'	; 
#	$srvcobjects_ref->{'rdc-wh-eos'}{'ports'}{'tcp'}{'3142'}++	; 
#	$ports_ref->{'tcp'}{'3142'}{'name'} = 'rdc-wh-eos'		; 
#	$srvcobjects_ref->{'spamtrap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spamtrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spamtrap'}{'port'}{'udp'} = '2568'	; 
#	$srvcobjects_ref->{'spamtrap'}{'ports'}{'udp'}{'2568'}++	; 
#	$ports_ref->{'udp'}{'2568'}{'name'} = 'spamtrap'		; 
#	$srvcobjects_ref->{'spamtrap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spamtrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spamtrap'}{'port'}{'tcp'} = '2568'	; 
#	$srvcobjects_ref->{'spamtrap'}{'ports'}{'tcp'}{'2568'}++	; 
#	$ports_ref->{'tcp'}{'2568'}{'name'} = 'spamtrap'		; 
#	$srvcobjects_ref->{'microcom-sbp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'microcom-sbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microcom-sbp'}{'port'}{'udp'} = '1680'	; 
#	$srvcobjects_ref->{'microcom-sbp'}{'ports'}{'udp'}{'1680'}++	; 
#	$ports_ref->{'udp'}{'1680'}{'name'} = 'microcom-sbp'		; 
#	$srvcobjects_ref->{'microcom-sbp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'microcom-sbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microcom-sbp'}{'port'}{'tcp'} = '1680'	; 
#	$srvcobjects_ref->{'microcom-sbp'}{'ports'}{'tcp'}{'1680'}++	; 
#	$ports_ref->{'tcp'}{'1680'}{'name'} = 'microcom-sbp'		; 
#	$srvcobjects_ref->{'dproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dproxy'}{'port'}{'udp'} = '1296'	; 
#	$srvcobjects_ref->{'dproxy'}{'ports'}{'udp'}{'1296'}++	; 
#	$ports_ref->{'udp'}{'1296'}{'name'} = 'dproxy'		; 
#	$srvcobjects_ref->{'dproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dproxy'}{'port'}{'tcp'} = '1296'	; 
#	$srvcobjects_ref->{'dproxy'}{'ports'}{'tcp'}{'1296'}++	; 
#	$ports_ref->{'tcp'}{'1296'}{'name'} = 'dproxy'		; 
#	$srvcobjects_ref->{'delibo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'delibo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'delibo'}{'port'}{'udp'} = '2562'	; 
#	$srvcobjects_ref->{'delibo'}{'ports'}{'udp'}{'2562'}++	; 
#	$ports_ref->{'udp'}{'2562'}{'name'} = 'delibo'		; 
#	$srvcobjects_ref->{'delibo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'delibo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'delibo'}{'port'}{'tcp'} = '2562'	; 
#	$srvcobjects_ref->{'delibo'}{'ports'}{'tcp'}{'2562'}++	; 
#	$ports_ref->{'tcp'}{'2562'}{'name'} = 'delibo'		; 
#	$srvcobjects_ref->{'rasadv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rasadv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rasadv'}{'port'}{'udp'} = '9753'	; 
#	$srvcobjects_ref->{'rasadv'}{'ports'}{'udp'}{'9753'}++	; 
#	$ports_ref->{'udp'}{'9753'}{'name'} = 'rasadv'		; 
#	$srvcobjects_ref->{'rasadv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rasadv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rasadv'}{'port'}{'tcp'} = '9753'	; 
#	$srvcobjects_ref->{'rasadv'}{'ports'}{'tcp'}{'9753'}++	; 
#	$ports_ref->{'tcp'}{'9753'}{'name'} = 'rasadv'		; 
#	$srvcobjects_ref->{'imap3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imap3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imap3'}{'port'}{'udp'} = '220'	; 
#	$srvcobjects_ref->{'imap3'}{'ports'}{'udp'}{'220'}++	; 
#	$ports_ref->{'udp'}{'220'}{'name'} = 'imap3'		; 
#	$srvcobjects_ref->{'imap3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imap3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imap3'}{'port'}{'tcp'} = '220'	; 
#	$srvcobjects_ref->{'imap3'}{'ports'}{'tcp'}{'220'}++	; 
#	$ports_ref->{'tcp'}{'220'}{'name'} = 'imap3'		; 
#	$srvcobjects_ref->{'gv-us'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gv-us'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gv-us'}{'port'}{'udp'} = '1369'	; 
#	$srvcobjects_ref->{'gv-us'}{'ports'}{'udp'}{'1369'}++	; 
#	$ports_ref->{'udp'}{'1369'}{'name'} = 'gv-us'		; 
#	$srvcobjects_ref->{'gv-us'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gv-us'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gv-us'}{'port'}{'tcp'} = '1369'	; 
#	$srvcobjects_ref->{'gv-us'}{'ports'}{'tcp'}{'1369'}++	; 
#	$ports_ref->{'tcp'}{'1369'}{'name'} = 'gv-us'		; 
#	$srvcobjects_ref->{'miroconnect'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'miroconnect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miroconnect'}{'port'}{'udp'} = '1532'	; 
#	$srvcobjects_ref->{'miroconnect'}{'ports'}{'udp'}{'1532'}++	; 
#	$ports_ref->{'udp'}{'1532'}{'name'} = 'miroconnect'		; 
#	$srvcobjects_ref->{'miroconnect'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'miroconnect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miroconnect'}{'port'}{'tcp'} = '1532'	; 
#	$srvcobjects_ref->{'miroconnect'}{'ports'}{'tcp'}{'1532'}++	; 
#	$ports_ref->{'tcp'}{'1532'}{'name'} = 'miroconnect'		; 
#	$srvcobjects_ref->{'sflow'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sflow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sflow'}{'port'}{'udp'} = '6343'	; 
#	$srvcobjects_ref->{'sflow'}{'ports'}{'udp'}{'6343'}++	; 
#	$ports_ref->{'udp'}{'6343'}{'name'} = 'sflow'		; 
#	$srvcobjects_ref->{'sflow'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sflow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sflow'}{'port'}{'tcp'} = '6343'	; 
#	$srvcobjects_ref->{'sflow'}{'ports'}{'tcp'}{'6343'}++	; 
#	$ports_ref->{'tcp'}{'6343'}{'name'} = 'sflow'		; 
#	$srvcobjects_ref->{'ipcd3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipcd3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcd3'}{'port'}{'udp'} = '1209'	; 
#	$srvcobjects_ref->{'ipcd3'}{'ports'}{'udp'}{'1209'}++	; 
#	$ports_ref->{'udp'}{'1209'}{'name'} = 'ipcd3'		; 
#	$srvcobjects_ref->{'ipcd3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipcd3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcd3'}{'port'}{'tcp'} = '1209'	; 
#	$srvcobjects_ref->{'ipcd3'}{'ports'}{'tcp'}{'1209'}++	; 
#	$ports_ref->{'tcp'}{'1209'}{'name'} = 'ipcd3'		; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'port'}{'udp'} = '6999'	; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'ports'}{'udp'}{'6999'}++	; 
#	$ports_ref->{'udp'}{'6999'}{'name'} = 'iatp-normalpri'		; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'port'}{'tcp'} = '6999'	; 
#	$srvcobjects_ref->{'iatp-normalpri'}{'ports'}{'tcp'}{'6999'}++	; 
#	$ports_ref->{'tcp'}{'6999'}{'name'} = 'iatp-normalpri'		; 
#	$srvcobjects_ref->{'iad3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iad3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iad3'}{'port'}{'udp'} = '1032'	; 
#	$srvcobjects_ref->{'iad3'}{'ports'}{'udp'}{'1032'}++	; 
#	$ports_ref->{'udp'}{'1032'}{'name'} = 'iad3'		; 
#	$srvcobjects_ref->{'iad3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iad3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iad3'}{'port'}{'tcp'} = '1032'	; 
#	$srvcobjects_ref->{'iad3'}{'ports'}{'tcp'}{'1032'}++	; 
#	$ports_ref->{'tcp'}{'1032'}{'name'} = 'iad3'		; 
#	$srvcobjects_ref->{'profile'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'profile'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'profile'}{'port'}{'udp'} = '136'	; 
#	$srvcobjects_ref->{'profile'}{'ports'}{'udp'}{'136'}++	; 
#	$ports_ref->{'udp'}{'136'}{'name'} = 'profile'		; 
#	$srvcobjects_ref->{'profile'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'profile'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'profile'}{'port'}{'tcp'} = '136'	; 
#	$srvcobjects_ref->{'profile'}{'ports'}{'tcp'}{'136'}++	; 
#	$ports_ref->{'tcp'}{'136'}{'name'} = 'profile'		; 
#	$srvcobjects_ref->{'serverview-rm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'serverview-rm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-rm'}{'port'}{'udp'} = '3172'	; 
#	$srvcobjects_ref->{'serverview-rm'}{'ports'}{'udp'}{'3172'}++	; 
#	$ports_ref->{'udp'}{'3172'}{'name'} = 'serverview-rm'		; 
#	$srvcobjects_ref->{'serverview-rm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'serverview-rm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-rm'}{'port'}{'tcp'} = '3172'	; 
#	$srvcobjects_ref->{'serverview-rm'}{'ports'}{'tcp'}{'3172'}++	; 
#	$ports_ref->{'tcp'}{'3172'}{'name'} = 'serverview-rm'		; 
#	$srvcobjects_ref->{'914c/g'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'914c/g'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'914c/g'}{'port'}{'udp'} = '211'	; 
#	$srvcobjects_ref->{'914c/g'}{'ports'}{'udp'}{'211'}++	; 
#	$ports_ref->{'udp'}{'211'}{'name'} = '914c/g'		; 
#	$srvcobjects_ref->{'914c/g'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'914c/g'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'914c/g'}{'port'}{'tcp'} = '211'	; 
#	$srvcobjects_ref->{'914c/g'}{'ports'}{'tcp'}{'211'}++	; 
#	$ports_ref->{'tcp'}{'211'}{'name'} = '914c/g'		; 
#	$srvcobjects_ref->{'denali-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'denali-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'denali-server'}{'port'}{'udp'} = '3444'	; 
#	$srvcobjects_ref->{'denali-server'}{'ports'}{'udp'}{'3444'}++	; 
#	$ports_ref->{'udp'}{'3444'}{'name'} = 'denali-server'		; 
#	$srvcobjects_ref->{'denali-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'denali-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'denali-server'}{'port'}{'tcp'} = '3444'	; 
#	$srvcobjects_ref->{'denali-server'}{'ports'}{'tcp'}{'3444'}++	; 
#	$ports_ref->{'tcp'}{'3444'}{'name'} = 'denali-server'		; 
#	$srvcobjects_ref->{'netopia-vo5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netopia-vo5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo5'}{'port'}{'udp'} = '1843'	; 
#	$srvcobjects_ref->{'netopia-vo5'}{'ports'}{'udp'}{'1843'}++	; 
#	$ports_ref->{'udp'}{'1843'}{'name'} = 'netopia-vo5'		; 
#	$srvcobjects_ref->{'netopia-vo5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netopia-vo5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo5'}{'port'}{'tcp'} = '1843'	; 
#	$srvcobjects_ref->{'netopia-vo5'}{'ports'}{'tcp'}{'1843'}++	; 
#	$ports_ref->{'tcp'}{'1843'}{'name'} = 'netopia-vo5'		; 
#	$srvcobjects_ref->{'hp-clic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-clic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-clic'}{'port'}{'udp'} = '3384'	; 
#	$srvcobjects_ref->{'hp-clic'}{'ports'}{'udp'}{'3384'}++	; 
#	$ports_ref->{'udp'}{'3384'}{'name'} = 'hp-clic'		; 
#	$srvcobjects_ref->{'hp-clic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-clic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-clic'}{'port'}{'tcp'} = '3384'	; 
#	$srvcobjects_ref->{'hp-clic'}{'ports'}{'tcp'}{'3384'}++	; 
#	$ports_ref->{'tcp'}{'3384'}{'name'} = 'hp-clic'		; 
#	$srvcobjects_ref->{'gdp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gdp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdp-port'}{'port'}{'udp'} = '1997'	; 
#	$srvcobjects_ref->{'gdp-port'}{'ports'}{'udp'}{'1997'}++	; 
#	$ports_ref->{'udp'}{'1997'}{'name'} = 'gdp-port'		; 
#	$srvcobjects_ref->{'gdp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gdp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdp-port'}{'port'}{'tcp'} = '1997'	; 
#	$srvcobjects_ref->{'gdp-port'}{'ports'}{'tcp'}{'1997'}++	; 
#	$ports_ref->{'tcp'}{'1997'}{'name'} = 'gdp-port'		; 
#	$srvcobjects_ref->{'iso-ip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iso-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-ip'}{'port'}{'udp'} = '147'	; 
#	$srvcobjects_ref->{'iso-ip'}{'ports'}{'udp'}{'147'}++	; 
#	$ports_ref->{'udp'}{'147'}{'name'} = 'iso-ip'		; 
#	$srvcobjects_ref->{'iso-ip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iso-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-ip'}{'port'}{'tcp'} = '147'	; 
#	$srvcobjects_ref->{'iso-ip'}{'ports'}{'tcp'}{'147'}++	; 
#	$ports_ref->{'tcp'}{'147'}{'name'} = 'iso-ip'		; 
#	$srvcobjects_ref->{'saism'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'saism'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saism'}{'port'}{'udp'} = '1436'	; 
#	$srvcobjects_ref->{'saism'}{'ports'}{'udp'}{'1436'}++	; 
#	$ports_ref->{'udp'}{'1436'}{'name'} = 'saism'		; 
#	$srvcobjects_ref->{'saism'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'saism'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saism'}{'port'}{'tcp'} = '1436'	; 
#	$srvcobjects_ref->{'saism'}{'ports'}{'tcp'}{'1436'}++	; 
#	$ports_ref->{'tcp'}{'1436'}{'name'} = 'saism'		; 
#	$srvcobjects_ref->{'quest-launcher'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quest-launcher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quest-launcher'}{'port'}{'udp'} = '3566'	; 
#	$srvcobjects_ref->{'quest-launcher'}{'ports'}{'udp'}{'3566'}++	; 
#	$ports_ref->{'udp'}{'3566'}{'name'} = 'quest-launcher'		; 
#	$srvcobjects_ref->{'quest-launcher'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quest-launcher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quest-launcher'}{'port'}{'tcp'} = '3566'	; 
#	$srvcobjects_ref->{'quest-launcher'}{'ports'}{'tcp'}{'3566'}++	; 
#	$ports_ref->{'tcp'}{'3566'}{'name'} = 'quest-launcher'		; 
#	$srvcobjects_ref->{'agri-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'agri-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agri-gateway'}{'port'}{'udp'} = '3026'	; 
#	$srvcobjects_ref->{'agri-gateway'}{'ports'}{'udp'}{'3026'}++	; 
#	$ports_ref->{'udp'}{'3026'}{'name'} = 'agri-gateway'		; 
#	$srvcobjects_ref->{'agri-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'agri-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agri-gateway'}{'port'}{'tcp'} = '3026'	; 
#	$srvcobjects_ref->{'agri-gateway'}{'ports'}{'tcp'}{'3026'}++	; 
#	$ports_ref->{'tcp'}{'3026'}{'name'} = 'agri-gateway'		; 
#	$srvcobjects_ref->{'davinci'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'davinci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'davinci'}{'port'}{'udp'} = '2542'	; 
#	$srvcobjects_ref->{'davinci'}{'ports'}{'udp'}{'2542'}++	; 
#	$ports_ref->{'udp'}{'2542'}{'name'} = 'davinci'		; 
#	$srvcobjects_ref->{'davinci'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'davinci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'davinci'}{'port'}{'tcp'} = '2542'	; 
#	$srvcobjects_ref->{'davinci'}{'ports'}{'tcp'}{'2542'}++	; 
#	$ports_ref->{'tcp'}{'2542'}{'name'} = 'davinci'		; 
#	$srvcobjects_ref->{'irc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'irc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irc'}{'port'}{'udp'} = '194'	; 
#	$srvcobjects_ref->{'irc'}{'ports'}{'udp'}{'194'}++	; 
#	$ports_ref->{'udp'}{'194'}{'name'} = 'irc'		; 
#	$srvcobjects_ref->{'irc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'irc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irc'}{'port'}{'tcp'} = '194'	; 
#	$srvcobjects_ref->{'irc'}{'ports'}{'tcp'}{'194'}++	; 
#	$ports_ref->{'tcp'}{'194'}{'name'} = 'irc'		; 
#	$srvcobjects_ref->{'icl-twobase7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase7'}{'port'}{'udp'} = '25006'	; 
#	$srvcobjects_ref->{'icl-twobase7'}{'ports'}{'udp'}{'25006'}++	; 
#	$ports_ref->{'udp'}{'25006'}{'name'} = 'icl-twobase7'		; 
#	$srvcobjects_ref->{'icl-twobase7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase7'}{'port'}{'tcp'} = '25006'	; 
#	$srvcobjects_ref->{'icl-twobase7'}{'ports'}{'tcp'}{'25006'}++	; 
#	$ports_ref->{'tcp'}{'25006'}{'name'} = 'icl-twobase7'		; 
#	$srvcobjects_ref->{'ac-tech'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ac-tech'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ac-tech'}{'port'}{'udp'} = '2796'	; 
#	$srvcobjects_ref->{'ac-tech'}{'ports'}{'udp'}{'2796'}++	; 
#	$ports_ref->{'udp'}{'2796'}{'name'} = 'ac-tech'		; 
#	$srvcobjects_ref->{'ac-tech'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ac-tech'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ac-tech'}{'port'}{'tcp'} = '2796'	; 
#	$srvcobjects_ref->{'ac-tech'}{'ports'}{'tcp'}{'2796'}++	; 
#	$ports_ref->{'tcp'}{'2796'}{'name'} = 'ac-tech'		; 
#	$srvcobjects_ref->{'ewctsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ewctsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewctsp'}{'port'}{'udp'} = '6066'	; 
#	$srvcobjects_ref->{'ewctsp'}{'ports'}{'udp'}{'6066'}++	; 
#	$ports_ref->{'udp'}{'6066'}{'name'} = 'ewctsp'		; 
#	$srvcobjects_ref->{'ewctsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ewctsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewctsp'}{'port'}{'tcp'} = '6066'	; 
#	$srvcobjects_ref->{'ewctsp'}{'ports'}{'tcp'}{'6066'}++	; 
#	$ports_ref->{'tcp'}{'6066'}{'name'} = 'ewctsp'		; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'port'}{'udp'} = '85'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'ports'}{'udp'}{'85'}++	; 
#	$ports_ref->{'udp'}{'85'}{'name'} = 'mit-ml-dev'		; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'port'}{'udp'} = '83'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'ports'}{'udp'}{'83'}++	; 
#	$ports_ref->{'udp'}{'83'}{'name'} = 'mit-ml-dev'		; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'port'}{'tcp'} = '85'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'ports'}{'tcp'}{'85'}++	; 
#	$ports_ref->{'tcp'}{'85'}{'name'} = 'mit-ml-dev'		; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'port'}{'tcp'} = '83'	; 
#	$srvcobjects_ref->{'mit-ml-dev'}{'ports'}{'tcp'}{'83'}++	; 
#	$ports_ref->{'tcp'}{'83'}{'name'} = 'mit-ml-dev'		; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'port'}{'udp'} = '5042'	; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'ports'}{'udp'}{'5042'}++	; 
#	$ports_ref->{'udp'}{'5042'}{'name'} = 'asnaacceler8db'		; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'port'}{'tcp'} = '5042'	; 
#	$srvcobjects_ref->{'asnaacceler8db'}{'ports'}{'tcp'}{'5042'}++	; 
#	$ports_ref->{'tcp'}{'5042'}{'name'} = 'asnaacceler8db'		; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'port'}{'udp'} = '2439'	; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'ports'}{'udp'}{'2439'}++	; 
#	$ports_ref->{'udp'}{'2439'}{'name'} = 'sybasedbsynch'		; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'port'}{'tcp'} = '2439'	; 
#	$srvcobjects_ref->{'sybasedbsynch'}{'ports'}{'tcp'}{'2439'}++	; 
#	$ports_ref->{'tcp'}{'2439'}{'name'} = 'sybasedbsynch'		; 
#	$srvcobjects_ref->{'sqdr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sqdr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sqdr'}{'port'}{'udp'} = '2728'	; 
#	$srvcobjects_ref->{'sqdr'}{'ports'}{'udp'}{'2728'}++	; 
#	$ports_ref->{'udp'}{'2728'}{'name'} = 'sqdr'		; 
#	$srvcobjects_ref->{'sqdr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sqdr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sqdr'}{'port'}{'tcp'} = '2728'	; 
#	$srvcobjects_ref->{'sqdr'}{'ports'}{'tcp'}{'2728'}++	; 
#	$ports_ref->{'tcp'}{'2728'}{'name'} = 'sqdr'		; 
#	$srvcobjects_ref->{'timed'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timed'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timed'}{'port'}{'udp'} = '525'	; 
#	$srvcobjects_ref->{'timed'}{'ports'}{'udp'}{'525'}++	; 
#	$ports_ref->{'udp'}{'525'}{'name'} = 'timed'		; 
#	$srvcobjects_ref->{'timed'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timed'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timed'}{'port'}{'tcp'} = '525'	; 
#	$srvcobjects_ref->{'timed'}{'ports'}{'tcp'}{'525'}++	; 
#	$ports_ref->{'tcp'}{'525'}{'name'} = 'timed'		; 
#	$srvcobjects_ref->{'swismgr2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swismgr2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swismgr2'}{'port'}{'udp'} = '6964'	; 
#	$srvcobjects_ref->{'swismgr2'}{'ports'}{'udp'}{'6964'}++	; 
#	$ports_ref->{'udp'}{'6964'}{'name'} = 'swismgr2'		; 
#	$srvcobjects_ref->{'swismgr2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swismgr2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swismgr2'}{'port'}{'tcp'} = '6964'	; 
#	$srvcobjects_ref->{'swismgr2'}{'ports'}{'tcp'}{'6964'}++	; 
#	$ports_ref->{'tcp'}{'6964'}{'name'} = 'swismgr2'		; 
#	$srvcobjects_ref->{'anet-m'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anet-m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-m'}{'port'}{'udp'} = '3340'	; 
#	$srvcobjects_ref->{'anet-m'}{'ports'}{'udp'}{'3340'}++	; 
#	$ports_ref->{'udp'}{'3340'}{'name'} = 'anet-m'		; 
#	$srvcobjects_ref->{'anet-m'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anet-m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-m'}{'port'}{'tcp'} = '3340'	; 
#	$srvcobjects_ref->{'anet-m'}{'ports'}{'tcp'}{'3340'}++	; 
#	$ports_ref->{'tcp'}{'3340'}{'name'} = 'anet-m'		; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'port'}{'udp'} = '1498'	; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'ports'}{'udp'}{'1498'}++	; 
#	$ports_ref->{'udp'}{'1498'}{'name'} = 'sybase-sqlany'		; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'port'}{'tcp'} = '1498'	; 
#	$srvcobjects_ref->{'sybase-sqlany'}{'ports'}{'tcp'}{'1498'}++	; 
#	$ports_ref->{'tcp'}{'1498'}{'name'} = 'sybase-sqlany'		; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'port'}{'udp'} = '2523'	; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'ports'}{'udp'}{'2523'}++	; 
#	$ports_ref->{'udp'}{'2523'}{'name'} = 'qke-llc-v3'		; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'port'}{'tcp'} = '2523'	; 
#	$srvcobjects_ref->{'qke-llc-v3'}{'ports'}{'tcp'}{'2523'}++	; 
#	$ports_ref->{'tcp'}{'2523'}{'name'} = 'qke-llc-v3'		; 
#	$srvcobjects_ref->{'xns-time'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xns-time'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-time'}{'port'}{'udp'} = '52'	; 
#	$srvcobjects_ref->{'xns-time'}{'ports'}{'udp'}{'52'}++	; 
#	$ports_ref->{'udp'}{'52'}{'name'} = 'xns-time'		; 
#	$srvcobjects_ref->{'xns-time'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xns-time'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-time'}{'port'}{'tcp'} = '52'	; 
#	$srvcobjects_ref->{'xns-time'}{'ports'}{'tcp'}{'52'}++	; 
#	$ports_ref->{'tcp'}{'52'}{'name'} = 'xns-time'		; 
#	$srvcobjects_ref->{'csccredir'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csccredir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csccredir'}{'port'}{'udp'} = '40842'	; 
#	$srvcobjects_ref->{'csccredir'}{'ports'}{'udp'}{'40842'}++	; 
#	$ports_ref->{'udp'}{'40842'}{'name'} = 'csccredir'		; 
#	$srvcobjects_ref->{'csccredir'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csccredir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csccredir'}{'port'}{'tcp'} = '40842'	; 
#	$srvcobjects_ref->{'csccredir'}{'ports'}{'tcp'}{'40842'}++	; 
#	$ports_ref->{'tcp'}{'40842'}{'name'} = 'csccredir'		; 
#	$srvcobjects_ref->{'isomair'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isomair'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isomair'}{'port'}{'udp'} = '3589'	; 
#	$srvcobjects_ref->{'isomair'}{'ports'}{'udp'}{'3589'}++	; 
#	$ports_ref->{'udp'}{'3589'}{'name'} = 'isomair'		; 
#	$srvcobjects_ref->{'isomair'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isomair'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isomair'}{'port'}{'tcp'} = '3589'	; 
#	$srvcobjects_ref->{'isomair'}{'ports'}{'tcp'}{'3589'}++	; 
#	$ports_ref->{'tcp'}{'3589'}{'name'} = 'isomair'		; 
#	$srvcobjects_ref->{'pc-telecommute'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pc-telecommute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pc-telecommute'}{'port'}{'udp'} = '2299'	; 
#	$srvcobjects_ref->{'pc-telecommute'}{'ports'}{'udp'}{'2299'}++	; 
#	$ports_ref->{'udp'}{'2299'}{'name'} = 'pc-telecommute'		; 
#	$srvcobjects_ref->{'pc-telecommute'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pc-telecommute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pc-telecommute'}{'port'}{'tcp'} = '2299'	; 
#	$srvcobjects_ref->{'pc-telecommute'}{'ports'}{'tcp'}{'2299'}++	; 
#	$ports_ref->{'tcp'}{'2299'}{'name'} = 'pc-telecommute'		; 
#	$srvcobjects_ref->{'k3software-cli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'k3software-cli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'k3software-cli'}{'port'}{'udp'} = '26263'	; 
#	$srvcobjects_ref->{'k3software-cli'}{'ports'}{'udp'}{'26263'}++	; 
#	$ports_ref->{'udp'}{'26263'}{'name'} = 'k3software-cli'		; 
#	$srvcobjects_ref->{'k3software-cli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'k3software-cli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'k3software-cli'}{'port'}{'tcp'} = '26263'	; 
#	$srvcobjects_ref->{'k3software-cli'}{'ports'}{'tcp'}{'26263'}++	; 
#	$ports_ref->{'tcp'}{'26263'}{'name'} = 'k3software-cli'		; 
#	$srvcobjects_ref->{'informatik-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'informatik-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'informatik-lm'}{'port'}{'udp'} = '1428'	; 
#	$srvcobjects_ref->{'informatik-lm'}{'ports'}{'udp'}{'1428'}++	; 
#	$ports_ref->{'udp'}{'1428'}{'name'} = 'informatik-lm'		; 
#	$srvcobjects_ref->{'informatik-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'informatik-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'informatik-lm'}{'port'}{'tcp'} = '1428'	; 
#	$srvcobjects_ref->{'informatik-lm'}{'ports'}{'tcp'}{'1428'}++	; 
#	$ports_ref->{'tcp'}{'1428'}{'name'} = 'informatik-lm'		; 
#	$srvcobjects_ref->{'vista-4gl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vista-4gl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vista-4gl'}{'port'}{'udp'} = '24249'	; 
#	$srvcobjects_ref->{'vista-4gl'}{'ports'}{'udp'}{'24249'}++	; 
#	$ports_ref->{'udp'}{'24249'}{'name'} = 'vista-4gl'		; 
#	$srvcobjects_ref->{'vista-4gl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vista-4gl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vista-4gl'}{'port'}{'tcp'} = '24249'	; 
#	$srvcobjects_ref->{'vista-4gl'}{'ports'}{'tcp'}{'24249'}++	; 
#	$ports_ref->{'tcp'}{'24249'}{'name'} = 'vista-4gl'		; 
#	$srvcobjects_ref->{'netrcs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrcs'}{'port'}{'udp'} = '742'	; 
#	$srvcobjects_ref->{'netrcs'}{'ports'}{'udp'}{'742'}++	; 
#	$ports_ref->{'udp'}{'742'}{'name'} = 'netrcs'		; 
#	$srvcobjects_ref->{'netrcs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrcs'}{'port'}{'tcp'} = '742'	; 
#	$srvcobjects_ref->{'netrcs'}{'ports'}{'tcp'}{'742'}++	; 
#	$ports_ref->{'tcp'}{'742'}{'name'} = 'netrcs'		; 
#	$srvcobjects_ref->{'vcs-app'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vcs-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcs-app'}{'port'}{'udp'} = '14141'	; 
#	$srvcobjects_ref->{'vcs-app'}{'ports'}{'udp'}{'14141'}++	; 
#	$ports_ref->{'udp'}{'14141'}{'name'} = 'vcs-app'		; 
#	$srvcobjects_ref->{'vcs-app'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vcs-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vcs-app'}{'port'}{'tcp'} = '14141'	; 
#	$srvcobjects_ref->{'vcs-app'}{'ports'}{'tcp'}{'14141'}++	; 
#	$ports_ref->{'tcp'}{'14141'}{'name'} = 'vcs-app'		; 
#	$srvcobjects_ref->{'crs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'crs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crs'}{'port'}{'udp'} = '507'	; 
#	$srvcobjects_ref->{'crs'}{'ports'}{'udp'}{'507'}++	; 
#	$ports_ref->{'udp'}{'507'}{'name'} = 'crs'		; 
#	$srvcobjects_ref->{'crs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'crs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crs'}{'port'}{'tcp'} = '507'	; 
#	$srvcobjects_ref->{'crs'}{'ports'}{'tcp'}{'507'}++	; 
#	$ports_ref->{'tcp'}{'507'}{'name'} = 'crs'		; 
#	$srvcobjects_ref->{'nm-assessor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nm-assessor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-assessor'}{'port'}{'udp'} = '3151'	; 
#	$srvcobjects_ref->{'nm-assessor'}{'ports'}{'udp'}{'3151'}++	; 
#	$ports_ref->{'udp'}{'3151'}{'name'} = 'nm-assessor'		; 
#	$srvcobjects_ref->{'nm-assessor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nm-assessor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-assessor'}{'port'}{'tcp'} = '3151'	; 
#	$srvcobjects_ref->{'nm-assessor'}{'ports'}{'tcp'}{'3151'}++	; 
#	$ports_ref->{'tcp'}{'3151'}{'name'} = 'nm-assessor'		; 
#	$srvcobjects_ref->{'edix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edix'}{'port'}{'udp'} = '3123'	; 
#	$srvcobjects_ref->{'edix'}{'ports'}{'udp'}{'3123'}++	; 
#	$ports_ref->{'udp'}{'3123'}{'name'} = 'edix'		; 
#	$srvcobjects_ref->{'edix'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edix'}{'port'}{'tcp'} = '3123'	; 
#	$srvcobjects_ref->{'edix'}{'ports'}{'tcp'}{'3123'}++	; 
#	$ports_ref->{'tcp'}{'3123'}{'name'} = 'edix'		; 
#	$srvcobjects_ref->{'digivote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'digivote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digivote'}{'port'}{'udp'} = '3223'	; 
#	$srvcobjects_ref->{'digivote'}{'ports'}{'udp'}{'3223'}++	; 
#	$ports_ref->{'udp'}{'3223'}{'name'} = 'digivote'		; 
#	$srvcobjects_ref->{'digivote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'digivote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'digivote'}{'port'}{'tcp'} = '3223'	; 
#	$srvcobjects_ref->{'digivote'}{'ports'}{'tcp'}{'3223'}++	; 
#	$ports_ref->{'tcp'}{'3223'}{'name'} = 'digivote'		; 
#	$srvcobjects_ref->{'livestats'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'livestats'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'livestats'}{'port'}{'udp'} = '2795'	; 
#	$srvcobjects_ref->{'livestats'}{'ports'}{'udp'}{'2795'}++	; 
#	$ports_ref->{'udp'}{'2795'}{'name'} = 'livestats'		; 
#	$srvcobjects_ref->{'livestats'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'livestats'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'livestats'}{'port'}{'tcp'} = '2795'	; 
#	$srvcobjects_ref->{'livestats'}{'ports'}{'tcp'}{'2795'}++	; 
#	$ports_ref->{'tcp'}{'2795'}{'name'} = 'livestats'		; 
#	$srvcobjects_ref->{'raw-serial'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raw-serial'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raw-serial'}{'port'}{'udp'} = '2167'	; 
#	$srvcobjects_ref->{'raw-serial'}{'ports'}{'udp'}{'2167'}++	; 
#	$ports_ref->{'udp'}{'2167'}{'name'} = 'raw-serial'		; 
#	$srvcobjects_ref->{'raw-serial'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raw-serial'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raw-serial'}{'port'}{'tcp'} = '2167'	; 
#	$srvcobjects_ref->{'raw-serial'}{'ports'}{'tcp'}{'2167'}++	; 
#	$ports_ref->{'tcp'}{'2167'}{'name'} = 'raw-serial'		; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'port'}{'udp'} = '3609'	; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'ports'}{'udp'}{'3609'}++	; 
#	$ports_ref->{'udp'}{'3609'}{'name'} = 'cpdi-pidas-cm'		; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'port'}{'tcp'} = '3609'	; 
#	$srvcobjects_ref->{'cpdi-pidas-cm'}{'ports'}{'tcp'}{'3609'}++	; 
#	$ports_ref->{'tcp'}{'3609'}{'name'} = 'cpdi-pidas-cm'		; 
#	$srvcobjects_ref->{'smile'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smile'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smile'}{'port'}{'udp'} = '3670'	; 
#	$srvcobjects_ref->{'smile'}{'ports'}{'udp'}{'3670'}++	; 
#	$ports_ref->{'udp'}{'3670'}{'name'} = 'smile'		; 
#	$srvcobjects_ref->{'smile'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smile'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smile'}{'port'}{'tcp'} = '3670'	; 
#	$srvcobjects_ref->{'smile'}{'ports'}{'tcp'}{'3670'}++	; 
#	$ports_ref->{'tcp'}{'3670'}{'name'} = 'smile'		; 
#	$srvcobjects_ref->{'opsec-ufp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsec-ufp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-ufp'}{'port'}{'udp'} = '18182'	; 
#	$srvcobjects_ref->{'opsec-ufp'}{'ports'}{'udp'}{'18182'}++	; 
#	$ports_ref->{'udp'}{'18182'}{'name'} = 'opsec-ufp'		; 
#	$srvcobjects_ref->{'opsec-ufp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsec-ufp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-ufp'}{'port'}{'tcp'} = '18182'	; 
#	$srvcobjects_ref->{'opsec-ufp'}{'ports'}{'tcp'}{'18182'}++	; 
#	$ports_ref->{'tcp'}{'18182'}{'name'} = 'opsec-ufp'		; 
#	$srvcobjects_ref->{'accu-lmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'accu-lmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accu-lmgr'}{'port'}{'udp'} = '7781'	; 
#	$srvcobjects_ref->{'accu-lmgr'}{'ports'}{'udp'}{'7781'}++	; 
#	$ports_ref->{'udp'}{'7781'}{'name'} = 'accu-lmgr'		; 
#	$srvcobjects_ref->{'accu-lmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'accu-lmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accu-lmgr'}{'port'}{'tcp'} = '7781'	; 
#	$srvcobjects_ref->{'accu-lmgr'}{'ports'}{'tcp'}{'7781'}++	; 
#	$ports_ref->{'tcp'}{'7781'}{'name'} = 'accu-lmgr'		; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'port'}{'udp'} = '7009'	; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'ports'}{'udp'}{'7009'}++	; 
#	$ports_ref->{'udp'}{'7009'}{'name'} = 'afs3-rmtsys'		; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'port'}{'tcp'} = '7009'	; 
#	$srvcobjects_ref->{'afs3-rmtsys'}{'ports'}{'tcp'}{'7009'}++	; 
#	$ports_ref->{'tcp'}{'7009'}{'name'} = 'afs3-rmtsys'		; 
#	$srvcobjects_ref->{'isi-gl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isi-gl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isi-gl'}{'port'}{'udp'} = '55'	; 
#	$srvcobjects_ref->{'isi-gl'}{'ports'}{'udp'}{'55'}++	; 
#	$ports_ref->{'udp'}{'55'}{'name'} = 'isi-gl'		; 
#	$srvcobjects_ref->{'isi-gl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isi-gl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isi-gl'}{'port'}{'tcp'} = '55'	; 
#	$srvcobjects_ref->{'isi-gl'}{'ports'}{'tcp'}{'55'}++	; 
#	$ports_ref->{'tcp'}{'55'}{'name'} = 'isi-gl'		; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'port'}{'udp'} = '1394'	; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'ports'}{'udp'}{'1394'}++	; 
#	$ports_ref->{'udp'}{'1394'}{'name'} = 'iclpv-nlc'		; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'port'}{'tcp'} = '1394'	; 
#	$srvcobjects_ref->{'iclpv-nlc'}{'ports'}{'tcp'}{'1394'}++	; 
#	$ports_ref->{'tcp'}{'1394'}{'name'} = 'iclpv-nlc'		; 
#	$srvcobjects_ref->{'appleqtc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appleqtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appleqtc'}{'port'}{'udp'} = '458'	; 
#	$srvcobjects_ref->{'appleqtc'}{'ports'}{'udp'}{'458'}++	; 
#	$ports_ref->{'udp'}{'458'}{'name'} = 'appleqtc'		; 
#	$srvcobjects_ref->{'appleqtc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appleqtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appleqtc'}{'port'}{'tcp'} = '458'	; 
#	$srvcobjects_ref->{'appleqtc'}{'ports'}{'tcp'}{'458'}++	; 
#	$ports_ref->{'tcp'}{'458'}{'name'} = 'appleqtc'		; 
#	$srvcobjects_ref->{'diamondport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'diamondport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'diamondport'}{'port'}{'udp'} = '33331'	; 
#	$srvcobjects_ref->{'diamondport'}{'ports'}{'udp'}{'33331'}++	; 
#	$ports_ref->{'udp'}{'33331'}{'name'} = 'diamondport'		; 
#	$srvcobjects_ref->{'diamondport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'diamondport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'diamondport'}{'port'}{'tcp'} = '33331'	; 
#	$srvcobjects_ref->{'diamondport'}{'ports'}{'tcp'}{'33331'}++	; 
#	$ports_ref->{'tcp'}{'33331'}{'name'} = 'diamondport'		; 
#	$srvcobjects_ref->{'efcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'efcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'efcp'}{'port'}{'udp'} = '3671'	; 
#	$srvcobjects_ref->{'efcp'}{'ports'}{'udp'}{'3671'}++	; 
#	$ports_ref->{'udp'}{'3671'}{'name'} = 'efcp'		; 
#	$srvcobjects_ref->{'efcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'efcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'efcp'}{'port'}{'tcp'} = '3671'	; 
#	$srvcobjects_ref->{'efcp'}{'ports'}{'tcp'}{'3671'}++	; 
#	$ports_ref->{'tcp'}{'3671'}{'name'} = 'efcp'		; 
#	$srvcobjects_ref->{'sun-dr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sun-dr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sun-dr'}{'port'}{'udp'} = '665'	; 
#	$srvcobjects_ref->{'sun-dr'}{'ports'}{'udp'}{'665'}++	; 
#	$ports_ref->{'udp'}{'665'}{'name'} = 'sun-dr'		; 
#	$srvcobjects_ref->{'sun-dr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sun-dr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sun-dr'}{'port'}{'tcp'} = '665'	; 
#	$srvcobjects_ref->{'sun-dr'}{'ports'}{'tcp'}{'665'}++	; 
#	$ports_ref->{'tcp'}{'665'}{'name'} = 'sun-dr'		; 
#	$srvcobjects_ref->{'emprise-lls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emprise-lls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emprise-lls'}{'port'}{'udp'} = '3585'	; 
#	$srvcobjects_ref->{'emprise-lls'}{'ports'}{'udp'}{'3585'}++	; 
#	$ports_ref->{'udp'}{'3585'}{'name'} = 'emprise-lls'		; 
#	$srvcobjects_ref->{'emprise-lls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emprise-lls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emprise-lls'}{'port'}{'tcp'} = '3585'	; 
#	$srvcobjects_ref->{'emprise-lls'}{'ports'}{'tcp'}{'3585'}++	; 
#	$ports_ref->{'tcp'}{'3585'}{'name'} = 'emprise-lls'		; 
#	$srvcobjects_ref->{'orbixd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orbixd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbixd'}{'port'}{'udp'} = '1570'	; 
#	$srvcobjects_ref->{'orbixd'}{'ports'}{'udp'}{'1570'}++	; 
#	$ports_ref->{'udp'}{'1570'}{'name'} = 'orbixd'		; 
#	$srvcobjects_ref->{'orbixd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orbixd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbixd'}{'port'}{'tcp'} = '1570'	; 
#	$srvcobjects_ref->{'orbixd'}{'ports'}{'tcp'}{'1570'}++	; 
#	$ports_ref->{'tcp'}{'1570'}{'name'} = 'orbixd'		; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'port'}{'udp'} = '3197'	; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'ports'}{'udp'}{'3197'}++	; 
#	$ports_ref->{'udp'}{'3197'}{'name'} = 'embrace-dp-s'		; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'port'}{'tcp'} = '3197'	; 
#	$srvcobjects_ref->{'embrace-dp-s'}{'ports'}{'tcp'}{'3197'}++	; 
#	$ports_ref->{'tcp'}{'3197'}{'name'} = 'embrace-dp-s'		; 
#	$srvcobjects_ref->{'unglue'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unglue'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unglue'}{'port'}{'udp'} = '2655'	; 
#	$srvcobjects_ref->{'unglue'}{'ports'}{'udp'}{'2655'}++	; 
#	$ports_ref->{'udp'}{'2655'}{'name'} = 'unglue'		; 
#	$srvcobjects_ref->{'unglue'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unglue'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unglue'}{'port'}{'tcp'} = '2655'	; 
#	$srvcobjects_ref->{'unglue'}{'ports'}{'tcp'}{'2655'}++	; 
#	$ports_ref->{'tcp'}{'2655'}{'name'} = 'unglue'		; 
#	$srvcobjects_ref->{'jetform'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jetform'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jetform'}{'port'}{'udp'} = '1706'	; 
#	$srvcobjects_ref->{'jetform'}{'ports'}{'udp'}{'1706'}++	; 
#	$ports_ref->{'udp'}{'1706'}{'name'} = 'jetform'		; 
#	$srvcobjects_ref->{'jetform'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jetform'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jetform'}{'port'}{'tcp'} = '1706'	; 
#	$srvcobjects_ref->{'jetform'}{'ports'}{'tcp'}{'1706'}++	; 
#	$ports_ref->{'tcp'}{'1706'}{'name'} = 'jetform'		; 
#	$srvcobjects_ref->{'dantz'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dantz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dantz'}{'port'}{'udp'} = '497'	; 
#	$srvcobjects_ref->{'dantz'}{'ports'}{'udp'}{'497'}++	; 
#	$ports_ref->{'udp'}{'497'}{'name'} = 'dantz'		; 
#	$srvcobjects_ref->{'dantz'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dantz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dantz'}{'port'}{'tcp'} = '497'	; 
#	$srvcobjects_ref->{'dantz'}{'ports'}{'tcp'}{'497'}++	; 
#	$ports_ref->{'tcp'}{'497'}{'name'} = 'dantz'		; 
#	$srvcobjects_ref->{'ssp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssp'}{'port'}{'udp'} = '3249'	; 
#	$srvcobjects_ref->{'ssp'}{'ports'}{'udp'}{'3249'}++	; 
#	$ports_ref->{'udp'}{'3249'}{'name'} = 'ssp'		; 
#	$srvcobjects_ref->{'ssp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssp'}{'port'}{'tcp'} = '3249'	; 
#	$srvcobjects_ref->{'ssp'}{'ports'}{'tcp'}{'3249'}++	; 
#	$ports_ref->{'tcp'}{'3249'}{'name'} = 'ssp'		; 
#	$srvcobjects_ref->{'iwec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iwec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwec'}{'port'}{'udp'} = '4801'	; 
#	$srvcobjects_ref->{'iwec'}{'ports'}{'udp'}{'4801'}++	; 
#	$ports_ref->{'udp'}{'4801'}{'name'} = 'iwec'		; 
#	$srvcobjects_ref->{'iwec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iwec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwec'}{'port'}{'tcp'} = '4801'	; 
#	$srvcobjects_ref->{'iwec'}{'ports'}{'tcp'}{'4801'}++	; 
#	$ports_ref->{'tcp'}{'4801'}{'name'} = 'iwec'		; 
#	$srvcobjects_ref->{'isysg-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isysg-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isysg-lm'}{'port'}{'udp'} = '1609'	; 
#	$srvcobjects_ref->{'isysg-lm'}{'ports'}{'udp'}{'1609'}++	; 
#	$ports_ref->{'udp'}{'1609'}{'name'} = 'isysg-lm'		; 
#	$srvcobjects_ref->{'isysg-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isysg-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isysg-lm'}{'port'}{'tcp'} = '1609'	; 
#	$srvcobjects_ref->{'isysg-lm'}{'ports'}{'tcp'}{'1609'}++	; 
#	$ports_ref->{'tcp'}{'1609'}{'name'} = 'isysg-lm'		; 
#	$srvcobjects_ref->{'gtp-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gtp-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtp-control'}{'port'}{'udp'} = '2123'	; 
#	$srvcobjects_ref->{'gtp-control'}{'ports'}{'udp'}{'2123'}++	; 
#	$ports_ref->{'udp'}{'2123'}{'name'} = 'gtp-control'		; 
#	$srvcobjects_ref->{'gtp-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gtp-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtp-control'}{'port'}{'tcp'} = '2123'	; 
#	$srvcobjects_ref->{'gtp-control'}{'ports'}{'tcp'}{'2123'}++	; 
#	$ports_ref->{'tcp'}{'2123'}{'name'} = 'gtp-control'		; 
#	$srvcobjects_ref->{'sfs-config'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sfs-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sfs-config'}{'port'}{'udp'} = '452'	; 
#	$srvcobjects_ref->{'sfs-config'}{'ports'}{'udp'}{'452'}++	; 
#	$ports_ref->{'udp'}{'452'}{'name'} = 'sfs-config'		; 
#	$srvcobjects_ref->{'sfs-config'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sfs-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sfs-config'}{'port'}{'tcp'} = '452'	; 
#	$srvcobjects_ref->{'sfs-config'}{'ports'}{'tcp'}{'452'}++	; 
#	$ports_ref->{'tcp'}{'452'}{'name'} = 'sfs-config'		; 
#	$srvcobjects_ref->{'healthd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'healthd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'healthd'}{'port'}{'udp'} = '1281'	; 
#	$srvcobjects_ref->{'healthd'}{'ports'}{'udp'}{'1281'}++	; 
#	$ports_ref->{'udp'}{'1281'}{'name'} = 'healthd'		; 
#	$srvcobjects_ref->{'healthd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'healthd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'healthd'}{'port'}{'tcp'} = '1281'	; 
#	$srvcobjects_ref->{'healthd'}{'ports'}{'tcp'}{'1281'}++	; 
#	$ports_ref->{'tcp'}{'1281'}{'name'} = 'healthd'		; 
#	$srvcobjects_ref->{'mysql'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mysql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mysql'}{'port'}{'udp'} = '3306'	; 
#	$srvcobjects_ref->{'mysql'}{'ports'}{'udp'}{'3306'}++	; 
#	$ports_ref->{'udp'}{'3306'}{'name'} = 'mysql'		; 
#	$srvcobjects_ref->{'mysql'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mysql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mysql'}{'port'}{'tcp'} = '3306'	; 
#	$srvcobjects_ref->{'mysql'}{'ports'}{'tcp'}{'3306'}++	; 
#	$ports_ref->{'tcp'}{'3306'}{'name'} = 'mysql'		; 
#	$srvcobjects_ref->{'lnvstatus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lnvstatus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvstatus'}{'port'}{'udp'} = '2283'	; 
#	$srvcobjects_ref->{'lnvstatus'}{'ports'}{'udp'}{'2283'}++	; 
#	$ports_ref->{'udp'}{'2283'}{'name'} = 'lnvstatus'		; 
#	$srvcobjects_ref->{'lnvstatus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lnvstatus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvstatus'}{'port'}{'tcp'} = '2283'	; 
#	$srvcobjects_ref->{'lnvstatus'}{'ports'}{'tcp'}{'2283'}++	; 
#	$ports_ref->{'tcp'}{'2283'}{'name'} = 'lnvstatus'		; 
#	$srvcobjects_ref->{'coauthor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'coauthor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'coauthor'}{'port'}{'udp'} = '1529'	; 
#	$srvcobjects_ref->{'coauthor'}{'ports'}{'udp'}{'1529'}++	; 
#	$ports_ref->{'udp'}{'1529'}{'name'} = 'coauthor'		; 
#	$srvcobjects_ref->{'coauthor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'coauthor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'coauthor'}{'port'}{'tcp'} = '1529'	; 
#	$srvcobjects_ref->{'coauthor'}{'ports'}{'tcp'}{'1529'}++	; 
#	$ports_ref->{'tcp'}{'1529'}{'name'} = 'coauthor'		; 
#	$srvcobjects_ref->{'entrusttime'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entrusttime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrusttime'}{'port'}{'udp'} = '309'	; 
#	$srvcobjects_ref->{'entrusttime'}{'ports'}{'udp'}{'309'}++	; 
#	$ports_ref->{'udp'}{'309'}{'name'} = 'entrusttime'		; 
#	$srvcobjects_ref->{'entrusttime'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entrusttime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrusttime'}{'port'}{'tcp'} = '309'	; 
#	$srvcobjects_ref->{'entrusttime'}{'ports'}{'tcp'}{'309'}++	; 
#	$ports_ref->{'tcp'}{'309'}{'name'} = 'entrusttime'		; 
#	$srvcobjects_ref->{'ipr-dglt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipr-dglt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipr-dglt'}{'port'}{'udp'} = '3678'	; 
#	$srvcobjects_ref->{'ipr-dglt'}{'ports'}{'udp'}{'3678'}++	; 
#	$ports_ref->{'udp'}{'3678'}{'name'} = 'ipr-dglt'		; 
#	$srvcobjects_ref->{'ipr-dglt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipr-dglt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipr-dglt'}{'port'}{'tcp'} = '3678'	; 
#	$srvcobjects_ref->{'ipr-dglt'}{'ports'}{'tcp'}{'3678'}++	; 
#	$ports_ref->{'tcp'}{'3678'}{'name'} = 'ipr-dglt'		; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'port'}{'udp'} = '1395'	; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'ports'}{'udp'}{'1395'}++	; 
#	$ports_ref->{'udp'}{'1395'}{'name'} = 'iclpv-wsm'		; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'port'}{'tcp'} = '1395'	; 
#	$srvcobjects_ref->{'iclpv-wsm'}{'ports'}{'tcp'}{'1395'}++	; 
#	$ports_ref->{'tcp'}{'1395'}{'name'} = 'iclpv-wsm'		; 
#	$srvcobjects_ref->{'l2f'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'l2f'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l2f'}{'port'}{'udp'} = '1701'	; 
#	$srvcobjects_ref->{'l2f'}{'ports'}{'udp'}{'1701'}++	; 
#	$ports_ref->{'udp'}{'1701'}{'name'} = 'l2f'		; 
#	$srvcobjects_ref->{'l2f'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'l2f'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l2f'}{'port'}{'tcp'} = '1701'	; 
#	$srvcobjects_ref->{'l2f'}{'ports'}{'tcp'}{'1701'}++	; 
#	$ports_ref->{'tcp'}{'1701'}{'name'} = 'l2f'		; 
#	$srvcobjects_ref->{'childkey-notif'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'childkey-notif'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'childkey-notif'}{'port'}{'udp'} = '1891'	; 
#	$srvcobjects_ref->{'childkey-notif'}{'ports'}{'udp'}{'1891'}++	; 
#	$ports_ref->{'udp'}{'1891'}{'name'} = 'childkey-notif'		; 
#	$srvcobjects_ref->{'childkey-notif'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'childkey-notif'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'childkey-notif'}{'port'}{'tcp'} = '1891'	; 
#	$srvcobjects_ref->{'childkey-notif'}{'ports'}{'tcp'}{'1891'}++	; 
#	$ports_ref->{'tcp'}{'1891'}{'name'} = 'childkey-notif'		; 
#	$srvcobjects_ref->{'lkcmserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lkcmserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lkcmserver'}{'port'}{'udp'} = '3278'	; 
#	$srvcobjects_ref->{'lkcmserver'}{'ports'}{'udp'}{'3278'}++	; 
#	$ports_ref->{'udp'}{'3278'}{'name'} = 'lkcmserver'		; 
#	$srvcobjects_ref->{'lkcmserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lkcmserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lkcmserver'}{'port'}{'tcp'} = '3278'	; 
#	$srvcobjects_ref->{'lkcmserver'}{'ports'}{'tcp'}{'3278'}++	; 
#	$ports_ref->{'tcp'}{'3278'}{'name'} = 'lkcmserver'		; 
#	$srvcobjects_ref->{'ndsauth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndsauth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndsauth'}{'port'}{'udp'} = '353'	; 
#	$srvcobjects_ref->{'ndsauth'}{'ports'}{'udp'}{'353'}++	; 
#	$ports_ref->{'udp'}{'353'}{'name'} = 'ndsauth'		; 
#	$srvcobjects_ref->{'ndsauth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndsauth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndsauth'}{'port'}{'tcp'} = '353'	; 
#	$srvcobjects_ref->{'ndsauth'}{'ports'}{'tcp'}{'353'}++	; 
#	$ports_ref->{'tcp'}{'353'}{'name'} = 'ndsauth'		; 
#	$srvcobjects_ref->{'ndl-als'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndl-als'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-als'}{'port'}{'udp'} = '3431'	; 
#	$srvcobjects_ref->{'ndl-als'}{'ports'}{'udp'}{'3431'}++	; 
#	$ports_ref->{'udp'}{'3431'}{'name'} = 'ndl-als'		; 
#	$srvcobjects_ref->{'ndl-als'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndl-als'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-als'}{'port'}{'tcp'} = '3431'	; 
#	$srvcobjects_ref->{'ndl-als'}{'ports'}{'tcp'}{'3431'}++	; 
#	$ports_ref->{'tcp'}{'3431'}{'name'} = 'ndl-als'		; 
#	$srvcobjects_ref->{'qubes'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qubes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qubes'}{'port'}{'udp'} = '1341'	; 
#	$srvcobjects_ref->{'qubes'}{'ports'}{'udp'}{'1341'}++	; 
#	$ports_ref->{'udp'}{'1341'}{'name'} = 'qubes'		; 
#	$srvcobjects_ref->{'qubes'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qubes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qubes'}{'port'}{'tcp'} = '1341'	; 
#	$srvcobjects_ref->{'qubes'}{'ports'}{'tcp'}{'1341'}++	; 
#	$ports_ref->{'tcp'}{'1341'}{'name'} = 'qubes'		; 
#	$srvcobjects_ref->{'italk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'italk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'italk'}{'port'}{'udp'} = '12345'	; 
#	$srvcobjects_ref->{'italk'}{'ports'}{'udp'}{'12345'}++	; 
#	$ports_ref->{'udp'}{'12345'}{'name'} = 'italk'		; 
#	$srvcobjects_ref->{'italk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'italk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'italk'}{'port'}{'tcp'} = '12345'	; 
#	$srvcobjects_ref->{'italk'}{'ports'}{'tcp'}{'12345'}++	; 
#	$ports_ref->{'tcp'}{'12345'}{'name'} = 'italk'		; 
#	$srvcobjects_ref->{'applix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'applix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'applix'}{'port'}{'udp'} = '999'	; 
#	$srvcobjects_ref->{'applix'}{'ports'}{'udp'}{'999'}++	; 
#	$ports_ref->{'udp'}{'999'}{'name'} = 'applix'		; 
#	$srvcobjects_ref->{'radan-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radan-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radan-http'}{'port'}{'udp'} = '8088'	; 
#	$srvcobjects_ref->{'radan-http'}{'ports'}{'udp'}{'8088'}++	; 
#	$ports_ref->{'udp'}{'8088'}{'name'} = 'radan-http'		; 
#	$srvcobjects_ref->{'radan-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radan-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radan-http'}{'port'}{'tcp'} = '8088'	; 
#	$srvcobjects_ref->{'radan-http'}{'ports'}{'tcp'}{'8088'}++	; 
#	$ports_ref->{'tcp'}{'8088'}{'name'} = 'radan-http'		; 
#	$srvcobjects_ref->{'sd-request'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sd-request'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd-request'}{'port'}{'tcp'} = '2384'	; 
#	$srvcobjects_ref->{'sd-request'}{'ports'}{'tcp'}{'2384'}++	; 
#	$ports_ref->{'tcp'}{'2384'}{'name'} = 'sd-request'		; 
#	$srvcobjects_ref->{'snac'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snac'}{'port'}{'udp'} = '3536'	; 
#	$srvcobjects_ref->{'snac'}{'ports'}{'udp'}{'3536'}++	; 
#	$ports_ref->{'udp'}{'3536'}{'name'} = 'snac'		; 
#	$srvcobjects_ref->{'snac'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snac'}{'port'}{'tcp'} = '3536'	; 
#	$srvcobjects_ref->{'snac'}{'ports'}{'tcp'}{'3536'}++	; 
#	$ports_ref->{'tcp'}{'3536'}{'name'} = 'snac'		; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'port'}{'udp'} = '441'	; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'ports'}{'udp'}{'441'}++	; 
#	$ports_ref->{'udp'}{'441'}{'name'} = 'decvms-sysmgt'		; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'port'}{'tcp'} = '441'	; 
#	$srvcobjects_ref->{'decvms-sysmgt'}{'ports'}{'tcp'}{'441'}++	; 
#	$ports_ref->{'tcp'}{'441'}{'name'} = 'decvms-sysmgt'		; 
#	$srvcobjects_ref->{'xnmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xnmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xnmp'}{'port'}{'udp'} = '1652'	; 
#	$srvcobjects_ref->{'xnmp'}{'ports'}{'udp'}{'1652'}++	; 
#	$ports_ref->{'udp'}{'1652'}{'name'} = 'xnmp'		; 
#	$srvcobjects_ref->{'xnmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xnmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xnmp'}{'port'}{'tcp'} = '1652'	; 
#	$srvcobjects_ref->{'xnmp'}{'ports'}{'tcp'}{'1652'}++	; 
#	$ports_ref->{'tcp'}{'1652'}{'name'} = 'xnmp'		; 
#	$srvcobjects_ref->{'metrics-pas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metrics-pas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metrics-pas'}{'port'}{'udp'} = '1824'	; 
#	$srvcobjects_ref->{'metrics-pas'}{'ports'}{'udp'}{'1824'}++	; 
#	$ports_ref->{'udp'}{'1824'}{'name'} = 'metrics-pas'		; 
#	$srvcobjects_ref->{'metrics-pas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metrics-pas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metrics-pas'}{'port'}{'tcp'} = '1824'	; 
#	$srvcobjects_ref->{'metrics-pas'}{'ports'}{'tcp'}{'1824'}++	; 
#	$ports_ref->{'tcp'}{'1824'}{'name'} = 'metrics-pas'		; 
#	$srvcobjects_ref->{'afs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs'}{'port'}{'udp'} = '1483'	; 
#	$srvcobjects_ref->{'afs'}{'ports'}{'udp'}{'1483'}++	; 
#	$ports_ref->{'udp'}{'1483'}{'name'} = 'afs'		; 
#	$srvcobjects_ref->{'afs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs'}{'port'}{'tcp'} = '1483'	; 
#	$srvcobjects_ref->{'afs'}{'ports'}{'tcp'}{'1483'}++	; 
#	$ports_ref->{'tcp'}{'1483'}{'name'} = 'afs'		; 
#	$srvcobjects_ref->{'cap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cap'}{'port'}{'udp'} = '1026'	; 
#	$srvcobjects_ref->{'cap'}{'ports'}{'udp'}{'1026'}++	; 
#	$ports_ref->{'udp'}{'1026'}{'name'} = 'cap'		; 
#	$srvcobjects_ref->{'cap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cap'}{'port'}{'tcp'} = '1026'	; 
#	$srvcobjects_ref->{'cap'}{'ports'}{'tcp'}{'1026'}++	; 
#	$ports_ref->{'tcp'}{'1026'}{'name'} = 'cap'		; 
#	$srvcobjects_ref->{'iwlistener'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iwlistener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwlistener'}{'port'}{'udp'} = '2866'	; 
#	$srvcobjects_ref->{'iwlistener'}{'ports'}{'udp'}{'2866'}++	; 
#	$ports_ref->{'udp'}{'2866'}{'name'} = 'iwlistener'		; 
#	$srvcobjects_ref->{'iwlistener'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iwlistener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwlistener'}{'port'}{'tcp'} = '2866'	; 
#	$srvcobjects_ref->{'iwlistener'}{'ports'}{'tcp'}{'2866'}++	; 
#	$ports_ref->{'tcp'}{'2866'}{'name'} = 'iwlistener'		; 
#	$srvcobjects_ref->{'tpmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tpmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tpmd'}{'port'}{'udp'} = '1906'	; 
#	$srvcobjects_ref->{'tpmd'}{'ports'}{'udp'}{'1906'}++	; 
#	$ports_ref->{'udp'}{'1906'}{'name'} = 'tpmd'		; 
#	$srvcobjects_ref->{'tpmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tpmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tpmd'}{'port'}{'tcp'} = '1906'	; 
#	$srvcobjects_ref->{'tpmd'}{'ports'}{'tcp'}{'1906'}++	; 
#	$ports_ref->{'tcp'}{'1906'}{'name'} = 'tpmd'		; 
#	$srvcobjects_ref->{'anet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet'}{'port'}{'udp'} = '212'	; 
#	$srvcobjects_ref->{'anet'}{'ports'}{'udp'}{'212'}++	; 
#	$ports_ref->{'udp'}{'212'}{'name'} = 'anet'		; 
#	$srvcobjects_ref->{'anet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet'}{'port'}{'tcp'} = '212'	; 
#	$srvcobjects_ref->{'anet'}{'ports'}{'tcp'}{'212'}++	; 
#	$ports_ref->{'tcp'}{'212'}{'name'} = 'anet'		; 
#	$srvcobjects_ref->{'mortgageware'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mortgageware'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mortgageware'}{'port'}{'udp'} = '367'	; 
#	$srvcobjects_ref->{'mortgageware'}{'ports'}{'udp'}{'367'}++	; 
#	$ports_ref->{'udp'}{'367'}{'name'} = 'mortgageware'		; 
#	$srvcobjects_ref->{'mortgageware'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mortgageware'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mortgageware'}{'port'}{'tcp'} = '367'	; 
#	$srvcobjects_ref->{'mortgageware'}{'ports'}{'tcp'}{'367'}++	; 
#	$ports_ref->{'tcp'}{'367'}{'name'} = 'mortgageware'		; 
#	$srvcobjects_ref->{'bootpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bootpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bootpc'}{'port'}{'udp'} = '68'	; 
#	$srvcobjects_ref->{'bootpc'}{'ports'}{'udp'}{'68'}++	; 
#	$ports_ref->{'udp'}{'68'}{'name'} = 'bootpc'		; 
#	$srvcobjects_ref->{'bootpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bootpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bootpc'}{'port'}{'tcp'} = '68'	; 
#	$srvcobjects_ref->{'bootpc'}{'ports'}{'tcp'}{'68'}++	; 
#	$ports_ref->{'tcp'}{'68'}{'name'} = 'bootpc'		; 
#	$srvcobjects_ref->{'netrjs-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrjs-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-3'}{'port'}{'udp'} = '73'	; 
#	$srvcobjects_ref->{'netrjs-3'}{'ports'}{'udp'}{'73'}++	; 
#	$ports_ref->{'udp'}{'73'}{'name'} = 'netrjs-3'		; 
#	$srvcobjects_ref->{'netrjs-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrjs-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-3'}{'port'}{'tcp'} = '73'	; 
#	$srvcobjects_ref->{'netrjs-3'}{'ports'}{'tcp'}{'73'}++	; 
#	$ports_ref->{'tcp'}{'73'}{'name'} = 'netrjs-3'		; 
#	$srvcobjects_ref->{'cscp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cscp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cscp'}{'port'}{'udp'} = '40841'	; 
#	$srvcobjects_ref->{'cscp'}{'ports'}{'udp'}{'40841'}++	; 
#	$ports_ref->{'udp'}{'40841'}{'name'} = 'cscp'		; 
#	$srvcobjects_ref->{'cscp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cscp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cscp'}{'port'}{'tcp'} = '40841'	; 
#	$srvcobjects_ref->{'cscp'}{'ports'}{'tcp'}{'40841'}++	; 
#	$ports_ref->{'tcp'}{'40841'}{'name'} = 'cscp'		; 
#	$srvcobjects_ref->{'canocentral0'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'canocentral0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canocentral0'}{'port'}{'udp'} = '1871'	; 
#	$srvcobjects_ref->{'canocentral0'}{'ports'}{'udp'}{'1871'}++	; 
#	$ports_ref->{'udp'}{'1871'}{'name'} = 'canocentral0'		; 
#	$srvcobjects_ref->{'canocentral0'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'canocentral0'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canocentral0'}{'port'}{'tcp'} = '1871'	; 
#	$srvcobjects_ref->{'canocentral0'}{'ports'}{'tcp'}{'1871'}++	; 
#	$ports_ref->{'tcp'}{'1871'}{'name'} = 'canocentral0'		; 
#	$srvcobjects_ref->{'turbonote-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'turbonote-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'turbonote-2'}{'port'}{'udp'} = '34249'	; 
#	$srvcobjects_ref->{'turbonote-2'}{'ports'}{'udp'}{'34249'}++	; 
#	$ports_ref->{'udp'}{'34249'}{'name'} = 'turbonote-2'		; 
#	$srvcobjects_ref->{'turbonote-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'turbonote-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'turbonote-2'}{'port'}{'tcp'} = '34249'	; 
#	$srvcobjects_ref->{'turbonote-2'}{'ports'}{'tcp'}{'34249'}++	; 
#	$ports_ref->{'tcp'}{'34249'}{'name'} = 'turbonote-2'		; 
#	$srvcobjects_ref->{'ctechlicensing'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctechlicensing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctechlicensing'}{'port'}{'udp'} = '9346'	; 
#	$srvcobjects_ref->{'ctechlicensing'}{'ports'}{'udp'}{'9346'}++	; 
#	$ports_ref->{'udp'}{'9346'}{'name'} = 'ctechlicensing'		; 
#	$srvcobjects_ref->{'ctechlicensing'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctechlicensing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctechlicensing'}{'port'}{'tcp'} = '9346'	; 
#	$srvcobjects_ref->{'ctechlicensing'}{'ports'}{'tcp'}{'9346'}++	; 
#	$ports_ref->{'tcp'}{'9346'}{'name'} = 'ctechlicensing'		; 
#	$srvcobjects_ref->{'talarian-udp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talarian-udp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-udp'}{'port'}{'udp'} = '5101'	; 
#	$srvcobjects_ref->{'talarian-udp'}{'ports'}{'udp'}{'5101'}++	; 
#	$ports_ref->{'udp'}{'5101'}{'name'} = 'talarian-udp'		; 
#	$srvcobjects_ref->{'bts-appserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bts-appserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bts-appserver'}{'port'}{'udp'} = '1961'	; 
#	$srvcobjects_ref->{'bts-appserver'}{'ports'}{'udp'}{'1961'}++	; 
#	$ports_ref->{'udp'}{'1961'}{'name'} = 'bts-appserver'		; 
#	$srvcobjects_ref->{'bts-appserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bts-appserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bts-appserver'}{'port'}{'tcp'} = '1961'	; 
#	$srvcobjects_ref->{'bts-appserver'}{'ports'}{'tcp'}{'1961'}++	; 
#	$ports_ref->{'tcp'}{'1961'}{'name'} = 'bts-appserver'		; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'port'}{'udp'} = '3211'	; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'ports'}{'udp'}{'3211'}++	; 
#	$ports_ref->{'udp'}{'3211'}{'name'} = 'avsecuremgmt'		; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'port'}{'tcp'} = '3211'	; 
#	$srvcobjects_ref->{'avsecuremgmt'}{'ports'}{'tcp'}{'3211'}++	; 
#	$ports_ref->{'tcp'}{'3211'}{'name'} = 'avsecuremgmt'		; 
#	$srvcobjects_ref->{'wpages'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wpages'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wpages'}{'port'}{'udp'} = '776'	; 
#	$srvcobjects_ref->{'wpages'}{'ports'}{'udp'}{'776'}++	; 
#	$ports_ref->{'udp'}{'776'}{'name'} = 'wpages'		; 
#	$srvcobjects_ref->{'wpages'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wpages'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wpages'}{'port'}{'tcp'} = '776'	; 
#	$srvcobjects_ref->{'wpages'}{'ports'}{'tcp'}{'776'}++	; 
#	$ports_ref->{'tcp'}{'776'}{'name'} = 'wpages'		; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'port'}{'udp'} = '16991'	; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'ports'}{'udp'}{'16991'}++	; 
#	$ports_ref->{'udp'}{'16991'}{'name'} = 'intel-rci-mp'		; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'port'}{'tcp'} = '16991'	; 
#	$srvcobjects_ref->{'intel-rci-mp'}{'ports'}{'tcp'}{'16991'}++	; 
#	$ports_ref->{'tcp'}{'16991'}{'name'} = 'intel-rci-mp'		; 
#	$srvcobjects_ref->{'funk-license'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'funk-license'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'funk-license'}{'port'}{'udp'} = '1787'	; 
#	$srvcobjects_ref->{'funk-license'}{'ports'}{'udp'}{'1787'}++	; 
#	$ports_ref->{'udp'}{'1787'}{'name'} = 'funk-license'		; 
#	$srvcobjects_ref->{'funk-license'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'funk-license'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'funk-license'}{'port'}{'tcp'} = '1787'	; 
#	$srvcobjects_ref->{'funk-license'}{'ports'}{'tcp'}{'1787'}++	; 
#	$ports_ref->{'tcp'}{'1787'}{'name'} = 'funk-license'		; 
#	$srvcobjects_ref->{'ohimsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ohimsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ohimsrv'}{'port'}{'udp'} = '506'	; 
#	$srvcobjects_ref->{'ohimsrv'}{'ports'}{'udp'}{'506'}++	; 
#	$ports_ref->{'udp'}{'506'}{'name'} = 'ohimsrv'		; 
#	$srvcobjects_ref->{'ohimsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ohimsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ohimsrv'}{'port'}{'tcp'} = '506'	; 
#	$srvcobjects_ref->{'ohimsrv'}{'ports'}{'tcp'}{'506'}++	; 
#	$ports_ref->{'tcp'}{'506'}{'name'} = 'ohimsrv'		; 
#	$srvcobjects_ref->{'wap-push-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-push-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-push-http'}{'port'}{'udp'} = '4035'	; 
#	$srvcobjects_ref->{'wap-push-http'}{'ports'}{'udp'}{'4035'}++	; 
#	$ports_ref->{'udp'}{'4035'}{'name'} = 'wap-push-http'		; 
#	$srvcobjects_ref->{'wap-push-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-push-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-push-http'}{'port'}{'tcp'} = '4035'	; 
#	$srvcobjects_ref->{'wap-push-http'}{'ports'}{'tcp'}{'4035'}++	; 
#	$ports_ref->{'tcp'}{'4035'}{'name'} = 'wap-push-http'		; 
#	$srvcobjects_ref->{'altserviceboot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'altserviceboot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altserviceboot'}{'port'}{'udp'} = '4011'	; 
#	$srvcobjects_ref->{'altserviceboot'}{'ports'}{'udp'}{'4011'}++	; 
#	$ports_ref->{'udp'}{'4011'}{'name'} = 'altserviceboot'		; 
#	$srvcobjects_ref->{'altserviceboot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'altserviceboot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altserviceboot'}{'port'}{'tcp'} = '4011'	; 
#	$srvcobjects_ref->{'altserviceboot'}{'ports'}{'tcp'}{'4011'}++	; 
#	$ports_ref->{'tcp'}{'4011'}{'name'} = 'altserviceboot'		; 
#	$srvcobjects_ref->{'newgenpay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newgenpay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newgenpay'}{'port'}{'udp'} = '3165'	; 
#	$srvcobjects_ref->{'newgenpay'}{'ports'}{'udp'}{'3165'}++	; 
#	$ports_ref->{'udp'}{'3165'}{'name'} = 'newgenpay'		; 
#	$srvcobjects_ref->{'newgenpay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newgenpay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newgenpay'}{'port'}{'tcp'} = '3165'	; 
#	$srvcobjects_ref->{'newgenpay'}{'ports'}{'tcp'}{'3165'}++	; 
#	$ports_ref->{'tcp'}{'3165'}{'name'} = 'newgenpay'		; 
#	$srvcobjects_ref->{'cogitate'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cogitate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cogitate'}{'port'}{'udp'} = '3039'	; 
#	$srvcobjects_ref->{'cogitate'}{'ports'}{'udp'}{'3039'}++	; 
#	$ports_ref->{'udp'}{'3039'}{'name'} = 'cogitate'		; 
#	$srvcobjects_ref->{'cogitate'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cogitate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cogitate'}{'port'}{'tcp'} = '3039'	; 
#	$srvcobjects_ref->{'cogitate'}{'ports'}{'tcp'}{'3039'}++	; 
#	$ports_ref->{'tcp'}{'3039'}{'name'} = 'cogitate'		; 
#	$srvcobjects_ref->{'irdmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'irdmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irdmi'}{'port'}{'udp'} = '8000'	; 
#	$srvcobjects_ref->{'irdmi'}{'ports'}{'udp'}{'8000'}++	; 
#	$ports_ref->{'udp'}{'8000'}{'name'} = 'irdmi'		; 
#	$srvcobjects_ref->{'irdmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'irdmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irdmi'}{'port'}{'tcp'} = '8000'	; 
#	$srvcobjects_ref->{'irdmi'}{'ports'}{'tcp'}{'8000'}++	; 
#	$ports_ref->{'tcp'}{'8000'}{'name'} = 'irdmi'		; 
#	$srvcobjects_ref->{'tnp1-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tnp1-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tnp1-port'}{'port'}{'udp'} = '4024'	; 
#	$srvcobjects_ref->{'tnp1-port'}{'ports'}{'udp'}{'4024'}++	; 
#	$ports_ref->{'udp'}{'4024'}{'name'} = 'tnp1-port'		; 
#	$srvcobjects_ref->{'tnp1-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tnp1-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tnp1-port'}{'port'}{'tcp'} = '4024'	; 
#	$srvcobjects_ref->{'tnp1-port'}{'ports'}{'tcp'}{'4024'}++	; 
#	$ports_ref->{'tcp'}{'4024'}{'name'} = 'tnp1-port'		; 
#	$srvcobjects_ref->{'appleugcontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appleugcontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appleugcontrol'}{'port'}{'udp'} = '2336'	; 
#	$srvcobjects_ref->{'appleugcontrol'}{'ports'}{'udp'}{'2336'}++	; 
#	$ports_ref->{'udp'}{'2336'}{'name'} = 'appleugcontrol'		; 
#	$srvcobjects_ref->{'appleugcontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appleugcontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appleugcontrol'}{'port'}{'tcp'} = '2336'	; 
#	$srvcobjects_ref->{'appleugcontrol'}{'ports'}{'tcp'}{'2336'}++	; 
#	$ports_ref->{'tcp'}{'2336'}{'name'} = 'appleugcontrol'		; 
#	$srvcobjects_ref->{'fj-hdnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fj-hdnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fj-hdnet'}{'port'}{'udp'} = '1717'	; 
#	$srvcobjects_ref->{'fj-hdnet'}{'ports'}{'udp'}{'1717'}++	; 
#	$ports_ref->{'udp'}{'1717'}{'name'} = 'fj-hdnet'		; 
#	$srvcobjects_ref->{'fj-hdnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fj-hdnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fj-hdnet'}{'port'}{'tcp'} = '1717'	; 
#	$srvcobjects_ref->{'fj-hdnet'}{'ports'}{'tcp'}{'1717'}++	; 
#	$ports_ref->{'tcp'}{'1717'}{'name'} = 'fj-hdnet'		; 
#	$srvcobjects_ref->{'radec-corp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radec-corp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radec-corp'}{'port'}{'udp'} = '5430'	; 
#	$srvcobjects_ref->{'radec-corp'}{'ports'}{'udp'}{'5430'}++	; 
#	$ports_ref->{'udp'}{'5430'}{'name'} = 'radec-corp'		; 
#	$srvcobjects_ref->{'radec-corp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radec-corp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radec-corp'}{'port'}{'tcp'} = '5430'	; 
#	$srvcobjects_ref->{'radec-corp'}{'ports'}{'tcp'}{'5430'}++	; 
#	$ports_ref->{'tcp'}{'5430'}{'name'} = 'radec-corp'		; 
#	$srvcobjects_ref->{'http-alt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'http-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-alt'}{'port'}{'udp'} = '591'	; 
#	$srvcobjects_ref->{'http-alt'}{'ports'}{'udp'}{'591'}++	; 
#	$ports_ref->{'udp'}{'591'}{'name'} = 'http-alt'		; 
#	$srvcobjects_ref->{'http-alt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'http-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-alt'}{'port'}{'udp'} = '8008'	; 
#	$srvcobjects_ref->{'http-alt'}{'ports'}{'udp'}{'8008'}++	; 
#	$ports_ref->{'udp'}{'8008'}{'name'} = 'http-alt'		; 
#	$srvcobjects_ref->{'http-alt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'http-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-alt'}{'port'}{'udp'} = '8080'	; 
#	$srvcobjects_ref->{'http-alt'}{'ports'}{'udp'}{'8080'}++	; 
#	$ports_ref->{'udp'}{'8080'}{'name'} = 'http-alt'		; 
#	$srvcobjects_ref->{'http-alt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'http-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-alt'}{'port'}{'tcp'} = '591'	; 
#	$srvcobjects_ref->{'http-alt'}{'ports'}{'tcp'}{'591'}++	; 
#	$ports_ref->{'tcp'}{'591'}{'name'} = 'http-alt'		; 
#	$srvcobjects_ref->{'http-alt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'http-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-alt'}{'port'}{'tcp'} = '8008'	; 
#	$srvcobjects_ref->{'http-alt'}{'ports'}{'tcp'}{'8008'}++	; 
#	$ports_ref->{'tcp'}{'8008'}{'name'} = 'http-alt'		; 
#	$srvcobjects_ref->{'http-alt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'http-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-alt'}{'port'}{'tcp'} = '8080'	; 
#	$srvcobjects_ref->{'http-alt'}{'ports'}{'tcp'}{'8080'}++	; 
#	$ports_ref->{'tcp'}{'8080'}{'name'} = 'http-alt'		; 
#	$srvcobjects_ref->{'dpserve'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dpserve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpserve'}{'port'}{'udp'} = '7020'	; 
#	$srvcobjects_ref->{'dpserve'}{'ports'}{'udp'}{'7020'}++	; 
#	$ports_ref->{'udp'}{'7020'}{'name'} = 'dpserve'		; 
#	$srvcobjects_ref->{'dpserve'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dpserve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpserve'}{'port'}{'tcp'} = '7020'	; 
#	$srvcobjects_ref->{'dpserve'}{'ports'}{'tcp'}{'7020'}++	; 
#	$ports_ref->{'tcp'}{'7020'}{'name'} = 'dpserve'		; 
#	$srvcobjects_ref->{'scol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scol'}{'port'}{'udp'} = '1200'	; 
#	$srvcobjects_ref->{'scol'}{'ports'}{'udp'}{'1200'}++	; 
#	$ports_ref->{'udp'}{'1200'}{'name'} = 'scol'		; 
#	$srvcobjects_ref->{'scol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scol'}{'port'}{'tcp'} = '1200'	; 
#	$srvcobjects_ref->{'scol'}{'ports'}{'tcp'}{'1200'}++	; 
#	$ports_ref->{'tcp'}{'1200'}{'name'} = 'scol'		; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'port'}{'udp'} = '2687'	; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'ports'}{'udp'}{'2687'}++	; 
#	$ports_ref->{'udp'}{'2687'}{'name'} = 'pq-lic-mgmt'		; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'port'}{'tcp'} = '2687'	; 
#	$srvcobjects_ref->{'pq-lic-mgmt'}{'ports'}{'tcp'}{'2687'}++	; 
#	$ports_ref->{'tcp'}{'2687'}{'name'} = 'pq-lic-mgmt'		; 
#	$srvcobjects_ref->{'tscchat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tscchat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tscchat'}{'port'}{'udp'} = '2330'	; 
#	$srvcobjects_ref->{'tscchat'}{'ports'}{'udp'}{'2330'}++	; 
#	$ports_ref->{'udp'}{'2330'}{'name'} = 'tscchat'		; 
#	$srvcobjects_ref->{'tscchat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tscchat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tscchat'}{'port'}{'tcp'} = '2330'	; 
#	$srvcobjects_ref->{'tscchat'}{'ports'}{'tcp'}{'2330'}++	; 
#	$ports_ref->{'tcp'}{'2330'}{'name'} = 'tscchat'		; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'port'}{'udp'} = '3063'	; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'ports'}{'udp'}{'3063'}++	; 
#	$ports_ref->{'udp'}{'3063'}{'name'} = 'ncadg-ip-udp'		; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'port'}{'tcp'} = '3063'	; 
#	$srvcobjects_ref->{'ncadg-ip-udp'}{'ports'}{'tcp'}{'3063'}++	; 
#	$ports_ref->{'tcp'}{'3063'}{'name'} = 'ncadg-ip-udp'		; 
#	$srvcobjects_ref->{'mylxamport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mylxamport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mylxamport'}{'port'}{'udp'} = '2981'	; 
#	$srvcobjects_ref->{'mylxamport'}{'ports'}{'udp'}{'2981'}++	; 
#	$ports_ref->{'udp'}{'2981'}{'name'} = 'mylxamport'		; 
#	$srvcobjects_ref->{'mylxamport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mylxamport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mylxamport'}{'port'}{'tcp'} = '2981'	; 
#	$srvcobjects_ref->{'mylxamport'}{'ports'}{'tcp'}{'2981'}++	; 
#	$ports_ref->{'tcp'}{'2981'}{'name'} = 'mylxamport'		; 
#	$srvcobjects_ref->{'asf-rmcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asf-rmcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asf-rmcp'}{'port'}{'udp'} = '623'	; 
#	$srvcobjects_ref->{'asf-rmcp'}{'ports'}{'udp'}{'623'}++	; 
#	$ports_ref->{'udp'}{'623'}{'name'} = 'asf-rmcp'		; 
#	$srvcobjects_ref->{'asf-rmcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asf-rmcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asf-rmcp'}{'port'}{'tcp'} = '623'	; 
#	$srvcobjects_ref->{'asf-rmcp'}{'ports'}{'tcp'}{'623'}++	; 
#	$ports_ref->{'tcp'}{'623'}{'name'} = 'asf-rmcp'		; 
#	$srvcobjects_ref->{'start-network'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'start-network'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'start-network'}{'port'}{'udp'} = '3615'	; 
#	$srvcobjects_ref->{'start-network'}{'ports'}{'udp'}{'3615'}++	; 
#	$ports_ref->{'udp'}{'3615'}{'name'} = 'start-network'		; 
#	$srvcobjects_ref->{'start-network'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'start-network'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'start-network'}{'port'}{'tcp'} = '3615'	; 
#	$srvcobjects_ref->{'start-network'}{'ports'}{'tcp'}{'3615'}++	; 
#	$ports_ref->{'tcp'}{'3615'}{'name'} = 'start-network'		; 
#	$srvcobjects_ref->{'listmgr-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'listmgr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'listmgr-port'}{'port'}{'udp'} = '3767'	; 
#	$srvcobjects_ref->{'listmgr-port'}{'ports'}{'udp'}{'3767'}++	; 
#	$ports_ref->{'udp'}{'3767'}{'name'} = 'listmgr-port'		; 
#	$srvcobjects_ref->{'listmgr-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'listmgr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'listmgr-port'}{'port'}{'tcp'} = '3767'	; 
#	$srvcobjects_ref->{'listmgr-port'}{'ports'}{'tcp'}{'3767'}++	; 
#	$ports_ref->{'tcp'}{'3767'}{'name'} = 'listmgr-port'		; 
#	$srvcobjects_ref->{'ratl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ratl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ratl'}{'port'}{'udp'} = '2449'	; 
#	$srvcobjects_ref->{'ratl'}{'ports'}{'udp'}{'2449'}++	; 
#	$ports_ref->{'udp'}{'2449'}{'name'} = 'ratl'		; 
#	$srvcobjects_ref->{'ratl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ratl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ratl'}{'port'}{'tcp'} = '2449'	; 
#	$srvcobjects_ref->{'ratl'}{'ports'}{'tcp'}{'2449'}++	; 
#	$ports_ref->{'tcp'}{'2449'}{'name'} = 'ratl'		; 
#	$srvcobjects_ref->{'rtss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtss'}{'port'}{'udp'} = '3090'	; 
#	$srvcobjects_ref->{'rtss'}{'ports'}{'udp'}{'3090'}++	; 
#	$ports_ref->{'udp'}{'3090'}{'name'} = 'rtss'		; 
#	$srvcobjects_ref->{'rtss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtss'}{'port'}{'tcp'} = '3090'	; 
#	$srvcobjects_ref->{'rtss'}{'ports'}{'tcp'}{'3090'}++	; 
#	$ports_ref->{'tcp'}{'3090'}{'name'} = 'rtss'		; 
#	$srvcobjects_ref->{'sstp-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sstp-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sstp-2'}{'port'}{'udp'} = '9801'	; 
#	$srvcobjects_ref->{'sstp-2'}{'ports'}{'udp'}{'9801'}++	; 
#	$ports_ref->{'udp'}{'9801'}{'name'} = 'sstp-2'		; 
#	$srvcobjects_ref->{'sstp-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sstp-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sstp-2'}{'port'}{'tcp'} = '9801'	; 
#	$srvcobjects_ref->{'sstp-2'}{'ports'}{'tcp'}{'9801'}++	; 
#	$ports_ref->{'tcp'}{'9801'}{'name'} = 'sstp-2'		; 
#	$srvcobjects_ref->{'battlenet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'battlenet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'battlenet'}{'port'}{'udp'} = '3724'	; 
#	$srvcobjects_ref->{'battlenet'}{'ports'}{'udp'}{'3724'}++	; 
#	$ports_ref->{'udp'}{'3724'}{'name'} = 'battlenet'		; 
#	$srvcobjects_ref->{'battlenet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'battlenet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'battlenet'}{'port'}{'tcp'} = '3724'	; 
#	$srvcobjects_ref->{'battlenet'}{'ports'}{'tcp'}{'3724'}++	; 
#	$ports_ref->{'tcp'}{'3724'}{'name'} = 'battlenet'		; 
#	$srvcobjects_ref->{'galaxy7-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'galaxy7-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'galaxy7-data'}{'port'}{'udp'} = '38201'	; 
#	$srvcobjects_ref->{'galaxy7-data'}{'ports'}{'udp'}{'38201'}++	; 
#	$ports_ref->{'udp'}{'38201'}{'name'} = 'galaxy7-data'		; 
#	$srvcobjects_ref->{'galaxy7-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'galaxy7-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'galaxy7-data'}{'port'}{'tcp'} = '38201'	; 
#	$srvcobjects_ref->{'galaxy7-data'}{'ports'}{'tcp'}{'38201'}++	; 
#	$ports_ref->{'tcp'}{'38201'}{'name'} = 'galaxy7-data'		; 
#	$srvcobjects_ref->{'backup-express'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'backup-express'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'backup-express'}{'port'}{'udp'} = '6123'	; 
#	$srvcobjects_ref->{'backup-express'}{'ports'}{'udp'}{'6123'}++	; 
#	$ports_ref->{'udp'}{'6123'}{'name'} = 'backup-express'		; 
#	$srvcobjects_ref->{'backup-express'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'backup-express'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'backup-express'}{'port'}{'tcp'} = '6123'	; 
#	$srvcobjects_ref->{'backup-express'}{'ports'}{'tcp'}{'6123'}++	; 
#	$ports_ref->{'tcp'}{'6123'}{'name'} = 'backup-express'		; 
#	$srvcobjects_ref->{'nvmsgd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nvmsgd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nvmsgd'}{'port'}{'tcp'} = '3519'	; 
#	$srvcobjects_ref->{'nvmsgd'}{'ports'}{'tcp'}{'3519'}++	; 
#	$ports_ref->{'tcp'}{'3519'}{'name'} = 'nvmsgd'		; 
#	$srvcobjects_ref->{'ias-reg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ias-reg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ias-reg'}{'port'}{'udp'} = '2140'	; 
#	$srvcobjects_ref->{'ias-reg'}{'ports'}{'udp'}{'2140'}++	; 
#	$ports_ref->{'udp'}{'2140'}{'name'} = 'ias-reg'		; 
#	$srvcobjects_ref->{'ias-reg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ias-reg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ias-reg'}{'port'}{'tcp'} = '2140'	; 
#	$srvcobjects_ref->{'ias-reg'}{'ports'}{'tcp'}{'2140'}++	; 
#	$ports_ref->{'tcp'}{'2140'}{'name'} = 'ias-reg'		; 
#	$srvcobjects_ref->{'rds2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rds2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rds2'}{'port'}{'udp'} = '1541'	; 
#	$srvcobjects_ref->{'rds2'}{'ports'}{'udp'}{'1541'}++	; 
#	$ports_ref->{'udp'}{'1541'}{'name'} = 'rds2'		; 
#	$srvcobjects_ref->{'rds2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rds2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rds2'}{'port'}{'tcp'} = '1541'	; 
#	$srvcobjects_ref->{'rds2'}{'ports'}{'tcp'}{'1541'}++	; 
#	$ports_ref->{'tcp'}{'1541'}{'name'} = 'rds2'		; 
#	$srvcobjects_ref->{'oc-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oc-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oc-lm'}{'port'}{'udp'} = '1448'	; 
#	$srvcobjects_ref->{'oc-lm'}{'ports'}{'udp'}{'1448'}++	; 
#	$ports_ref->{'udp'}{'1448'}{'name'} = 'oc-lm'		; 
#	$srvcobjects_ref->{'oc-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oc-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oc-lm'}{'port'}{'tcp'} = '1448'	; 
#	$srvcobjects_ref->{'oc-lm'}{'ports'}{'tcp'}{'1448'}++	; 
#	$ports_ref->{'tcp'}{'1448'}{'name'} = 'oc-lm'		; 
#	$srvcobjects_ref->{'unify-adapter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unify-adapter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unify-adapter'}{'port'}{'udp'} = '1889'	; 
#	$srvcobjects_ref->{'unify-adapter'}{'ports'}{'udp'}{'1889'}++	; 
#	$ports_ref->{'udp'}{'1889'}{'name'} = 'unify-adapter'		; 
#	$srvcobjects_ref->{'unify-adapter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unify-adapter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unify-adapter'}{'port'}{'tcp'} = '1889'	; 
#	$srvcobjects_ref->{'unify-adapter'}{'ports'}{'tcp'}{'1889'}++	; 
#	$ports_ref->{'tcp'}{'1889'}{'name'} = 'unify-adapter'		; 
#	$srvcobjects_ref->{'metasage'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metasage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metasage'}{'port'}{'udp'} = '1207'	; 
#	$srvcobjects_ref->{'metasage'}{'ports'}{'udp'}{'1207'}++	; 
#	$ports_ref->{'udp'}{'1207'}{'name'} = 'metasage'		; 
#	$srvcobjects_ref->{'metasage'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metasage'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metasage'}{'port'}{'tcp'} = '1207'	; 
#	$srvcobjects_ref->{'metasage'}{'ports'}{'tcp'}{'1207'}++	; 
#	$ports_ref->{'tcp'}{'1207'}{'name'} = 'metasage'		; 
#	$srvcobjects_ref->{'re101'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'re101'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'re101'}{'port'}{'udp'} = '1343'	; 
#	$srvcobjects_ref->{'re101'}{'ports'}{'udp'}{'1343'}++	; 
#	$ports_ref->{'udp'}{'1343'}{'name'} = 're101'		; 
#	$srvcobjects_ref->{'re101'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'re101'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'re101'}{'port'}{'tcp'} = '1343'	; 
#	$srvcobjects_ref->{'re101'}{'ports'}{'tcp'}{'1343'}++	; 
#	$ports_ref->{'tcp'}{'1343'}{'name'} = 're101'		; 
#	$srvcobjects_ref->{'dbabble'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbabble'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbabble'}{'port'}{'udp'} = '8132'	; 
#	$srvcobjects_ref->{'dbabble'}{'ports'}{'udp'}{'8132'}++	; 
#	$ports_ref->{'udp'}{'8132'}{'name'} = 'dbabble'		; 
#	$srvcobjects_ref->{'dbabble'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbabble'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbabble'}{'port'}{'tcp'} = '8132'	; 
#	$srvcobjects_ref->{'dbabble'}{'ports'}{'tcp'}{'8132'}++	; 
#	$ports_ref->{'tcp'}{'8132'}{'name'} = 'dbabble'		; 
#	$srvcobjects_ref->{'proshareaudio'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proshareaudio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshareaudio'}{'port'}{'udp'} = '5713'	; 
#	$srvcobjects_ref->{'proshareaudio'}{'ports'}{'udp'}{'5713'}++	; 
#	$ports_ref->{'udp'}{'5713'}{'name'} = 'proshareaudio'		; 
#	$srvcobjects_ref->{'proshareaudio'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proshareaudio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshareaudio'}{'port'}{'tcp'} = '5713'	; 
#	$srvcobjects_ref->{'proshareaudio'}{'ports'}{'tcp'}{'5713'}++	; 
#	$ports_ref->{'tcp'}{'5713'}{'name'} = 'proshareaudio'		; 
#	$srvcobjects_ref->{'chromagrafx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chromagrafx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chromagrafx'}{'port'}{'udp'} = '1373'	; 
#	$srvcobjects_ref->{'chromagrafx'}{'ports'}{'udp'}{'1373'}++	; 
#	$ports_ref->{'udp'}{'1373'}{'name'} = 'chromagrafx'		; 
#	$srvcobjects_ref->{'chromagrafx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chromagrafx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chromagrafx'}{'port'}{'tcp'} = '1373'	; 
#	$srvcobjects_ref->{'chromagrafx'}{'ports'}{'tcp'}{'1373'}++	; 
#	$ports_ref->{'tcp'}{'1373'}{'name'} = 'chromagrafx'		; 
#	$srvcobjects_ref->{'netsteward'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netsteward'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsteward'}{'port'}{'udp'} = '2810'	; 
#	$srvcobjects_ref->{'netsteward'}{'ports'}{'udp'}{'2810'}++	; 
#	$ports_ref->{'udp'}{'2810'}{'name'} = 'netsteward'		; 
#	$srvcobjects_ref->{'netsteward'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netsteward'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsteward'}{'port'}{'tcp'} = '2810'	; 
#	$srvcobjects_ref->{'netsteward'}{'ports'}{'tcp'}{'2810'}++	; 
#	$ports_ref->{'tcp'}{'2810'}{'name'} = 'netsteward'		; 
#	$srvcobjects_ref->{'msmq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msmq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msmq'}{'port'}{'udp'} = '1801'	; 
#	$srvcobjects_ref->{'msmq'}{'ports'}{'udp'}{'1801'}++	; 
#	$ports_ref->{'udp'}{'1801'}{'name'} = 'msmq'		; 
#	$srvcobjects_ref->{'msmq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msmq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msmq'}{'port'}{'tcp'} = '1801'	; 
#	$srvcobjects_ref->{'msmq'}{'ports'}{'tcp'}{'1801'}++	; 
#	$ports_ref->{'tcp'}{'1801'}{'name'} = 'msmq'		; 
#	$srvcobjects_ref->{'lm-instmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lm-instmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-instmgr'}{'port'}{'udp'} = '8205'	; 
#	$srvcobjects_ref->{'lm-instmgr'}{'ports'}{'udp'}{'8205'}++	; 
#	$ports_ref->{'udp'}{'8205'}{'name'} = 'lm-instmgr'		; 
#	$srvcobjects_ref->{'lm-instmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lm-instmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-instmgr'}{'port'}{'tcp'} = '8205'	; 
#	$srvcobjects_ref->{'lm-instmgr'}{'ports'}{'tcp'}{'8205'}++	; 
#	$ports_ref->{'tcp'}{'8205'}{'name'} = 'lm-instmgr'		; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'port'}{'udp'} = '1083'	; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'ports'}{'udp'}{'1083'}++	; 
#	$ports_ref->{'udp'}{'1083'}{'name'} = 'ansoft-lm-1'		; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'port'}{'tcp'} = '1083'	; 
#	$srvcobjects_ref->{'ansoft-lm-1'}{'ports'}{'tcp'}{'1083'}++	; 
#	$ports_ref->{'tcp'}{'1083'}{'name'} = 'ansoft-lm-1'		; 
#	$srvcobjects_ref->{'ewall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ewall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewall'}{'port'}{'udp'} = '1328'	; 
#	$srvcobjects_ref->{'ewall'}{'ports'}{'udp'}{'1328'}++	; 
#	$ports_ref->{'udp'}{'1328'}{'name'} = 'ewall'		; 
#	$srvcobjects_ref->{'ewall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ewall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewall'}{'port'}{'tcp'} = '1328'	; 
#	$srvcobjects_ref->{'ewall'}{'ports'}{'tcp'}{'1328'}++	; 
#	$ports_ref->{'tcp'}{'1328'}{'name'} = 'ewall'		; 
#	$srvcobjects_ref->{'edb-server2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edb-server2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edb-server2'}{'port'}{'udp'} = '3711'	; 
#	$srvcobjects_ref->{'edb-server2'}{'ports'}{'udp'}{'3711'}++	; 
#	$ports_ref->{'udp'}{'3711'}{'name'} = 'edb-server2'		; 
#	$srvcobjects_ref->{'edb-server2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edb-server2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edb-server2'}{'port'}{'tcp'} = '3711'	; 
#	$srvcobjects_ref->{'edb-server2'}{'ports'}{'tcp'}{'3711'}++	; 
#	$ports_ref->{'tcp'}{'3711'}{'name'} = 'edb-server2'		; 
#	$srvcobjects_ref->{'dtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtp'}{'port'}{'udp'} = '3663'	; 
#	$srvcobjects_ref->{'dtp'}{'ports'}{'udp'}{'3663'}++	; 
#	$ports_ref->{'udp'}{'3663'}{'name'} = 'dtp'		; 
#	$srvcobjects_ref->{'dtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtp'}{'port'}{'tcp'} = '3663'	; 
#	$srvcobjects_ref->{'dtp'}{'ports'}{'tcp'}{'3663'}++	; 
#	$ports_ref->{'tcp'}{'3663'}{'name'} = 'dtp'		; 
#	$srvcobjects_ref->{'nbx-au'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nbx-au'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-au'}{'port'}{'udp'} = '2094'	; 
#	$srvcobjects_ref->{'nbx-au'}{'ports'}{'udp'}{'2094'}++	; 
#	$ports_ref->{'udp'}{'2094'}{'name'} = 'nbx-au'		; 
#	$srvcobjects_ref->{'nbx-au'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nbx-au'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-au'}{'port'}{'tcp'} = '2094'	; 
#	$srvcobjects_ref->{'nbx-au'}{'ports'}{'tcp'}{'2094'}++	; 
#	$ports_ref->{'tcp'}{'2094'}{'name'} = 'nbx-au'		; 
#	$srvcobjects_ref->{'ftrapid-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftrapid-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftrapid-1'}{'port'}{'udp'} = '1746'	; 
#	$srvcobjects_ref->{'ftrapid-1'}{'ports'}{'udp'}{'1746'}++	; 
#	$ports_ref->{'udp'}{'1746'}{'name'} = 'ftrapid-1'		; 
#	$srvcobjects_ref->{'ftrapid-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftrapid-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftrapid-1'}{'port'}{'tcp'} = '1746'	; 
#	$srvcobjects_ref->{'ftrapid-1'}{'ports'}{'tcp'}{'1746'}++	; 
#	$ports_ref->{'tcp'}{'1746'}{'name'} = 'ftrapid-1'		; 
#	$srvcobjects_ref->{'swa-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swa-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-2'}{'port'}{'udp'} = '9024'	; 
#	$srvcobjects_ref->{'swa-2'}{'ports'}{'udp'}{'9024'}++	; 
#	$ports_ref->{'udp'}{'9024'}{'name'} = 'swa-2'		; 
#	$srvcobjects_ref->{'swa-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swa-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-2'}{'port'}{'tcp'} = '9024'	; 
#	$srvcobjects_ref->{'swa-2'}{'ports'}{'tcp'}{'9024'}++	; 
#	$ports_ref->{'tcp'}{'9024'}{'name'} = 'swa-2'		; 
#	$srvcobjects_ref->{'msgclnt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msgclnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msgclnt'}{'port'}{'udp'} = '8786'	; 
#	$srvcobjects_ref->{'msgclnt'}{'ports'}{'udp'}{'8786'}++	; 
#	$ports_ref->{'udp'}{'8786'}{'name'} = 'msgclnt'		; 
#	$srvcobjects_ref->{'msgclnt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msgclnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msgclnt'}{'port'}{'tcp'} = '8786'	; 
#	$srvcobjects_ref->{'msgclnt'}{'ports'}{'tcp'}{'8786'}++	; 
#	$ports_ref->{'tcp'}{'8786'}{'name'} = 'msgclnt'		; 
#	$srvcobjects_ref->{'beeyond'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'beeyond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beeyond'}{'port'}{'udp'} = '2414'	; 
#	$srvcobjects_ref->{'beeyond'}{'ports'}{'udp'}{'2414'}++	; 
#	$ports_ref->{'udp'}{'2414'}{'name'} = 'beeyond'		; 
#	$srvcobjects_ref->{'beeyond'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'beeyond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beeyond'}{'port'}{'tcp'} = '2414'	; 
#	$srvcobjects_ref->{'beeyond'}{'ports'}{'tcp'}{'2414'}++	; 
#	$ports_ref->{'tcp'}{'2414'}{'name'} = 'beeyond'		; 
#	$srvcobjects_ref->{'genrad-mux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'genrad-mux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genrad-mux'}{'port'}{'udp'} = '176'	; 
#	$srvcobjects_ref->{'genrad-mux'}{'ports'}{'udp'}{'176'}++	; 
#	$ports_ref->{'udp'}{'176'}{'name'} = 'genrad-mux'		; 
#	$srvcobjects_ref->{'genrad-mux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'genrad-mux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genrad-mux'}{'port'}{'tcp'} = '176'	; 
#	$srvcobjects_ref->{'genrad-mux'}{'ports'}{'tcp'}{'176'}++	; 
#	$ports_ref->{'tcp'}{'176'}{'name'} = 'genrad-mux'		; 
#	$srvcobjects_ref->{'omginitialrefs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'omginitialrefs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'omginitialrefs'}{'port'}{'udp'} = '900'	; 
#	$srvcobjects_ref->{'omginitialrefs'}{'ports'}{'udp'}{'900'}++	; 
#	$ports_ref->{'udp'}{'900'}{'name'} = 'omginitialrefs'		; 
#	$srvcobjects_ref->{'omginitialrefs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'omginitialrefs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'omginitialrefs'}{'port'}{'tcp'} = '900'	; 
#	$srvcobjects_ref->{'omginitialrefs'}{'ports'}{'tcp'}{'900'}++	; 
#	$ports_ref->{'tcp'}{'900'}{'name'} = 'omginitialrefs'		; 
#	$srvcobjects_ref->{'tick-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tick-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tick-port'}{'port'}{'udp'} = '3200'	; 
#	$srvcobjects_ref->{'tick-port'}{'ports'}{'udp'}{'3200'}++	; 
#	$ports_ref->{'udp'}{'3200'}{'name'} = 'tick-port'		; 
#	$srvcobjects_ref->{'tick-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tick-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tick-port'}{'port'}{'tcp'} = '3200'	; 
#	$srvcobjects_ref->{'tick-port'}{'ports'}{'tcp'}{'3200'}++	; 
#	$ports_ref->{'tcp'}{'3200'}{'name'} = 'tick-port'		; 
#	$srvcobjects_ref->{'geniuslm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'geniuslm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'geniuslm'}{'port'}{'udp'} = '3005'	; 
#	$srvcobjects_ref->{'geniuslm'}{'ports'}{'udp'}{'3005'}++	; 
#	$ports_ref->{'udp'}{'3005'}{'name'} = 'geniuslm'		; 
#	$srvcobjects_ref->{'geniuslm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'geniuslm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'geniuslm'}{'port'}{'tcp'} = '3005'	; 
#	$srvcobjects_ref->{'geniuslm'}{'ports'}{'tcp'}{'3005'}++	; 
#	$ports_ref->{'tcp'}{'3005'}{'name'} = 'geniuslm'		; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'port'}{'udp'} = '3603'	; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'ports'}{'udp'}{'3603'}++	; 
#	$ports_ref->{'udp'}{'3603'}{'name'} = 'int-rcv-cntrl'		; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'port'}{'tcp'} = '3603'	; 
#	$srvcobjects_ref->{'int-rcv-cntrl'}{'ports'}{'tcp'}{'3603'}++	; 
#	$ports_ref->{'tcp'}{'3603'}{'name'} = 'int-rcv-cntrl'		; 
#	$srvcobjects_ref->{'newlixreg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newlixreg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newlixreg'}{'port'}{'udp'} = '2671'	; 
#	$srvcobjects_ref->{'newlixreg'}{'ports'}{'udp'}{'2671'}++	; 
#	$ports_ref->{'udp'}{'2671'}{'name'} = 'newlixreg'		; 
#	$srvcobjects_ref->{'newlixreg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newlixreg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newlixreg'}{'port'}{'tcp'} = '2671'	; 
#	$srvcobjects_ref->{'newlixreg'}{'ports'}{'tcp'}{'2671'}++	; 
#	$ports_ref->{'tcp'}{'2671'}{'name'} = 'newlixreg'		; 
#	$srvcobjects_ref->{'itose'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itose'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itose'}{'port'}{'udp'} = '4348'	; 
#	$srvcobjects_ref->{'itose'}{'ports'}{'udp'}{'4348'}++	; 
#	$ports_ref->{'udp'}{'4348'}{'name'} = 'itose'		; 
#	$srvcobjects_ref->{'itose'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itose'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itose'}{'port'}{'tcp'} = '4348'	; 
#	$srvcobjects_ref->{'itose'}{'ports'}{'tcp'}{'4348'}++	; 
#	$ports_ref->{'tcp'}{'4348'}{'name'} = 'itose'		; 
#	$srvcobjects_ref->{'ardusmul'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ardusmul'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardusmul'}{'port'}{'udp'} = '1835'	; 
#	$srvcobjects_ref->{'ardusmul'}{'ports'}{'udp'}{'1835'}++	; 
#	$ports_ref->{'udp'}{'1835'}{'name'} = 'ardusmul'		; 
#	$srvcobjects_ref->{'ardusmul'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ardusmul'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardusmul'}{'port'}{'tcp'} = '1835'	; 
#	$srvcobjects_ref->{'ardusmul'}{'ports'}{'tcp'}{'1835'}++	; 
#	$ports_ref->{'tcp'}{'1835'}{'name'} = 'ardusmul'		; 
#	$srvcobjects_ref->{'neoiface'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'neoiface'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neoiface'}{'port'}{'udp'} = '1285'	; 
#	$srvcobjects_ref->{'neoiface'}{'ports'}{'udp'}{'1285'}++	; 
#	$ports_ref->{'udp'}{'1285'}{'name'} = 'neoiface'		; 
#	$srvcobjects_ref->{'neoiface'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'neoiface'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neoiface'}{'port'}{'tcp'} = '1285'	; 
#	$srvcobjects_ref->{'neoiface'}{'ports'}{'tcp'}{'1285'}++	; 
#	$ports_ref->{'tcp'}{'1285'}{'name'} = 'neoiface'		; 
#	$srvcobjects_ref->{'volley'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'volley'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'volley'}{'port'}{'udp'} = '3625'	; 
#	$srvcobjects_ref->{'volley'}{'ports'}{'udp'}{'3625'}++	; 
#	$ports_ref->{'udp'}{'3625'}{'name'} = 'volley'		; 
#	$srvcobjects_ref->{'volley'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'volley'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'volley'}{'port'}{'tcp'} = '3625'	; 
#	$srvcobjects_ref->{'volley'}{'ports'}{'tcp'}{'3625'}++	; 
#	$ports_ref->{'tcp'}{'3625'}{'name'} = 'volley'		; 
#	$srvcobjects_ref->{'wizard'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wizard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wizard'}{'port'}{'udp'} = '2001'	; 
#	$srvcobjects_ref->{'wizard'}{'ports'}{'udp'}{'2001'}++	; 
#	$ports_ref->{'udp'}{'2001'}{'name'} = 'wizard'		; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'port'}{'udp'} = '5554'	; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'ports'}{'udp'}{'5554'}++	; 
#	$ports_ref->{'udp'}{'5554'}{'name'} = 'sgi-esphttp'		; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'port'}{'tcp'} = '5554'	; 
#	$srvcobjects_ref->{'sgi-esphttp'}{'ports'}{'tcp'}{'5554'}++	; 
#	$ports_ref->{'tcp'}{'5554'}{'name'} = 'sgi-esphttp'		; 
#	$srvcobjects_ref->{'cspuni'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cspuni'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspuni'}{'port'}{'udp'} = '2806'	; 
#	$srvcobjects_ref->{'cspuni'}{'ports'}{'udp'}{'2806'}++	; 
#	$ports_ref->{'udp'}{'2806'}{'name'} = 'cspuni'		; 
#	$srvcobjects_ref->{'cspuni'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cspuni'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cspuni'}{'port'}{'tcp'} = '2806'	; 
#	$srvcobjects_ref->{'cspuni'}{'ports'}{'tcp'}{'2806'}++	; 
#	$ports_ref->{'tcp'}{'2806'}{'name'} = 'cspuni'		; 
#	$srvcobjects_ref->{'adobeserver-5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adobeserver-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-5'}{'port'}{'udp'} = '3705'	; 
#	$srvcobjects_ref->{'adobeserver-5'}{'ports'}{'udp'}{'3705'}++	; 
#	$ports_ref->{'udp'}{'3705'}{'name'} = 'adobeserver-5'		; 
#	$srvcobjects_ref->{'adobeserver-5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adobeserver-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-5'}{'port'}{'tcp'} = '3705'	; 
#	$srvcobjects_ref->{'adobeserver-5'}{'ports'}{'tcp'}{'3705'}++	; 
#	$ports_ref->{'tcp'}{'3705'}{'name'} = 'adobeserver-5'		; 
#	$srvcobjects_ref->{'iee-qfx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iee-qfx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iee-qfx'}{'port'}{'udp'} = '1284'	; 
#	$srvcobjects_ref->{'iee-qfx'}{'ports'}{'udp'}{'1284'}++	; 
#	$ports_ref->{'udp'}{'1284'}{'name'} = 'iee-qfx'		; 
#	$srvcobjects_ref->{'iee-qfx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iee-qfx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iee-qfx'}{'port'}{'tcp'} = '1284'	; 
#	$srvcobjects_ref->{'iee-qfx'}{'ports'}{'tcp'}{'1284'}++	; 
#	$ports_ref->{'tcp'}{'1284'}{'name'} = 'iee-qfx'		; 
#	$srvcobjects_ref->{'broker_service'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'broker_service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'broker_service'}{'port'}{'udp'} = '3014'	; 
#	$srvcobjects_ref->{'broker_service'}{'ports'}{'udp'}{'3014'}++	; 
#	$ports_ref->{'udp'}{'3014'}{'name'} = 'broker_service'		; 
#	$srvcobjects_ref->{'broker_service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'broker_service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'broker_service'}{'port'}{'tcp'} = '3014'	; 
#	$srvcobjects_ref->{'broker_service'}{'ports'}{'tcp'}{'3014'}++	; 
#	$ports_ref->{'tcp'}{'3014'}{'name'} = 'broker_service'		; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'port'}{'udp'} = '1629'	; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'ports'}{'udp'}{'1629'}++	; 
#	$ports_ref->{'udp'}{'1629'}{'name'} = 'lontalk-urgnt'		; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'port'}{'tcp'} = '1629'	; 
#	$srvcobjects_ref->{'lontalk-urgnt'}{'ports'}{'tcp'}{'1629'}++	; 
#	$ports_ref->{'tcp'}{'1629'}{'name'} = 'lontalk-urgnt'		; 
#	$srvcobjects_ref->{'unicall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unicall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unicall'}{'port'}{'udp'} = '4343'	; 
#	$srvcobjects_ref->{'unicall'}{'ports'}{'udp'}{'4343'}++	; 
#	$ports_ref->{'udp'}{'4343'}{'name'} = 'unicall'		; 
#	$srvcobjects_ref->{'unicall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unicall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unicall'}{'port'}{'tcp'} = '4343'	; 
#	$srvcobjects_ref->{'unicall'}{'ports'}{'tcp'}{'4343'}++	; 
#	$ports_ref->{'tcp'}{'4343'}{'name'} = 'unicall'		; 
#	$srvcobjects_ref->{'unix-status'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unix-status'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unix-status'}{'port'}{'udp'} = '1957'	; 
#	$srvcobjects_ref->{'unix-status'}{'ports'}{'udp'}{'1957'}++	; 
#	$ports_ref->{'udp'}{'1957'}{'name'} = 'unix-status'		; 
#	$srvcobjects_ref->{'unix-status'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unix-status'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unix-status'}{'port'}{'tcp'} = '1957'	; 
#	$srvcobjects_ref->{'unix-status'}{'ports'}{'tcp'}{'1957'}++	; 
#	$ports_ref->{'tcp'}{'1957'}{'name'} = 'unix-status'		; 
#	$srvcobjects_ref->{'eyelink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eyelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eyelink'}{'port'}{'udp'} = '589'	; 
#	$srvcobjects_ref->{'eyelink'}{'ports'}{'udp'}{'589'}++	; 
#	$ports_ref->{'udp'}{'589'}{'name'} = 'eyelink'		; 
#	$srvcobjects_ref->{'eyelink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eyelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eyelink'}{'port'}{'tcp'} = '589'	; 
#	$srvcobjects_ref->{'eyelink'}{'ports'}{'tcp'}{'589'}++	; 
#	$ports_ref->{'tcp'}{'589'}{'name'} = 'eyelink'		; 
#	$srvcobjects_ref->{'iapp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iapp'}{'port'}{'udp'} = '2313'	; 
#	$srvcobjects_ref->{'iapp'}{'ports'}{'udp'}{'2313'}++	; 
#	$ports_ref->{'udp'}{'2313'}{'name'} = 'iapp'		; 
#	$srvcobjects_ref->{'iapp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iapp'}{'port'}{'tcp'} = '2313'	; 
#	$srvcobjects_ref->{'iapp'}{'ports'}{'tcp'}{'2313'}++	; 
#	$ports_ref->{'tcp'}{'2313'}{'name'} = 'iapp'		; 
#	$srvcobjects_ref->{'netview-aix-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-3'}{'port'}{'udp'} = '1663'	; 
#	$srvcobjects_ref->{'netview-aix-3'}{'ports'}{'udp'}{'1663'}++	; 
#	$ports_ref->{'udp'}{'1663'}{'name'} = 'netview-aix-3'		; 
#	$srvcobjects_ref->{'netview-aix-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-3'}{'port'}{'tcp'} = '1663'	; 
#	$srvcobjects_ref->{'netview-aix-3'}{'ports'}{'tcp'}{'1663'}++	; 
#	$ports_ref->{'tcp'}{'1663'}{'name'} = 'netview-aix-3'		; 
#	$srvcobjects_ref->{'sep'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sep'}{'port'}{'udp'} = '2089'	; 
#	$srvcobjects_ref->{'sep'}{'ports'}{'udp'}{'2089'}++	; 
#	$ports_ref->{'udp'}{'2089'}{'name'} = 'sep'		; 
#	$srvcobjects_ref->{'sep'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sep'}{'port'}{'tcp'} = '2089'	; 
#	$srvcobjects_ref->{'sep'}{'ports'}{'tcp'}{'2089'}++	; 
#	$ports_ref->{'tcp'}{'2089'}{'name'} = 'sep'		; 
#	$srvcobjects_ref->{'bpmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bpmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpmd'}{'port'}{'udp'} = '3593'	; 
#	$srvcobjects_ref->{'bpmd'}{'ports'}{'udp'}{'3593'}++	; 
#	$ports_ref->{'udp'}{'3593'}{'name'} = 'bpmd'		; 
#	$srvcobjects_ref->{'bpmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bpmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpmd'}{'port'}{'tcp'} = '3593'	; 
#	$srvcobjects_ref->{'bpmd'}{'ports'}{'tcp'}{'3593'}++	; 
#	$ports_ref->{'tcp'}{'3593'}{'name'} = 'bpmd'		; 
#	$srvcobjects_ref->{'fhsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fhsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fhsp'}{'port'}{'udp'} = '1807'	; 
#	$srvcobjects_ref->{'fhsp'}{'ports'}{'udp'}{'1807'}++	; 
#	$ports_ref->{'udp'}{'1807'}{'name'} = 'fhsp'		; 
#	$srvcobjects_ref->{'fhsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fhsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fhsp'}{'port'}{'tcp'} = '1807'	; 
#	$srvcobjects_ref->{'fhsp'}{'ports'}{'tcp'}{'1807'}++	; 
#	$ports_ref->{'tcp'}{'1807'}{'name'} = 'fhsp'		; 
#	$srvcobjects_ref->{'labrat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'labrat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'labrat'}{'port'}{'udp'} = '2560'	; 
#	$srvcobjects_ref->{'labrat'}{'ports'}{'udp'}{'2560'}++	; 
#	$ports_ref->{'udp'}{'2560'}{'name'} = 'labrat'		; 
#	$srvcobjects_ref->{'labrat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'labrat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'labrat'}{'port'}{'tcp'} = '2560'	; 
#	$srvcobjects_ref->{'labrat'}{'ports'}{'tcp'}{'2560'}++	; 
#	$ports_ref->{'tcp'}{'2560'}{'name'} = 'labrat'		; 
#	$srvcobjects_ref->{'essp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'essp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'essp'}{'port'}{'udp'} = '2969'	; 
#	$srvcobjects_ref->{'essp'}{'ports'}{'udp'}{'2969'}++	; 
#	$ports_ref->{'udp'}{'2969'}{'name'} = 'essp'		; 
#	$srvcobjects_ref->{'essp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'essp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'essp'}{'port'}{'tcp'} = '2969'	; 
#	$srvcobjects_ref->{'essp'}{'ports'}{'tcp'}{'2969'}++	; 
#	$ports_ref->{'tcp'}{'2969'}{'name'} = 'essp'		; 
#	$srvcobjects_ref->{'system-monitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'system-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'system-monitor'}{'port'}{'udp'} = '2609'	; 
#	$srvcobjects_ref->{'system-monitor'}{'ports'}{'udp'}{'2609'}++	; 
#	$ports_ref->{'udp'}{'2609'}{'name'} = 'system-monitor'		; 
#	$srvcobjects_ref->{'system-monitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'system-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'system-monitor'}{'port'}{'tcp'} = '2609'	; 
#	$srvcobjects_ref->{'system-monitor'}{'ports'}{'tcp'}{'2609'}++	; 
#	$ports_ref->{'tcp'}{'2609'}{'name'} = 'system-monitor'		; 
#	$srvcobjects_ref->{'upnotifyp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'upnotifyp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upnotifyp'}{'port'}{'udp'} = '4445'	; 
#	$srvcobjects_ref->{'upnotifyp'}{'ports'}{'udp'}{'4445'}++	; 
#	$ports_ref->{'udp'}{'4445'}{'name'} = 'upnotifyp'		; 
#	$srvcobjects_ref->{'upnotifyp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'upnotifyp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'upnotifyp'}{'port'}{'tcp'} = '4445'	; 
#	$srvcobjects_ref->{'upnotifyp'}{'ports'}{'tcp'}{'4445'}++	; 
#	$ports_ref->{'tcp'}{'4445'}{'name'} = 'upnotifyp'		; 
#	$srvcobjects_ref->{'softaudit'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'softaudit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softaudit'}{'port'}{'udp'} = '3419'	; 
#	$srvcobjects_ref->{'softaudit'}{'ports'}{'udp'}{'3419'}++	; 
#	$ports_ref->{'udp'}{'3419'}{'name'} = 'softaudit'		; 
#	$srvcobjects_ref->{'softaudit'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'softaudit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softaudit'}{'port'}{'tcp'} = '3419'	; 
#	$srvcobjects_ref->{'softaudit'}{'ports'}{'tcp'}{'3419'}++	; 
#	$ports_ref->{'tcp'}{'3419'}{'name'} = 'softaudit'		; 
#	$srvcobjects_ref->{'vat-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vat-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vat-control'}{'port'}{'udp'} = '3457'	; 
#	$srvcobjects_ref->{'vat-control'}{'ports'}{'udp'}{'3457'}++	; 
#	$ports_ref->{'udp'}{'3457'}{'name'} = 'vat-control'		; 
#	$srvcobjects_ref->{'vat-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vat-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vat-control'}{'port'}{'tcp'} = '3457'	; 
#	$srvcobjects_ref->{'vat-control'}{'ports'}{'tcp'}{'3457'}++	; 
#	$ports_ref->{'tcp'}{'3457'}{'name'} = 'vat-control'		; 
#	$srvcobjects_ref->{'isns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isns'}{'port'}{'udp'} = '3205'	; 
#	$srvcobjects_ref->{'isns'}{'ports'}{'udp'}{'3205'}++	; 
#	$ports_ref->{'udp'}{'3205'}{'name'} = 'isns'		; 
#	$srvcobjects_ref->{'isns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isns'}{'port'}{'tcp'} = '3205'	; 
#	$srvcobjects_ref->{'isns'}{'ports'}{'tcp'}{'3205'}++	; 
#	$ports_ref->{'tcp'}{'3205'}{'name'} = 'isns'		; 
#	$srvcobjects_ref->{'close-combat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'close-combat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'close-combat'}{'port'}{'udp'} = '1944'	; 
#	$srvcobjects_ref->{'close-combat'}{'ports'}{'udp'}{'1944'}++	; 
#	$ports_ref->{'udp'}{'1944'}{'name'} = 'close-combat'		; 
#	$srvcobjects_ref->{'close-combat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'close-combat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'close-combat'}{'port'}{'tcp'} = '1944'	; 
#	$srvcobjects_ref->{'close-combat'}{'ports'}{'tcp'}{'1944'}++	; 
#	$ports_ref->{'tcp'}{'1944'}{'name'} = 'close-combat'		; 
#	$srvcobjects_ref->{'entextnetwk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entextnetwk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextnetwk'}{'port'}{'udp'} = '12001'	; 
#	$srvcobjects_ref->{'entextnetwk'}{'ports'}{'udp'}{'12001'}++	; 
#	$ports_ref->{'udp'}{'12001'}{'name'} = 'entextnetwk'		; 
#	$srvcobjects_ref->{'entextnetwk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entextnetwk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextnetwk'}{'port'}{'tcp'} = '12001'	; 
#	$srvcobjects_ref->{'entextnetwk'}{'ports'}{'tcp'}{'12001'}++	; 
#	$ports_ref->{'tcp'}{'12001'}{'name'} = 'entextnetwk'		; 
#	$srvcobjects_ref->{'nimspooler'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nimspooler'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimspooler'}{'port'}{'udp'} = '48001'	; 
#	$srvcobjects_ref->{'nimspooler'}{'ports'}{'udp'}{'48001'}++	; 
#	$ports_ref->{'udp'}{'48001'}{'name'} = 'nimspooler'		; 
#	$srvcobjects_ref->{'nimspooler'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nimspooler'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimspooler'}{'port'}{'tcp'} = '48001'	; 
#	$srvcobjects_ref->{'nimspooler'}{'ports'}{'tcp'}{'48001'}++	; 
#	$ports_ref->{'tcp'}{'48001'}{'name'} = 'nimspooler'		; 
#	$srvcobjects_ref->{'savant'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'savant'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'savant'}{'port'}{'udp'} = '3391'	; 
#	$srvcobjects_ref->{'savant'}{'ports'}{'udp'}{'3391'}++	; 
#	$ports_ref->{'udp'}{'3391'}{'name'} = 'savant'		; 
#	$srvcobjects_ref->{'savant'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'savant'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'savant'}{'port'}{'tcp'} = '3391'	; 
#	$srvcobjects_ref->{'savant'}{'ports'}{'tcp'}{'3391'}++	; 
#	$ports_ref->{'tcp'}{'3391'}{'name'} = 'savant'		; 
#	$srvcobjects_ref->{'unihub-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unihub-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unihub-server'}{'port'}{'udp'} = '2357'	; 
#	$srvcobjects_ref->{'unihub-server'}{'ports'}{'udp'}{'2357'}++	; 
#	$ports_ref->{'udp'}{'2357'}{'name'} = 'unihub-server'		; 
#	$srvcobjects_ref->{'unihub-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unihub-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unihub-server'}{'port'}{'tcp'} = '2357'	; 
#	$srvcobjects_ref->{'unihub-server'}{'ports'}{'tcp'}{'2357'}++	; 
#	$ports_ref->{'tcp'}{'2357'}{'name'} = 'unihub-server'		; 
#	$srvcobjects_ref->{'dsmcc-session'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsmcc-session'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-session'}{'port'}{'udp'} = '13819'	; 
#	$srvcobjects_ref->{'dsmcc-session'}{'ports'}{'udp'}{'13819'}++	; 
#	$ports_ref->{'udp'}{'13819'}{'name'} = 'dsmcc-session'		; 
#	$srvcobjects_ref->{'dsmcc-session'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsmcc-session'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-session'}{'port'}{'tcp'} = '13819'	; 
#	$srvcobjects_ref->{'dsmcc-session'}{'ports'}{'tcp'}{'13819'}++	; 
#	$ports_ref->{'tcp'}{'13819'}{'name'} = 'dsmcc-session'		; 
#	$srvcobjects_ref->{'systemics-sox'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'systemics-sox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'systemics-sox'}{'port'}{'udp'} = '5406'	; 
#	$srvcobjects_ref->{'systemics-sox'}{'ports'}{'udp'}{'5406'}++	; 
#	$ports_ref->{'udp'}{'5406'}{'name'} = 'systemics-sox'		; 
#	$srvcobjects_ref->{'systemics-sox'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'systemics-sox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'systemics-sox'}{'port'}{'tcp'} = '5406'	; 
#	$srvcobjects_ref->{'systemics-sox'}{'ports'}{'tcp'}{'5406'}++	; 
#	$ports_ref->{'tcp'}{'5406'}{'name'} = 'systemics-sox'		; 
#	$srvcobjects_ref->{'dmaf-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dmaf-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmaf-server'}{'port'}{'tcp'} = '3574'	; 
#	$srvcobjects_ref->{'dmaf-server'}{'ports'}{'tcp'}{'3574'}++	; 
#	$ports_ref->{'tcp'}{'3574'}{'name'} = 'dmaf-server'		; 
#	$srvcobjects_ref->{'ka0wuc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ka0wuc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ka0wuc'}{'port'}{'udp'} = '2822'	; 
#	$srvcobjects_ref->{'ka0wuc'}{'ports'}{'udp'}{'2822'}++	; 
#	$ports_ref->{'udp'}{'2822'}{'name'} = 'ka0wuc'		; 
#	$srvcobjects_ref->{'ka0wuc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ka0wuc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ka0wuc'}{'port'}{'tcp'} = '2822'	; 
#	$srvcobjects_ref->{'ka0wuc'}{'ports'}{'tcp'}{'2822'}++	; 
#	$ports_ref->{'tcp'}{'2822'}{'name'} = 'ka0wuc'		; 
#	$srvcobjects_ref->{'opc-job-track'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opc-job-track'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opc-job-track'}{'port'}{'udp'} = '424'	; 
#	$srvcobjects_ref->{'opc-job-track'}{'ports'}{'udp'}{'424'}++	; 
#	$ports_ref->{'udp'}{'424'}{'name'} = 'opc-job-track'		; 
#	$srvcobjects_ref->{'opc-job-track'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opc-job-track'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opc-job-track'}{'port'}{'tcp'} = '424'	; 
#	$srvcobjects_ref->{'opc-job-track'}{'ports'}{'tcp'}{'424'}++	; 
#	$ports_ref->{'tcp'}{'424'}{'name'} = 'opc-job-track'		; 
#	$srvcobjects_ref->{'citadel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'citadel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citadel'}{'port'}{'udp'} = '504'	; 
#	$srvcobjects_ref->{'citadel'}{'ports'}{'udp'}{'504'}++	; 
#	$ports_ref->{'udp'}{'504'}{'name'} = 'citadel'		; 
#	$srvcobjects_ref->{'citadel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'citadel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citadel'}{'port'}{'tcp'} = '504'	; 
#	$srvcobjects_ref->{'citadel'}{'ports'}{'tcp'}{'504'}++	; 
#	$ports_ref->{'tcp'}{'504'}{'name'} = 'citadel'		; 
#	$srvcobjects_ref->{'direcpc-video'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'direcpc-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direcpc-video'}{'port'}{'udp'} = '1825'	; 
#	$srvcobjects_ref->{'direcpc-video'}{'ports'}{'udp'}{'1825'}++	; 
#	$ports_ref->{'udp'}{'1825'}{'name'} = 'direcpc-video'		; 
#	$srvcobjects_ref->{'direcpc-video'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'direcpc-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direcpc-video'}{'port'}{'tcp'} = '1825'	; 
#	$srvcobjects_ref->{'direcpc-video'}{'ports'}{'tcp'}{'1825'}++	; 
#	$ports_ref->{'tcp'}{'1825'}{'name'} = 'direcpc-video'		; 
#	$srvcobjects_ref->{'gxtelmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gxtelmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gxtelmd'}{'port'}{'udp'} = '2356'	; 
#	$srvcobjects_ref->{'gxtelmd'}{'ports'}{'udp'}{'2356'}++	; 
#	$ports_ref->{'udp'}{'2356'}{'name'} = 'gxtelmd'		; 
#	$srvcobjects_ref->{'gxtelmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gxtelmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gxtelmd'}{'port'}{'tcp'} = '2356'	; 
#	$srvcobjects_ref->{'gxtelmd'}{'ports'}{'tcp'}{'2356'}++	; 
#	$ports_ref->{'tcp'}{'2356'}{'name'} = 'gxtelmd'		; 
#	$srvcobjects_ref->{'sonar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sonar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonar'}{'port'}{'udp'} = '572'	; 
#	$srvcobjects_ref->{'sonar'}{'ports'}{'udp'}{'572'}++	; 
#	$ports_ref->{'udp'}{'572'}{'name'} = 'sonar'		; 
#	$srvcobjects_ref->{'sonar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sonar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonar'}{'port'}{'tcp'} = '572'	; 
#	$srvcobjects_ref->{'sonar'}{'ports'}{'tcp'}{'572'}++	; 
#	$ports_ref->{'tcp'}{'572'}{'name'} = 'sonar'		; 
#	$srvcobjects_ref->{'apc-5455'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-5455'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-5455'}{'port'}{'udp'} = '5455'	; 
#	$srvcobjects_ref->{'apc-5455'}{'ports'}{'udp'}{'5455'}++	; 
#	$ports_ref->{'udp'}{'5455'}{'name'} = 'apc-5455'		; 
#	$srvcobjects_ref->{'apc-5455'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-5455'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-5455'}{'port'}{'tcp'} = '5455'	; 
#	$srvcobjects_ref->{'apc-5455'}{'ports'}{'tcp'}{'5455'}++	; 
#	$ports_ref->{'tcp'}{'5455'}{'name'} = 'apc-5455'		; 
#	$srvcobjects_ref->{'kerberos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kerberos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kerberos'}{'port'}{'udp'} = '88'	; 
#	$srvcobjects_ref->{'kerberos'}{'ports'}{'udp'}{'88'}++	; 
#	$ports_ref->{'udp'}{'88'}{'name'} = 'kerberos'		; 
#	$srvcobjects_ref->{'kerberos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kerberos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kerberos'}{'port'}{'tcp'} = '88'	; 
#	$srvcobjects_ref->{'kerberos'}{'ports'}{'tcp'}{'88'}++	; 
#	$ports_ref->{'tcp'}{'88'}{'name'} = 'kerberos'		; 
#	$srvcobjects_ref->{'mediavault-gui'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mediavault-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mediavault-gui'}{'port'}{'udp'} = '3673'	; 
#	$srvcobjects_ref->{'mediavault-gui'}{'ports'}{'udp'}{'3673'}++	; 
#	$ports_ref->{'udp'}{'3673'}{'name'} = 'mediavault-gui'		; 
#	$srvcobjects_ref->{'mediavault-gui'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mediavault-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mediavault-gui'}{'port'}{'tcp'} = '3673'	; 
#	$srvcobjects_ref->{'mediavault-gui'}{'ports'}{'tcp'}{'3673'}++	; 
#	$ports_ref->{'tcp'}{'3673'}{'name'} = 'mediavault-gui'		; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'port'}{'udp'} = '1293'	; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'ports'}{'udp'}{'1293'}++	; 
#	$ports_ref->{'udp'}{'1293'}{'name'} = 'pkt-krb-ipsec'		; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'port'}{'tcp'} = '1293'	; 
#	$srvcobjects_ref->{'pkt-krb-ipsec'}{'ports'}{'tcp'}{'1293'}++	; 
#	$ports_ref->{'tcp'}{'1293'}{'name'} = 'pkt-krb-ipsec'		; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'port'}{'udp'} = '3986'	; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'ports'}{'udp'}{'3986'}++	; 
#	$ports_ref->{'udp'}{'3986'}{'name'} = 'mapper-ws_ethd'		; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'port'}{'tcp'} = '3986'	; 
#	$srvcobjects_ref->{'mapper-ws_ethd'}{'ports'}{'tcp'}{'3986'}++	; 
#	$ports_ref->{'tcp'}{'3986'}{'name'} = 'mapper-ws_ethd'		; 
#	$srvcobjects_ref->{'inbusiness'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'inbusiness'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'inbusiness'}{'port'}{'udp'} = '244'	; 
#	$srvcobjects_ref->{'inbusiness'}{'ports'}{'udp'}{'244'}++	; 
#	$ports_ref->{'udp'}{'244'}{'name'} = 'inbusiness'		; 
#	$srvcobjects_ref->{'inbusiness'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'inbusiness'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'inbusiness'}{'port'}{'tcp'} = '244'	; 
#	$srvcobjects_ref->{'inbusiness'}{'ports'}{'tcp'}{'244'}++	; 
#	$ports_ref->{'tcp'}{'244'}{'name'} = 'inbusiness'		; 
#	$srvcobjects_ref->{'winqedit'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'winqedit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winqedit'}{'port'}{'udp'} = '7395'	; 
#	$srvcobjects_ref->{'winqedit'}{'ports'}{'udp'}{'7395'}++	; 
#	$ports_ref->{'udp'}{'7395'}{'name'} = 'winqedit'		; 
#	$srvcobjects_ref->{'winqedit'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'winqedit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winqedit'}{'port'}{'tcp'} = '7395'	; 
#	$srvcobjects_ref->{'winqedit'}{'ports'}{'tcp'}{'7395'}++	; 
#	$ports_ref->{'tcp'}{'7395'}{'name'} = 'winqedit'		; 
#	$srvcobjects_ref->{'lmdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lmdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lmdp'}{'port'}{'udp'} = '2623'	; 
#	$srvcobjects_ref->{'lmdp'}{'ports'}{'udp'}{'2623'}++	; 
#	$ports_ref->{'udp'}{'2623'}{'name'} = 'lmdp'		; 
#	$srvcobjects_ref->{'lmdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lmdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lmdp'}{'port'}{'tcp'} = '2623'	; 
#	$srvcobjects_ref->{'lmdp'}{'ports'}{'tcp'}{'2623'}++	; 
#	$ports_ref->{'tcp'}{'2623'}{'name'} = 'lmdp'		; 
#	$srvcobjects_ref->{'ibm-ssd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-ssd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-ssd'}{'port'}{'udp'} = '1260'	; 
#	$srvcobjects_ref->{'ibm-ssd'}{'ports'}{'udp'}{'1260'}++	; 
#	$ports_ref->{'udp'}{'1260'}{'name'} = 'ibm-ssd'		; 
#	$srvcobjects_ref->{'ibm-ssd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-ssd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-ssd'}{'port'}{'tcp'} = '1260'	; 
#	$srvcobjects_ref->{'ibm-ssd'}{'ports'}{'tcp'}{'1260'}++	; 
#	$ports_ref->{'tcp'}{'1260'}{'name'} = 'ibm-ssd'		; 
#	$srvcobjects_ref->{'ndmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndmp'}{'port'}{'udp'} = '10000'	; 
#	$srvcobjects_ref->{'ndmp'}{'ports'}{'udp'}{'10000'}++	; 
#	$ports_ref->{'udp'}{'10000'}{'name'} = 'ndmp'		; 
#	$srvcobjects_ref->{'ndmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndmp'}{'port'}{'tcp'} = '10000'	; 
#	$srvcobjects_ref->{'ndmp'}{'ports'}{'tcp'}{'10000'}++	; 
#	$ports_ref->{'tcp'}{'10000'}{'name'} = 'ndmp'		; 
#	$srvcobjects_ref->{'kana'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kana'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kana'}{'port'}{'udp'} = '2656'	; 
#	$srvcobjects_ref->{'kana'}{'ports'}{'udp'}{'2656'}++	; 
#	$ports_ref->{'udp'}{'2656'}{'name'} = 'kana'		; 
#	$srvcobjects_ref->{'kana'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kana'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kana'}{'port'}{'tcp'} = '2656'	; 
#	$srvcobjects_ref->{'kana'}{'ports'}{'tcp'}{'2656'}++	; 
#	$ports_ref->{'tcp'}{'2656'}{'name'} = 'kana'		; 
#	$srvcobjects_ref->{'dj-ilm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dj-ilm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dj-ilm'}{'port'}{'udp'} = '3362'	; 
#	$srvcobjects_ref->{'dj-ilm'}{'ports'}{'udp'}{'3362'}++	; 
#	$ports_ref->{'udp'}{'3362'}{'name'} = 'dj-ilm'		; 
#	$srvcobjects_ref->{'dj-ilm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dj-ilm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dj-ilm'}{'port'}{'tcp'} = '3362'	; 
#	$srvcobjects_ref->{'dj-ilm'}{'ports'}{'tcp'}{'3362'}++	; 
#	$ports_ref->{'tcp'}{'3362'}{'name'} = 'dj-ilm'		; 
#	$srvcobjects_ref->{'webaccess'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webaccess'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webaccess'}{'port'}{'udp'} = '1739'	; 
#	$srvcobjects_ref->{'webaccess'}{'ports'}{'udp'}{'1739'}++	; 
#	$ports_ref->{'udp'}{'1739'}{'name'} = 'webaccess'		; 
#	$srvcobjects_ref->{'webaccess'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webaccess'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webaccess'}{'port'}{'tcp'} = '1739'	; 
#	$srvcobjects_ref->{'webaccess'}{'ports'}{'tcp'}{'1739'}++	; 
#	$ports_ref->{'tcp'}{'1739'}{'name'} = 'webaccess'		; 
#	$srvcobjects_ref->{'dbisamserver1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbisamserver1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbisamserver1'}{'port'}{'udp'} = '12005'	; 
#	$srvcobjects_ref->{'dbisamserver1'}{'ports'}{'udp'}{'12005'}++	; 
#	$ports_ref->{'udp'}{'12005'}{'name'} = 'dbisamserver1'		; 
#	$srvcobjects_ref->{'dbisamserver1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbisamserver1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbisamserver1'}{'port'}{'tcp'} = '12005'	; 
#	$srvcobjects_ref->{'dbisamserver1'}{'ports'}{'tcp'}{'12005'}++	; 
#	$ports_ref->{'tcp'}{'12005'}{'name'} = 'dbisamserver1'		; 
#	$srvcobjects_ref->{'incp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'incp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'incp'}{'port'}{'udp'} = '2932'	; 
#	$srvcobjects_ref->{'incp'}{'ports'}{'udp'}{'2932'}++	; 
#	$ports_ref->{'udp'}{'2932'}{'name'} = 'incp'		; 
#	$srvcobjects_ref->{'incp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'incp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'incp'}{'port'}{'tcp'} = '2932'	; 
#	$srvcobjects_ref->{'incp'}{'ports'}{'tcp'}{'2932'}++	; 
#	$ports_ref->{'tcp'}{'2932'}{'name'} = 'incp'		; 
#	$srvcobjects_ref->{'hello'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hello'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hello'}{'port'}{'udp'} = '1789'	; 
#	$srvcobjects_ref->{'hello'}{'ports'}{'udp'}{'1789'}++	; 
#	$ports_ref->{'udp'}{'1789'}{'name'} = 'hello'		; 
#	$srvcobjects_ref->{'hello'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hello'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hello'}{'port'}{'tcp'} = '1789'	; 
#	$srvcobjects_ref->{'hello'}{'ports'}{'tcp'}{'1789'}++	; 
#	$ports_ref->{'tcp'}{'1789'}{'name'} = 'hello'		; 
#	$srvcobjects_ref->{'btrieve'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'btrieve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btrieve'}{'port'}{'udp'} = '3351'	; 
#	$srvcobjects_ref->{'btrieve'}{'ports'}{'udp'}{'3351'}++	; 
#	$ports_ref->{'udp'}{'3351'}{'name'} = 'btrieve'		; 
#	$srvcobjects_ref->{'btrieve'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'btrieve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btrieve'}{'port'}{'tcp'} = '3351'	; 
#	$srvcobjects_ref->{'btrieve'}{'ports'}{'tcp'}{'3351'}++	; 
#	$ports_ref->{'tcp'}{'3351'}{'name'} = 'btrieve'		; 
#	$srvcobjects_ref->{'asia'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asia'}{'port'}{'udp'} = '626'	; 
#	$srvcobjects_ref->{'asia'}{'ports'}{'udp'}{'626'}++	; 
#	$ports_ref->{'udp'}{'626'}{'name'} = 'asia'		; 
#	$srvcobjects_ref->{'asia'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asia'}{'port'}{'tcp'} = '626'	; 
#	$srvcobjects_ref->{'asia'}{'ports'}{'tcp'}{'626'}++	; 
#	$ports_ref->{'tcp'}{'626'}{'name'} = 'asia'		; 
#	$srvcobjects_ref->{'rmiaux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmiaux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmiaux'}{'port'}{'udp'} = '10990'	; 
#	$srvcobjects_ref->{'rmiaux'}{'ports'}{'udp'}{'10990'}++	; 
#	$ports_ref->{'udp'}{'10990'}{'name'} = 'rmiaux'		; 
#	$srvcobjects_ref->{'rmiaux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmiaux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmiaux'}{'port'}{'tcp'} = '10990'	; 
#	$srvcobjects_ref->{'rmiaux'}{'ports'}{'tcp'}{'10990'}++	; 
#	$ports_ref->{'tcp'}{'10990'}{'name'} = 'rmiaux'		; 
#	$srvcobjects_ref->{'slinkysearch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slinkysearch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slinkysearch'}{'port'}{'udp'} = '1225'	; 
#	$srvcobjects_ref->{'slinkysearch'}{'ports'}{'udp'}{'1225'}++	; 
#	$ports_ref->{'udp'}{'1225'}{'name'} = 'slinkysearch'		; 
#	$srvcobjects_ref->{'slinkysearch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slinkysearch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slinkysearch'}{'port'}{'tcp'} = '1225'	; 
#	$srvcobjects_ref->{'slinkysearch'}{'ports'}{'tcp'}{'1225'}++	; 
#	$ports_ref->{'tcp'}{'1225'}{'name'} = 'slinkysearch'		; 
#	$srvcobjects_ref->{'vat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vat'}{'port'}{'udp'} = '3456'	; 
#	$srvcobjects_ref->{'vat'}{'ports'}{'udp'}{'3456'}++	; 
#	$ports_ref->{'udp'}{'3456'}{'name'} = 'vat'		; 
#	$srvcobjects_ref->{'vat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vat'}{'port'}{'tcp'} = '3456'	; 
#	$srvcobjects_ref->{'vat'}{'ports'}{'tcp'}{'3456'}++	; 
#	$ports_ref->{'tcp'}{'3456'}{'name'} = 'vat'		; 
#	$srvcobjects_ref->{'meta-corp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'meta-corp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meta-corp'}{'port'}{'udp'} = '6141'	; 
#	$srvcobjects_ref->{'meta-corp'}{'ports'}{'udp'}{'6141'}++	; 
#	$ports_ref->{'udp'}{'6141'}{'name'} = 'meta-corp'		; 
#	$srvcobjects_ref->{'meta-corp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'meta-corp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meta-corp'}{'port'}{'tcp'} = '6141'	; 
#	$srvcobjects_ref->{'meta-corp'}{'ports'}{'tcp'}{'6141'}++	; 
#	$ports_ref->{'tcp'}{'6141'}{'name'} = 'meta-corp'		; 
#	$srvcobjects_ref->{'sysscanner'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sysscanner'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysscanner'}{'port'}{'udp'} = '3251'	; 
#	$srvcobjects_ref->{'sysscanner'}{'ports'}{'udp'}{'3251'}++	; 
#	$ports_ref->{'udp'}{'3251'}{'name'} = 'sysscanner'		; 
#	$srvcobjects_ref->{'sysscanner'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sysscanner'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysscanner'}{'port'}{'tcp'} = '3251'	; 
#	$srvcobjects_ref->{'sysscanner'}{'ports'}{'tcp'}{'3251'}++	; 
#	$ports_ref->{'tcp'}{'3251'}{'name'} = 'sysscanner'		; 
#	$srvcobjects_ref->{'https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'https'}{'port'}{'udp'} = '443'	; 
#	$srvcobjects_ref->{'https'}{'ports'}{'udp'}{'443'}++	; 
#	$ports_ref->{'udp'}{'443'}{'name'} = 'https'		; 
#	$srvcobjects_ref->{'https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'https'}{'port'}{'tcp'} = '443'	; 
#	$srvcobjects_ref->{'https'}{'ports'}{'tcp'}{'443'}++	; 
#	$ports_ref->{'tcp'}{'443'}{'name'} = 'https'		; 
#	$srvcobjects_ref->{'sais'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sais'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sais'}{'port'}{'udp'} = '1426'	; 
#	$srvcobjects_ref->{'sais'}{'ports'}{'udp'}{'1426'}++	; 
#	$ports_ref->{'udp'}{'1426'}{'name'} = 'sais'		; 
#	$srvcobjects_ref->{'sais'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sais'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sais'}{'port'}{'tcp'} = '1426'	; 
#	$srvcobjects_ref->{'sais'}{'ports'}{'tcp'}{'1426'}++	; 
#	$ports_ref->{'tcp'}{'1426'}{'name'} = 'sais'		; 
#	$srvcobjects_ref->{'enl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'enl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enl'}{'port'}{'udp'} = '1804'	; 
#	$srvcobjects_ref->{'enl'}{'ports'}{'udp'}{'1804'}++	; 
#	$ports_ref->{'udp'}{'1804'}{'name'} = 'enl'		; 
#	$srvcobjects_ref->{'enl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'enl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enl'}{'port'}{'tcp'} = '1804'	; 
#	$srvcobjects_ref->{'enl'}{'ports'}{'tcp'}{'1804'}++	; 
#	$ports_ref->{'tcp'}{'1804'}{'name'} = 'enl'		; 
#	$srvcobjects_ref->{'haipe-discover'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'haipe-discover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'haipe-discover'}{'port'}{'udp'} = '3623'	; 
#	$srvcobjects_ref->{'haipe-discover'}{'ports'}{'udp'}{'3623'}++	; 
#	$ports_ref->{'udp'}{'3623'}{'name'} = 'haipe-discover'		; 
#	$srvcobjects_ref->{'haipe-discover'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'haipe-discover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'haipe-discover'}{'port'}{'tcp'} = '3623'	; 
#	$srvcobjects_ref->{'haipe-discover'}{'ports'}{'tcp'}{'3623'}++	; 
#	$ports_ref->{'tcp'}{'3623'}{'name'} = 'haipe-discover'		; 
#	$srvcobjects_ref->{'ibm-diradm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-diradm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-diradm'}{'port'}{'udp'} = '3538'	; 
#	$srvcobjects_ref->{'ibm-diradm'}{'ports'}{'udp'}{'3538'}++	; 
#	$ports_ref->{'udp'}{'3538'}{'name'} = 'ibm-diradm'		; 
#	$srvcobjects_ref->{'ibm-diradm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-diradm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-diradm'}{'port'}{'tcp'} = '3538'	; 
#	$srvcobjects_ref->{'ibm-diradm'}{'ports'}{'tcp'}{'3538'}++	; 
#	$ports_ref->{'tcp'}{'3538'}{'name'} = 'ibm-diradm'		; 
#	$srvcobjects_ref->{'quicksuite'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quicksuite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quicksuite'}{'port'}{'udp'} = '2900'	; 
#	$srvcobjects_ref->{'quicksuite'}{'ports'}{'udp'}{'2900'}++	; 
#	$ports_ref->{'udp'}{'2900'}{'name'} = 'quicksuite'		; 
#	$srvcobjects_ref->{'quicksuite'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quicksuite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quicksuite'}{'port'}{'tcp'} = '2900'	; 
#	$srvcobjects_ref->{'quicksuite'}{'ports'}{'tcp'}{'2900'}++	; 
#	$ports_ref->{'tcp'}{'2900'}{'name'} = 'quicksuite'		; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'port'}{'udp'} = '1466'	; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'ports'}{'udp'}{'1466'}++	; 
#	$ports_ref->{'udp'}{'1466'}{'name'} = 'oceansoft-lm'		; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'port'}{'tcp'} = '1466'	; 
#	$srvcobjects_ref->{'oceansoft-lm'}{'ports'}{'tcp'}{'1466'}++	; 
#	$ports_ref->{'tcp'}{'1466'}{'name'} = 'oceansoft-lm'		; 
#	$srvcobjects_ref->{'at-nbp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-nbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-nbp'}{'port'}{'udp'} = '202'	; 
#	$srvcobjects_ref->{'at-nbp'}{'ports'}{'udp'}{'202'}++	; 
#	$ports_ref->{'udp'}{'202'}{'name'} = 'at-nbp'		; 
#	$srvcobjects_ref->{'at-nbp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-nbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-nbp'}{'port'}{'tcp'} = '202'	; 
#	$srvcobjects_ref->{'at-nbp'}{'ports'}{'tcp'}{'202'}++	; 
#	$ports_ref->{'tcp'}{'202'}{'name'} = 'at-nbp'		; 
#	$srvcobjects_ref->{'mediaspace'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mediaspace'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mediaspace'}{'port'}{'udp'} = '3594'	; 
#	$srvcobjects_ref->{'mediaspace'}{'ports'}{'udp'}{'3594'}++	; 
#	$ports_ref->{'udp'}{'3594'}{'name'} = 'mediaspace'		; 
#	$srvcobjects_ref->{'mediaspace'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mediaspace'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mediaspace'}{'port'}{'tcp'} = '3594'	; 
#	$srvcobjects_ref->{'mediaspace'}{'ports'}{'tcp'}{'3594'}++	; 
#	$ports_ref->{'tcp'}{'3594'}{'name'} = 'mediaspace'		; 
#	$srvcobjects_ref->{'enpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'enpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enpc'}{'port'}{'udp'} = '3289'	; 
#	$srvcobjects_ref->{'enpc'}{'ports'}{'udp'}{'3289'}++	; 
#	$ports_ref->{'udp'}{'3289'}{'name'} = 'enpc'		; 
#	$srvcobjects_ref->{'enpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'enpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enpc'}{'port'}{'tcp'} = '3289'	; 
#	$srvcobjects_ref->{'enpc'}{'ports'}{'tcp'}{'3289'}++	; 
#	$ports_ref->{'tcp'}{'3289'}{'name'} = 'enpc'		; 
#	$srvcobjects_ref->{'ddi-udp-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddi-udp-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-udp-3'}{'port'}{'udp'} = '8890'	; 
#	$srvcobjects_ref->{'ddi-udp-3'}{'ports'}{'udp'}{'8890'}++	; 
#	$ports_ref->{'udp'}{'8890'}{'name'} = 'ddi-udp-3'		; 
#	$srvcobjects_ref->{'seaodbc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'seaodbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seaodbc'}{'port'}{'udp'} = '2471'	; 
#	$srvcobjects_ref->{'seaodbc'}{'ports'}{'udp'}{'2471'}++	; 
#	$ports_ref->{'udp'}{'2471'}{'name'} = 'seaodbc'		; 
#	$srvcobjects_ref->{'seaodbc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'seaodbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seaodbc'}{'port'}{'tcp'} = '2471'	; 
#	$srvcobjects_ref->{'seaodbc'}{'ports'}{'tcp'}{'2471'}++	; 
#	$ports_ref->{'tcp'}{'2471'}{'name'} = 'seaodbc'		; 
#	$srvcobjects_ref->{'crestron-cip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'crestron-cip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crestron-cip'}{'port'}{'udp'} = '41794'	; 
#	$srvcobjects_ref->{'crestron-cip'}{'ports'}{'udp'}{'41794'}++	; 
#	$ports_ref->{'udp'}{'41794'}{'name'} = 'crestron-cip'		; 
#	$srvcobjects_ref->{'crestron-cip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'crestron-cip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crestron-cip'}{'port'}{'tcp'} = '41794'	; 
#	$srvcobjects_ref->{'crestron-cip'}{'ports'}{'tcp'}{'41794'}++	; 
#	$ports_ref->{'tcp'}{'41794'}{'name'} = 'crestron-cip'		; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'port'}{'udp'} = '11967'	; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'ports'}{'udp'}{'11967'}++	; 
#	$ports_ref->{'udp'}{'11967'}{'name'} = 'sysinfo-sp'		; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'port'}{'tcp'} = '11967'	; 
#	$srvcobjects_ref->{'sysinfo-sp'}{'ports'}{'tcp'}{'11967'}++	; 
#	$ports_ref->{'tcp'}{'11967'}{'name'} = 'sysinfo-sp'		; 
#	$srvcobjects_ref->{'repcmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'repcmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'repcmd'}{'port'}{'udp'} = '641'	; 
#	$srvcobjects_ref->{'repcmd'}{'ports'}{'udp'}{'641'}++	; 
#	$ports_ref->{'udp'}{'641'}{'name'} = 'repcmd'		; 
#	$srvcobjects_ref->{'repcmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'repcmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'repcmd'}{'port'}{'tcp'} = '641'	; 
#	$srvcobjects_ref->{'repcmd'}{'ports'}{'tcp'}{'641'}++	; 
#	$ports_ref->{'tcp'}{'641'}{'name'} = 'repcmd'		; 
#	$srvcobjects_ref->{'ucentric-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ucentric-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ucentric-ds'}{'port'}{'udp'} = '2879'	; 
#	$srvcobjects_ref->{'ucentric-ds'}{'ports'}{'udp'}{'2879'}++	; 
#	$ports_ref->{'udp'}{'2879'}{'name'} = 'ucentric-ds'		; 
#	$srvcobjects_ref->{'ucentric-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ucentric-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ucentric-ds'}{'port'}{'tcp'} = '2879'	; 
#	$srvcobjects_ref->{'ucentric-ds'}{'ports'}{'tcp'}{'2879'}++	; 
#	$ports_ref->{'tcp'}{'2879'}{'name'} = 'ucentric-ds'		; 
#	$srvcobjects_ref->{'gwen-sonya'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gwen-sonya'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gwen-sonya'}{'port'}{'udp'} = '2778'	; 
#	$srvcobjects_ref->{'gwen-sonya'}{'ports'}{'udp'}{'2778'}++	; 
#	$ports_ref->{'udp'}{'2778'}{'name'} = 'gwen-sonya'		; 
#	$srvcobjects_ref->{'gwen-sonya'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gwen-sonya'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gwen-sonya'}{'port'}{'tcp'} = '2778'	; 
#	$srvcobjects_ref->{'gwen-sonya'}{'ports'}{'tcp'}{'2778'}++	; 
#	$ports_ref->{'tcp'}{'2778'}{'name'} = 'gwen-sonya'		; 
#	$srvcobjects_ref->{'targus-getdata3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'targus-getdata3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata3'}{'port'}{'udp'} = '5203'	; 
#	$srvcobjects_ref->{'targus-getdata3'}{'ports'}{'udp'}{'5203'}++	; 
#	$ports_ref->{'udp'}{'5203'}{'name'} = 'targus-getdata3'		; 
#	$srvcobjects_ref->{'targus-getdata3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'targus-getdata3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'targus-getdata3'}{'port'}{'tcp'} = '5203'	; 
#	$srvcobjects_ref->{'targus-getdata3'}{'ports'}{'tcp'}{'5203'}++	; 
#	$ports_ref->{'tcp'}{'5203'}{'name'} = 'targus-getdata3'		; 
#	$srvcobjects_ref->{'optima-vnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'optima-vnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optima-vnet'}{'port'}{'udp'} = '1051'	; 
#	$srvcobjects_ref->{'optima-vnet'}{'ports'}{'udp'}{'1051'}++	; 
#	$ports_ref->{'udp'}{'1051'}{'name'} = 'optima-vnet'		; 
#	$srvcobjects_ref->{'optima-vnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'optima-vnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optima-vnet'}{'port'}{'tcp'} = '1051'	; 
#	$srvcobjects_ref->{'optima-vnet'}{'ports'}{'tcp'}{'1051'}++	; 
#	$ports_ref->{'tcp'}{'1051'}{'name'} = 'optima-vnet'		; 
#	$srvcobjects_ref->{'hydap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hydap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hydap'}{'port'}{'udp'} = '15000'	; 
#	$srvcobjects_ref->{'hydap'}{'ports'}{'udp'}{'15000'}++	; 
#	$ports_ref->{'udp'}{'15000'}{'name'} = 'hydap'		; 
#	$srvcobjects_ref->{'hydap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hydap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hydap'}{'port'}{'tcp'} = '15000'	; 
#	$srvcobjects_ref->{'hydap'}{'ports'}{'tcp'}{'15000'}++	; 
#	$ports_ref->{'tcp'}{'15000'}{'name'} = 'hydap'		; 
#	$srvcobjects_ref->{'iatp-highpri'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iatp-highpri'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iatp-highpri'}{'port'}{'udp'} = '6998'	; 
#	$srvcobjects_ref->{'iatp-highpri'}{'ports'}{'udp'}{'6998'}++	; 
#	$ports_ref->{'udp'}{'6998'}{'name'} = 'iatp-highpri'		; 
#	$srvcobjects_ref->{'iatp-highpri'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iatp-highpri'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iatp-highpri'}{'port'}{'tcp'} = '6998'	; 
#	$srvcobjects_ref->{'iatp-highpri'}{'ports'}{'tcp'}{'6998'}++	; 
#	$ports_ref->{'tcp'}{'6998'}{'name'} = 'iatp-highpri'		; 
#	$srvcobjects_ref->{'hosts2-ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hosts2-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hosts2-ns'}{'port'}{'udp'} = '81'	; 
#	$srvcobjects_ref->{'hosts2-ns'}{'ports'}{'udp'}{'81'}++	; 
#	$ports_ref->{'udp'}{'81'}{'name'} = 'hosts2-ns'		; 
#	$srvcobjects_ref->{'hosts2-ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hosts2-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hosts2-ns'}{'port'}{'tcp'} = '81'	; 
#	$srvcobjects_ref->{'hosts2-ns'}{'ports'}{'tcp'}{'81'}++	; 
#	$ports_ref->{'tcp'}{'81'}{'name'} = 'hosts2-ns'		; 
#	$srvcobjects_ref->{'encore'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'encore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'encore'}{'port'}{'udp'} = '1740'	; 
#	$srvcobjects_ref->{'encore'}{'ports'}{'udp'}{'1740'}++	; 
#	$ports_ref->{'udp'}{'1740'}{'name'} = 'encore'		; 
#	$srvcobjects_ref->{'encore'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'encore'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'encore'}{'port'}{'tcp'} = '1740'	; 
#	$srvcobjects_ref->{'encore'}{'ports'}{'tcp'}{'1740'}++	; 
#	$ports_ref->{'tcp'}{'1740'}{'name'} = 'encore'		; 
#	$srvcobjects_ref->{'filenet-rpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filenet-rpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-rpc'}{'port'}{'udp'} = '32769'	; 
#	$srvcobjects_ref->{'filenet-rpc'}{'ports'}{'udp'}{'32769'}++	; 
#	$ports_ref->{'udp'}{'32769'}{'name'} = 'filenet-rpc'		; 
#	$srvcobjects_ref->{'filenet-rpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filenet-rpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-rpc'}{'port'}{'tcp'} = '32769'	; 
#	$srvcobjects_ref->{'filenet-rpc'}{'ports'}{'tcp'}{'32769'}++	; 
#	$ports_ref->{'tcp'}{'32769'}{'name'} = 'filenet-rpc'		; 
#	$srvcobjects_ref->{'xinuexpansion1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xinuexpansion1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinuexpansion1'}{'port'}{'udp'} = '2021'	; 
#	$srvcobjects_ref->{'xinuexpansion1'}{'ports'}{'udp'}{'2021'}++	; 
#	$ports_ref->{'udp'}{'2021'}{'name'} = 'xinuexpansion1'		; 
#	$srvcobjects_ref->{'eudora-set'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eudora-set'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eudora-set'}{'port'}{'udp'} = '592'	; 
#	$srvcobjects_ref->{'eudora-set'}{'ports'}{'udp'}{'592'}++	; 
#	$ports_ref->{'udp'}{'592'}{'name'} = 'eudora-set'		; 
#	$srvcobjects_ref->{'eudora-set'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eudora-set'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eudora-set'}{'port'}{'tcp'} = '592'	; 
#	$srvcobjects_ref->{'eudora-set'}{'ports'}{'tcp'}{'592'}++	; 
#	$ports_ref->{'tcp'}{'592'}{'name'} = 'eudora-set'		; 
#	$srvcobjects_ref->{'med-ltp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'med-ltp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-ltp'}{'port'}{'udp'} = '24000'	; 
#	$srvcobjects_ref->{'med-ltp'}{'ports'}{'udp'}{'24000'}++	; 
#	$ports_ref->{'udp'}{'24000'}{'name'} = 'med-ltp'		; 
#	$srvcobjects_ref->{'med-ltp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'med-ltp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-ltp'}{'port'}{'tcp'} = '24000'	; 
#	$srvcobjects_ref->{'med-ltp'}{'ports'}{'tcp'}{'24000'}++	; 
#	$ports_ref->{'tcp'}{'24000'}{'name'} = 'med-ltp'		; 
#	$srvcobjects_ref->{'telindus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telindus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telindus'}{'port'}{'udp'} = '1728'	; 
#	$srvcobjects_ref->{'telindus'}{'ports'}{'udp'}{'1728'}++	; 
#	$ports_ref->{'udp'}{'1728'}{'name'} = 'telindus'		; 
#	$srvcobjects_ref->{'telindus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telindus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telindus'}{'port'}{'tcp'} = '1728'	; 
#	$srvcobjects_ref->{'telindus'}{'ports'}{'tcp'}{'1728'}++	; 
#	$ports_ref->{'tcp'}{'1728'}{'name'} = 'telindus'		; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'port'}{'udp'} = '3257'	; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'ports'}{'udp'}{'3257'}++	; 
#	$ports_ref->{'udp'}{'3257'}{'name'} = 'cpqrpm-server'		; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'port'}{'tcp'} = '3257'	; 
#	$srvcobjects_ref->{'cpqrpm-server'}{'ports'}{'tcp'}{'3257'}++	; 
#	$ports_ref->{'tcp'}{'3257'}{'name'} = 'cpqrpm-server'		; 
#	$srvcobjects_ref->{'health-trap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'health-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'health-trap'}{'port'}{'udp'} = '1162'	; 
#	$srvcobjects_ref->{'health-trap'}{'ports'}{'udp'}{'1162'}++	; 
#	$ports_ref->{'udp'}{'1162'}{'name'} = 'health-trap'		; 
#	$srvcobjects_ref->{'health-trap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'health-trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'health-trap'}{'port'}{'tcp'} = '1162'	; 
#	$srvcobjects_ref->{'health-trap'}{'ports'}{'tcp'}{'1162'}++	; 
#	$ports_ref->{'tcp'}{'1162'}{'name'} = 'health-trap'		; 
#	$srvcobjects_ref->{'visitview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'visitview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visitview'}{'port'}{'udp'} = '1631'	; 
#	$srvcobjects_ref->{'visitview'}{'ports'}{'udp'}{'1631'}++	; 
#	$ports_ref->{'udp'}{'1631'}{'name'} = 'visitview'		; 
#	$srvcobjects_ref->{'visitview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'visitview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visitview'}{'port'}{'tcp'} = '1631'	; 
#	$srvcobjects_ref->{'visitview'}{'ports'}{'tcp'}{'1631'}++	; 
#	$ports_ref->{'tcp'}{'1631'}{'name'} = 'visitview'		; 
#	$srvcobjects_ref->{'ssowatch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssowatch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssowatch'}{'port'}{'udp'} = '3644'	; 
#	$srvcobjects_ref->{'ssowatch'}{'ports'}{'udp'}{'3644'}++	; 
#	$ports_ref->{'udp'}{'3644'}{'name'} = 'ssowatch'		; 
#	$srvcobjects_ref->{'ssowatch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssowatch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssowatch'}{'port'}{'tcp'} = '3644'	; 
#	$srvcobjects_ref->{'ssowatch'}{'ports'}{'tcp'}{'3644'}++	; 
#	$ports_ref->{'tcp'}{'3644'}{'name'} = 'ssowatch'		; 
#	$srvcobjects_ref->{'ncube-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncube-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncube-lm'}{'port'}{'udp'} = '1521'	; 
#	$srvcobjects_ref->{'ncube-lm'}{'ports'}{'udp'}{'1521'}++	; 
#	$ports_ref->{'udp'}{'1521'}{'name'} = 'ncube-lm'		; 
#	$srvcobjects_ref->{'ncube-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncube-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncube-lm'}{'port'}{'tcp'} = '1521'	; 
#	$srvcobjects_ref->{'ncube-lm'}{'ports'}{'tcp'}{'1521'}++	; 
#	$ports_ref->{'tcp'}{'1521'}{'name'} = 'ncube-lm'		; 
#	$srvcobjects_ref->{'patrol-snmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'patrol-snmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol-snmp'}{'port'}{'udp'} = '8161'	; 
#	$srvcobjects_ref->{'patrol-snmp'}{'ports'}{'udp'}{'8161'}++	; 
#	$ports_ref->{'udp'}{'8161'}{'name'} = 'patrol-snmp'		; 
#	$srvcobjects_ref->{'patrol-snmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'patrol-snmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol-snmp'}{'port'}{'tcp'} = '8161'	; 
#	$srvcobjects_ref->{'patrol-snmp'}{'ports'}{'tcp'}{'8161'}++	; 
#	$ports_ref->{'tcp'}{'8161'}{'name'} = 'patrol-snmp'		; 
#	$srvcobjects_ref->{'ias-admind'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ias-admind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ias-admind'}{'port'}{'udp'} = '2141'	; 
#	$srvcobjects_ref->{'ias-admind'}{'ports'}{'udp'}{'2141'}++	; 
#	$ports_ref->{'udp'}{'2141'}{'name'} = 'ias-admind'		; 
#	$srvcobjects_ref->{'ias-admind'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ias-admind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ias-admind'}{'port'}{'tcp'} = '2141'	; 
#	$srvcobjects_ref->{'ias-admind'}{'ports'}{'tcp'}{'2141'}++	; 
#	$ports_ref->{'tcp'}{'2141'}{'name'} = 'ias-admind'		; 
#	$srvcobjects_ref->{'synchronet-db'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synchronet-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synchronet-db'}{'port'}{'udp'} = '6100'	; 
#	$srvcobjects_ref->{'synchronet-db'}{'ports'}{'udp'}{'6100'}++	; 
#	$ports_ref->{'udp'}{'6100'}{'name'} = 'synchronet-db'		; 
#	$srvcobjects_ref->{'synchronet-db'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synchronet-db'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synchronet-db'}{'port'}{'tcp'} = '6100'	; 
#	$srvcobjects_ref->{'synchronet-db'}{'ports'}{'tcp'}{'6100'}++	; 
#	$ports_ref->{'tcp'}{'6100'}{'name'} = 'synchronet-db'		; 
#	$srvcobjects_ref->{'umm-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'umm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'umm-port'}{'port'}{'udp'} = '3098'	; 
#	$srvcobjects_ref->{'umm-port'}{'ports'}{'udp'}{'3098'}++	; 
#	$ports_ref->{'udp'}{'3098'}{'name'} = 'umm-port'		; 
#	$srvcobjects_ref->{'umm-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'umm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'umm-port'}{'port'}{'tcp'} = '3098'	; 
#	$srvcobjects_ref->{'umm-port'}{'ports'}{'tcp'}{'3098'}++	; 
#	$ports_ref->{'tcp'}{'3098'}{'name'} = 'umm-port'		; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'port'}{'udp'} = '1279'	; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'ports'}{'udp'}{'1279'}++	; 
#	$ports_ref->{'udp'}{'1279'}{'name'} = 'dellwebadmin-2'		; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'port'}{'tcp'} = '1279'	; 
#	$srvcobjects_ref->{'dellwebadmin-2'}{'ports'}{'tcp'}{'1279'}++	; 
#	$ports_ref->{'tcp'}{'1279'}{'name'} = 'dellwebadmin-2'		; 
#	$srvcobjects_ref->{'proxim'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proxim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proxim'}{'port'}{'udp'} = '1732'	; 
#	$srvcobjects_ref->{'proxim'}{'ports'}{'udp'}{'1732'}++	; 
#	$ports_ref->{'udp'}{'1732'}{'name'} = 'proxim'		; 
#	$srvcobjects_ref->{'proxim'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proxim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proxim'}{'port'}{'tcp'} = '1732'	; 
#	$srvcobjects_ref->{'proxim'}{'ports'}{'tcp'}{'1732'}++	; 
#	$ports_ref->{'tcp'}{'1732'}{'name'} = 'proxim'		; 
#	$srvcobjects_ref->{'swa-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swa-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-4'}{'port'}{'udp'} = '9026'	; 
#	$srvcobjects_ref->{'swa-4'}{'ports'}{'udp'}{'9026'}++	; 
#	$ports_ref->{'udp'}{'9026'}{'name'} = 'swa-4'		; 
#	$srvcobjects_ref->{'swa-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swa-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-4'}{'port'}{'tcp'} = '9026'	; 
#	$srvcobjects_ref->{'swa-4'}{'ports'}{'tcp'}{'9026'}++	; 
#	$ports_ref->{'tcp'}{'9026'}{'name'} = 'swa-4'		; 
#	$srvcobjects_ref->{'sychrond'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sychrond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sychrond'}{'port'}{'udp'} = '3723'	; 
#	$srvcobjects_ref->{'sychrond'}{'ports'}{'udp'}{'3723'}++	; 
#	$ports_ref->{'udp'}{'3723'}{'name'} = 'sychrond'		; 
#	$srvcobjects_ref->{'sychrond'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sychrond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sychrond'}{'port'}{'tcp'} = '3723'	; 
#	$srvcobjects_ref->{'sychrond'}{'ports'}{'tcp'}{'3723'}++	; 
#	$ports_ref->{'tcp'}{'3723'}{'name'} = 'sychrond'		; 
#	$srvcobjects_ref->{'qrh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qrh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qrh'}{'port'}{'udp'} = '752'	; 
#	$srvcobjects_ref->{'qrh'}{'ports'}{'udp'}{'752'}++	; 
#	$ports_ref->{'udp'}{'752'}{'name'} = 'qrh'		; 
#	$srvcobjects_ref->{'qrh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qrh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qrh'}{'port'}{'tcp'} = '752'	; 
#	$srvcobjects_ref->{'qrh'}{'ports'}{'tcp'}{'752'}++	; 
#	$ports_ref->{'tcp'}{'752'}{'name'} = 'qrh'		; 
#	$srvcobjects_ref->{'unimobilectrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unimobilectrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unimobilectrl'}{'port'}{'udp'} = '2927'	; 
#	$srvcobjects_ref->{'unimobilectrl'}{'ports'}{'udp'}{'2927'}++	; 
#	$ports_ref->{'udp'}{'2927'}{'name'} = 'unimobilectrl'		; 
#	$srvcobjects_ref->{'unimobilectrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unimobilectrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unimobilectrl'}{'port'}{'tcp'} = '2927'	; 
#	$srvcobjects_ref->{'unimobilectrl'}{'ports'}{'tcp'}{'2927'}++	; 
#	$ports_ref->{'tcp'}{'2927'}{'name'} = 'unimobilectrl'		; 
#	$srvcobjects_ref->{'a15'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'a15'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a15'}{'port'}{'udp'} = '3598'	; 
#	$srvcobjects_ref->{'a15'}{'ports'}{'udp'}{'3598'}++	; 
#	$ports_ref->{'udp'}{'3598'}{'name'} = 'a15'		; 
#	$srvcobjects_ref->{'a15'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'a15'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a15'}{'port'}{'tcp'} = '3598'	; 
#	$srvcobjects_ref->{'a15'}{'ports'}{'tcp'}{'3598'}++	; 
#	$ports_ref->{'tcp'}{'3598'}{'name'} = 'a15'		; 
#	$srvcobjects_ref->{'elcsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elcsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elcsd'}{'port'}{'udp'} = '704'	; 
#	$srvcobjects_ref->{'elcsd'}{'ports'}{'udp'}{'704'}++	; 
#	$ports_ref->{'udp'}{'704'}{'name'} = 'elcsd'		; 
#	$srvcobjects_ref->{'elcsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elcsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elcsd'}{'port'}{'tcp'} = '704'	; 
#	$srvcobjects_ref->{'elcsd'}{'ports'}{'tcp'}{'704'}++	; 
#	$ports_ref->{'tcp'}{'704'}{'name'} = 'elcsd'		; 
#	$srvcobjects_ref->{'fcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp'}{'port'}{'udp'} = '510'	; 
#	$srvcobjects_ref->{'fcp'}{'ports'}{'udp'}{'510'}++	; 
#	$ports_ref->{'udp'}{'510'}{'name'} = 'fcp'		; 
#	$srvcobjects_ref->{'fcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp'}{'port'}{'tcp'} = '510'	; 
#	$srvcobjects_ref->{'fcp'}{'ports'}{'tcp'}{'510'}++	; 
#	$ports_ref->{'tcp'}{'510'}{'name'} = 'fcp'		; 
#	$srvcobjects_ref->{'ng-umds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ng-umds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ng-umds'}{'port'}{'udp'} = '1690'	; 
#	$srvcobjects_ref->{'ng-umds'}{'ports'}{'udp'}{'1690'}++	; 
#	$ports_ref->{'udp'}{'1690'}{'name'} = 'ng-umds'		; 
#	$srvcobjects_ref->{'ng-umds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ng-umds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ng-umds'}{'port'}{'tcp'} = '1690'	; 
#	$srvcobjects_ref->{'ng-umds'}{'ports'}{'tcp'}{'1690'}++	; 
#	$ports_ref->{'tcp'}{'1690'}{'name'} = 'ng-umds'		; 
#	$srvcobjects_ref->{'aironetddp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aironetddp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aironetddp'}{'port'}{'udp'} = '2887'	; 
#	$srvcobjects_ref->{'aironetddp'}{'ports'}{'udp'}{'2887'}++	; 
#	$ports_ref->{'udp'}{'2887'}{'name'} = 'aironetddp'		; 
#	$srvcobjects_ref->{'aironetddp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aironetddp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aironetddp'}{'port'}{'tcp'} = '2887'	; 
#	$srvcobjects_ref->{'aironetddp'}{'ports'}{'tcp'}{'2887'}++	; 
#	$ports_ref->{'tcp'}{'2887'}{'name'} = 'aironetddp'		; 
#	$srvcobjects_ref->{'ecolor-imager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ecolor-imager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecolor-imager'}{'port'}{'udp'} = '3263'	; 
#	$srvcobjects_ref->{'ecolor-imager'}{'ports'}{'udp'}{'3263'}++	; 
#	$ports_ref->{'udp'}{'3263'}{'name'} = 'ecolor-imager'		; 
#	$srvcobjects_ref->{'ecolor-imager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ecolor-imager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecolor-imager'}{'port'}{'tcp'} = '3263'	; 
#	$srvcobjects_ref->{'ecolor-imager'}{'ports'}{'tcp'}{'3263'}++	; 
#	$ports_ref->{'tcp'}{'3263'}{'name'} = 'ecolor-imager'		; 
#	$srvcobjects_ref->{'rescap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rescap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rescap'}{'port'}{'udp'} = '283'	; 
#	$srvcobjects_ref->{'rescap'}{'ports'}{'udp'}{'283'}++	; 
#	$ports_ref->{'udp'}{'283'}{'name'} = 'rescap'		; 
#	$srvcobjects_ref->{'rescap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rescap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rescap'}{'port'}{'tcp'} = '283'	; 
#	$srvcobjects_ref->{'rescap'}{'ports'}{'tcp'}{'283'}++	; 
#	$ports_ref->{'tcp'}{'283'}{'name'} = 'rescap'		; 
#	$srvcobjects_ref->{'madge-om'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'madge-om'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'madge-om'}{'port'}{'udp'} = '2453'	; 
#	$srvcobjects_ref->{'madge-om'}{'ports'}{'udp'}{'2453'}++	; 
#	$ports_ref->{'udp'}{'2453'}{'name'} = 'madge-om'		; 
#	$srvcobjects_ref->{'madge-om'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'madge-om'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'madge-om'}{'port'}{'tcp'} = '2453'	; 
#	$srvcobjects_ref->{'madge-om'}{'ports'}{'tcp'}{'2453'}++	; 
#	$ports_ref->{'tcp'}{'2453'}{'name'} = 'madge-om'		; 
#	$srvcobjects_ref->{'zip'}{'type'} = 'ddp'	; 
#	$srvcobjects_ref->{'zip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zip'}{'port'}{'ddp'} = '6'	; 
#	$srvcobjects_ref->{'zip'}{'ports'}{'ddp'}{'6'}++	; 
#	$ports_ref->{'ddp'}{'6'}{'name'} = 'zip'		; 
#	$srvcobjects_ref->{'ptp-general'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ptp-general'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptp-general'}{'port'}{'udp'} = '320'	; 
#	$srvcobjects_ref->{'ptp-general'}{'ports'}{'udp'}{'320'}++	; 
#	$ports_ref->{'udp'}{'320'}{'name'} = 'ptp-general'		; 
#	$srvcobjects_ref->{'ptp-general'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ptp-general'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptp-general'}{'port'}{'tcp'} = '320'	; 
#	$srvcobjects_ref->{'ptp-general'}{'ports'}{'tcp'}{'320'}++	; 
#	$ports_ref->{'tcp'}{'320'}{'name'} = 'ptp-general'		; 
#	$srvcobjects_ref->{'ill'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ill'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ill'}{'port'}{'udp'} = '1611'	; 
#	$srvcobjects_ref->{'ill'}{'ports'}{'udp'}{'1611'}++	; 
#	$ports_ref->{'udp'}{'1611'}{'name'} = 'ill'		; 
#	$srvcobjects_ref->{'ill'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ill'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ill'}{'port'}{'tcp'} = '1611'	; 
#	$srvcobjects_ref->{'ill'}{'ports'}{'tcp'}{'1611'}++	; 
#	$ports_ref->{'tcp'}{'1611'}{'name'} = 'ill'		; 
#	$srvcobjects_ref->{'hylafax'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hylafax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hylafax'}{'port'}{'udp'} = '4559'	; 
#	$srvcobjects_ref->{'hylafax'}{'ports'}{'udp'}{'4559'}++	; 
#	$ports_ref->{'udp'}{'4559'}{'name'} = 'hylafax'		; 
#	$srvcobjects_ref->{'hylafax'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hylafax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hylafax'}{'port'}{'tcp'} = '4559'	; 
#	$srvcobjects_ref->{'hylafax'}{'ports'}{'tcp'}{'4559'}++	; 
#	$ports_ref->{'tcp'}{'4559'}{'name'} = 'hylafax'		; 
#	$srvcobjects_ref->{'pago-services2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pago-services2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pago-services2'}{'port'}{'udp'} = '30002'	; 
#	$srvcobjects_ref->{'pago-services2'}{'ports'}{'udp'}{'30002'}++	; 
#	$ports_ref->{'udp'}{'30002'}{'name'} = 'pago-services2'		; 
#	$srvcobjects_ref->{'pago-services2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pago-services2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pago-services2'}{'port'}{'tcp'} = '30002'	; 
#	$srvcobjects_ref->{'pago-services2'}{'ports'}{'tcp'}{'30002'}++	; 
#	$ports_ref->{'tcp'}{'30002'}{'name'} = 'pago-services2'		; 
#	$srvcobjects_ref->{'oracle-em1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oracle-em1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-em1'}{'port'}{'udp'} = '1748'	; 
#	$srvcobjects_ref->{'oracle-em1'}{'ports'}{'udp'}{'1748'}++	; 
#	$ports_ref->{'udp'}{'1748'}{'name'} = 'oracle-em1'		; 
#	$srvcobjects_ref->{'oracle-em1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oracle-em1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-em1'}{'port'}{'tcp'} = '1748'	; 
#	$srvcobjects_ref->{'oracle-em1'}{'ports'}{'tcp'}{'1748'}++	; 
#	$ports_ref->{'tcp'}{'1748'}{'name'} = 'oracle-em1'		; 
#	$srvcobjects_ref->{'unisql-java'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unisql-java'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unisql-java'}{'port'}{'udp'} = '1979'	; 
#	$srvcobjects_ref->{'unisql-java'}{'ports'}{'udp'}{'1979'}++	; 
#	$ports_ref->{'udp'}{'1979'}{'name'} = 'unisql-java'		; 
#	$srvcobjects_ref->{'unisql-java'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unisql-java'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unisql-java'}{'port'}{'tcp'} = '1979'	; 
#	$srvcobjects_ref->{'unisql-java'}{'ports'}{'tcp'}{'1979'}++	; 
#	$ports_ref->{'tcp'}{'1979'}{'name'} = 'unisql-java'		; 
#	$srvcobjects_ref->{'re-mail-ck'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'re-mail-ck'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'re-mail-ck'}{'port'}{'udp'} = '50'	; 
#	$srvcobjects_ref->{'re-mail-ck'}{'ports'}{'udp'}{'50'}++	; 
#	$ports_ref->{'udp'}{'50'}{'name'} = 're-mail-ck'		; 
#	$srvcobjects_ref->{'re-mail-ck'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'re-mail-ck'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'re-mail-ck'}{'port'}{'tcp'} = '50'	; 
#	$srvcobjects_ref->{'re-mail-ck'}{'ports'}{'tcp'}{'50'}++	; 
#	$ports_ref->{'tcp'}{'50'}{'name'} = 're-mail-ck'		; 
#	$srvcobjects_ref->{'iafdbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iafdbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iafdbase'}{'port'}{'udp'} = '480'	; 
#	$srvcobjects_ref->{'iafdbase'}{'ports'}{'udp'}{'480'}++	; 
#	$ports_ref->{'udp'}{'480'}{'name'} = 'iafdbase'		; 
#	$srvcobjects_ref->{'iafdbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iafdbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iafdbase'}{'port'}{'tcp'} = '480'	; 
#	$srvcobjects_ref->{'iafdbase'}{'ports'}{'tcp'}{'480'}++	; 
#	$ports_ref->{'tcp'}{'480'}{'name'} = 'iafdbase'		; 
#	$srvcobjects_ref->{'hp-sci'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-sci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sci'}{'port'}{'udp'} = '1299'	; 
#	$srvcobjects_ref->{'hp-sci'}{'ports'}{'udp'}{'1299'}++	; 
#	$ports_ref->{'udp'}{'1299'}{'name'} = 'hp-sci'		; 
#	$srvcobjects_ref->{'hp-sci'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-sci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sci'}{'port'}{'tcp'} = '1299'	; 
#	$srvcobjects_ref->{'hp-sci'}{'ports'}{'tcp'}{'1299'}++	; 
#	$ports_ref->{'tcp'}{'1299'}{'name'} = 'hp-sci'		; 
#	$srvcobjects_ref->{'hb-engine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hb-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hb-engine'}{'port'}{'udp'} = '1703'	; 
#	$srvcobjects_ref->{'hb-engine'}{'ports'}{'udp'}{'1703'}++	; 
#	$ports_ref->{'udp'}{'1703'}{'name'} = 'hb-engine'		; 
#	$srvcobjects_ref->{'hb-engine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hb-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hb-engine'}{'port'}{'tcp'} = '1703'	; 
#	$srvcobjects_ref->{'hb-engine'}{'ports'}{'tcp'}{'1703'}++	; 
#	$ports_ref->{'tcp'}{'1703'}{'name'} = 'hb-engine'		; 
#	$srvcobjects_ref->{'bues_service'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bues_service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bues_service'}{'port'}{'udp'} = '2446'	; 
#	$srvcobjects_ref->{'bues_service'}{'ports'}{'udp'}{'2446'}++	; 
#	$ports_ref->{'udp'}{'2446'}{'name'} = 'bues_service'		; 
#	$srvcobjects_ref->{'bues_service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bues_service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bues_service'}{'port'}{'tcp'} = '2446'	; 
#	$srvcobjects_ref->{'bues_service'}{'ports'}{'tcp'}{'2446'}++	; 
#	$ports_ref->{'tcp'}{'2446'}{'name'} = 'bues_service'		; 
#	$srvcobjects_ref->{'pn-requester2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pn-requester2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pn-requester2'}{'port'}{'udp'} = '2718'	; 
#	$srvcobjects_ref->{'pn-requester2'}{'ports'}{'udp'}{'2718'}++	; 
#	$ports_ref->{'udp'}{'2718'}{'name'} = 'pn-requester2'		; 
#	$srvcobjects_ref->{'pn-requester2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pn-requester2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pn-requester2'}{'port'}{'tcp'} = '2718'	; 
#	$srvcobjects_ref->{'pn-requester2'}{'ports'}{'tcp'}{'2718'}++	; 
#	$ports_ref->{'tcp'}{'2718'}{'name'} = 'pn-requester2'		; 
#	$srvcobjects_ref->{'appswitch-emp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appswitch-emp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appswitch-emp'}{'port'}{'udp'} = '2616'	; 
#	$srvcobjects_ref->{'appswitch-emp'}{'ports'}{'udp'}{'2616'}++	; 
#	$ports_ref->{'udp'}{'2616'}{'name'} = 'appswitch-emp'		; 
#	$srvcobjects_ref->{'appswitch-emp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appswitch-emp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appswitch-emp'}{'port'}{'tcp'} = '2616'	; 
#	$srvcobjects_ref->{'appswitch-emp'}{'ports'}{'tcp'}{'2616'}++	; 
#	$ports_ref->{'tcp'}{'2616'}{'name'} = 'appswitch-emp'		; 
#	$srvcobjects_ref->{'worldfusion1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'worldfusion1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldfusion1'}{'port'}{'udp'} = '2595'	; 
#	$srvcobjects_ref->{'worldfusion1'}{'ports'}{'udp'}{'2595'}++	; 
#	$ports_ref->{'udp'}{'2595'}{'name'} = 'worldfusion1'		; 
#	$srvcobjects_ref->{'worldfusion1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'worldfusion1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldfusion1'}{'port'}{'tcp'} = '2595'	; 
#	$srvcobjects_ref->{'worldfusion1'}{'ports'}{'tcp'}{'2595'}++	; 
#	$ports_ref->{'tcp'}{'2595'}{'name'} = 'worldfusion1'		; 
#	$srvcobjects_ref->{'webmachine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webmachine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webmachine'}{'port'}{'udp'} = '1963'	; 
#	$srvcobjects_ref->{'webmachine'}{'ports'}{'udp'}{'1963'}++	; 
#	$ports_ref->{'udp'}{'1963'}{'name'} = 'webmachine'		; 
#	$srvcobjects_ref->{'webmachine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webmachine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webmachine'}{'port'}{'tcp'} = '1963'	; 
#	$srvcobjects_ref->{'webmachine'}{'ports'}{'tcp'}{'1963'}++	; 
#	$ports_ref->{'tcp'}{'1963'}{'name'} = 'webmachine'		; 
#	$srvcobjects_ref->{'rets'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rets'}{'port'}{'udp'} = '6103'	; 
#	$srvcobjects_ref->{'rets'}{'ports'}{'udp'}{'6103'}++	; 
#	$ports_ref->{'udp'}{'6103'}{'name'} = 'rets'		; 
#	$srvcobjects_ref->{'rets'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rets'}{'port'}{'tcp'} = '6103'	; 
#	$srvcobjects_ref->{'rets'}{'ports'}{'tcp'}{'6103'}++	; 
#	$ports_ref->{'tcp'}{'6103'}{'name'} = 'rets'		; 
#	$srvcobjects_ref->{'apollo-status'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apollo-status'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apollo-status'}{'port'}{'udp'} = '2758'	; 
#	$srvcobjects_ref->{'apollo-status'}{'ports'}{'udp'}{'2758'}++	; 
#	$ports_ref->{'udp'}{'2758'}{'name'} = 'apollo-status'		; 
#	$srvcobjects_ref->{'apollo-status'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apollo-status'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apollo-status'}{'port'}{'tcp'} = '2758'	; 
#	$srvcobjects_ref->{'apollo-status'}{'ports'}{'tcp'}{'2758'}++	; 
#	$ports_ref->{'tcp'}{'2758'}{'name'} = 'apollo-status'		; 
#	$srvcobjects_ref->{'vitalanalysis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vitalanalysis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vitalanalysis'}{'port'}{'udp'} = '2474'	; 
#	$srvcobjects_ref->{'vitalanalysis'}{'ports'}{'udp'}{'2474'}++	; 
#	$ports_ref->{'udp'}{'2474'}{'name'} = 'vitalanalysis'		; 
#	$srvcobjects_ref->{'vitalanalysis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vitalanalysis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vitalanalysis'}{'port'}{'tcp'} = '2474'	; 
#	$srvcobjects_ref->{'vitalanalysis'}{'ports'}{'tcp'}{'2474'}++	; 
#	$ports_ref->{'tcp'}{'2474'}{'name'} = 'vitalanalysis'		; 
#	$srvcobjects_ref->{'nqs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nqs'}{'port'}{'udp'} = '607'	; 
#	$srvcobjects_ref->{'nqs'}{'ports'}{'udp'}{'607'}++	; 
#	$ports_ref->{'udp'}{'607'}{'name'} = 'nqs'		; 
#	$srvcobjects_ref->{'nqs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nqs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nqs'}{'port'}{'tcp'} = '607'	; 
#	$srvcobjects_ref->{'nqs'}{'ports'}{'tcp'}{'607'}++	; 
#	$ports_ref->{'tcp'}{'607'}{'name'} = 'nqs'		; 
#	$srvcobjects_ref->{'kv-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kv-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kv-server'}{'port'}{'udp'} = '3360'	; 
#	$srvcobjects_ref->{'kv-server'}{'ports'}{'udp'}{'3360'}++	; 
#	$ports_ref->{'udp'}{'3360'}{'name'} = 'kv-server'		; 
#	$srvcobjects_ref->{'kv-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kv-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kv-server'}{'port'}{'tcp'} = '3360'	; 
#	$srvcobjects_ref->{'kv-server'}{'ports'}{'tcp'}{'3360'}++	; 
#	$ports_ref->{'tcp'}{'3360'}{'name'} = 'kv-server'		; 
#	$srvcobjects_ref->{'isbconference2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isbconference2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isbconference2'}{'port'}{'udp'} = '1245'	; 
#	$srvcobjects_ref->{'isbconference2'}{'ports'}{'udp'}{'1245'}++	; 
#	$ports_ref->{'udp'}{'1245'}{'name'} = 'isbconference2'		; 
#	$srvcobjects_ref->{'isbconference2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isbconference2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isbconference2'}{'port'}{'tcp'} = '1245'	; 
#	$srvcobjects_ref->{'isbconference2'}{'ports'}{'tcp'}{'1245'}++	; 
#	$ports_ref->{'tcp'}{'1245'}{'name'} = 'isbconference2'		; 
#	$srvcobjects_ref->{'amx-webadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amx-webadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amx-webadmin'}{'port'}{'udp'} = '2929'	; 
#	$srvcobjects_ref->{'amx-webadmin'}{'ports'}{'udp'}{'2929'}++	; 
#	$ports_ref->{'udp'}{'2929'}{'name'} = 'amx-webadmin'		; 
#	$srvcobjects_ref->{'amx-webadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amx-webadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amx-webadmin'}{'port'}{'tcp'} = '2929'	; 
#	$srvcobjects_ref->{'amx-webadmin'}{'ports'}{'tcp'}{'2929'}++	; 
#	$ports_ref->{'tcp'}{'2929'}{'name'} = 'amx-webadmin'		; 
#	$srvcobjects_ref->{'pacmand'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pacmand'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pacmand'}{'port'}{'udp'} = '1307'	; 
#	$srvcobjects_ref->{'pacmand'}{'ports'}{'udp'}{'1307'}++	; 
#	$ports_ref->{'udp'}{'1307'}{'name'} = 'pacmand'		; 
#	$srvcobjects_ref->{'pacmand'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pacmand'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pacmand'}{'port'}{'tcp'} = '1307'	; 
#	$srvcobjects_ref->{'pacmand'}{'ports'}{'tcp'}{'1307'}++	; 
#	$ports_ref->{'tcp'}{'1307'}{'name'} = 'pacmand'		; 
#	$srvcobjects_ref->{'nicelink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nicelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicelink'}{'port'}{'udp'} = '1095'	; 
#	$srvcobjects_ref->{'nicelink'}{'ports'}{'udp'}{'1095'}++	; 
#	$ports_ref->{'udp'}{'1095'}{'name'} = 'nicelink'		; 
#	$srvcobjects_ref->{'nicelink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nicelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicelink'}{'port'}{'tcp'} = '1095'	; 
#	$srvcobjects_ref->{'nicelink'}{'ports'}{'tcp'}{'1095'}++	; 
#	$ports_ref->{'tcp'}{'1095'}{'name'} = 'nicelink'		; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'port'}{'udp'} = '1317'	; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'ports'}{'udp'}{'1317'}++	; 
#	$ports_ref->{'udp'}{'1317'}{'name'} = 'vrts-ipcserver'		; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'port'}{'tcp'} = '1317'	; 
#	$srvcobjects_ref->{'vrts-ipcserver'}{'ports'}{'tcp'}{'1317'}++	; 
#	$ports_ref->{'tcp'}{'1317'}{'name'} = 'vrts-ipcserver'		; 
#	$srvcobjects_ref->{'statsci1-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'statsci1-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statsci1-lm'}{'port'}{'udp'} = '6144'	; 
#	$srvcobjects_ref->{'statsci1-lm'}{'ports'}{'udp'}{'6144'}++	; 
#	$ports_ref->{'udp'}{'6144'}{'name'} = 'statsci1-lm'		; 
#	$srvcobjects_ref->{'statsci1-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'statsci1-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statsci1-lm'}{'port'}{'tcp'} = '6144'	; 
#	$srvcobjects_ref->{'statsci1-lm'}{'ports'}{'tcp'}{'6144'}++	; 
#	$ports_ref->{'tcp'}{'6144'}{'name'} = 'statsci1-lm'		; 
#	$srvcobjects_ref->{'veritas-vis2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'veritas-vis2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-vis2'}{'port'}{'udp'} = '2994'	; 
#	$srvcobjects_ref->{'veritas-vis2'}{'ports'}{'udp'}{'2994'}++	; 
#	$ports_ref->{'udp'}{'2994'}{'name'} = 'veritas-vis2'		; 
#	$srvcobjects_ref->{'veritas-vis2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'veritas-vis2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-vis2'}{'port'}{'tcp'} = '2994'	; 
#	$srvcobjects_ref->{'veritas-vis2'}{'ports'}{'tcp'}{'2994'}++	; 
#	$ports_ref->{'tcp'}{'2994'}{'name'} = 'veritas-vis2'		; 
#	$srvcobjects_ref->{'mctp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctp'}{'port'}{'udp'} = '1100'	; 
#	$srvcobjects_ref->{'mctp'}{'ports'}{'udp'}{'1100'}++	; 
#	$ports_ref->{'udp'}{'1100'}{'name'} = 'mctp'		; 
#	$srvcobjects_ref->{'mctp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctp'}{'port'}{'tcp'} = '1100'	; 
#	$srvcobjects_ref->{'mctp'}{'ports'}{'tcp'}{'1100'}++	; 
#	$ports_ref->{'tcp'}{'1100'}{'name'} = 'mctp'		; 
#	$srvcobjects_ref->{'aztec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aztec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aztec'}{'port'}{'udp'} = '3512'	; 
#	$srvcobjects_ref->{'aztec'}{'ports'}{'udp'}{'3512'}++	; 
#	$ports_ref->{'udp'}{'3512'}{'name'} = 'aztec'		; 
#	$srvcobjects_ref->{'aztec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aztec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aztec'}{'port'}{'tcp'} = '3512'	; 
#	$srvcobjects_ref->{'aztec'}{'ports'}{'tcp'}{'3512'}++	; 
#	$ports_ref->{'tcp'}{'3512'}{'name'} = 'aztec'		; 
#	$srvcobjects_ref->{'imsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imsp'}{'port'}{'udp'} = '406'	; 
#	$srvcobjects_ref->{'imsp'}{'ports'}{'udp'}{'406'}++	; 
#	$ports_ref->{'udp'}{'406'}{'name'} = 'imsp'		; 
#	$srvcobjects_ref->{'imsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imsp'}{'port'}{'tcp'} = '406'	; 
#	$srvcobjects_ref->{'imsp'}{'ports'}{'tcp'}{'406'}++	; 
#	$ports_ref->{'tcp'}{'406'}{'name'} = 'imsp'		; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'port'}{'udp'} = '3132'	; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'ports'}{'udp'}{'3132'}++	; 
#	$ports_ref->{'udp'}{'3132'}{'name'} = 'ms-rule-engine'		; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'port'}{'tcp'} = '3132'	; 
#	$srvcobjects_ref->{'ms-rule-engine'}{'ports'}{'tcp'}{'3132'}++	; 
#	$ports_ref->{'tcp'}{'3132'}{'name'} = 'ms-rule-engine'		; 
#	$srvcobjects_ref->{'cert-responder'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cert-responder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cert-responder'}{'port'}{'udp'} = '1640'	; 
#	$srvcobjects_ref->{'cert-responder'}{'ports'}{'udp'}{'1640'}++	; 
#	$ports_ref->{'udp'}{'1640'}{'name'} = 'cert-responder'		; 
#	$srvcobjects_ref->{'cert-responder'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cert-responder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cert-responder'}{'port'}{'tcp'} = '1640'	; 
#	$srvcobjects_ref->{'cert-responder'}{'ports'}{'tcp'}{'1640'}++	; 
#	$ports_ref->{'tcp'}{'1640'}{'name'} = 'cert-responder'		; 
#	$srvcobjects_ref->{'arcpd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arcpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arcpd'}{'port'}{'udp'} = '3513'	; 
#	$srvcobjects_ref->{'arcpd'}{'ports'}{'udp'}{'3513'}++	; 
#	$ports_ref->{'udp'}{'3513'}{'name'} = 'arcpd'		; 
#	$srvcobjects_ref->{'arcpd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arcpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arcpd'}{'port'}{'tcp'} = '3513'	; 
#	$srvcobjects_ref->{'arcpd'}{'ports'}{'tcp'}{'3513'}++	; 
#	$ports_ref->{'tcp'}{'3513'}{'name'} = 'arcpd'		; 
#	$srvcobjects_ref->{'swr-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swr-port'}{'port'}{'udp'} = '3491'	; 
#	$srvcobjects_ref->{'swr-port'}{'ports'}{'udp'}{'3491'}++	; 
#	$ports_ref->{'udp'}{'3491'}{'name'} = 'swr-port'		; 
#	$srvcobjects_ref->{'swr-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swr-port'}{'port'}{'tcp'} = '3491'	; 
#	$srvcobjects_ref->{'swr-port'}{'ports'}{'tcp'}{'3491'}++	; 
#	$ports_ref->{'tcp'}{'3491'}{'name'} = 'swr-port'		; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'port'}{'udp'} = '3009'	; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'ports'}{'udp'}{'3009'}++	; 
#	$ports_ref->{'udp'}{'3009'}{'name'} = 'pxc-ntfy'		; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'port'}{'tcp'} = '3009'	; 
#	$srvcobjects_ref->{'pxc-ntfy'}{'ports'}{'tcp'}{'3009'}++	; 
#	$ports_ref->{'tcp'}{'3009'}{'name'} = 'pxc-ntfy'		; 
#	$srvcobjects_ref->{'sagectlpanel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sagectlpanel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sagectlpanel'}{'port'}{'udp'} = '3698'	; 
#	$srvcobjects_ref->{'sagectlpanel'}{'ports'}{'udp'}{'3698'}++	; 
#	$ports_ref->{'udp'}{'3698'}{'name'} = 'sagectlpanel'		; 
#	$srvcobjects_ref->{'sagectlpanel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sagectlpanel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sagectlpanel'}{'port'}{'tcp'} = '3698'	; 
#	$srvcobjects_ref->{'sagectlpanel'}{'ports'}{'tcp'}{'3698'}++	; 
#	$ports_ref->{'tcp'}{'3698'}{'name'} = 'sagectlpanel'		; 
#	$srvcobjects_ref->{'iscsi-target'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iscsi-target'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iscsi-target'}{'port'}{'udp'} = '3260'	; 
#	$srvcobjects_ref->{'iscsi-target'}{'ports'}{'udp'}{'3260'}++	; 
#	$ports_ref->{'udp'}{'3260'}{'name'} = 'iscsi-target'		; 
#	$srvcobjects_ref->{'iscsi-target'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iscsi-target'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iscsi-target'}{'port'}{'tcp'} = '3260'	; 
#	$srvcobjects_ref->{'iscsi-target'}{'ports'}{'tcp'}{'3260'}++	; 
#	$ports_ref->{'tcp'}{'3260'}{'name'} = 'iscsi-target'		; 
#	$srvcobjects_ref->{'netcelera'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netcelera'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcelera'}{'port'}{'udp'} = '3701'	; 
#	$srvcobjects_ref->{'netcelera'}{'ports'}{'udp'}{'3701'}++	; 
#	$ports_ref->{'udp'}{'3701'}{'name'} = 'netcelera'		; 
#	$srvcobjects_ref->{'netcelera'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netcelera'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcelera'}{'port'}{'tcp'} = '3701'	; 
#	$srvcobjects_ref->{'netcelera'}{'ports'}{'tcp'}{'3701'}++	; 
#	$ports_ref->{'tcp'}{'3701'}{'name'} = 'netcelera'		; 
#	$srvcobjects_ref->{'qotd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qotd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qotd'}{'port'}{'udp'} = '17'	; 
#	$srvcobjects_ref->{'qotd'}{'ports'}{'udp'}{'17'}++	; 
#	$ports_ref->{'udp'}{'17'}{'name'} = 'qotd'		; 
#	$srvcobjects_ref->{'qotd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qotd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qotd'}{'port'}{'tcp'} = '17'	; 
#	$srvcobjects_ref->{'qotd'}{'ports'}{'tcp'}{'17'}++	; 
#	$ports_ref->{'tcp'}{'17'}{'name'} = 'qotd'		; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'port'}{'udp'} = '1803'	; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'ports'}{'udp'}{'1803'}++	; 
#	$ports_ref->{'udp'}{'1803'}{'name'} = 'hp-hcip-gwy'		; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'port'}{'tcp'} = '1803'	; 
#	$srvcobjects_ref->{'hp-hcip-gwy'}{'ports'}{'tcp'}{'1803'}++	; 
#	$ports_ref->{'tcp'}{'1803'}{'name'} = 'hp-hcip-gwy'		; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'port'}{'udp'} = '1950'	; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'ports'}{'udp'}{'1950'}++	; 
#	$ports_ref->{'udp'}{'1950'}{'name'} = 'ismaeasdaqtest'		; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'port'}{'tcp'} = '1950'	; 
#	$srvcobjects_ref->{'ismaeasdaqtest'}{'ports'}{'tcp'}{'1950'}++	; 
#	$ports_ref->{'tcp'}{'1950'}{'name'} = 'ismaeasdaqtest'		; 
#	$srvcobjects_ref->{'vistium-share'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vistium-share'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vistium-share'}{'port'}{'udp'} = '1545'	; 
#	$srvcobjects_ref->{'vistium-share'}{'ports'}{'udp'}{'1545'}++	; 
#	$ports_ref->{'udp'}{'1545'}{'name'} = 'vistium-share'		; 
#	$srvcobjects_ref->{'vistium-share'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vistium-share'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vistium-share'}{'port'}{'tcp'} = '1545'	; 
#	$srvcobjects_ref->{'vistium-share'}{'ports'}{'tcp'}{'1545'}++	; 
#	$ports_ref->{'tcp'}{'1545'}{'name'} = 'vistium-share'		; 
#	$srvcobjects_ref->{'ewnn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ewnn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewnn'}{'port'}{'udp'} = '2674'	; 
#	$srvcobjects_ref->{'ewnn'}{'ports'}{'udp'}{'2674'}++	; 
#	$ports_ref->{'udp'}{'2674'}{'name'} = 'ewnn'		; 
#	$srvcobjects_ref->{'ewnn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ewnn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ewnn'}{'port'}{'tcp'} = '2674'	; 
#	$srvcobjects_ref->{'ewnn'}{'ports'}{'tcp'}{'2674'}++	; 
#	$ports_ref->{'tcp'}{'2674'}{'name'} = 'ewnn'		; 
#	$srvcobjects_ref->{'nas-metering'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nas-metering'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nas-metering'}{'port'}{'udp'} = '2286'	; 
#	$srvcobjects_ref->{'nas-metering'}{'ports'}{'udp'}{'2286'}++	; 
#	$ports_ref->{'udp'}{'2286'}{'name'} = 'nas-metering'		; 
#	$srvcobjects_ref->{'nas-metering'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nas-metering'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nas-metering'}{'port'}{'tcp'} = '2286'	; 
#	$srvcobjects_ref->{'nas-metering'}{'ports'}{'tcp'}{'2286'}++	; 
#	$ports_ref->{'tcp'}{'2286'}{'name'} = 'nas-metering'		; 
#	$srvcobjects_ref->{'cogsys-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cogsys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cogsys-lm'}{'port'}{'udp'} = '3377'	; 
#	$srvcobjects_ref->{'cogsys-lm'}{'ports'}{'udp'}{'3377'}++	; 
#	$ports_ref->{'udp'}{'3377'}{'name'} = 'cogsys-lm'		; 
#	$srvcobjects_ref->{'cogsys-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cogsys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cogsys-lm'}{'port'}{'tcp'} = '3377'	; 
#	$srvcobjects_ref->{'cogsys-lm'}{'ports'}{'tcp'}{'3377'}++	; 
#	$ports_ref->{'tcp'}{'3377'}{'name'} = 'cogsys-lm'		; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'port'}{'udp'} = '2253'	; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'ports'}{'udp'}{'2253'}++	; 
#	$ports_ref->{'udp'}{'2253'}{'name'} = 'dtv-chan-req'		; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'port'}{'tcp'} = '2253'	; 
#	$srvcobjects_ref->{'dtv-chan-req'}{'ports'}{'tcp'}{'2253'}++	; 
#	$ports_ref->{'tcp'}{'2253'}{'name'} = 'dtv-chan-req'		; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'port'}{'udp'} = '1743'	; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'ports'}{'udp'}{'1743'}++	; 
#	$ports_ref->{'udp'}{'1743'}{'name'} = 'cinegrfx-lm'		; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'port'}{'tcp'} = '1743'	; 
#	$srvcobjects_ref->{'cinegrfx-lm'}{'ports'}{'tcp'}{'1743'}++	; 
#	$ports_ref->{'tcp'}{'1743'}{'name'} = 'cinegrfx-lm'		; 
#	$srvcobjects_ref->{'scpi-telnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scpi-telnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scpi-telnet'}{'port'}{'udp'} = '5024'	; 
#	$srvcobjects_ref->{'scpi-telnet'}{'ports'}{'udp'}{'5024'}++	; 
#	$ports_ref->{'udp'}{'5024'}{'name'} = 'scpi-telnet'		; 
#	$srvcobjects_ref->{'scpi-telnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scpi-telnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scpi-telnet'}{'port'}{'tcp'} = '5024'	; 
#	$srvcobjects_ref->{'scpi-telnet'}{'ports'}{'tcp'}{'5024'}++	; 
#	$ports_ref->{'tcp'}{'5024'}{'name'} = 'scpi-telnet'		; 
#	$srvcobjects_ref->{'rfile'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rfile'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfile'}{'port'}{'tcp'} = '750'	; 
#	$srvcobjects_ref->{'rfile'}{'ports'}{'tcp'}{'750'}++	; 
#	$ports_ref->{'tcp'}{'750'}{'name'} = 'rfile'		; 
#	$srvcobjects_ref->{'csdmbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csdmbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdmbase'}{'port'}{'udp'} = '1467'	; 
#	$srvcobjects_ref->{'csdmbase'}{'ports'}{'udp'}{'1467'}++	; 
#	$ports_ref->{'udp'}{'1467'}{'name'} = 'csdmbase'		; 
#	$srvcobjects_ref->{'csdmbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csdmbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdmbase'}{'port'}{'udp'} = '1471'	; 
#	$srvcobjects_ref->{'csdmbase'}{'ports'}{'udp'}{'1471'}++	; 
#	$ports_ref->{'udp'}{'1471'}{'name'} = 'csdmbase'		; 
#	$srvcobjects_ref->{'csdmbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csdmbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdmbase'}{'port'}{'tcp'} = '1467'	; 
#	$srvcobjects_ref->{'csdmbase'}{'ports'}{'tcp'}{'1467'}++	; 
#	$ports_ref->{'tcp'}{'1467'}{'name'} = 'csdmbase'		; 
#	$srvcobjects_ref->{'csdmbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csdmbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdmbase'}{'port'}{'tcp'} = '1471'	; 
#	$srvcobjects_ref->{'csdmbase'}{'ports'}{'tcp'}{'1471'}++	; 
#	$ports_ref->{'tcp'}{'1471'}{'name'} = 'csdmbase'		; 
#	$srvcobjects_ref->{'ripng'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ripng'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ripng'}{'port'}{'udp'} = '521'	; 
#	$srvcobjects_ref->{'ripng'}{'ports'}{'udp'}{'521'}++	; 
#	$ports_ref->{'udp'}{'521'}{'name'} = 'ripng'		; 
#	$srvcobjects_ref->{'ripng'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ripng'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ripng'}{'port'}{'tcp'} = '521'	; 
#	$srvcobjects_ref->{'ripng'}{'ports'}{'tcp'}{'521'}++	; 
#	$ports_ref->{'tcp'}{'521'}{'name'} = 'ripng'		; 
#	$srvcobjects_ref->{'icl-twobase4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase4'}{'port'}{'udp'} = '25003'	; 
#	$srvcobjects_ref->{'icl-twobase4'}{'ports'}{'udp'}{'25003'}++	; 
#	$ports_ref->{'udp'}{'25003'}{'name'} = 'icl-twobase4'		; 
#	$srvcobjects_ref->{'icl-twobase4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase4'}{'port'}{'tcp'} = '25003'	; 
#	$srvcobjects_ref->{'icl-twobase4'}{'ports'}{'tcp'}{'25003'}++	; 
#	$ports_ref->{'tcp'}{'25003'}{'name'} = 'icl-twobase4'		; 
#	$srvcobjects_ref->{'redstone-cpss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'redstone-cpss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstone-cpss'}{'port'}{'udp'} = '2928'	; 
#	$srvcobjects_ref->{'redstone-cpss'}{'ports'}{'udp'}{'2928'}++	; 
#	$ports_ref->{'udp'}{'2928'}{'name'} = 'redstone-cpss'		; 
#	$srvcobjects_ref->{'redstone-cpss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'redstone-cpss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstone-cpss'}{'port'}{'tcp'} = '2928'	; 
#	$srvcobjects_ref->{'redstone-cpss'}{'ports'}{'tcp'}{'2928'}++	; 
#	$ports_ref->{'tcp'}{'2928'}{'name'} = 'redstone-cpss'		; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'port'}{'udp'} = '2897'	; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'ports'}{'udp'}{'2897'}++	; 
#	$ports_ref->{'udp'}{'2897'}{'name'} = 'citrix-rtmp'		; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'port'}{'tcp'} = '2897'	; 
#	$srvcobjects_ref->{'citrix-rtmp'}{'ports'}{'tcp'}{'2897'}++	; 
#	$ports_ref->{'tcp'}{'2897'}{'name'} = 'citrix-rtmp'		; 
#	$srvcobjects_ref->{'cindycollab'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cindycollab'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cindycollab'}{'port'}{'udp'} = '3770'	; 
#	$srvcobjects_ref->{'cindycollab'}{'ports'}{'udp'}{'3770'}++	; 
#	$ports_ref->{'udp'}{'3770'}{'name'} = 'cindycollab'		; 
#	$srvcobjects_ref->{'cindycollab'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cindycollab'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cindycollab'}{'port'}{'tcp'} = '3770'	; 
#	$srvcobjects_ref->{'cindycollab'}{'ports'}{'tcp'}{'3770'}++	; 
#	$ports_ref->{'tcp'}{'3770'}{'name'} = 'cindycollab'		; 
#	$srvcobjects_ref->{'hp-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-server'}{'port'}{'udp'} = '5225'	; 
#	$srvcobjects_ref->{'hp-server'}{'ports'}{'udp'}{'5225'}++	; 
#	$ports_ref->{'udp'}{'5225'}{'name'} = 'hp-server'		; 
#	$srvcobjects_ref->{'hp-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-server'}{'port'}{'tcp'} = '5225'	; 
#	$srvcobjects_ref->{'hp-server'}{'ports'}{'tcp'}{'5225'}++	; 
#	$ports_ref->{'tcp'}{'5225'}{'name'} = 'hp-server'		; 
#	$srvcobjects_ref->{'mini-sql'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mini-sql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mini-sql'}{'port'}{'udp'} = '1114'	; 
#	$srvcobjects_ref->{'mini-sql'}{'ports'}{'udp'}{'1114'}++	; 
#	$ports_ref->{'udp'}{'1114'}{'name'} = 'mini-sql'		; 
#	$srvcobjects_ref->{'mini-sql'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mini-sql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mini-sql'}{'port'}{'tcp'} = '1114'	; 
#	$srvcobjects_ref->{'mini-sql'}{'ports'}{'tcp'}{'1114'}++	; 
#	$ports_ref->{'tcp'}{'1114'}{'name'} = 'mini-sql'		; 
#	$srvcobjects_ref->{'fjdmimgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjdmimgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjdmimgr'}{'port'}{'udp'} = '9374'	; 
#	$srvcobjects_ref->{'fjdmimgr'}{'ports'}{'udp'}{'9374'}++	; 
#	$ports_ref->{'udp'}{'9374'}{'name'} = 'fjdmimgr'		; 
#	$srvcobjects_ref->{'fjdmimgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjdmimgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjdmimgr'}{'port'}{'tcp'} = '9374'	; 
#	$srvcobjects_ref->{'fjdmimgr'}{'ports'}{'tcp'}{'9374'}++	; 
#	$ports_ref->{'tcp'}{'9374'}{'name'} = 'fjdmimgr'		; 
#	$srvcobjects_ref->{'directplay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directplay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directplay'}{'port'}{'udp'} = '2234'	; 
#	$srvcobjects_ref->{'directplay'}{'ports'}{'udp'}{'2234'}++	; 
#	$ports_ref->{'udp'}{'2234'}{'name'} = 'directplay'		; 
#	$srvcobjects_ref->{'directplay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directplay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directplay'}{'port'}{'tcp'} = '2234'	; 
#	$srvcobjects_ref->{'directplay'}{'ports'}{'tcp'}{'2234'}++	; 
#	$ports_ref->{'tcp'}{'2234'}{'name'} = 'directplay'		; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'port'}{'udp'} = '2667'	; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'ports'}{'udp'}{'2667'}++	; 
#	$ports_ref->{'udp'}{'2667'}{'name'} = 'alarm-clock-s'		; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'port'}{'tcp'} = '2667'	; 
#	$srvcobjects_ref->{'alarm-clock-s'}{'ports'}{'tcp'}{'2667'}++	; 
#	$ports_ref->{'tcp'}{'2667'}{'name'} = 'alarm-clock-s'		; 
#	$srvcobjects_ref->{'cadabra-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadabra-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadabra-lm'}{'port'}{'udp'} = '1563'	; 
#	$srvcobjects_ref->{'cadabra-lm'}{'ports'}{'udp'}{'1563'}++	; 
#	$ports_ref->{'udp'}{'1563'}{'name'} = 'cadabra-lm'		; 
#	$srvcobjects_ref->{'cadabra-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadabra-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadabra-lm'}{'port'}{'tcp'} = '1563'	; 
#	$srvcobjects_ref->{'cadabra-lm'}{'ports'}{'tcp'}{'1563'}++	; 
#	$ports_ref->{'tcp'}{'1563'}{'name'} = 'cadabra-lm'		; 
#	$srvcobjects_ref->{'cvc_hostd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cvc_hostd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvc_hostd'}{'port'}{'udp'} = '442'	; 
#	$srvcobjects_ref->{'cvc_hostd'}{'ports'}{'udp'}{'442'}++	; 
#	$ports_ref->{'udp'}{'442'}{'name'} = 'cvc_hostd'		; 
#	$srvcobjects_ref->{'cvc_hostd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cvc_hostd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvc_hostd'}{'port'}{'tcp'} = '442'	; 
#	$srvcobjects_ref->{'cvc_hostd'}{'ports'}{'tcp'}{'442'}++	; 
#	$ports_ref->{'tcp'}{'442'}{'name'} = 'cvc_hostd'		; 
#	$srvcobjects_ref->{'pay-per-view'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pay-per-view'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pay-per-view'}{'port'}{'udp'} = '1564'	; 
#	$srvcobjects_ref->{'pay-per-view'}{'ports'}{'udp'}{'1564'}++	; 
#	$ports_ref->{'udp'}{'1564'}{'name'} = 'pay-per-view'		; 
#	$srvcobjects_ref->{'pay-per-view'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pay-per-view'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pay-per-view'}{'port'}{'tcp'} = '1564'	; 
#	$srvcobjects_ref->{'pay-per-view'}{'ports'}{'tcp'}{'1564'}++	; 
#	$ports_ref->{'tcp'}{'1564'}{'name'} = 'pay-per-view'		; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'port'}{'udp'} = '363'	; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'ports'}{'udp'}{'363'}++	; 
#	$ports_ref->{'udp'}{'363'}{'name'} = 'rsvp_tunnel'		; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'port'}{'tcp'} = '363'	; 
#	$srvcobjects_ref->{'rsvp_tunnel'}{'ports'}{'tcp'}{'363'}++	; 
#	$ports_ref->{'tcp'}{'363'}{'name'} = 'rsvp_tunnel'		; 
#	$srvcobjects_ref->{'pdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdp'}{'port'}{'udp'} = '1675'	; 
#	$srvcobjects_ref->{'pdp'}{'ports'}{'udp'}{'1675'}++	; 
#	$ports_ref->{'udp'}{'1675'}{'name'} = 'pdp'		; 
#	$srvcobjects_ref->{'pdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdp'}{'port'}{'tcp'} = '1675'	; 
#	$srvcobjects_ref->{'pdp'}{'ports'}{'tcp'}{'1675'}++	; 
#	$ports_ref->{'tcp'}{'1675'}{'name'} = 'pdp'		; 
#	$srvcobjects_ref->{'ambit-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ambit-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ambit-lm'}{'port'}{'udp'} = '6831'	; 
#	$srvcobjects_ref->{'ambit-lm'}{'ports'}{'udp'}{'6831'}++	; 
#	$ports_ref->{'udp'}{'6831'}{'name'} = 'ambit-lm'		; 
#	$srvcobjects_ref->{'ambit-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ambit-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ambit-lm'}{'port'}{'tcp'} = '6831'	; 
#	$srvcobjects_ref->{'ambit-lm'}{'ports'}{'tcp'}{'6831'}++	; 
#	$ports_ref->{'tcp'}{'6831'}{'name'} = 'ambit-lm'		; 
#	$srvcobjects_ref->{'vpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpp'}{'port'}{'udp'} = '677'	; 
#	$srvcobjects_ref->{'vpp'}{'ports'}{'udp'}{'677'}++	; 
#	$ports_ref->{'udp'}{'677'}{'name'} = 'vpp'		; 
#	$srvcobjects_ref->{'vpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpp'}{'port'}{'tcp'} = '677'	; 
#	$srvcobjects_ref->{'vpp'}{'ports'}{'tcp'}{'677'}++	; 
#	$ports_ref->{'tcp'}{'677'}{'name'} = 'vpp'		; 
#	$srvcobjects_ref->{'spss-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spss-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spss-lm'}{'port'}{'udp'} = '1759'	; 
#	$srvcobjects_ref->{'spss-lm'}{'ports'}{'udp'}{'1759'}++	; 
#	$ports_ref->{'udp'}{'1759'}{'name'} = 'spss-lm'		; 
#	$srvcobjects_ref->{'spss-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spss-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spss-lm'}{'port'}{'tcp'} = '1759'	; 
#	$srvcobjects_ref->{'spss-lm'}{'ports'}{'tcp'}{'1759'}++	; 
#	$ports_ref->{'tcp'}{'1759'}{'name'} = 'spss-lm'		; 
#	$srvcobjects_ref->{'pds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pds'}{'port'}{'udp'} = '9595'	; 
#	$srvcobjects_ref->{'pds'}{'ports'}{'udp'}{'9595'}++	; 
#	$ports_ref->{'udp'}{'9595'}{'name'} = 'pds'		; 
#	$srvcobjects_ref->{'pds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pds'}{'port'}{'tcp'} = '9595'	; 
#	$srvcobjects_ref->{'pds'}{'ports'}{'tcp'}{'9595'}++	; 
#	$ports_ref->{'tcp'}{'9595'}{'name'} = 'pds'		; 
#	$srvcobjects_ref->{'kpn-icw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kpn-icw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kpn-icw'}{'port'}{'udp'} = '3699'	; 
#	$srvcobjects_ref->{'kpn-icw'}{'ports'}{'udp'}{'3699'}++	; 
#	$ports_ref->{'udp'}{'3699'}{'name'} = 'kpn-icw'		; 
#	$srvcobjects_ref->{'kpn-icw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kpn-icw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kpn-icw'}{'port'}{'tcp'} = '3699'	; 
#	$srvcobjects_ref->{'kpn-icw'}{'ports'}{'tcp'}{'3699'}++	; 
#	$ports_ref->{'tcp'}{'3699'}{'name'} = 'kpn-icw'		; 
#	$srvcobjects_ref->{'innosys-acl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'innosys-acl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'innosys-acl'}{'port'}{'udp'} = '1413'	; 
#	$srvcobjects_ref->{'innosys-acl'}{'ports'}{'udp'}{'1413'}++	; 
#	$ports_ref->{'udp'}{'1413'}{'name'} = 'innosys-acl'		; 
#	$srvcobjects_ref->{'innosys-acl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'innosys-acl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'innosys-acl'}{'port'}{'tcp'} = '1413'	; 
#	$srvcobjects_ref->{'innosys-acl'}{'ports'}{'tcp'}{'1413'}++	; 
#	$ports_ref->{'tcp'}{'1413'}{'name'} = 'innosys-acl'		; 
#	$srvcobjects_ref->{'swismgr1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swismgr1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swismgr1'}{'port'}{'udp'} = '6963'	; 
#	$srvcobjects_ref->{'swismgr1'}{'ports'}{'udp'}{'6963'}++	; 
#	$ports_ref->{'udp'}{'6963'}{'name'} = 'swismgr1'		; 
#	$srvcobjects_ref->{'swismgr1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swismgr1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swismgr1'}{'port'}{'tcp'} = '6963'	; 
#	$srvcobjects_ref->{'swismgr1'}{'ports'}{'tcp'}{'6963'}++	; 
#	$ports_ref->{'tcp'}{'6963'}{'name'} = 'swismgr1'		; 
#	$srvcobjects_ref->{'slinterbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slinterbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slinterbase'}{'port'}{'udp'} = '3065'	; 
#	$srvcobjects_ref->{'slinterbase'}{'ports'}{'udp'}{'3065'}++	; 
#	$ports_ref->{'udp'}{'3065'}{'name'} = 'slinterbase'		; 
#	$srvcobjects_ref->{'slinterbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slinterbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slinterbase'}{'port'}{'tcp'} = '3065'	; 
#	$srvcobjects_ref->{'slinterbase'}{'ports'}{'tcp'}{'3065'}++	; 
#	$ports_ref->{'tcp'}{'3065'}{'name'} = 'slinterbase'		; 
#	$srvcobjects_ref->{'isode-dua'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isode-dua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isode-dua'}{'port'}{'udp'} = '17007'	; 
#	$srvcobjects_ref->{'isode-dua'}{'ports'}{'udp'}{'17007'}++	; 
#	$ports_ref->{'udp'}{'17007'}{'name'} = 'isode-dua'		; 
#	$srvcobjects_ref->{'isode-dua'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isode-dua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isode-dua'}{'port'}{'tcp'} = '17007'	; 
#	$srvcobjects_ref->{'isode-dua'}{'ports'}{'tcp'}{'17007'}++	; 
#	$ports_ref->{'tcp'}{'17007'}{'name'} = 'isode-dua'		; 
#	$srvcobjects_ref->{'intuitive-edge'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intuitive-edge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intuitive-edge'}{'port'}{'udp'} = '1355'	; 
#	$srvcobjects_ref->{'intuitive-edge'}{'ports'}{'udp'}{'1355'}++	; 
#	$ports_ref->{'udp'}{'1355'}{'name'} = 'intuitive-edge'		; 
#	$srvcobjects_ref->{'intuitive-edge'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intuitive-edge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intuitive-edge'}{'port'}{'tcp'} = '1355'	; 
#	$srvcobjects_ref->{'intuitive-edge'}{'ports'}{'tcp'}{'1355'}++	; 
#	$ports_ref->{'tcp'}{'1355'}{'name'} = 'intuitive-edge'		; 
#	$srvcobjects_ref->{'privatechat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'privatechat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privatechat'}{'port'}{'udp'} = '1735'	; 
#	$srvcobjects_ref->{'privatechat'}{'ports'}{'udp'}{'1735'}++	; 
#	$ports_ref->{'udp'}{'1735'}{'name'} = 'privatechat'		; 
#	$srvcobjects_ref->{'privatechat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'privatechat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privatechat'}{'port'}{'tcp'} = '1735'	; 
#	$srvcobjects_ref->{'privatechat'}{'ports'}{'tcp'}{'1735'}++	; 
#	$ports_ref->{'tcp'}{'1735'}{'name'} = 'privatechat'		; 
#	$srvcobjects_ref->{'hao'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hao'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hao'}{'port'}{'udp'} = '2245'	; 
#	$srvcobjects_ref->{'hao'}{'ports'}{'udp'}{'2245'}++	; 
#	$ports_ref->{'udp'}{'2245'}{'name'} = 'hao'		; 
#	$srvcobjects_ref->{'hao'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hao'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hao'}{'port'}{'tcp'} = '2245'	; 
#	$srvcobjects_ref->{'hao'}{'ports'}{'tcp'}{'2245'}++	; 
#	$ports_ref->{'tcp'}{'2245'}{'name'} = 'hao'		; 
#	$srvcobjects_ref->{'radclientport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radclientport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radclientport'}{'port'}{'udp'} = '3178'	; 
#	$srvcobjects_ref->{'radclientport'}{'ports'}{'udp'}{'3178'}++	; 
#	$ports_ref->{'udp'}{'3178'}{'name'} = 'radclientport'		; 
#	$srvcobjects_ref->{'radclientport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radclientport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radclientport'}{'port'}{'tcp'} = '3178'	; 
#	$srvcobjects_ref->{'radclientport'}{'ports'}{'tcp'}{'3178'}++	; 
#	$ports_ref->{'tcp'}{'3178'}{'name'} = 'radclientport'		; 
#	$srvcobjects_ref->{'iclpv-pm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclpv-pm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-pm'}{'port'}{'udp'} = '1392'	; 
#	$srvcobjects_ref->{'iclpv-pm'}{'ports'}{'udp'}{'1392'}++	; 
#	$ports_ref->{'udp'}{'1392'}{'name'} = 'iclpv-pm'		; 
#	$srvcobjects_ref->{'iclpv-pm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclpv-pm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-pm'}{'port'}{'tcp'} = '1392'	; 
#	$srvcobjects_ref->{'iclpv-pm'}{'ports'}{'tcp'}{'1392'}++	; 
#	$ports_ref->{'tcp'}{'1392'}{'name'} = 'iclpv-pm'		; 
#	$srvcobjects_ref->{'bootserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bootserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bootserver'}{'port'}{'udp'} = '2016'	; 
#	$srvcobjects_ref->{'bootserver'}{'ports'}{'udp'}{'2016'}++	; 
#	$ports_ref->{'udp'}{'2016'}{'name'} = 'bootserver'		; 
#	$srvcobjects_ref->{'bootserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bootserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bootserver'}{'port'}{'tcp'} = '2016'	; 
#	$srvcobjects_ref->{'bootserver'}{'ports'}{'tcp'}{'2016'}++	; 
#	$ports_ref->{'tcp'}{'2016'}{'name'} = 'bootserver'		; 
#	$srvcobjects_ref->{'delos-dms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'delos-dms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'delos-dms'}{'port'}{'udp'} = '3714'	; 
#	$srvcobjects_ref->{'delos-dms'}{'ports'}{'udp'}{'3714'}++	; 
#	$ports_ref->{'udp'}{'3714'}{'name'} = 'delos-dms'		; 
#	$srvcobjects_ref->{'delos-dms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'delos-dms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'delos-dms'}{'port'}{'tcp'} = '3714'	; 
#	$srvcobjects_ref->{'delos-dms'}{'ports'}{'tcp'}{'3714'}++	; 
#	$ports_ref->{'tcp'}{'3714'}{'name'} = 'delos-dms'		; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'port'}{'udp'} = '1417'	; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'ports'}{'udp'}{'1417'}++	; 
#	$ports_ref->{'udp'}{'1417'}{'name'} = 'timbuktu-srv1'		; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'port'}{'tcp'} = '1417'	; 
#	$srvcobjects_ref->{'timbuktu-srv1'}{'ports'}{'tcp'}{'1417'}++	; 
#	$ports_ref->{'tcp'}{'1417'}{'name'} = 'timbuktu-srv1'		; 
#	$srvcobjects_ref->{'localinfosrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'localinfosrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'localinfosrvr'}{'port'}{'udp'} = '1487'	; 
#	$srvcobjects_ref->{'localinfosrvr'}{'ports'}{'udp'}{'1487'}++	; 
#	$ports_ref->{'udp'}{'1487'}{'name'} = 'localinfosrvr'		; 
#	$srvcobjects_ref->{'localinfosrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'localinfosrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'localinfosrvr'}{'port'}{'tcp'} = '1487'	; 
#	$srvcobjects_ref->{'localinfosrvr'}{'ports'}{'tcp'}{'1487'}++	; 
#	$ports_ref->{'tcp'}{'1487'}{'name'} = 'localinfosrvr'		; 
#	$srvcobjects_ref->{'apw-registry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apw-registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apw-registry'}{'port'}{'udp'} = '3758'	; 
#	$srvcobjects_ref->{'apw-registry'}{'ports'}{'udp'}{'3758'}++	; 
#	$ports_ref->{'udp'}{'3758'}{'name'} = 'apw-registry'		; 
#	$srvcobjects_ref->{'apw-registry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apw-registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apw-registry'}{'port'}{'tcp'} = '3758'	; 
#	$srvcobjects_ref->{'apw-registry'}{'ports'}{'tcp'}{'3758'}++	; 
#	$ports_ref->{'tcp'}{'3758'}{'name'} = 'apw-registry'		; 
#	$srvcobjects_ref->{'h263-video'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h263-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h263-video'}{'port'}{'udp'} = '2979'	; 
#	$srvcobjects_ref->{'h263-video'}{'ports'}{'udp'}{'2979'}++	; 
#	$ports_ref->{'udp'}{'2979'}{'name'} = 'h263-video'		; 
#	$srvcobjects_ref->{'h263-video'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h263-video'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h263-video'}{'port'}{'tcp'} = '2979'	; 
#	$srvcobjects_ref->{'h263-video'}{'ports'}{'tcp'}{'2979'}++	; 
#	$ports_ref->{'tcp'}{'2979'}{'name'} = 'h263-video'		; 
#	$srvcobjects_ref->{'wpgs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wpgs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wpgs'}{'port'}{'udp'} = '780'	; 
#	$srvcobjects_ref->{'wpgs'}{'ports'}{'udp'}{'780'}++	; 
#	$ports_ref->{'udp'}{'780'}{'name'} = 'wpgs'		; 
#	$srvcobjects_ref->{'wpgs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wpgs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wpgs'}{'port'}{'tcp'} = '780'	; 
#	$srvcobjects_ref->{'wpgs'}{'ports'}{'tcp'}{'780'}++	; 
#	$ports_ref->{'tcp'}{'780'}{'name'} = 'wpgs'		; 
#	$srvcobjects_ref->{'nimrod-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nimrod-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimrod-agent'}{'port'}{'udp'} = '1617'	; 
#	$srvcobjects_ref->{'nimrod-agent'}{'ports'}{'udp'}{'1617'}++	; 
#	$ports_ref->{'udp'}{'1617'}{'name'} = 'nimrod-agent'		; 
#	$srvcobjects_ref->{'nimrod-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nimrod-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimrod-agent'}{'port'}{'tcp'} = '1617'	; 
#	$srvcobjects_ref->{'nimrod-agent'}{'ports'}{'tcp'}{'1617'}++	; 
#	$ports_ref->{'tcp'}{'1617'}{'name'} = 'nimrod-agent'		; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'port'}{'udp'} = '3343'	; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'ports'}{'udp'}{'3343'}++	; 
#	$ports_ref->{'udp'}{'3343'}{'name'} = 'ms-cluster-net'		; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'port'}{'tcp'} = '3343'	; 
#	$srvcobjects_ref->{'ms-cluster-net'}{'ports'}{'tcp'}{'3343'}++	; 
#	$ports_ref->{'tcp'}{'3343'}{'name'} = 'ms-cluster-net'		; 
#	$srvcobjects_ref->{'scientia-sdb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scientia-sdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scientia-sdb'}{'port'}{'udp'} = '1811'	; 
#	$srvcobjects_ref->{'scientia-sdb'}{'ports'}{'udp'}{'1811'}++	; 
#	$ports_ref->{'udp'}{'1811'}{'name'} = 'scientia-sdb'		; 
#	$srvcobjects_ref->{'scientia-sdb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scientia-sdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scientia-sdb'}{'port'}{'tcp'} = '1811'	; 
#	$srvcobjects_ref->{'scientia-sdb'}{'ports'}{'tcp'}{'1811'}++	; 
#	$ports_ref->{'tcp'}{'1811'}{'name'} = 'scientia-sdb'		; 
#	$srvcobjects_ref->{'x500ms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'x500ms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x500ms'}{'port'}{'udp'} = '5757'	; 
#	$srvcobjects_ref->{'x500ms'}{'ports'}{'udp'}{'5757'}++	; 
#	$ports_ref->{'udp'}{'5757'}{'name'} = 'x500ms'		; 
#	$srvcobjects_ref->{'x500ms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'x500ms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x500ms'}{'port'}{'tcp'} = '5757'	; 
#	$srvcobjects_ref->{'x500ms'}{'ports'}{'tcp'}{'5757'}++	; 
#	$ports_ref->{'tcp'}{'5757'}{'name'} = 'x500ms'		; 
#	$srvcobjects_ref->{'conf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'conf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'conf'}{'port'}{'tcp'} = '2008'	; 
#	$srvcobjects_ref->{'conf'}{'ports'}{'tcp'}{'2008'}++	; 
#	$ports_ref->{'tcp'}{'2008'}{'name'} = 'conf'		; 
#	$srvcobjects_ref->{'hri-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hri-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hri-port'}{'port'}{'udp'} = '3439'	; 
#	$srvcobjects_ref->{'hri-port'}{'ports'}{'udp'}{'3439'}++	; 
#	$ports_ref->{'udp'}{'3439'}{'name'} = 'hri-port'		; 
#	$srvcobjects_ref->{'hri-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hri-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hri-port'}{'port'}{'tcp'} = '3439'	; 
#	$srvcobjects_ref->{'hri-port'}{'ports'}{'tcp'}{'3439'}++	; 
#	$ports_ref->{'tcp'}{'3439'}{'name'} = 'hri-port'		; 
#	$srvcobjects_ref->{'iua'}{'type'} = 'sctp'	; 
#	$srvcobjects_ref->{'iua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iua'}{'port'}{'sctp'} = '9900'	; 
#	$srvcobjects_ref->{'iua'}{'ports'}{'sctp'}{'9900'}++	; 
#	$ports_ref->{'sctp'}{'9900'}{'name'} = 'iua'		; 
#	$srvcobjects_ref->{'iua'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iua'}{'port'}{'udp'} = '9900'	; 
#	$srvcobjects_ref->{'iua'}{'ports'}{'udp'}{'9900'}++	; 
#	$ports_ref->{'udp'}{'9900'}{'name'} = 'iua'		; 
#	$srvcobjects_ref->{'iua'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iua'}{'port'}{'tcp'} = '9900'	; 
#	$srvcobjects_ref->{'iua'}{'ports'}{'tcp'}{'9900'}++	; 
#	$ports_ref->{'tcp'}{'9900'}{'name'} = 'iua'		; 
#	$srvcobjects_ref->{'rt-event-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rt-event-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rt-event-s'}{'port'}{'udp'} = '3707'	; 
#	$srvcobjects_ref->{'rt-event-s'}{'ports'}{'udp'}{'3707'}++	; 
#	$ports_ref->{'udp'}{'3707'}{'name'} = 'rt-event-s'		; 
#	$srvcobjects_ref->{'rt-event-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rt-event-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rt-event-s'}{'port'}{'tcp'} = '3707'	; 
#	$srvcobjects_ref->{'rt-event-s'}{'ports'}{'tcp'}{'3707'}++	; 
#	$ports_ref->{'tcp'}{'3707'}{'name'} = 'rt-event-s'		; 
#	$srvcobjects_ref->{'scc-security'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scc-security'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scc-security'}{'port'}{'udp'} = '582'	; 
#	$srvcobjects_ref->{'scc-security'}{'ports'}{'udp'}{'582'}++	; 
#	$ports_ref->{'udp'}{'582'}{'name'} = 'scc-security'		; 
#	$srvcobjects_ref->{'scc-security'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scc-security'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scc-security'}{'port'}{'tcp'} = '582'	; 
#	$srvcobjects_ref->{'scc-security'}{'ports'}{'tcp'}{'582'}++	; 
#	$ports_ref->{'tcp'}{'582'}{'name'} = 'scc-security'		; 
#	$srvcobjects_ref->{'navisphere-sec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'navisphere-sec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navisphere-sec'}{'port'}{'udp'} = '2163'	; 
#	$srvcobjects_ref->{'navisphere-sec'}{'ports'}{'udp'}{'2163'}++	; 
#	$ports_ref->{'udp'}{'2163'}{'name'} = 'navisphere-sec'		; 
#	$srvcobjects_ref->{'navisphere-sec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'navisphere-sec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navisphere-sec'}{'port'}{'tcp'} = '2163'	; 
#	$srvcobjects_ref->{'navisphere-sec'}{'ports'}{'tcp'}{'2163'}++	; 
#	$ports_ref->{'tcp'}{'2163'}{'name'} = 'navisphere-sec'		; 
#	$srvcobjects_ref->{'hassle'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hassle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hassle'}{'port'}{'udp'} = '375'	; 
#	$srvcobjects_ref->{'hassle'}{'ports'}{'udp'}{'375'}++	; 
#	$ports_ref->{'udp'}{'375'}{'name'} = 'hassle'		; 
#	$srvcobjects_ref->{'hassle'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hassle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hassle'}{'port'}{'tcp'} = '375'	; 
#	$srvcobjects_ref->{'hassle'}{'ports'}{'tcp'}{'375'}++	; 
#	$ports_ref->{'tcp'}{'375'}{'name'} = 'hassle'		; 
#	$srvcobjects_ref->{'cmip-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cmip-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmip-agent'}{'port'}{'udp'} = '164'	; 
#	$srvcobjects_ref->{'cmip-agent'}{'ports'}{'udp'}{'164'}++	; 
#	$ports_ref->{'udp'}{'164'}{'name'} = 'cmip-agent'		; 
#	$srvcobjects_ref->{'cmip-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cmip-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmip-agent'}{'port'}{'tcp'} = '164'	; 
#	$srvcobjects_ref->{'cmip-agent'}{'ports'}{'tcp'}{'164'}++	; 
#	$ports_ref->{'tcp'}{'164'}{'name'} = 'cmip-agent'		; 
#	$srvcobjects_ref->{'hcp-wismar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hcp-wismar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hcp-wismar'}{'port'}{'udp'} = '686'	; 
#	$srvcobjects_ref->{'hcp-wismar'}{'ports'}{'udp'}{'686'}++	; 
#	$ports_ref->{'udp'}{'686'}{'name'} = 'hcp-wismar'		; 
#	$srvcobjects_ref->{'hcp-wismar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hcp-wismar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hcp-wismar'}{'port'}{'tcp'} = '686'	; 
#	$srvcobjects_ref->{'hcp-wismar'}{'ports'}{'tcp'}{'686'}++	; 
#	$ports_ref->{'tcp'}{'686'}{'name'} = 'hcp-wismar'		; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'port'}{'udp'} = '1687'	; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'ports'}{'udp'}{'1687'}++	; 
#	$ports_ref->{'udp'}{'1687'}{'name'} = 'nsjtp-ctrl'		; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'port'}{'tcp'} = '1687'	; 
#	$srvcobjects_ref->{'nsjtp-ctrl'}{'ports'}{'tcp'}{'1687'}++	; 
#	$ports_ref->{'tcp'}{'1687'}{'name'} = 'nsjtp-ctrl'		; 
#	$srvcobjects_ref->{'iwserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iwserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwserver'}{'port'}{'udp'} = '2166'	; 
#	$srvcobjects_ref->{'iwserver'}{'ports'}{'udp'}{'2166'}++	; 
#	$ports_ref->{'udp'}{'2166'}{'name'} = 'iwserver'		; 
#	$srvcobjects_ref->{'iwserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iwserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwserver'}{'port'}{'tcp'} = '2166'	; 
#	$srvcobjects_ref->{'iwserver'}{'ports'}{'tcp'}{'2166'}++	; 
#	$ports_ref->{'tcp'}{'2166'}{'name'} = 'iwserver'		; 
#	$srvcobjects_ref->{'mctet-master'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mctet-master'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctet-master'}{'port'}{'udp'} = '3115'	; 
#	$srvcobjects_ref->{'mctet-master'}{'ports'}{'udp'}{'3115'}++	; 
#	$ports_ref->{'udp'}{'3115'}{'name'} = 'mctet-master'		; 
#	$srvcobjects_ref->{'mctet-master'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mctet-master'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctet-master'}{'port'}{'tcp'} = '3115'	; 
#	$srvcobjects_ref->{'mctet-master'}{'ports'}{'tcp'}{'3115'}++	; 
#	$ports_ref->{'tcp'}{'3115'}{'name'} = 'mctet-master'		; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'port'}{'udp'} = '2645'	; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'ports'}{'udp'}{'2645'}++	; 
#	$ports_ref->{'udp'}{'2645'}{'name'} = 'novell-ipx-cmd'		; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'port'}{'tcp'} = '2645'	; 
#	$srvcobjects_ref->{'novell-ipx-cmd'}{'ports'}{'tcp'}{'2645'}++	; 
#	$ports_ref->{'tcp'}{'2645'}{'name'} = 'novell-ipx-cmd'		; 
#	$srvcobjects_ref->{'rbr-discovery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rbr-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rbr-discovery'}{'port'}{'udp'} = '3553'	; 
#	$srvcobjects_ref->{'rbr-discovery'}{'ports'}{'udp'}{'3553'}++	; 
#	$ports_ref->{'udp'}{'3553'}{'name'} = 'rbr-discovery'		; 
#	$srvcobjects_ref->{'rbr-discovery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rbr-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rbr-discovery'}{'port'}{'tcp'} = '3553'	; 
#	$srvcobjects_ref->{'rbr-discovery'}{'ports'}{'tcp'}{'3553'}++	; 
#	$ports_ref->{'tcp'}{'3553'}{'name'} = 'rbr-discovery'		; 
#	$srvcobjects_ref->{'siipat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'siipat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'siipat'}{'port'}{'udp'} = '1733'	; 
#	$srvcobjects_ref->{'siipat'}{'ports'}{'udp'}{'1733'}++	; 
#	$ports_ref->{'udp'}{'1733'}{'name'} = 'siipat'		; 
#	$srvcobjects_ref->{'siipat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'siipat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'siipat'}{'port'}{'tcp'} = '1733'	; 
#	$srvcobjects_ref->{'siipat'}{'ports'}{'tcp'}{'1733'}++	; 
#	$ports_ref->{'tcp'}{'1733'}{'name'} = 'siipat'		; 
#	$srvcobjects_ref->{'splitlock-gw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'splitlock-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'splitlock-gw'}{'port'}{'udp'} = '3647'	; 
#	$srvcobjects_ref->{'splitlock-gw'}{'ports'}{'udp'}{'3647'}++	; 
#	$ports_ref->{'udp'}{'3647'}{'name'} = 'splitlock-gw'		; 
#	$srvcobjects_ref->{'splitlock-gw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'splitlock-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'splitlock-gw'}{'port'}{'tcp'} = '3647'	; 
#	$srvcobjects_ref->{'splitlock-gw'}{'ports'}{'tcp'}{'3647'}++	; 
#	$ports_ref->{'tcp'}{'3647'}{'name'} = 'splitlock-gw'		; 
#	$srvcobjects_ref->{'rrirtr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrirtr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrirtr'}{'port'}{'udp'} = '1693'	; 
#	$srvcobjects_ref->{'rrirtr'}{'ports'}{'udp'}{'1693'}++	; 
#	$ports_ref->{'udp'}{'1693'}{'name'} = 'rrirtr'		; 
#	$srvcobjects_ref->{'rrirtr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrirtr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrirtr'}{'port'}{'tcp'} = '1693'	; 
#	$srvcobjects_ref->{'rrirtr'}{'ports'}{'tcp'}{'1693'}++	; 
#	$ports_ref->{'tcp'}{'1693'}{'name'} = 'rrirtr'		; 
#	$srvcobjects_ref->{'messageservice'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'messageservice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'messageservice'}{'port'}{'udp'} = '2311'	; 
#	$srvcobjects_ref->{'messageservice'}{'ports'}{'udp'}{'2311'}++	; 
#	$ports_ref->{'udp'}{'2311'}{'name'} = 'messageservice'		; 
#	$srvcobjects_ref->{'messageservice'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'messageservice'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'messageservice'}{'port'}{'tcp'} = '2311'	; 
#	$srvcobjects_ref->{'messageservice'}{'ports'}{'tcp'}{'2311'}++	; 
#	$ports_ref->{'tcp'}{'2311'}{'name'} = 'messageservice'		; 
#	$srvcobjects_ref->{'synchronet-upd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synchronet-upd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synchronet-upd'}{'port'}{'udp'} = '6102'	; 
#	$srvcobjects_ref->{'synchronet-upd'}{'ports'}{'udp'}{'6102'}++	; 
#	$ports_ref->{'udp'}{'6102'}{'name'} = 'synchronet-upd'		; 
#	$srvcobjects_ref->{'synchronet-upd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synchronet-upd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synchronet-upd'}{'port'}{'tcp'} = '6102'	; 
#	$srvcobjects_ref->{'synchronet-upd'}{'ports'}{'tcp'}{'6102'}++	; 
#	$ports_ref->{'tcp'}{'6102'}{'name'} = 'synchronet-upd'		; 
#	$srvcobjects_ref->{'arepa-raft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arepa-raft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arepa-raft'}{'port'}{'udp'} = '3025'	; 
#	$srvcobjects_ref->{'arepa-raft'}{'ports'}{'udp'}{'3025'}++	; 
#	$ports_ref->{'udp'}{'3025'}{'name'} = 'arepa-raft'		; 
#	$srvcobjects_ref->{'arepa-raft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arepa-raft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arepa-raft'}{'port'}{'tcp'} = '3025'	; 
#	$srvcobjects_ref->{'arepa-raft'}{'ports'}{'tcp'}{'3025'}++	; 
#	$ports_ref->{'tcp'}{'3025'}{'name'} = 'arepa-raft'		; 
#	$srvcobjects_ref->{'dcs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dcs'}{'port'}{'udp'} = '1367'	; 
#	$srvcobjects_ref->{'dcs'}{'ports'}{'udp'}{'1367'}++	; 
#	$ports_ref->{'udp'}{'1367'}{'name'} = 'dcs'		; 
#	$srvcobjects_ref->{'dcs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dcs'}{'port'}{'tcp'} = '1367'	; 
#	$srvcobjects_ref->{'dcs'}{'ports'}{'tcp'}{'1367'}++	; 
#	$ports_ref->{'tcp'}{'1367'}{'name'} = 'dcs'		; 
#	$srvcobjects_ref->{'pspserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pspserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pspserver'}{'port'}{'udp'} = '2353'	; 
#	$srvcobjects_ref->{'pspserver'}{'ports'}{'udp'}{'2353'}++	; 
#	$ports_ref->{'udp'}{'2353'}{'name'} = 'pspserver'		; 
#	$srvcobjects_ref->{'pspserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pspserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pspserver'}{'port'}{'tcp'} = '2353'	; 
#	$srvcobjects_ref->{'pspserver'}{'ports'}{'tcp'}{'2353'}++	; 
#	$ports_ref->{'tcp'}{'2353'}{'name'} = 'pspserver'		; 
#	$srvcobjects_ref->{'csnet-ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csnet-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csnet-ns'}{'port'}{'udp'} = '105'	; 
#	$srvcobjects_ref->{'csnet-ns'}{'ports'}{'udp'}{'105'}++	; 
#	$ports_ref->{'udp'}{'105'}{'name'} = 'csnet-ns'		; 
#	$srvcobjects_ref->{'csnet-ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csnet-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csnet-ns'}{'port'}{'tcp'} = '105'	; 
#	$srvcobjects_ref->{'csnet-ns'}{'ports'}{'tcp'}{'105'}++	; 
#	$ports_ref->{'tcp'}{'105'}{'name'} = 'csnet-ns'		; 
#	$srvcobjects_ref->{'jmact3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmact3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmact3'}{'port'}{'udp'} = '6961'	; 
#	$srvcobjects_ref->{'jmact3'}{'ports'}{'udp'}{'6961'}++	; 
#	$ports_ref->{'udp'}{'6961'}{'name'} = 'jmact3'		; 
#	$srvcobjects_ref->{'jmact3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmact3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmact3'}{'port'}{'tcp'} = '6961'	; 
#	$srvcobjects_ref->{'jmact3'}{'ports'}{'tcp'}{'6961'}++	; 
#	$ports_ref->{'tcp'}{'6961'}{'name'} = 'jmact3'		; 
#	$srvcobjects_ref->{'dna-cml'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dna-cml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dna-cml'}{'port'}{'udp'} = '436'	; 
#	$srvcobjects_ref->{'dna-cml'}{'ports'}{'udp'}{'436'}++	; 
#	$ports_ref->{'udp'}{'436'}{'name'} = 'dna-cml'		; 
#	$srvcobjects_ref->{'dna-cml'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dna-cml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dna-cml'}{'port'}{'tcp'} = '436'	; 
#	$srvcobjects_ref->{'dna-cml'}{'ports'}{'tcp'}{'436'}++	; 
#	$ports_ref->{'tcp'}{'436'}{'name'} = 'dna-cml'		; 
#	$srvcobjects_ref->{'imagequery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imagequery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imagequery'}{'port'}{'udp'} = '2239'	; 
#	$srvcobjects_ref->{'imagequery'}{'ports'}{'udp'}{'2239'}++	; 
#	$ports_ref->{'udp'}{'2239'}{'name'} = 'imagequery'		; 
#	$srvcobjects_ref->{'imagequery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imagequery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imagequery'}{'port'}{'tcp'} = '2239'	; 
#	$srvcobjects_ref->{'imagequery'}{'ports'}{'tcp'}{'2239'}++	; 
#	$ports_ref->{'tcp'}{'2239'}{'name'} = 'imagequery'		; 
#	$srvcobjects_ref->{'lpcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lpcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lpcp'}{'port'}{'udp'} = '1298'	; 
#	$srvcobjects_ref->{'lpcp'}{'ports'}{'udp'}{'1298'}++	; 
#	$ports_ref->{'udp'}{'1298'}{'name'} = 'lpcp'		; 
#	$srvcobjects_ref->{'lpcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lpcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lpcp'}{'port'}{'tcp'} = '1298'	; 
#	$srvcobjects_ref->{'lpcp'}{'ports'}{'tcp'}{'1298'}++	; 
#	$ports_ref->{'tcp'}{'1298'}{'name'} = 'lpcp'		; 
#	$srvcobjects_ref->{'nasmanager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nasmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nasmanager'}{'port'}{'udp'} = '1960'	; 
#	$srvcobjects_ref->{'nasmanager'}{'ports'}{'udp'}{'1960'}++	; 
#	$ports_ref->{'udp'}{'1960'}{'name'} = 'nasmanager'		; 
#	$srvcobjects_ref->{'nasmanager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nasmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nasmanager'}{'port'}{'tcp'} = '1960'	; 
#	$srvcobjects_ref->{'nasmanager'}{'ports'}{'tcp'}{'1960'}++	; 
#	$ports_ref->{'tcp'}{'1960'}{'name'} = 'nasmanager'		; 
#	$srvcobjects_ref->{'commplex-main'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'commplex-main'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commplex-main'}{'port'}{'udp'} = '5000'	; 
#	$srvcobjects_ref->{'commplex-main'}{'ports'}{'udp'}{'5000'}++	; 
#	$ports_ref->{'udp'}{'5000'}{'name'} = 'commplex-main'		; 
#	$srvcobjects_ref->{'commplex-main'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'commplex-main'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commplex-main'}{'port'}{'tcp'} = '5000'	; 
#	$srvcobjects_ref->{'commplex-main'}{'ports'}{'tcp'}{'5000'}++	; 
#	$ports_ref->{'tcp'}{'5000'}{'name'} = 'commplex-main'		; 
#	$srvcobjects_ref->{'tarantella'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tarantella'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tarantella'}{'port'}{'udp'} = '3144'	; 
#	$srvcobjects_ref->{'tarantella'}{'ports'}{'udp'}{'3144'}++	; 
#	$ports_ref->{'udp'}{'3144'}{'name'} = 'tarantella'		; 
#	$srvcobjects_ref->{'tarantella'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tarantella'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tarantella'}{'port'}{'tcp'} = '3144'	; 
#	$srvcobjects_ref->{'tarantella'}{'ports'}{'tcp'}{'3144'}++	; 
#	$ports_ref->{'tcp'}{'3144'}{'name'} = 'tarantella'		; 
#	$srvcobjects_ref->{'dpsi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dpsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpsi'}{'port'}{'udp'} = '315'	; 
#	$srvcobjects_ref->{'dpsi'}{'ports'}{'udp'}{'315'}++	; 
#	$ports_ref->{'udp'}{'315'}{'name'} = 'dpsi'		; 
#	$srvcobjects_ref->{'dpsi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dpsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpsi'}{'port'}{'tcp'} = '315'	; 
#	$srvcobjects_ref->{'dpsi'}{'ports'}{'tcp'}{'315'}++	; 
#	$ports_ref->{'tcp'}{'315'}{'name'} = 'dpsi'		; 
#	$srvcobjects_ref->{'ferrari-foam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ferrari-foam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ferrari-foam'}{'port'}{'udp'} = '3216'	; 
#	$srvcobjects_ref->{'ferrari-foam'}{'ports'}{'udp'}{'3216'}++	; 
#	$ports_ref->{'udp'}{'3216'}{'name'} = 'ferrari-foam'		; 
#	$srvcobjects_ref->{'ferrari-foam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ferrari-foam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ferrari-foam'}{'port'}{'tcp'} = '3216'	; 
#	$srvcobjects_ref->{'ferrari-foam'}{'ports'}{'tcp'}{'3216'}++	; 
#	$ports_ref->{'tcp'}{'3216'}{'name'} = 'ferrari-foam'		; 
#	$srvcobjects_ref->{'argis-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'argis-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'argis-ds'}{'port'}{'udp'} = '2582'	; 
#	$srvcobjects_ref->{'argis-ds'}{'ports'}{'udp'}{'2582'}++	; 
#	$ports_ref->{'udp'}{'2582'}{'name'} = 'argis-ds'		; 
#	$srvcobjects_ref->{'argis-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'argis-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'argis-ds'}{'port'}{'tcp'} = '2582'	; 
#	$srvcobjects_ref->{'argis-ds'}{'ports'}{'tcp'}{'2582'}++	; 
#	$ports_ref->{'tcp'}{'2582'}{'name'} = 'argis-ds'		; 
#	$srvcobjects_ref->{'rmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmt'}{'port'}{'udp'} = '411'	; 
#	$srvcobjects_ref->{'rmt'}{'ports'}{'udp'}{'411'}++	; 
#	$ports_ref->{'udp'}{'411'}{'name'} = 'rmt'		; 
#	$srvcobjects_ref->{'rmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmt'}{'port'}{'tcp'} = '411'	; 
#	$srvcobjects_ref->{'rmt'}{'ports'}{'tcp'}{'411'}++	; 
#	$ports_ref->{'tcp'}{'411'}{'name'} = 'rmt'		; 
#	$srvcobjects_ref->{'rfx-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rfx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfx-lm'}{'port'}{'udp'} = '1497'	; 
#	$srvcobjects_ref->{'rfx-lm'}{'ports'}{'udp'}{'1497'}++	; 
#	$ports_ref->{'udp'}{'1497'}{'name'} = 'rfx-lm'		; 
#	$srvcobjects_ref->{'rfx-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rfx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfx-lm'}{'port'}{'tcp'} = '1497'	; 
#	$srvcobjects_ref->{'rfx-lm'}{'ports'}{'tcp'}{'1497'}++	; 
#	$ports_ref->{'tcp'}{'1497'}{'name'} = 'rfx-lm'		; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'port'}{'udp'} = '2683'	; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'ports'}{'udp'}{'2683'}++	; 
#	$ports_ref->{'udp'}{'2683'}{'name'} = 'ncdloadbalance'		; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'port'}{'tcp'} = '2683'	; 
#	$srvcobjects_ref->{'ncdloadbalance'}{'ports'}{'tcp'}{'2683'}++	; 
#	$ports_ref->{'tcp'}{'2683'}{'name'} = 'ncdloadbalance'		; 
#	$srvcobjects_ref->{'opsmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsmgr'}{'port'}{'udp'} = '1270'	; 
#	$srvcobjects_ref->{'opsmgr'}{'ports'}{'udp'}{'1270'}++	; 
#	$ports_ref->{'udp'}{'1270'}{'name'} = 'opsmgr'		; 
#	$srvcobjects_ref->{'opsmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsmgr'}{'port'}{'tcp'} = '1270'	; 
#	$srvcobjects_ref->{'opsmgr'}{'ports'}{'tcp'}{'1270'}++	; 
#	$ports_ref->{'tcp'}{'1270'}{'name'} = 'opsmgr'		; 
#	$srvcobjects_ref->{'elad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elad'}{'port'}{'udp'} = '1893'	; 
#	$srvcobjects_ref->{'elad'}{'ports'}{'udp'}{'1893'}++	; 
#	$ports_ref->{'udp'}{'1893'}{'name'} = 'elad'		; 
#	$srvcobjects_ref->{'elad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elad'}{'port'}{'tcp'} = '1893'	; 
#	$srvcobjects_ref->{'elad'}{'ports'}{'tcp'}{'1893'}++	; 
#	$ports_ref->{'tcp'}{'1893'}{'name'} = 'elad'		; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'port'}{'udp'} = '2444'	; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'ports'}{'udp'}{'2444'}++	; 
#	$ports_ref->{'udp'}{'2444'}{'name'} = 'btpp2sectrans'		; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'port'}{'tcp'} = '2444'	; 
#	$srvcobjects_ref->{'btpp2sectrans'}{'ports'}{'tcp'}{'2444'}++	; 
#	$ports_ref->{'tcp'}{'2444'}{'name'} = 'btpp2sectrans'		; 
#	$srvcobjects_ref->{'itactionserver2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itactionserver2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itactionserver2'}{'port'}{'udp'} = '7281'	; 
#	$srvcobjects_ref->{'itactionserver2'}{'ports'}{'udp'}{'7281'}++	; 
#	$ports_ref->{'udp'}{'7281'}{'name'} = 'itactionserver2'		; 
#	$srvcobjects_ref->{'itactionserver2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itactionserver2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itactionserver2'}{'port'}{'tcp'} = '7281'	; 
#	$srvcobjects_ref->{'itactionserver2'}{'ports'}{'tcp'}{'7281'}++	; 
#	$ports_ref->{'tcp'}{'7281'}{'name'} = 'itactionserver2'		; 
#	$srvcobjects_ref->{'metagram'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metagram'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metagram'}{'port'}{'udp'} = '99'	; 
#	$srvcobjects_ref->{'metagram'}{'ports'}{'udp'}{'99'}++	; 
#	$ports_ref->{'udp'}{'99'}{'name'} = 'metagram'		; 
#	$srvcobjects_ref->{'metagram'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metagram'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metagram'}{'port'}{'tcp'} = '99'	; 
#	$srvcobjects_ref->{'metagram'}{'ports'}{'tcp'}{'99'}++	; 
#	$ports_ref->{'tcp'}{'99'}{'name'} = 'metagram'		; 
#	$srvcobjects_ref->{'emware-oft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emware-oft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emware-oft'}{'port'}{'udp'} = '3567'	; 
#	$srvcobjects_ref->{'emware-oft'}{'ports'}{'udp'}{'3567'}++	; 
#	$ports_ref->{'udp'}{'3567'}{'name'} = 'emware-oft'		; 
#	$srvcobjects_ref->{'emware-oft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emware-oft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emware-oft'}{'port'}{'tcp'} = '3567'	; 
#	$srvcobjects_ref->{'emware-oft'}{'ports'}{'tcp'}{'3567'}++	; 
#	$ports_ref->{'tcp'}{'3567'}{'name'} = 'emware-oft'		; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'port'}{'udp'} = '617'	; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'ports'}{'udp'}{'617'}++	; 
#	$ports_ref->{'udp'}{'617'}{'name'} = 'sco-dtmgr'		; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'port'}{'tcp'} = '617'	; 
#	$srvcobjects_ref->{'sco-dtmgr'}{'ports'}{'tcp'}{'617'}++	; 
#	$ports_ref->{'tcp'}{'617'}{'name'} = 'sco-dtmgr'		; 
#	$srvcobjects_ref->{'shivadiscovery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shivadiscovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shivadiscovery'}{'port'}{'udp'} = '1502'	; 
#	$srvcobjects_ref->{'shivadiscovery'}{'ports'}{'udp'}{'1502'}++	; 
#	$ports_ref->{'udp'}{'1502'}{'name'} = 'shivadiscovery'		; 
#	$srvcobjects_ref->{'shivadiscovery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shivadiscovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shivadiscovery'}{'port'}{'tcp'} = '1502'	; 
#	$srvcobjects_ref->{'shivadiscovery'}{'ports'}{'tcp'}{'1502'}++	; 
#	$ports_ref->{'tcp'}{'1502'}{'name'} = 'shivadiscovery'		; 
#	$srvcobjects_ref->{'pluribus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pluribus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pluribus'}{'port'}{'udp'} = '3469'	; 
#	$srvcobjects_ref->{'pluribus'}{'ports'}{'udp'}{'3469'}++	; 
#	$ports_ref->{'udp'}{'3469'}{'name'} = 'pluribus'		; 
#	$srvcobjects_ref->{'pluribus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pluribus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pluribus'}{'port'}{'tcp'} = '3469'	; 
#	$srvcobjects_ref->{'pluribus'}{'ports'}{'tcp'}{'3469'}++	; 
#	$ports_ref->{'tcp'}{'3469'}{'name'} = 'pluribus'		; 
#	$srvcobjects_ref->{'lpsrecommender'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lpsrecommender'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lpsrecommender'}{'port'}{'udp'} = '2620'	; 
#	$srvcobjects_ref->{'lpsrecommender'}{'ports'}{'udp'}{'2620'}++	; 
#	$ports_ref->{'udp'}{'2620'}{'name'} = 'lpsrecommender'		; 
#	$srvcobjects_ref->{'lpsrecommender'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lpsrecommender'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lpsrecommender'}{'port'}{'tcp'} = '2620'	; 
#	$srvcobjects_ref->{'lpsrecommender'}{'ports'}{'tcp'}{'2620'}++	; 
#	$ports_ref->{'tcp'}{'2620'}{'name'} = 'lpsrecommender'		; 
#	$srvcobjects_ref->{'re-conn-proto'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'re-conn-proto'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'re-conn-proto'}{'port'}{'udp'} = '1306'	; 
#	$srvcobjects_ref->{'re-conn-proto'}{'ports'}{'udp'}{'1306'}++	; 
#	$ports_ref->{'udp'}{'1306'}{'name'} = 're-conn-proto'		; 
#	$srvcobjects_ref->{'re-conn-proto'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'re-conn-proto'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'re-conn-proto'}{'port'}{'tcp'} = '1306'	; 
#	$srvcobjects_ref->{'re-conn-proto'}{'ports'}{'tcp'}{'1306'}++	; 
#	$ports_ref->{'tcp'}{'1306'}{'name'} = 're-conn-proto'		; 
#	$srvcobjects_ref->{'j-lan-p'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'j-lan-p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'j-lan-p'}{'port'}{'udp'} = '2808'	; 
#	$srvcobjects_ref->{'j-lan-p'}{'ports'}{'udp'}{'2808'}++	; 
#	$ports_ref->{'udp'}{'2808'}{'name'} = 'j-lan-p'		; 
#	$srvcobjects_ref->{'j-lan-p'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'j-lan-p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'j-lan-p'}{'port'}{'tcp'} = '2808'	; 
#	$srvcobjects_ref->{'j-lan-p'}{'ports'}{'tcp'}{'2808'}++	; 
#	$ports_ref->{'tcp'}{'2808'}{'name'} = 'j-lan-p'		; 
#	$srvcobjects_ref->{'ipsec-msft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipsec-msft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipsec-msft'}{'port'}{'udp'} = '4500'	; 
#	$srvcobjects_ref->{'ipsec-msft'}{'ports'}{'udp'}{'4500'}++	; 
#	$ports_ref->{'udp'}{'4500'}{'name'} = 'ipsec-msft'		; 
#	$srvcobjects_ref->{'ipsec-msft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipsec-msft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipsec-msft'}{'port'}{'tcp'} = '4500'	; 
#	$srvcobjects_ref->{'ipsec-msft'}{'ports'}{'tcp'}{'4500'}++	; 
#	$ports_ref->{'tcp'}{'4500'}{'name'} = 'ipsec-msft'		; 
#	$srvcobjects_ref->{'direct'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'direct'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direct'}{'port'}{'udp'} = '242'	; 
#	$srvcobjects_ref->{'direct'}{'ports'}{'udp'}{'242'}++	; 
#	$ports_ref->{'udp'}{'242'}{'name'} = 'direct'		; 
#	$srvcobjects_ref->{'direct'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'direct'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direct'}{'port'}{'tcp'} = '242'	; 
#	$srvcobjects_ref->{'direct'}{'ports'}{'tcp'}{'242'}++	; 
#	$ports_ref->{'tcp'}{'242'}{'name'} = 'direct'		; 
#	$srvcobjects_ref->{'smsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smsp'}{'port'}{'udp'} = '413'	; 
#	$srvcobjects_ref->{'smsp'}{'ports'}{'udp'}{'413'}++	; 
#	$ports_ref->{'udp'}{'413'}{'name'} = 'smsp'		; 
#	$srvcobjects_ref->{'smsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smsp'}{'port'}{'tcp'} = '413'	; 
#	$srvcobjects_ref->{'smsp'}{'ports'}{'tcp'}{'413'}++	; 
#	$ports_ref->{'tcp'}{'413'}{'name'} = 'smsp'		; 
#	$srvcobjects_ref->{'cycleserv2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cycleserv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cycleserv2'}{'port'}{'udp'} = '772'	; 
#	$srvcobjects_ref->{'cycleserv2'}{'ports'}{'udp'}{'772'}++	; 
#	$ports_ref->{'udp'}{'772'}{'name'} = 'cycleserv2'		; 
#	$srvcobjects_ref->{'cycleserv2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cycleserv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cycleserv2'}{'port'}{'tcp'} = '772'	; 
#	$srvcobjects_ref->{'cycleserv2'}{'ports'}{'tcp'}{'772'}++	; 
#	$ports_ref->{'tcp'}{'772'}{'name'} = 'cycleserv2'		; 
#	$srvcobjects_ref->{'xiostatus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xiostatus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xiostatus'}{'port'}{'udp'} = '2341'	; 
#	$srvcobjects_ref->{'xiostatus'}{'ports'}{'udp'}{'2341'}++	; 
#	$ports_ref->{'udp'}{'2341'}{'name'} = 'xiostatus'		; 
#	$srvcobjects_ref->{'xiostatus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xiostatus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xiostatus'}{'port'}{'tcp'} = '2341'	; 
#	$srvcobjects_ref->{'xiostatus'}{'ports'}{'tcp'}{'2341'}++	; 
#	$ports_ref->{'tcp'}{'2341'}{'name'} = 'xiostatus'		; 
#	$srvcobjects_ref->{'aap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aap'}{'port'}{'udp'} = '2878'	; 
#	$srvcobjects_ref->{'aap'}{'ports'}{'udp'}{'2878'}++	; 
#	$ports_ref->{'udp'}{'2878'}{'name'} = 'aap'		; 
#	$srvcobjects_ref->{'aap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aap'}{'port'}{'tcp'} = '2878'	; 
#	$srvcobjects_ref->{'aap'}{'ports'}{'tcp'}{'2878'}++	; 
#	$ports_ref->{'tcp'}{'2878'}{'name'} = 'aap'		; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'port'}{'udp'} = '2427'	; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'ports'}{'udp'}{'2427'}++	; 
#	$ports_ref->{'udp'}{'2427'}{'name'} = 'mgcp-gateway'		; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'port'}{'tcp'} = '2427'	; 
#	$srvcobjects_ref->{'mgcp-gateway'}{'ports'}{'tcp'}{'2427'}++	; 
#	$ports_ref->{'tcp'}{'2427'}{'name'} = 'mgcp-gateway'		; 
#	$srvcobjects_ref->{'wip-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wip-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wip-port'}{'port'}{'udp'} = '3414'	; 
#	$srvcobjects_ref->{'wip-port'}{'ports'}{'udp'}{'3414'}++	; 
#	$ports_ref->{'udp'}{'3414'}{'name'} = 'wip-port'		; 
#	$srvcobjects_ref->{'wip-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wip-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wip-port'}{'port'}{'tcp'} = '3414'	; 
#	$srvcobjects_ref->{'wip-port'}{'ports'}{'tcp'}{'3414'}++	; 
#	$ports_ref->{'tcp'}{'3414'}{'name'} = 'wip-port'		; 
#	$srvcobjects_ref->{'ratio-adp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ratio-adp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ratio-adp'}{'port'}{'udp'} = '1108'	; 
#	$srvcobjects_ref->{'ratio-adp'}{'ports'}{'udp'}{'1108'}++	; 
#	$ports_ref->{'udp'}{'1108'}{'name'} = 'ratio-adp'		; 
#	$srvcobjects_ref->{'ratio-adp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ratio-adp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ratio-adp'}{'port'}{'tcp'} = '1108'	; 
#	$srvcobjects_ref->{'ratio-adp'}{'ports'}{'tcp'}{'1108'}++	; 
#	$ports_ref->{'tcp'}{'1108'}{'name'} = 'ratio-adp'		; 
#	$srvcobjects_ref->{'index-pc-wb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'index-pc-wb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'index-pc-wb'}{'port'}{'udp'} = '2127'	; 
#	$srvcobjects_ref->{'index-pc-wb'}{'ports'}{'udp'}{'2127'}++	; 
#	$ports_ref->{'udp'}{'2127'}{'name'} = 'index-pc-wb'		; 
#	$srvcobjects_ref->{'index-pc-wb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'index-pc-wb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'index-pc-wb'}{'port'}{'tcp'} = '2127'	; 
#	$srvcobjects_ref->{'index-pc-wb'}{'ports'}{'tcp'}{'2127'}++	; 
#	$ports_ref->{'tcp'}{'2127'}{'name'} = 'index-pc-wb'		; 
#	$srvcobjects_ref->{'sns-protocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-protocol'}{'port'}{'udp'} = '2409'	; 
#	$srvcobjects_ref->{'sns-protocol'}{'ports'}{'udp'}{'2409'}++	; 
#	$ports_ref->{'udp'}{'2409'}{'name'} = 'sns-protocol'		; 
#	$srvcobjects_ref->{'sns-protocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-protocol'}{'port'}{'tcp'} = '2409'	; 
#	$srvcobjects_ref->{'sns-protocol'}{'ports'}{'tcp'}{'2409'}++	; 
#	$ports_ref->{'tcp'}{'2409'}{'name'} = 'sns-protocol'		; 
#	$srvcobjects_ref->{'imtc-map'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imtc-map'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imtc-map'}{'port'}{'udp'} = '2202'	; 
#	$srvcobjects_ref->{'imtc-map'}{'ports'}{'udp'}{'2202'}++	; 
#	$ports_ref->{'udp'}{'2202'}{'name'} = 'imtc-map'		; 
#	$srvcobjects_ref->{'imtc-map'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imtc-map'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imtc-map'}{'port'}{'tcp'} = '2202'	; 
#	$srvcobjects_ref->{'imtc-map'}{'ports'}{'tcp'}{'2202'}++	; 
#	$ports_ref->{'tcp'}{'2202'}{'name'} = 'imtc-map'		; 
#	$srvcobjects_ref->{'mcs-messaging'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcs-messaging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-messaging'}{'port'}{'udp'} = '3331'	; 
#	$srvcobjects_ref->{'mcs-messaging'}{'ports'}{'udp'}{'3331'}++	; 
#	$ports_ref->{'udp'}{'3331'}{'name'} = 'mcs-messaging'		; 
#	$srvcobjects_ref->{'mcs-messaging'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcs-messaging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-messaging'}{'port'}{'tcp'} = '3331'	; 
#	$srvcobjects_ref->{'mcs-messaging'}{'ports'}{'tcp'}{'3331'}++	; 
#	$ports_ref->{'tcp'}{'3331'}{'name'} = 'mcs-messaging'		; 
#	$srvcobjects_ref->{'toad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'toad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'toad'}{'port'}{'udp'} = '2669'	; 
#	$srvcobjects_ref->{'toad'}{'ports'}{'udp'}{'2669'}++	; 
#	$ports_ref->{'udp'}{'2669'}{'name'} = 'toad'		; 
#	$srvcobjects_ref->{'toad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'toad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'toad'}{'port'}{'tcp'} = '2669'	; 
#	$srvcobjects_ref->{'toad'}{'ports'}{'tcp'}{'2669'}++	; 
#	$ports_ref->{'tcp'}{'2669'}{'name'} = 'toad'		; 
#	$srvcobjects_ref->{'datex-asn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'datex-asn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datex-asn'}{'port'}{'udp'} = '355'	; 
#	$srvcobjects_ref->{'datex-asn'}{'ports'}{'udp'}{'355'}++	; 
#	$ports_ref->{'udp'}{'355'}{'name'} = 'datex-asn'		; 
#	$srvcobjects_ref->{'datex-asn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'datex-asn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datex-asn'}{'port'}{'tcp'} = '355'	; 
#	$srvcobjects_ref->{'datex-asn'}{'ports'}{'tcp'}{'355'}++	; 
#	$ports_ref->{'tcp'}{'355'}{'name'} = 'datex-asn'		; 
#	$srvcobjects_ref->{'nat-stun-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nat-stun-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nat-stun-port'}{'port'}{'udp'} = '3478'	; 
#	$srvcobjects_ref->{'nat-stun-port'}{'ports'}{'udp'}{'3478'}++	; 
#	$ports_ref->{'udp'}{'3478'}{'name'} = 'nat-stun-port'		; 
#	$srvcobjects_ref->{'nat-stun-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nat-stun-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nat-stun-port'}{'port'}{'tcp'} = '3478'	; 
#	$srvcobjects_ref->{'nat-stun-port'}{'ports'}{'tcp'}{'3478'}++	; 
#	$ports_ref->{'tcp'}{'3478'}{'name'} = 'nat-stun-port'		; 
#	$srvcobjects_ref->{'ets'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ets'}{'port'}{'udp'} = '1569'	; 
#	$srvcobjects_ref->{'ets'}{'ports'}{'udp'}{'1569'}++	; 
#	$ports_ref->{'udp'}{'1569'}{'name'} = 'ets'		; 
#	$srvcobjects_ref->{'ets'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ets'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ets'}{'port'}{'tcp'} = '1569'	; 
#	$srvcobjects_ref->{'ets'}{'ports'}{'tcp'}{'1569'}++	; 
#	$ports_ref->{'tcp'}{'1569'}{'name'} = 'ets'		; 
#	$srvcobjects_ref->{'isis-ambc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isis-ambc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isis-ambc'}{'port'}{'udp'} = '1643'	; 
#	$srvcobjects_ref->{'isis-ambc'}{'ports'}{'udp'}{'1643'}++	; 
#	$ports_ref->{'udp'}{'1643'}{'name'} = 'isis-ambc'		; 
#	$srvcobjects_ref->{'isis-ambc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isis-ambc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isis-ambc'}{'port'}{'tcp'} = '1643'	; 
#	$srvcobjects_ref->{'isis-ambc'}{'ports'}{'tcp'}{'1643'}++	; 
#	$ports_ref->{'tcp'}{'1643'}{'name'} = 'isis-ambc'		; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'port'}{'udp'} = '3616'	; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'ports'}{'udp'}{'3616'}++	; 
#	$ports_ref->{'udp'}{'3616'}{'name'} = 'cd3o-protocol'		; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'port'}{'tcp'} = '3616'	; 
#	$srvcobjects_ref->{'cd3o-protocol'}{'ports'}{'tcp'}{'3616'}++	; 
#	$ports_ref->{'tcp'}{'3616'}{'name'} = 'cd3o-protocol'		; 
#	$srvcobjects_ref->{'corba-iiop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'corba-iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corba-iiop'}{'port'}{'udp'} = '683'	; 
#	$srvcobjects_ref->{'corba-iiop'}{'ports'}{'udp'}{'683'}++	; 
#	$ports_ref->{'udp'}{'683'}{'name'} = 'corba-iiop'		; 
#	$srvcobjects_ref->{'corba-iiop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'corba-iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corba-iiop'}{'port'}{'tcp'} = '683'	; 
#	$srvcobjects_ref->{'corba-iiop'}{'ports'}{'tcp'}{'683'}++	; 
#	$ports_ref->{'tcp'}{'683'}{'name'} = 'corba-iiop'		; 
#	$srvcobjects_ref->{'sns-channels'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-channels'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-channels'}{'port'}{'udp'} = '3380'	; 
#	$srvcobjects_ref->{'sns-channels'}{'ports'}{'udp'}{'3380'}++	; 
#	$ports_ref->{'udp'}{'3380'}{'name'} = 'sns-channels'		; 
#	$srvcobjects_ref->{'sns-channels'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-channels'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-channels'}{'port'}{'tcp'} = '3380'	; 
#	$srvcobjects_ref->{'sns-channels'}{'ports'}{'tcp'}{'3380'}++	; 
#	$ports_ref->{'tcp'}{'3380'}{'name'} = 'sns-channels'		; 
#	$srvcobjects_ref->{'ivmanager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ivmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivmanager'}{'port'}{'udp'} = '1276'	; 
#	$srvcobjects_ref->{'ivmanager'}{'ports'}{'udp'}{'1276'}++	; 
#	$ports_ref->{'udp'}{'1276'}{'name'} = 'ivmanager'		; 
#	$srvcobjects_ref->{'ivmanager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ivmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivmanager'}{'port'}{'tcp'} = '1276'	; 
#	$srvcobjects_ref->{'ivmanager'}{'ports'}{'tcp'}{'1276'}++	; 
#	$ports_ref->{'tcp'}{'1276'}{'name'} = 'ivmanager'		; 
#	$srvcobjects_ref->{'bxp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bxp'}{'port'}{'udp'} = '4027'	; 
#	$srvcobjects_ref->{'bxp'}{'ports'}{'udp'}{'4027'}++	; 
#	$ports_ref->{'udp'}{'4027'}{'name'} = 'bxp'		; 
#	$srvcobjects_ref->{'bxp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bxp'}{'port'}{'tcp'} = '4027'	; 
#	$srvcobjects_ref->{'bxp'}{'ports'}{'tcp'}{'4027'}++	; 
#	$ports_ref->{'tcp'}{'4027'}{'name'} = 'bxp'		; 
#	$srvcobjects_ref->{'pxc-spvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-spvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-spvr'}{'port'}{'udp'} = '4006'	; 
#	$srvcobjects_ref->{'pxc-spvr'}{'ports'}{'udp'}{'4006'}++	; 
#	$ports_ref->{'udp'}{'4006'}{'name'} = 'pxc-spvr'		; 
#	$srvcobjects_ref->{'pxc-spvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-spvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-spvr'}{'port'}{'tcp'} = '4006'	; 
#	$srvcobjects_ref->{'pxc-spvr'}{'ports'}{'tcp'}{'4006'}++	; 
#	$ports_ref->{'tcp'}{'4006'}{'name'} = 'pxc-spvr'		; 
#	$srvcobjects_ref->{'sun-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sun-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sun-lm'}{'port'}{'udp'} = '7588'	; 
#	$srvcobjects_ref->{'sun-lm'}{'ports'}{'udp'}{'7588'}++	; 
#	$ports_ref->{'udp'}{'7588'}{'name'} = 'sun-lm'		; 
#	$srvcobjects_ref->{'sun-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sun-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sun-lm'}{'port'}{'tcp'} = '7588'	; 
#	$srvcobjects_ref->{'sun-lm'}{'ports'}{'tcp'}{'7588'}++	; 
#	$ports_ref->{'tcp'}{'7588'}{'name'} = 'sun-lm'		; 
#	$srvcobjects_ref->{'devshr-nts'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'devshr-nts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'devshr-nts'}{'port'}{'udp'} = '552'	; 
#	$srvcobjects_ref->{'devshr-nts'}{'ports'}{'udp'}{'552'}++	; 
#	$ports_ref->{'udp'}{'552'}{'name'} = 'devshr-nts'		; 
#	$srvcobjects_ref->{'devshr-nts'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'devshr-nts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'devshr-nts'}{'port'}{'tcp'} = '552'	; 
#	$srvcobjects_ref->{'devshr-nts'}{'ports'}{'tcp'}{'552'}++	; 
#	$ports_ref->{'tcp'}{'552'}{'name'} = 'devshr-nts'		; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'port'}{'udp'} = '383'	; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'ports'}{'udp'}{'383'}++	; 
#	$ports_ref->{'udp'}{'383'}{'name'} = 'hp-alarm-mgr'		; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'port'}{'tcp'} = '383'	; 
#	$srvcobjects_ref->{'hp-alarm-mgr'}{'ports'}{'tcp'}{'383'}++	; 
#	$ports_ref->{'tcp'}{'383'}{'name'} = 'hp-alarm-mgr'		; 
#	$srvcobjects_ref->{'llm-pass'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'llm-pass'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llm-pass'}{'port'}{'udp'} = '2813'	; 
#	$srvcobjects_ref->{'llm-pass'}{'ports'}{'udp'}{'2813'}++	; 
#	$ports_ref->{'udp'}{'2813'}{'name'} = 'llm-pass'		; 
#	$srvcobjects_ref->{'llm-pass'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'llm-pass'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'llm-pass'}{'port'}{'tcp'} = '2813'	; 
#	$srvcobjects_ref->{'llm-pass'}{'ports'}{'tcp'}{'2813'}++	; 
#	$ports_ref->{'tcp'}{'2813'}{'name'} = 'llm-pass'		; 
#	$srvcobjects_ref->{'apcupsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apcupsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apcupsd'}{'port'}{'udp'} = '3551'	; 
#	$srvcobjects_ref->{'apcupsd'}{'ports'}{'udp'}{'3551'}++	; 
#	$ports_ref->{'udp'}{'3551'}{'name'} = 'apcupsd'		; 
#	$srvcobjects_ref->{'apcupsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apcupsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apcupsd'}{'port'}{'tcp'} = '3551'	; 
#	$srvcobjects_ref->{'apcupsd'}{'ports'}{'tcp'}{'3551'}++	; 
#	$ports_ref->{'tcp'}{'3551'}{'name'} = 'apcupsd'		; 
#	$srvcobjects_ref->{'nati-vi-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nati-vi-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-vi-server'}{'port'}{'udp'} = '3363'	; 
#	$srvcobjects_ref->{'nati-vi-server'}{'ports'}{'udp'}{'3363'}++	; 
#	$ports_ref->{'udp'}{'3363'}{'name'} = 'nati-vi-server'		; 
#	$srvcobjects_ref->{'nati-vi-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nati-vi-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-vi-server'}{'port'}{'tcp'} = '3363'	; 
#	$srvcobjects_ref->{'nati-vi-server'}{'ports'}{'tcp'}{'3363'}++	; 
#	$ports_ref->{'tcp'}{'3363'}{'name'} = 'nati-vi-server'		; 
#	$srvcobjects_ref->{'pcanywheredata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcanywheredata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcanywheredata'}{'port'}{'udp'} = '5631'	; 
#	$srvcobjects_ref->{'pcanywheredata'}{'ports'}{'udp'}{'5631'}++	; 
#	$ports_ref->{'udp'}{'5631'}{'name'} = 'pcanywheredata'		; 
#	$srvcobjects_ref->{'pcanywheredata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcanywheredata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcanywheredata'}{'port'}{'tcp'} = '5631'	; 
#	$srvcobjects_ref->{'pcanywheredata'}{'ports'}{'tcp'}{'5631'}++	; 
#	$ports_ref->{'tcp'}{'5631'}{'name'} = 'pcanywheredata'		; 
#	$srvcobjects_ref->{'vx-auth-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vx-auth-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vx-auth-port'}{'port'}{'udp'} = '3207'	; 
#	$srvcobjects_ref->{'vx-auth-port'}{'ports'}{'udp'}{'3207'}++	; 
#	$ports_ref->{'udp'}{'3207'}{'name'} = 'vx-auth-port'		; 
#	$srvcobjects_ref->{'vx-auth-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vx-auth-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vx-auth-port'}{'port'}{'tcp'} = '3207'	; 
#	$srvcobjects_ref->{'vx-auth-port'}{'ports'}{'tcp'}{'3207'}++	; 
#	$ports_ref->{'tcp'}{'3207'}{'name'} = 'vx-auth-port'		; 
#	$srvcobjects_ref->{'caller9'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'caller9'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caller9'}{'port'}{'udp'} = '2906'	; 
#	$srvcobjects_ref->{'caller9'}{'ports'}{'udp'}{'2906'}++	; 
#	$ports_ref->{'udp'}{'2906'}{'name'} = 'caller9'		; 
#	$srvcobjects_ref->{'caller9'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'caller9'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caller9'}{'port'}{'tcp'} = '2906'	; 
#	$srvcobjects_ref->{'caller9'}{'ports'}{'tcp'}{'2906'}++	; 
#	$ports_ref->{'tcp'}{'2906'}{'name'} = 'caller9'		; 
#	$srvcobjects_ref->{'artifact-msg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'artifact-msg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'artifact-msg'}{'port'}{'udp'} = '3518'	; 
#	$srvcobjects_ref->{'artifact-msg'}{'ports'}{'udp'}{'3518'}++	; 
#	$ports_ref->{'udp'}{'3518'}{'name'} = 'artifact-msg'		; 
#	$srvcobjects_ref->{'artifact-msg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'artifact-msg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'artifact-msg'}{'port'}{'tcp'} = '3518'	; 
#	$srvcobjects_ref->{'artifact-msg'}{'ports'}{'tcp'}{'3518'}++	; 
#	$ports_ref->{'tcp'}{'3518'}{'name'} = 'artifact-msg'		; 
#	$srvcobjects_ref->{'ptk-alink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ptk-alink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptk-alink'}{'port'}{'udp'} = '3089'	; 
#	$srvcobjects_ref->{'ptk-alink'}{'ports'}{'udp'}{'3089'}++	; 
#	$ports_ref->{'udp'}{'3089'}{'name'} = 'ptk-alink'		; 
#	$srvcobjects_ref->{'ptk-alink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ptk-alink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptk-alink'}{'port'}{'tcp'} = '3089'	; 
#	$srvcobjects_ref->{'ptk-alink'}{'ports'}{'tcp'}{'3089'}++	; 
#	$ports_ref->{'tcp'}{'3089'}{'name'} = 'ptk-alink'		; 
#	$srvcobjects_ref->{'irdmi2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'irdmi2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irdmi2'}{'port'}{'udp'} = '7999'	; 
#	$srvcobjects_ref->{'irdmi2'}{'ports'}{'udp'}{'7999'}++	; 
#	$ports_ref->{'udp'}{'7999'}{'name'} = 'irdmi2'		; 
#	$srvcobjects_ref->{'irdmi2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'irdmi2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irdmi2'}{'port'}{'tcp'} = '7999'	; 
#	$srvcobjects_ref->{'irdmi2'}{'ports'}{'tcp'}{'7999'}++	; 
#	$ports_ref->{'tcp'}{'7999'}{'name'} = 'irdmi2'		; 
#	$srvcobjects_ref->{'netchat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netchat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netchat'}{'port'}{'udp'} = '2451'	; 
#	$srvcobjects_ref->{'netchat'}{'ports'}{'udp'}{'2451'}++	; 
#	$ports_ref->{'udp'}{'2451'}{'name'} = 'netchat'		; 
#	$srvcobjects_ref->{'netchat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netchat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netchat'}{'port'}{'tcp'} = '2451'	; 
#	$srvcobjects_ref->{'netchat'}{'ports'}{'tcp'}{'2451'}++	; 
#	$ports_ref->{'tcp'}{'2451'}{'name'} = 'netchat'		; 
#	$srvcobjects_ref->{'procos-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'procos-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'procos-lm'}{'port'}{'udp'} = '3248'	; 
#	$srvcobjects_ref->{'procos-lm'}{'ports'}{'udp'}{'3248'}++	; 
#	$ports_ref->{'udp'}{'3248'}{'name'} = 'procos-lm'		; 
#	$srvcobjects_ref->{'procos-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'procos-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'procos-lm'}{'port'}{'tcp'} = '3248'	; 
#	$srvcobjects_ref->{'procos-lm'}{'ports'}{'tcp'}{'3248'}++	; 
#	$ports_ref->{'tcp'}{'3248'}{'name'} = 'procos-lm'		; 
#	$srvcobjects_ref->{'talon-engine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talon-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talon-engine'}{'port'}{'udp'} = '7012'	; 
#	$srvcobjects_ref->{'talon-engine'}{'ports'}{'udp'}{'7012'}++	; 
#	$ports_ref->{'udp'}{'7012'}{'name'} = 'talon-engine'		; 
#	$srvcobjects_ref->{'talon-engine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talon-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talon-engine'}{'port'}{'tcp'} = '7012'	; 
#	$srvcobjects_ref->{'talon-engine'}{'ports'}{'tcp'}{'7012'}++	; 
#	$ports_ref->{'tcp'}{'7012'}{'name'} = 'talon-engine'		; 
#	$srvcobjects_ref->{'ctiprogramload'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctiprogramload'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctiprogramload'}{'port'}{'udp'} = '4452'	; 
#	$srvcobjects_ref->{'ctiprogramload'}{'ports'}{'udp'}{'4452'}++	; 
#	$ports_ref->{'udp'}{'4452'}{'name'} = 'ctiprogramload'		; 
#	$srvcobjects_ref->{'ctiprogramload'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctiprogramload'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctiprogramload'}{'port'}{'tcp'} = '4452'	; 
#	$srvcobjects_ref->{'ctiprogramload'}{'ports'}{'tcp'}{'4452'}++	; 
#	$ports_ref->{'tcp'}{'4452'}{'name'} = 'ctiprogramload'		; 
#	$srvcobjects_ref->{'unot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unot'}{'port'}{'udp'} = '5055'	; 
#	$srvcobjects_ref->{'unot'}{'ports'}{'udp'}{'5055'}++	; 
#	$ports_ref->{'udp'}{'5055'}{'name'} = 'unot'		; 
#	$srvcobjects_ref->{'unot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unot'}{'port'}{'tcp'} = '5055'	; 
#	$srvcobjects_ref->{'unot'}{'ports'}{'tcp'}{'5055'}++	; 
#	$ports_ref->{'tcp'}{'5055'}{'name'} = 'unot'		; 
#	$srvcobjects_ref->{'centerline'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'centerline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'centerline'}{'port'}{'udp'} = '3987'	; 
#	$srvcobjects_ref->{'centerline'}{'ports'}{'udp'}{'3987'}++	; 
#	$ports_ref->{'udp'}{'3987'}{'name'} = 'centerline'		; 
#	$srvcobjects_ref->{'centerline'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'centerline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'centerline'}{'port'}{'tcp'} = '3987'	; 
#	$srvcobjects_ref->{'centerline'}{'ports'}{'tcp'}{'3987'}++	; 
#	$ports_ref->{'tcp'}{'3987'}{'name'} = 'centerline'		; 
#	$srvcobjects_ref->{'jerand-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jerand-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jerand-lm'}{'port'}{'udp'} = '1810'	; 
#	$srvcobjects_ref->{'jerand-lm'}{'ports'}{'udp'}{'1810'}++	; 
#	$ports_ref->{'udp'}{'1810'}{'name'} = 'jerand-lm'		; 
#	$srvcobjects_ref->{'jerand-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jerand-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jerand-lm'}{'port'}{'tcp'} = '1810'	; 
#	$srvcobjects_ref->{'jerand-lm'}{'ports'}{'tcp'}{'1810'}++	; 
#	$ports_ref->{'tcp'}{'1810'}{'name'} = 'jerand-lm'		; 
#	$srvcobjects_ref->{'decbsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'decbsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decbsrv'}{'port'}{'udp'} = '579'	; 
#	$srvcobjects_ref->{'decbsrv'}{'ports'}{'udp'}{'579'}++	; 
#	$ports_ref->{'udp'}{'579'}{'name'} = 'decbsrv'		; 
#	$srvcobjects_ref->{'decbsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'decbsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'decbsrv'}{'port'}{'tcp'} = '579'	; 
#	$srvcobjects_ref->{'decbsrv'}{'ports'}{'tcp'}{'579'}++	; 
#	$ports_ref->{'tcp'}{'579'}{'name'} = 'decbsrv'		; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'port'}{'udp'} = '4018'	; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'ports'}{'udp'}{'4018'}++	; 
#	$ports_ref->{'udp'}{'4018'}{'name'} = 'talarian-mcast4'		; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'port'}{'tcp'} = '4018'	; 
#	$srvcobjects_ref->{'talarian-mcast4'}{'ports'}{'tcp'}{'4018'}++	; 
#	$ports_ref->{'tcp'}{'4018'}{'name'} = 'talarian-mcast4'		; 
#	$srvcobjects_ref->{'utcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'utcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utcd'}{'port'}{'udp'} = '1506'	; 
#	$srvcobjects_ref->{'utcd'}{'ports'}{'udp'}{'1506'}++	; 
#	$ports_ref->{'udp'}{'1506'}{'name'} = 'utcd'		; 
#	$srvcobjects_ref->{'utcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'utcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utcd'}{'port'}{'tcp'} = '1506'	; 
#	$srvcobjects_ref->{'utcd'}{'ports'}{'tcp'}{'1506'}++	; 
#	$ports_ref->{'tcp'}{'1506'}{'name'} = 'utcd'		; 
#	$srvcobjects_ref->{'opcon-xps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opcon-xps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opcon-xps'}{'port'}{'udp'} = '3100'	; 
#	$srvcobjects_ref->{'opcon-xps'}{'ports'}{'udp'}{'3100'}++	; 
#	$ports_ref->{'udp'}{'3100'}{'name'} = 'opcon-xps'		; 
#	$srvcobjects_ref->{'opcon-xps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opcon-xps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opcon-xps'}{'port'}{'tcp'} = '3100'	; 
#	$srvcobjects_ref->{'opcon-xps'}{'ports'}{'tcp'}{'3100'}++	; 
#	$ports_ref->{'tcp'}{'3100'}{'name'} = 'opcon-xps'		; 
#	$srvcobjects_ref->{'tsdos390'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tsdos390'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsdos390'}{'port'}{'udp'} = '1237'	; 
#	$srvcobjects_ref->{'tsdos390'}{'ports'}{'udp'}{'1237'}++	; 
#	$ports_ref->{'udp'}{'1237'}{'name'} = 'tsdos390'		; 
#	$srvcobjects_ref->{'tsdos390'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tsdos390'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsdos390'}{'port'}{'tcp'} = '1237'	; 
#	$srvcobjects_ref->{'tsdos390'}{'ports'}{'tcp'}{'1237'}++	; 
#	$ports_ref->{'tcp'}{'1237'}{'name'} = 'tsdos390'		; 
#	$srvcobjects_ref->{'ora-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ora-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ora-lm'}{'port'}{'udp'} = '1446'	; 
#	$srvcobjects_ref->{'ora-lm'}{'ports'}{'udp'}{'1446'}++	; 
#	$ports_ref->{'udp'}{'1446'}{'name'} = 'ora-lm'		; 
#	$srvcobjects_ref->{'ora-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ora-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ora-lm'}{'port'}{'tcp'} = '1446'	; 
#	$srvcobjects_ref->{'ora-lm'}{'ports'}{'tcp'}{'1446'}++	; 
#	$ports_ref->{'tcp'}{'1446'}{'name'} = 'ora-lm'		; 
#	$srvcobjects_ref->{'ticf-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ticf-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ticf-2'}{'port'}{'udp'} = '493'	; 
#	$srvcobjects_ref->{'ticf-2'}{'ports'}{'udp'}{'493'}++	; 
#	$ports_ref->{'udp'}{'493'}{'name'} = 'ticf-2'		; 
#	$srvcobjects_ref->{'ticf-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ticf-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ticf-2'}{'port'}{'tcp'} = '493'	; 
#	$srvcobjects_ref->{'ticf-2'}{'ports'}{'tcp'}{'493'}++	; 
#	$ports_ref->{'tcp'}{'493'}{'name'} = 'ticf-2'		; 
#	$srvcobjects_ref->{'suucp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'suucp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'suucp'}{'port'}{'udp'} = '4031'	; 
#	$srvcobjects_ref->{'suucp'}{'ports'}{'udp'}{'4031'}++	; 
#	$ports_ref->{'udp'}{'4031'}{'name'} = 'suucp'		; 
#	$srvcobjects_ref->{'suucp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'suucp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'suucp'}{'port'}{'tcp'} = '4031'	; 
#	$srvcobjects_ref->{'suucp'}{'ports'}{'tcp'}{'4031'}++	; 
#	$ports_ref->{'tcp'}{'4031'}{'name'} = 'suucp'		; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'port'}{'udp'} = '3330'	; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'ports'}{'udp'}{'3330'}++	; 
#	$ports_ref->{'udp'}{'3330'}{'name'} = 'mcs-calypsoicf'		; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'port'}{'tcp'} = '3330'	; 
#	$srvcobjects_ref->{'mcs-calypsoicf'}{'ports'}{'tcp'}{'3330'}++	; 
#	$ports_ref->{'tcp'}{'3330'}{'name'} = 'mcs-calypsoicf'		; 
#	$srvcobjects_ref->{'di-traceware'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'di-traceware'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'di-traceware'}{'port'}{'udp'} = '3041'	; 
#	$srvcobjects_ref->{'di-traceware'}{'ports'}{'udp'}{'3041'}++	; 
#	$ports_ref->{'udp'}{'3041'}{'name'} = 'di-traceware'		; 
#	$srvcobjects_ref->{'di-traceware'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'di-traceware'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'di-traceware'}{'port'}{'tcp'} = '3041'	; 
#	$srvcobjects_ref->{'di-traceware'}{'ports'}{'tcp'}{'3041'}++	; 
#	$ports_ref->{'tcp'}{'3041'}{'name'} = 'di-traceware'		; 
#	$srvcobjects_ref->{'covia'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'covia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'covia'}{'port'}{'udp'} = '64'	; 
#	$srvcobjects_ref->{'covia'}{'ports'}{'udp'}{'64'}++	; 
#	$ports_ref->{'udp'}{'64'}{'name'} = 'covia'		; 
#	$srvcobjects_ref->{'covia'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'covia'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'covia'}{'port'}{'tcp'} = '64'	; 
#	$srvcobjects_ref->{'covia'}{'ports'}{'tcp'}{'64'}++	; 
#	$ports_ref->{'tcp'}{'64'}{'name'} = 'covia'		; 
#	$srvcobjects_ref->{'snare'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snare'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snare'}{'port'}{'udp'} = '509'	; 
#	$srvcobjects_ref->{'snare'}{'ports'}{'udp'}{'509'}++	; 
#	$ports_ref->{'udp'}{'509'}{'name'} = 'snare'		; 
#	$srvcobjects_ref->{'snare'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snare'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snare'}{'port'}{'tcp'} = '509'	; 
#	$srvcobjects_ref->{'snare'}{'ports'}{'tcp'}{'509'}++	; 
#	$ports_ref->{'tcp'}{'509'}{'name'} = 'snare'		; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'port'}{'udp'} = '9747'	; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'ports'}{'udp'}{'9747'}++	; 
#	$ports_ref->{'udp'}{'9747'}{'name'} = 'l5nas-parchan'		; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'port'}{'tcp'} = '9747'	; 
#	$srvcobjects_ref->{'l5nas-parchan'}{'ports'}{'tcp'}{'9747'}++	; 
#	$ports_ref->{'tcp'}{'9747'}{'name'} = 'l5nas-parchan'		; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'port'}{'udp'} = '6146'	; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'ports'}{'udp'}{'6146'}++	; 
#	$ports_ref->{'udp'}{'6146'}{'name'} = 'lonewolf-lm'		; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'port'}{'tcp'} = '6146'	; 
#	$srvcobjects_ref->{'lonewolf-lm'}{'ports'}{'tcp'}{'6146'}++	; 
#	$ports_ref->{'tcp'}{'6146'}{'name'} = 'lonewolf-lm'		; 
#	$srvcobjects_ref->{'jabber-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jabber-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jabber-server'}{'port'}{'udp'} = '5269'	; 
#	$srvcobjects_ref->{'jabber-server'}{'ports'}{'udp'}{'5269'}++	; 
#	$ports_ref->{'udp'}{'5269'}{'name'} = 'jabber-server'		; 
#	$srvcobjects_ref->{'jabber-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jabber-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jabber-server'}{'port'}{'tcp'} = '5269'	; 
#	$srvcobjects_ref->{'jabber-server'}{'ports'}{'tcp'}{'5269'}++	; 
#	$ports_ref->{'tcp'}{'5269'}{'name'} = 'jabber-server'		; 
#	$srvcobjects_ref->{'datacaptor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'datacaptor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datacaptor'}{'port'}{'udp'} = '1857'	; 
#	$srvcobjects_ref->{'datacaptor'}{'ports'}{'udp'}{'1857'}++	; 
#	$ports_ref->{'udp'}{'1857'}{'name'} = 'datacaptor'		; 
#	$srvcobjects_ref->{'datacaptor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'datacaptor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'datacaptor'}{'port'}{'tcp'} = '1857'	; 
#	$srvcobjects_ref->{'datacaptor'}{'ports'}{'tcp'}{'1857'}++	; 
#	$ports_ref->{'tcp'}{'1857'}{'name'} = 'datacaptor'		; 
#	$srvcobjects_ref->{'descent3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'descent3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'descent3'}{'port'}{'udp'} = '2092'	; 
#	$srvcobjects_ref->{'descent3'}{'ports'}{'udp'}{'2092'}++	; 
#	$ports_ref->{'udp'}{'2092'}{'name'} = 'descent3'		; 
#	$srvcobjects_ref->{'descent3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'descent3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'descent3'}{'port'}{'tcp'} = '2092'	; 
#	$srvcobjects_ref->{'descent3'}{'ports'}{'tcp'}{'2092'}++	; 
#	$ports_ref->{'tcp'}{'2092'}{'name'} = 'descent3'		; 
#	$srvcobjects_ref->{'precise-i3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'precise-i3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'precise-i3'}{'port'}{'udp'} = '3607'	; 
#	$srvcobjects_ref->{'precise-i3'}{'ports'}{'udp'}{'3607'}++	; 
#	$ports_ref->{'udp'}{'3607'}{'name'} = 'precise-i3'		; 
#	$srvcobjects_ref->{'precise-i3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'precise-i3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'precise-i3'}{'port'}{'tcp'} = '3607'	; 
#	$srvcobjects_ref->{'precise-i3'}{'ports'}{'tcp'}{'3607'}++	; 
#	$ports_ref->{'tcp'}{'3607'}{'name'} = 'precise-i3'		; 
#	$srvcobjects_ref->{'ardus-trns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ardus-trns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardus-trns'}{'port'}{'udp'} = '1115'	; 
#	$srvcobjects_ref->{'ardus-trns'}{'ports'}{'udp'}{'1115'}++	; 
#	$ports_ref->{'udp'}{'1115'}{'name'} = 'ardus-trns'		; 
#	$srvcobjects_ref->{'ardus-trns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ardus-trns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardus-trns'}{'port'}{'tcp'} = '1115'	; 
#	$srvcobjects_ref->{'ardus-trns'}{'ports'}{'tcp'}{'1115'}++	; 
#	$ports_ref->{'tcp'}{'1115'}{'name'} = 'ardus-trns'		; 
#	$srvcobjects_ref->{'smartcard-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smartcard-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smartcard-port'}{'port'}{'udp'} = '3516'	; 
#	$srvcobjects_ref->{'smartcard-port'}{'ports'}{'udp'}{'3516'}++	; 
#	$ports_ref->{'udp'}{'3516'}{'name'} = 'smartcard-port'		; 
#	$srvcobjects_ref->{'smartcard-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smartcard-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smartcard-port'}{'port'}{'tcp'} = '3516'	; 
#	$srvcobjects_ref->{'smartcard-port'}{'ports'}{'tcp'}{'3516'}++	; 
#	$ports_ref->{'tcp'}{'3516'}{'name'} = 'smartcard-port'		; 
#	$srvcobjects_ref->{'3com-webview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3com-webview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-webview'}{'port'}{'udp'} = '2339'	; 
#	$srvcobjects_ref->{'3com-webview'}{'ports'}{'udp'}{'2339'}++	; 
#	$ports_ref->{'udp'}{'2339'}{'name'} = '3com-webview'		; 
#	$srvcobjects_ref->{'3com-webview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3com-webview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-webview'}{'port'}{'tcp'} = '2339'	; 
#	$srvcobjects_ref->{'3com-webview'}{'ports'}{'tcp'}{'2339'}++	; 
#	$ports_ref->{'tcp'}{'2339'}{'name'} = '3com-webview'		; 
#	$srvcobjects_ref->{'jibe-eb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jibe-eb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jibe-eb'}{'port'}{'udp'} = '3777'	; 
#	$srvcobjects_ref->{'jibe-eb'}{'ports'}{'udp'}{'3777'}++	; 
#	$ports_ref->{'udp'}{'3777'}{'name'} = 'jibe-eb'		; 
#	$srvcobjects_ref->{'jibe-eb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jibe-eb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jibe-eb'}{'port'}{'tcp'} = '3777'	; 
#	$srvcobjects_ref->{'jibe-eb'}{'ports'}{'tcp'}{'3777'}++	; 
#	$ports_ref->{'tcp'}{'3777'}{'name'} = 'jibe-eb'		; 
#	$srvcobjects_ref->{'pconnectmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pconnectmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pconnectmgr'}{'port'}{'udp'} = '1562'	; 
#	$srvcobjects_ref->{'pconnectmgr'}{'ports'}{'udp'}{'1562'}++	; 
#	$ports_ref->{'udp'}{'1562'}{'name'} = 'pconnectmgr'		; 
#	$srvcobjects_ref->{'pconnectmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pconnectmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pconnectmgr'}{'port'}{'tcp'} = '1562'	; 
#	$srvcobjects_ref->{'pconnectmgr'}{'ports'}{'tcp'}{'1562'}++	; 
#	$ports_ref->{'tcp'}{'1562'}{'name'} = 'pconnectmgr'		; 
#	$srvcobjects_ref->{'sentinel-ent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sentinel-ent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentinel-ent'}{'port'}{'udp'} = '3712'	; 
#	$srvcobjects_ref->{'sentinel-ent'}{'ports'}{'udp'}{'3712'}++	; 
#	$ports_ref->{'udp'}{'3712'}{'name'} = 'sentinel-ent'		; 
#	$srvcobjects_ref->{'sentinel-ent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sentinel-ent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentinel-ent'}{'port'}{'tcp'} = '3712'	; 
#	$srvcobjects_ref->{'sentinel-ent'}{'ports'}{'tcp'}{'3712'}++	; 
#	$ports_ref->{'tcp'}{'3712'}{'name'} = 'sentinel-ent'		; 
#	$srvcobjects_ref->{'hdl-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hdl-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hdl-srv'}{'port'}{'udp'} = '2641'	; 
#	$srvcobjects_ref->{'hdl-srv'}{'ports'}{'udp'}{'2641'}++	; 
#	$ports_ref->{'udp'}{'2641'}{'name'} = 'hdl-srv'		; 
#	$srvcobjects_ref->{'hdl-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hdl-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hdl-srv'}{'port'}{'tcp'} = '2641'	; 
#	$srvcobjects_ref->{'hdl-srv'}{'ports'}{'tcp'}{'2641'}++	; 
#	$ports_ref->{'tcp'}{'2641'}{'name'} = 'hdl-srv'		; 
#	$srvcobjects_ref->{'exbit-escp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'exbit-escp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exbit-escp'}{'port'}{'udp'} = '1316'	; 
#	$srvcobjects_ref->{'exbit-escp'}{'ports'}{'udp'}{'1316'}++	; 
#	$ports_ref->{'udp'}{'1316'}{'name'} = 'exbit-escp'		; 
#	$srvcobjects_ref->{'exbit-escp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'exbit-escp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exbit-escp'}{'port'}{'tcp'} = '1316'	; 
#	$srvcobjects_ref->{'exbit-escp'}{'ports'}{'tcp'}{'1316'}++	; 
#	$ports_ref->{'tcp'}{'1316'}{'name'} = 'exbit-escp'		; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'port'}{'udp'} = '1452'	; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'ports'}{'udp'}{'1452'}++	; 
#	$ports_ref->{'udp'}{'1452'}{'name'} = 'gtegsc-lm'		; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'port'}{'tcp'} = '1452'	; 
#	$srvcobjects_ref->{'gtegsc-lm'}{'ports'}{'tcp'}{'1452'}++	; 
#	$ports_ref->{'tcp'}{'1452'}{'name'} = 'gtegsc-lm'		; 
#	$srvcobjects_ref->{'unieng'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unieng'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unieng'}{'port'}{'udp'} = '5730'	; 
#	$srvcobjects_ref->{'unieng'}{'ports'}{'udp'}{'5730'}++	; 
#	$ports_ref->{'udp'}{'5730'}{'name'} = 'unieng'		; 
#	$srvcobjects_ref->{'unieng'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unieng'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unieng'}{'port'}{'tcp'} = '5730'	; 
#	$srvcobjects_ref->{'unieng'}{'ports'}{'tcp'}{'5730'}++	; 
#	$ports_ref->{'tcp'}{'5730'}{'name'} = 'unieng'		; 
#	$srvcobjects_ref->{'mpnjsomg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpnjsomg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsomg'}{'port'}{'udp'} = '2686'	; 
#	$srvcobjects_ref->{'mpnjsomg'}{'ports'}{'udp'}{'2686'}++	; 
#	$ports_ref->{'udp'}{'2686'}{'name'} = 'mpnjsomg'		; 
#	$srvcobjects_ref->{'mpnjsomg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpnjsomg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsomg'}{'port'}{'tcp'} = '2686'	; 
#	$srvcobjects_ref->{'mpnjsomg'}{'ports'}{'tcp'}{'2686'}++	; 
#	$ports_ref->{'tcp'}{'2686'}{'name'} = 'mpnjsomg'		; 
#	$srvcobjects_ref->{'erpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'erpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'erpc'}{'port'}{'udp'} = '121'	; 
#	$srvcobjects_ref->{'erpc'}{'ports'}{'udp'}{'121'}++	; 
#	$ports_ref->{'udp'}{'121'}{'name'} = 'erpc'		; 
#	$srvcobjects_ref->{'erpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'erpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'erpc'}{'port'}{'tcp'} = '121'	; 
#	$srvcobjects_ref->{'erpc'}{'ports'}{'tcp'}{'121'}++	; 
#	$ports_ref->{'tcp'}{'121'}{'name'} = 'erpc'		; 
#	$srvcobjects_ref->{'gnunet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gnunet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gnunet'}{'port'}{'udp'} = '2086'	; 
#	$srvcobjects_ref->{'gnunet'}{'ports'}{'udp'}{'2086'}++	; 
#	$ports_ref->{'udp'}{'2086'}{'name'} = 'gnunet'		; 
#	$srvcobjects_ref->{'gnunet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gnunet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gnunet'}{'port'}{'tcp'} = '2086'	; 
#	$srvcobjects_ref->{'gnunet'}{'ports'}{'tcp'}{'2086'}++	; 
#	$ports_ref->{'tcp'}{'2086'}{'name'} = 'gnunet'		; 
#	$srvcobjects_ref->{'ezrelay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ezrelay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezrelay'}{'port'}{'udp'} = '10103'	; 
#	$srvcobjects_ref->{'ezrelay'}{'ports'}{'udp'}{'10103'}++	; 
#	$ports_ref->{'udp'}{'10103'}{'name'} = 'ezrelay'		; 
#	$srvcobjects_ref->{'ezrelay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ezrelay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezrelay'}{'port'}{'tcp'} = '10103'	; 
#	$srvcobjects_ref->{'ezrelay'}{'ports'}{'tcp'}{'10103'}++	; 
#	$ports_ref->{'tcp'}{'10103'}{'name'} = 'ezrelay'		; 
#	$srvcobjects_ref->{'infoseek'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infoseek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infoseek'}{'port'}{'udp'} = '414'	; 
#	$srvcobjects_ref->{'infoseek'}{'ports'}{'udp'}{'414'}++	; 
#	$ports_ref->{'udp'}{'414'}{'name'} = 'infoseek'		; 
#	$srvcobjects_ref->{'infoseek'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infoseek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infoseek'}{'port'}{'tcp'} = '414'	; 
#	$srvcobjects_ref->{'infoseek'}{'ports'}{'tcp'}{'414'}++	; 
#	$ports_ref->{'tcp'}{'414'}{'name'} = 'infoseek'		; 
#	$srvcobjects_ref->{'intersan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intersan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intersan'}{'port'}{'udp'} = '1331'	; 
#	$srvcobjects_ref->{'intersan'}{'ports'}{'udp'}{'1331'}++	; 
#	$ports_ref->{'udp'}{'1331'}{'name'} = 'intersan'		; 
#	$srvcobjects_ref->{'intersan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intersan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intersan'}{'port'}{'tcp'} = '1331'	; 
#	$srvcobjects_ref->{'intersan'}{'ports'}{'tcp'}{'1331'}++	; 
#	$ports_ref->{'tcp'}{'1331'}{'name'} = 'intersan'		; 
#	$srvcobjects_ref->{'versatalk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'versatalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'versatalk'}{'port'}{'udp'} = '3738'	; 
#	$srvcobjects_ref->{'versatalk'}{'ports'}{'udp'}{'3738'}++	; 
#	$ports_ref->{'udp'}{'3738'}{'name'} = 'versatalk'		; 
#	$srvcobjects_ref->{'versatalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'versatalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'versatalk'}{'port'}{'tcp'} = '3738'	; 
#	$srvcobjects_ref->{'versatalk'}{'ports'}{'tcp'}{'3738'}++	; 
#	$ports_ref->{'tcp'}{'3738'}{'name'} = 'versatalk'		; 
#	$srvcobjects_ref->{'micom-pfs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'micom-pfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micom-pfs'}{'port'}{'udp'} = '490'	; 
#	$srvcobjects_ref->{'micom-pfs'}{'ports'}{'udp'}{'490'}++	; 
#	$ports_ref->{'udp'}{'490'}{'name'} = 'micom-pfs'		; 
#	$srvcobjects_ref->{'micom-pfs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'micom-pfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micom-pfs'}{'port'}{'tcp'} = '490'	; 
#	$srvcobjects_ref->{'micom-pfs'}{'ports'}{'tcp'}{'490'}++	; 
#	$ports_ref->{'tcp'}{'490'}{'name'} = 'micom-pfs'		; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'port'}{'udp'} = '620'	; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'ports'}{'udp'}{'620'}++	; 
#	$ports_ref->{'udp'}{'620'}{'name'} = 'sco-websrvrmgr'		; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'port'}{'tcp'} = '620'	; 
#	$srvcobjects_ref->{'sco-websrvrmgr'}{'ports'}{'tcp'}{'620'}++	; 
#	$ports_ref->{'tcp'}{'620'}{'name'} = 'sco-websrvrmgr'		; 
#	$srvcobjects_ref->{'gsmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gsmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsmp'}{'port'}{'udp'} = '6068'	; 
#	$srvcobjects_ref->{'gsmp'}{'ports'}{'udp'}{'6068'}++	; 
#	$ports_ref->{'udp'}{'6068'}{'name'} = 'gsmp'		; 
#	$srvcobjects_ref->{'gsmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gsmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsmp'}{'port'}{'tcp'} = '6068'	; 
#	$srvcobjects_ref->{'gsmp'}{'ports'}{'tcp'}{'6068'}++	; 
#	$ports_ref->{'tcp'}{'6068'}{'name'} = 'gsmp'		; 
#	$srvcobjects_ref->{'lupa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lupa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lupa'}{'port'}{'udp'} = '1212'	; 
#	$srvcobjects_ref->{'lupa'}{'ports'}{'udp'}{'1212'}++	; 
#	$ports_ref->{'udp'}{'1212'}{'name'} = 'lupa'		; 
#	$srvcobjects_ref->{'lupa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lupa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lupa'}{'port'}{'tcp'} = '1212'	; 
#	$srvcobjects_ref->{'lupa'}{'ports'}{'tcp'}{'1212'}++	; 
#	$ports_ref->{'tcp'}{'1212'}{'name'} = 'lupa'		; 
#	$srvcobjects_ref->{'taurus-wh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'taurus-wh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taurus-wh'}{'port'}{'udp'} = '1610'	; 
#	$srvcobjects_ref->{'taurus-wh'}{'ports'}{'udp'}{'1610'}++	; 
#	$ports_ref->{'udp'}{'1610'}{'name'} = 'taurus-wh'		; 
#	$srvcobjects_ref->{'taurus-wh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'taurus-wh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taurus-wh'}{'port'}{'tcp'} = '1610'	; 
#	$srvcobjects_ref->{'taurus-wh'}{'ports'}{'tcp'}{'1610'}++	; 
#	$ports_ref->{'tcp'}{'1610'}{'name'} = 'taurus-wh'		; 
#	$srvcobjects_ref->{'quake'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'quake'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quake'}{'port'}{'udp'} = '26000'	; 
#	$srvcobjects_ref->{'quake'}{'ports'}{'udp'}{'26000'}++	; 
#	$ports_ref->{'udp'}{'26000'}{'name'} = 'quake'		; 
#	$srvcobjects_ref->{'quake'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'quake'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'quake'}{'port'}{'tcp'} = '26000'	; 
#	$srvcobjects_ref->{'quake'}{'ports'}{'tcp'}{'26000'}++	; 
#	$ports_ref->{'tcp'}{'26000'}{'name'} = 'quake'		; 
#	$srvcobjects_ref->{'netspeak-cs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netspeak-cs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-cs'}{'port'}{'udp'} = '21847'	; 
#	$srvcobjects_ref->{'netspeak-cs'}{'ports'}{'udp'}{'21847'}++	; 
#	$ports_ref->{'udp'}{'21847'}{'name'} = 'netspeak-cs'		; 
#	$srvcobjects_ref->{'netspeak-cs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netspeak-cs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-cs'}{'port'}{'tcp'} = '21847'	; 
#	$srvcobjects_ref->{'netspeak-cs'}{'ports'}{'tcp'}{'21847'}++	; 
#	$ports_ref->{'tcp'}{'21847'}{'name'} = 'netspeak-cs'		; 
#	$srvcobjects_ref->{'boomerang'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boomerang'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boomerang'}{'port'}{'udp'} = '1304'	; 
#	$srvcobjects_ref->{'boomerang'}{'ports'}{'udp'}{'1304'}++	; 
#	$ports_ref->{'udp'}{'1304'}{'name'} = 'boomerang'		; 
#	$srvcobjects_ref->{'boomerang'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boomerang'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boomerang'}{'port'}{'tcp'} = '1304'	; 
#	$srvcobjects_ref->{'boomerang'}{'ports'}{'tcp'}{'1304'}++	; 
#	$ports_ref->{'tcp'}{'1304'}{'name'} = 'boomerang'		; 
#	$srvcobjects_ref->{'sg-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sg-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sg-lm'}{'port'}{'udp'} = '1659'	; 
#	$srvcobjects_ref->{'sg-lm'}{'ports'}{'udp'}{'1659'}++	; 
#	$ports_ref->{'udp'}{'1659'}{'name'} = 'sg-lm'		; 
#	$srvcobjects_ref->{'sg-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sg-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sg-lm'}{'port'}{'tcp'} = '1659'	; 
#	$srvcobjects_ref->{'sg-lm'}{'ports'}{'tcp'}{'1659'}++	; 
#	$ports_ref->{'tcp'}{'1659'}{'name'} = 'sg-lm'		; 
#	$srvcobjects_ref->{'uucp-path'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uucp-path'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uucp-path'}{'port'}{'udp'} = '117'	; 
#	$srvcobjects_ref->{'uucp-path'}{'ports'}{'udp'}{'117'}++	; 
#	$ports_ref->{'udp'}{'117'}{'name'} = 'uucp-path'		; 
#	$srvcobjects_ref->{'uucp-path'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uucp-path'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uucp-path'}{'port'}{'tcp'} = '117'	; 
#	$srvcobjects_ref->{'uucp-path'}{'ports'}{'tcp'}{'117'}++	; 
#	$ports_ref->{'tcp'}{'117'}{'name'} = 'uucp-path'		; 
#	$srvcobjects_ref->{'qsnet-assist'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qsnet-assist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-assist'}{'port'}{'udp'} = '4356'	; 
#	$srvcobjects_ref->{'qsnet-assist'}{'ports'}{'udp'}{'4356'}++	; 
#	$ports_ref->{'udp'}{'4356'}{'name'} = 'qsnet-assist'		; 
#	$srvcobjects_ref->{'qsnet-assist'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qsnet-assist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-assist'}{'port'}{'tcp'} = '4356'	; 
#	$srvcobjects_ref->{'qsnet-assist'}{'ports'}{'tcp'}{'4356'}++	; 
#	$ports_ref->{'tcp'}{'4356'}{'name'} = 'qsnet-assist'		; 
#	$srvcobjects_ref->{'pdb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdb'}{'port'}{'udp'} = '3033'	; 
#	$srvcobjects_ref->{'pdb'}{'ports'}{'udp'}{'3033'}++	; 
#	$ports_ref->{'udp'}{'3033'}{'name'} = 'pdb'		; 
#	$srvcobjects_ref->{'pdb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdb'}{'port'}{'tcp'} = '3033'	; 
#	$srvcobjects_ref->{'pdb'}{'ports'}{'tcp'}{'3033'}++	; 
#	$ports_ref->{'tcp'}{'3033'}{'name'} = 'pdb'		; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'port'}{'udp'} = '1655'	; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'ports'}{'udp'}{'1655'}++	; 
#	$ports_ref->{'udp'}{'1655'}{'name'} = 'dec-mbadmin'		; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'port'}{'tcp'} = '1655'	; 
#	$srvcobjects_ref->{'dec-mbadmin'}{'ports'}{'tcp'}{'1655'}++	; 
#	$ports_ref->{'tcp'}{'1655'}{'name'} = 'dec-mbadmin'		; 
#	$srvcobjects_ref->{'xinupageserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xinupageserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinupageserver'}{'port'}{'udp'} = '2020'	; 
#	$srvcobjects_ref->{'xinupageserver'}{'ports'}{'udp'}{'2020'}++	; 
#	$ports_ref->{'udp'}{'2020'}{'name'} = 'xinupageserver'		; 
#	$srvcobjects_ref->{'xinupageserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xinupageserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinupageserver'}{'port'}{'tcp'} = '2020'	; 
#	$srvcobjects_ref->{'xinupageserver'}{'ports'}{'tcp'}{'2020'}++	; 
#	$ports_ref->{'tcp'}{'2020'}{'name'} = 'xinupageserver'		; 
#	$srvcobjects_ref->{'data-insurance'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'data-insurance'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'data-insurance'}{'port'}{'udp'} = '2764'	; 
#	$srvcobjects_ref->{'data-insurance'}{'ports'}{'udp'}{'2764'}++	; 
#	$ports_ref->{'udp'}{'2764'}{'name'} = 'data-insurance'		; 
#	$srvcobjects_ref->{'data-insurance'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'data-insurance'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'data-insurance'}{'port'}{'tcp'} = '2764'	; 
#	$srvcobjects_ref->{'data-insurance'}{'ports'}{'tcp'}{'2764'}++	; 
#	$ports_ref->{'tcp'}{'2764'}{'name'} = 'data-insurance'		; 
#	$srvcobjects_ref->{'synotics-broker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synotics-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synotics-broker'}{'port'}{'udp'} = '392'	; 
#	$srvcobjects_ref->{'synotics-broker'}{'ports'}{'udp'}{'392'}++	; 
#	$ports_ref->{'udp'}{'392'}{'name'} = 'synotics-broker'		; 
#	$srvcobjects_ref->{'synotics-broker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synotics-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synotics-broker'}{'port'}{'tcp'} = '392'	; 
#	$srvcobjects_ref->{'synotics-broker'}{'ports'}{'tcp'}{'392'}++	; 
#	$ports_ref->{'tcp'}{'392'}{'name'} = 'synotics-broker'		; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'port'}{'udp'} = '664'	; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'ports'}{'udp'}{'664'}++	; 
#	$ports_ref->{'udp'}{'664'}{'name'} = 'asf-secure-rmcp'		; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'port'}{'tcp'} = '664'	; 
#	$srvcobjects_ref->{'asf-secure-rmcp'}{'ports'}{'tcp'}{'664'}++	; 
#	$ports_ref->{'tcp'}{'664'}{'name'} = 'asf-secure-rmcp'		; 
#	$srvcobjects_ref->{'rkb-oscs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rkb-oscs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rkb-oscs'}{'port'}{'udp'} = '1817'	; 
#	$srvcobjects_ref->{'rkb-oscs'}{'ports'}{'udp'}{'1817'}++	; 
#	$ports_ref->{'udp'}{'1817'}{'name'} = 'rkb-oscs'		; 
#	$srvcobjects_ref->{'rkb-oscs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rkb-oscs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rkb-oscs'}{'port'}{'tcp'} = '1817'	; 
#	$srvcobjects_ref->{'rkb-oscs'}{'ports'}{'tcp'}{'1817'}++	; 
#	$ports_ref->{'tcp'}{'1817'}{'name'} = 'rkb-oscs'		; 
#	$srvcobjects_ref->{'m2pa'}{'type'} = 'sctp'	; 
#	$srvcobjects_ref->{'m2pa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m2pa'}{'port'}{'sctp'} = '3565'	; 
#	$srvcobjects_ref->{'m2pa'}{'ports'}{'sctp'}{'3565'}++	; 
#	$ports_ref->{'sctp'}{'3565'}{'name'} = 'm2pa'		; 
#	$srvcobjects_ref->{'m2pa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'m2pa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m2pa'}{'port'}{'tcp'} = '3565'	; 
#	$srvcobjects_ref->{'m2pa'}{'ports'}{'tcp'}{'3565'}++	; 
#	$ports_ref->{'tcp'}{'3565'}{'name'} = 'm2pa'		; 
#	$srvcobjects_ref->{'asoki-sma'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asoki-sma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asoki-sma'}{'port'}{'udp'} = '3087'	; 
#	$srvcobjects_ref->{'asoki-sma'}{'ports'}{'udp'}{'3087'}++	; 
#	$ports_ref->{'udp'}{'3087'}{'name'} = 'asoki-sma'		; 
#	$srvcobjects_ref->{'asoki-sma'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asoki-sma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asoki-sma'}{'port'}{'tcp'} = '3087'	; 
#	$srvcobjects_ref->{'asoki-sma'}{'ports'}{'tcp'}{'3087'}++	; 
#	$ports_ref->{'tcp'}{'3087'}{'name'} = 'asoki-sma'		; 
#	$srvcobjects_ref->{'wbem-https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wbem-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wbem-https'}{'port'}{'udp'} = '5989'	; 
#	$srvcobjects_ref->{'wbem-https'}{'ports'}{'udp'}{'5989'}++	; 
#	$ports_ref->{'udp'}{'5989'}{'name'} = 'wbem-https'		; 
#	$srvcobjects_ref->{'wbem-https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wbem-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wbem-https'}{'port'}{'tcp'} = '5989'	; 
#	$srvcobjects_ref->{'wbem-https'}{'ports'}{'tcp'}{'5989'}++	; 
#	$ports_ref->{'tcp'}{'5989'}{'name'} = 'wbem-https'		; 
#	$srvcobjects_ref->{'wacp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wacp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wacp'}{'port'}{'udp'} = '3633'	; 
#	$srvcobjects_ref->{'wacp'}{'ports'}{'udp'}{'3633'}++	; 
#	$ports_ref->{'udp'}{'3633'}{'name'} = 'wacp'		; 
#	$srvcobjects_ref->{'wacp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wacp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wacp'}{'port'}{'tcp'} = '3633'	; 
#	$srvcobjects_ref->{'wacp'}{'ports'}{'tcp'}{'3633'}++	; 
#	$ports_ref->{'tcp'}{'3633'}{'name'} = 'wacp'		; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'port'}{'udp'} = '14936'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'ports'}{'udp'}{'14936'}++	; 
#	$ports_ref->{'udp'}{'14936'}{'name'} = 'hde-lcesrvr-1'		; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'port'}{'tcp'} = '14936'	; 
#	$srvcobjects_ref->{'hde-lcesrvr-1'}{'ports'}{'tcp'}{'14936'}++	; 
#	$ports_ref->{'tcp'}{'14936'}{'name'} = 'hde-lcesrvr-1'		; 
#	$srvcobjects_ref->{'dls-monitor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dls-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls-monitor'}{'port'}{'udp'} = '2048'	; 
#	$srvcobjects_ref->{'dls-monitor'}{'ports'}{'udp'}{'2048'}++	; 
#	$ports_ref->{'udp'}{'2048'}{'name'} = 'dls-monitor'		; 
#	$srvcobjects_ref->{'dls-monitor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dls-monitor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls-monitor'}{'port'}{'tcp'} = '2048'	; 
#	$srvcobjects_ref->{'dls-monitor'}{'ports'}{'tcp'}{'2048'}++	; 
#	$ports_ref->{'tcp'}{'2048'}{'name'} = 'dls-monitor'		; 
#	$srvcobjects_ref->{'dlip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dlip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlip'}{'port'}{'udp'} = '7201'	; 
#	$srvcobjects_ref->{'dlip'}{'ports'}{'udp'}{'7201'}++	; 
#	$ports_ref->{'udp'}{'7201'}{'name'} = 'dlip'		; 
#	$srvcobjects_ref->{'dlip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dlip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlip'}{'port'}{'tcp'} = '7201'	; 
#	$srvcobjects_ref->{'dlip'}{'ports'}{'tcp'}{'7201'}++	; 
#	$ports_ref->{'tcp'}{'7201'}{'name'} = 'dlip'		; 
#	$srvcobjects_ref->{'wimsic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wimsic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wimsic'}{'port'}{'udp'} = '1326'	; 
#	$srvcobjects_ref->{'wimsic'}{'ports'}{'udp'}{'1326'}++	; 
#	$ports_ref->{'udp'}{'1326'}{'name'} = 'wimsic'		; 
#	$srvcobjects_ref->{'wimsic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wimsic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wimsic'}{'port'}{'tcp'} = '1326'	; 
#	$srvcobjects_ref->{'wimsic'}{'ports'}{'tcp'}{'1326'}++	; 
#	$ports_ref->{'tcp'}{'1326'}{'name'} = 'wimsic'		; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'port'}{'udp'} = '3267'	; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'ports'}{'udp'}{'3267'}++	; 
#	$ports_ref->{'udp'}{'3267'}{'name'} = 'ibm-dial-out'		; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'port'}{'tcp'} = '3267'	; 
#	$srvcobjects_ref->{'ibm-dial-out'}{'ports'}{'tcp'}{'3267'}++	; 
#	$ports_ref->{'tcp'}{'3267'}{'name'} = 'ibm-dial-out'		; 
#	$srvcobjects_ref->{'avinstalldisc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avinstalldisc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avinstalldisc'}{'port'}{'udp'} = '3502'	; 
#	$srvcobjects_ref->{'avinstalldisc'}{'ports'}{'udp'}{'3502'}++	; 
#	$ports_ref->{'udp'}{'3502'}{'name'} = 'avinstalldisc'		; 
#	$srvcobjects_ref->{'avinstalldisc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avinstalldisc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avinstalldisc'}{'port'}{'tcp'} = '3502'	; 
#	$srvcobjects_ref->{'avinstalldisc'}{'ports'}{'tcp'}{'3502'}++	; 
#	$ports_ref->{'tcp'}{'3502'}{'name'} = 'avinstalldisc'		; 
#	$srvcobjects_ref->{'vsnm-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsnm-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsnm-agent'}{'port'}{'udp'} = '3375'	; 
#	$srvcobjects_ref->{'vsnm-agent'}{'ports'}{'udp'}{'3375'}++	; 
#	$ports_ref->{'udp'}{'3375'}{'name'} = 'vsnm-agent'		; 
#	$srvcobjects_ref->{'vsnm-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsnm-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsnm-agent'}{'port'}{'tcp'} = '3375'	; 
#	$srvcobjects_ref->{'vsnm-agent'}{'ports'}{'tcp'}{'3375'}++	; 
#	$ports_ref->{'tcp'}{'3375'}{'name'} = 'vsnm-agent'		; 
#	$srvcobjects_ref->{'keysrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'keysrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'keysrvr'}{'port'}{'udp'} = '19283'	; 
#	$srvcobjects_ref->{'keysrvr'}{'ports'}{'udp'}{'19283'}++	; 
#	$ports_ref->{'udp'}{'19283'}{'name'} = 'keysrvr'		; 
#	$srvcobjects_ref->{'keysrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'keysrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'keysrvr'}{'port'}{'tcp'} = '19283'	; 
#	$srvcobjects_ref->{'keysrvr'}{'ports'}{'tcp'}{'19283'}++	; 
#	$ports_ref->{'tcp'}{'19283'}{'name'} = 'keysrvr'		; 
#	$srvcobjects_ref->{'imqbrokerd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imqbrokerd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imqbrokerd'}{'port'}{'udp'} = '7676'	; 
#	$srvcobjects_ref->{'imqbrokerd'}{'ports'}{'udp'}{'7676'}++	; 
#	$ports_ref->{'udp'}{'7676'}{'name'} = 'imqbrokerd'		; 
#	$srvcobjects_ref->{'imqbrokerd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imqbrokerd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imqbrokerd'}{'port'}{'tcp'} = '7676'	; 
#	$srvcobjects_ref->{'imqbrokerd'}{'ports'}{'tcp'}{'7676'}++	; 
#	$ports_ref->{'tcp'}{'7676'}{'name'} = 'imqbrokerd'		; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'port'}{'udp'} = '9600'	; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'ports'}{'udp'}{'9600'}++	; 
#	$ports_ref->{'udp'}{'9600'}{'name'} = 'micromuse-ncpw'		; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'port'}{'tcp'} = '9600'	; 
#	$srvcobjects_ref->{'micromuse-ncpw'}{'ports'}{'tcp'}{'9600'}++	; 
#	$ports_ref->{'tcp'}{'9600'}{'name'} = 'micromuse-ncpw'		; 
#	$srvcobjects_ref->{'njfss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'njfss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'njfss'}{'port'}{'udp'} = '3092'	; 
#	$srvcobjects_ref->{'njfss'}{'ports'}{'udp'}{'3092'}++	; 
#	$ports_ref->{'udp'}{'3092'}{'name'} = 'njfss'		; 
#	$srvcobjects_ref->{'njfss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'njfss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'njfss'}{'port'}{'tcp'} = '3092'	; 
#	$srvcobjects_ref->{'njfss'}{'ports'}{'tcp'}{'3092'}++	; 
#	$ports_ref->{'tcp'}{'3092'}{'name'} = 'njfss'		; 
#	$srvcobjects_ref->{'jini-discovery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jini-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jini-discovery'}{'port'}{'udp'} = '4160'	; 
#	$srvcobjects_ref->{'jini-discovery'}{'ports'}{'udp'}{'4160'}++	; 
#	$ports_ref->{'udp'}{'4160'}{'name'} = 'jini-discovery'		; 
#	$srvcobjects_ref->{'jini-discovery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jini-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jini-discovery'}{'port'}{'tcp'} = '4160'	; 
#	$srvcobjects_ref->{'jini-discovery'}{'ports'}{'tcp'}{'4160'}++	; 
#	$ports_ref->{'tcp'}{'4160'}{'name'} = 'jini-discovery'		; 
#	$srvcobjects_ref->{'rapidmq-center'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rapidmq-center'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapidmq-center'}{'port'}{'udp'} = '3093'	; 
#	$srvcobjects_ref->{'rapidmq-center'}{'ports'}{'udp'}{'3093'}++	; 
#	$ports_ref->{'udp'}{'3093'}{'name'} = 'rapidmq-center'		; 
#	$srvcobjects_ref->{'rapidmq-center'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rapidmq-center'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rapidmq-center'}{'port'}{'tcp'} = '3093'	; 
#	$srvcobjects_ref->{'rapidmq-center'}{'ports'}{'tcp'}{'3093'}++	; 
#	$ports_ref->{'tcp'}{'3093'}{'name'} = 'rapidmq-center'		; 
#	$srvcobjects_ref->{'dsc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsc'}{'port'}{'udp'} = '3390'	; 
#	$srvcobjects_ref->{'dsc'}{'ports'}{'udp'}{'3390'}++	; 
#	$ports_ref->{'udp'}{'3390'}{'name'} = 'dsc'		; 
#	$srvcobjects_ref->{'dsc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsc'}{'port'}{'tcp'} = '3390'	; 
#	$srvcobjects_ref->{'dsc'}{'ports'}{'tcp'}{'3390'}++	; 
#	$ports_ref->{'tcp'}{'3390'}{'name'} = 'dsc'		; 
#	$srvcobjects_ref->{'uohost'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uohost'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uohost'}{'port'}{'udp'} = '3314'	; 
#	$srvcobjects_ref->{'uohost'}{'ports'}{'udp'}{'3314'}++	; 
#	$ports_ref->{'udp'}{'3314'}{'name'} = 'uohost'		; 
#	$srvcobjects_ref->{'uohost'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uohost'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uohost'}{'port'}{'tcp'} = '3314'	; 
#	$srvcobjects_ref->{'uohost'}{'ports'}{'tcp'}{'3314'}++	; 
#	$ports_ref->{'tcp'}{'3314'}{'name'} = 'uohost'		; 
#	$srvcobjects_ref->{'di-ase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'di-ase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'di-ase'}{'port'}{'udp'} = '3046'	; 
#	$srvcobjects_ref->{'di-ase'}{'ports'}{'udp'}{'3046'}++	; 
#	$ports_ref->{'udp'}{'3046'}{'name'} = 'di-ase'		; 
#	$srvcobjects_ref->{'di-ase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'di-ase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'di-ase'}{'port'}{'tcp'} = '3046'	; 
#	$srvcobjects_ref->{'di-ase'}{'ports'}{'tcp'}{'3046'}++	; 
#	$ports_ref->{'tcp'}{'3046'}{'name'} = 'di-ase'		; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'port'}{'udp'} = '2982'	; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'ports'}{'udp'}{'2982'}++	; 
#	$ports_ref->{'udp'}{'2982'}{'name'} = 'iwb-whiteboard'		; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'port'}{'tcp'} = '2982'	; 
#	$srvcobjects_ref->{'iwb-whiteboard'}{'ports'}{'tcp'}{'2982'}++	; 
#	$ports_ref->{'tcp'}{'2982'}{'name'} = 'iwb-whiteboard'		; 
#	$srvcobjects_ref->{'cycleserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cycleserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cycleserv'}{'port'}{'udp'} = '763'	; 
#	$srvcobjects_ref->{'cycleserv'}{'ports'}{'udp'}{'763'}++	; 
#	$ports_ref->{'udp'}{'763'}{'name'} = 'cycleserv'		; 
#	$srvcobjects_ref->{'cycleserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cycleserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cycleserv'}{'port'}{'tcp'} = '763'	; 
#	$srvcobjects_ref->{'cycleserv'}{'ports'}{'tcp'}{'763'}++	; 
#	$ports_ref->{'tcp'}{'763'}{'name'} = 'cycleserv'		; 
#	$srvcobjects_ref->{'gsiftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gsiftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsiftp'}{'port'}{'udp'} = '2811'	; 
#	$srvcobjects_ref->{'gsiftp'}{'ports'}{'udp'}{'2811'}++	; 
#	$ports_ref->{'udp'}{'2811'}{'name'} = 'gsiftp'		; 
#	$srvcobjects_ref->{'gsiftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gsiftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsiftp'}{'port'}{'tcp'} = '2811'	; 
#	$srvcobjects_ref->{'gsiftp'}{'ports'}{'tcp'}{'2811'}++	; 
#	$ports_ref->{'tcp'}{'2811'}{'name'} = 'gsiftp'		; 
#	$srvcobjects_ref->{'repliweb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'repliweb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'repliweb'}{'port'}{'udp'} = '2837'	; 
#	$srvcobjects_ref->{'repliweb'}{'ports'}{'udp'}{'2837'}++	; 
#	$ports_ref->{'udp'}{'2837'}{'name'} = 'repliweb'		; 
#	$srvcobjects_ref->{'repliweb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'repliweb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'repliweb'}{'port'}{'tcp'} = '2837'	; 
#	$srvcobjects_ref->{'repliweb'}{'ports'}{'tcp'}{'2837'}++	; 
#	$ports_ref->{'tcp'}{'2837'}{'name'} = 'repliweb'		; 
#	$srvcobjects_ref->{'wherehoo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wherehoo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wherehoo'}{'port'}{'udp'} = '5859'	; 
#	$srvcobjects_ref->{'wherehoo'}{'ports'}{'udp'}{'5859'}++	; 
#	$ports_ref->{'udp'}{'5859'}{'name'} = 'wherehoo'		; 
#	$srvcobjects_ref->{'wherehoo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wherehoo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wherehoo'}{'port'}{'tcp'} = '5859'	; 
#	$srvcobjects_ref->{'wherehoo'}{'ports'}{'tcp'}{'5859'}++	; 
#	$ports_ref->{'tcp'}{'5859'}{'name'} = 'wherehoo'		; 
#	$srvcobjects_ref->{'cp-cluster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cp-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cp-cluster'}{'port'}{'udp'} = '8116'	; 
#	$srvcobjects_ref->{'cp-cluster'}{'ports'}{'udp'}{'8116'}++	; 
#	$ports_ref->{'udp'}{'8116'}{'name'} = 'cp-cluster'		; 
#	$srvcobjects_ref->{'cp-cluster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cp-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cp-cluster'}{'port'}{'tcp'} = '8116'	; 
#	$srvcobjects_ref->{'cp-cluster'}{'ports'}{'tcp'}{'8116'}++	; 
#	$ports_ref->{'tcp'}{'8116'}{'name'} = 'cp-cluster'		; 
#	$srvcobjects_ref->{'piranha2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'piranha2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'piranha2'}{'port'}{'udp'} = '4601'	; 
#	$srvcobjects_ref->{'piranha2'}{'ports'}{'udp'}{'4601'}++	; 
#	$ports_ref->{'udp'}{'4601'}{'name'} = 'piranha2'		; 
#	$srvcobjects_ref->{'piranha2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'piranha2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'piranha2'}{'port'}{'tcp'} = '4601'	; 
#	$srvcobjects_ref->{'piranha2'}{'ports'}{'tcp'}{'4601'}++	; 
#	$ports_ref->{'tcp'}{'4601'}{'name'} = 'piranha2'		; 
#	$srvcobjects_ref->{'jt400'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jt400'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jt400'}{'port'}{'udp'} = '3470'	; 
#	$srvcobjects_ref->{'jt400'}{'ports'}{'udp'}{'3470'}++	; 
#	$ports_ref->{'udp'}{'3470'}{'name'} = 'jt400'		; 
#	$srvcobjects_ref->{'jt400'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jt400'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jt400'}{'port'}{'tcp'} = '3470'	; 
#	$srvcobjects_ref->{'jt400'}{'ports'}{'tcp'}{'3470'}++	; 
#	$ports_ref->{'tcp'}{'3470'}{'name'} = 'jt400'		; 
#	$srvcobjects_ref->{'ctcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctcd'}{'port'}{'udp'} = '1851'	; 
#	$srvcobjects_ref->{'ctcd'}{'ports'}{'udp'}{'1851'}++	; 
#	$ports_ref->{'udp'}{'1851'}{'name'} = 'ctcd'		; 
#	$srvcobjects_ref->{'ctcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctcd'}{'port'}{'tcp'} = '1851'	; 
#	$srvcobjects_ref->{'ctcd'}{'ports'}{'tcp'}{'1851'}++	; 
#	$ports_ref->{'tcp'}{'1851'}{'name'} = 'ctcd'		; 
#	$srvcobjects_ref->{'gte-samp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gte-samp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gte-samp'}{'port'}{'udp'} = '2643'	; 
#	$srvcobjects_ref->{'gte-samp'}{'ports'}{'udp'}{'2643'}++	; 
#	$ports_ref->{'udp'}{'2643'}{'name'} = 'gte-samp'		; 
#	$srvcobjects_ref->{'gte-samp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gte-samp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gte-samp'}{'port'}{'tcp'} = '2643'	; 
#	$srvcobjects_ref->{'gte-samp'}{'ports'}{'tcp'}{'2643'}++	; 
#	$ports_ref->{'tcp'}{'2643'}{'name'} = 'gte-samp'		; 
#	$srvcobjects_ref->{'aed-512'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aed-512'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aed-512'}{'port'}{'udp'} = '149'	; 
#	$srvcobjects_ref->{'aed-512'}{'ports'}{'udp'}{'149'}++	; 
#	$ports_ref->{'udp'}{'149'}{'name'} = 'aed-512'		; 
#	$srvcobjects_ref->{'aed-512'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aed-512'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aed-512'}{'port'}{'tcp'} = '149'	; 
#	$srvcobjects_ref->{'aed-512'}{'ports'}{'tcp'}{'149'}++	; 
#	$ports_ref->{'tcp'}{'149'}{'name'} = 'aed-512'		; 
#	$srvcobjects_ref->{'rfe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rfe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfe'}{'port'}{'udp'} = '5002'	; 
#	$srvcobjects_ref->{'rfe'}{'ports'}{'udp'}{'5002'}++	; 
#	$ports_ref->{'udp'}{'5002'}{'name'} = 'rfe'		; 
#	$srvcobjects_ref->{'rfe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rfe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfe'}{'port'}{'tcp'} = '5002'	; 
#	$srvcobjects_ref->{'rfe'}{'ports'}{'tcp'}{'5002'}++	; 
#	$ports_ref->{'tcp'}{'5002'}{'name'} = 'rfe'		; 
#	$srvcobjects_ref->{'ehp-backup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ehp-backup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ehp-backup'}{'port'}{'udp'} = '3638'	; 
#	$srvcobjects_ref->{'ehp-backup'}{'ports'}{'udp'}{'3638'}++	; 
#	$ports_ref->{'udp'}{'3638'}{'name'} = 'ehp-backup'		; 
#	$srvcobjects_ref->{'ehp-backup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ehp-backup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ehp-backup'}{'port'}{'tcp'} = '3638'	; 
#	$srvcobjects_ref->{'ehp-backup'}{'ports'}{'tcp'}{'3638'}++	; 
#	$ports_ref->{'tcp'}{'3638'}{'name'} = 'ehp-backup'		; 
#	$srvcobjects_ref->{'nattyserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nattyserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nattyserver'}{'port'}{'udp'} = '3753'	; 
#	$srvcobjects_ref->{'nattyserver'}{'ports'}{'udp'}{'3753'}++	; 
#	$ports_ref->{'udp'}{'3753'}{'name'} = 'nattyserver'		; 
#	$srvcobjects_ref->{'nattyserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nattyserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nattyserver'}{'port'}{'tcp'} = '3753'	; 
#	$srvcobjects_ref->{'nattyserver'}{'ports'}{'tcp'}{'3753'}++	; 
#	$ports_ref->{'tcp'}{'3753'}{'name'} = 'nattyserver'		; 
#	$srvcobjects_ref->{'lonworks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lonworks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lonworks'}{'port'}{'udp'} = '2540'	; 
#	$srvcobjects_ref->{'lonworks'}{'ports'}{'udp'}{'2540'}++	; 
#	$ports_ref->{'udp'}{'2540'}{'name'} = 'lonworks'		; 
#	$srvcobjects_ref->{'lonworks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lonworks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lonworks'}{'port'}{'tcp'} = '2540'	; 
#	$srvcobjects_ref->{'lonworks'}{'ports'}{'tcp'}{'2540'}++	; 
#	$ports_ref->{'tcp'}{'2540'}{'name'} = 'lonworks'		; 
#	$srvcobjects_ref->{'rje'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rje'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rje'}{'port'}{'udp'} = '5'	; 
#	$srvcobjects_ref->{'rje'}{'ports'}{'udp'}{'5'}++	; 
#	$ports_ref->{'udp'}{'5'}{'name'} = 'rje'		; 
#	$srvcobjects_ref->{'rje'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rje'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rje'}{'port'}{'tcp'} = '5'	; 
#	$srvcobjects_ref->{'rje'}{'ports'}{'tcp'}{'5'}++	; 
#	$ports_ref->{'tcp'}{'5'}{'name'} = 'rje'		; 
#	$srvcobjects_ref->{'tn-tl-r1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tn-tl-r1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-r1'}{'port'}{'tcp'} = '1580'	; 
#	$srvcobjects_ref->{'tn-tl-r1'}{'ports'}{'tcp'}{'1580'}++	; 
#	$ports_ref->{'tcp'}{'1580'}{'name'} = 'tn-tl-r1'		; 
#	$srvcobjects_ref->{'stun-p1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stun-p1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-p1'}{'port'}{'udp'} = '1990'	; 
#	$srvcobjects_ref->{'stun-p1'}{'ports'}{'udp'}{'1990'}++	; 
#	$ports_ref->{'udp'}{'1990'}{'name'} = 'stun-p1'		; 
#	$srvcobjects_ref->{'stun-p1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stun-p1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-p1'}{'port'}{'tcp'} = '1990'	; 
#	$srvcobjects_ref->{'stun-p1'}{'ports'}{'tcp'}{'1990'}++	; 
#	$ports_ref->{'tcp'}{'1990'}{'name'} = 'stun-p1'		; 
#	$srvcobjects_ref->{'powerburst'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'powerburst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerburst'}{'port'}{'udp'} = '485'	; 
#	$srvcobjects_ref->{'powerburst'}{'ports'}{'udp'}{'485'}++	; 
#	$ports_ref->{'udp'}{'485'}{'name'} = 'powerburst'		; 
#	$srvcobjects_ref->{'powerburst'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'powerburst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerburst'}{'port'}{'tcp'} = '485'	; 
#	$srvcobjects_ref->{'powerburst'}{'ports'}{'tcp'}{'485'}++	; 
#	$ports_ref->{'tcp'}{'485'}{'name'} = 'powerburst'		; 
#	$srvcobjects_ref->{'lstp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lstp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lstp'}{'port'}{'udp'} = '2559'	; 
#	$srvcobjects_ref->{'lstp'}{'ports'}{'udp'}{'2559'}++	; 
#	$ports_ref->{'udp'}{'2559'}{'name'} = 'lstp'		; 
#	$srvcobjects_ref->{'lstp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lstp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lstp'}{'port'}{'tcp'} = '2559'	; 
#	$srvcobjects_ref->{'lstp'}{'ports'}{'tcp'}{'2559'}++	; 
#	$ports_ref->{'tcp'}{'2559'}{'name'} = 'lstp'		; 
#	$srvcobjects_ref->{'egptlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'egptlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'egptlm'}{'port'}{'udp'} = '3328'	; 
#	$srvcobjects_ref->{'egptlm'}{'ports'}{'udp'}{'3328'}++	; 
#	$ports_ref->{'udp'}{'3328'}{'name'} = 'egptlm'		; 
#	$srvcobjects_ref->{'egptlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'egptlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'egptlm'}{'port'}{'tcp'} = '3328'	; 
#	$srvcobjects_ref->{'egptlm'}{'ports'}{'tcp'}{'3328'}++	; 
#	$ports_ref->{'tcp'}{'3328'}{'name'} = 'egptlm'		; 
#	$srvcobjects_ref->{'spcsdlobby'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spcsdlobby'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spcsdlobby'}{'port'}{'udp'} = '2888'	; 
#	$srvcobjects_ref->{'spcsdlobby'}{'ports'}{'udp'}{'2888'}++	; 
#	$ports_ref->{'udp'}{'2888'}{'name'} = 'spcsdlobby'		; 
#	$srvcobjects_ref->{'spcsdlobby'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spcsdlobby'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spcsdlobby'}{'port'}{'tcp'} = '2888'	; 
#	$srvcobjects_ref->{'spcsdlobby'}{'ports'}{'tcp'}{'2888'}++	; 
#	$ports_ref->{'tcp'}{'2888'}{'name'} = 'spcsdlobby'		; 
#	$srvcobjects_ref->{'ubxd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ubxd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ubxd'}{'port'}{'udp'} = '4034'	; 
#	$srvcobjects_ref->{'ubxd'}{'ports'}{'udp'}{'4034'}++	; 
#	$ports_ref->{'udp'}{'4034'}{'name'} = 'ubxd'		; 
#	$srvcobjects_ref->{'ubxd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ubxd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ubxd'}{'port'}{'tcp'} = '4034'	; 
#	$srvcobjects_ref->{'ubxd'}{'ports'}{'tcp'}{'4034'}++	; 
#	$ports_ref->{'tcp'}{'4034'}{'name'} = 'ubxd'		; 
#	$srvcobjects_ref->{'u-dbap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'u-dbap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'u-dbap'}{'port'}{'udp'} = '3584'	; 
#	$srvcobjects_ref->{'u-dbap'}{'ports'}{'udp'}{'3584'}++	; 
#	$ports_ref->{'udp'}{'3584'}{'name'} = 'u-dbap'		; 
#	$srvcobjects_ref->{'u-dbap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'u-dbap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'u-dbap'}{'port'}{'tcp'} = '3584'	; 
#	$srvcobjects_ref->{'u-dbap'}{'ports'}{'tcp'}{'3584'}++	; 
#	$ports_ref->{'tcp'}{'3584'}{'name'} = 'u-dbap'		; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'port'}{'udp'} = '1901'	; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'ports'}{'udp'}{'1901'}++	; 
#	$ports_ref->{'udp'}{'1901'}{'name'} = 'fjicl-tep-a'		; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'port'}{'tcp'} = '1901'	; 
#	$srvcobjects_ref->{'fjicl-tep-a'}{'ports'}{'tcp'}{'1901'}++	; 
#	$ports_ref->{'tcp'}{'1901'}{'name'} = 'fjicl-tep-a'		; 
#	$srvcobjects_ref->{'virtualtape'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'virtualtape'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtualtape'}{'port'}{'udp'} = '2386'	; 
#	$srvcobjects_ref->{'virtualtape'}{'ports'}{'udp'}{'2386'}++	; 
#	$ports_ref->{'udp'}{'2386'}{'name'} = 'virtualtape'		; 
#	$srvcobjects_ref->{'virtualtape'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'virtualtape'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtualtape'}{'port'}{'tcp'} = '2386'	; 
#	$srvcobjects_ref->{'virtualtape'}{'ports'}{'tcp'}{'2386'}++	; 
#	$ports_ref->{'tcp'}{'2386'}{'name'} = 'virtualtape'		; 
#	$srvcobjects_ref->{'venus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'venus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'venus'}{'port'}{'udp'} = '2430'	; 
#	$srvcobjects_ref->{'venus'}{'ports'}{'udp'}{'2430'}++	; 
#	$ports_ref->{'udp'}{'2430'}{'name'} = 'venus'		; 
#	$srvcobjects_ref->{'venus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'venus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'venus'}{'port'}{'tcp'} = '2430'	; 
#	$srvcobjects_ref->{'venus'}{'ports'}{'tcp'}{'2430'}++	; 
#	$ports_ref->{'tcp'}{'2430'}{'name'} = 'venus'		; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'port'}{'udp'} = '1332'	; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'ports'}{'udp'}{'1332'}++	; 
#	$ports_ref->{'udp'}{'1332'}{'name'} = 'pcia-rxp-b'		; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'port'}{'tcp'} = '1332'	; 
#	$srvcobjects_ref->{'pcia-rxp-b'}{'ports'}{'tcp'}{'1332'}++	; 
#	$ports_ref->{'tcp'}{'1332'}{'name'} = 'pcia-rxp-b'		; 
#	$srvcobjects_ref->{'crmsbits'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'crmsbits'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crmsbits'}{'port'}{'udp'} = '2422'	; 
#	$srvcobjects_ref->{'crmsbits'}{'ports'}{'udp'}{'2422'}++	; 
#	$ports_ref->{'udp'}{'2422'}{'name'} = 'crmsbits'		; 
#	$srvcobjects_ref->{'crmsbits'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'crmsbits'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crmsbits'}{'port'}{'tcp'} = '2422'	; 
#	$srvcobjects_ref->{'crmsbits'}{'ports'}{'tcp'}{'2422'}++	; 
#	$ports_ref->{'tcp'}{'2422'}{'name'} = 'crmsbits'		; 
#	$srvcobjects_ref->{'commonspace'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'commonspace'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commonspace'}{'port'}{'udp'} = '1592'	; 
#	$srvcobjects_ref->{'commonspace'}{'ports'}{'udp'}{'1592'}++	; 
#	$ports_ref->{'udp'}{'1592'}{'name'} = 'commonspace'		; 
#	$srvcobjects_ref->{'commonspace'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'commonspace'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commonspace'}{'port'}{'tcp'} = '1592'	; 
#	$srvcobjects_ref->{'commonspace'}{'ports'}{'tcp'}{'1592'}++	; 
#	$ports_ref->{'tcp'}{'1592'}{'name'} = 'commonspace'		; 
#	$srvcobjects_ref->{'appliance-cfg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appliance-cfg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appliance-cfg'}{'port'}{'udp'} = '2898'	; 
#	$srvcobjects_ref->{'appliance-cfg'}{'ports'}{'udp'}{'2898'}++	; 
#	$ports_ref->{'udp'}{'2898'}{'name'} = 'appliance-cfg'		; 
#	$srvcobjects_ref->{'appliance-cfg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appliance-cfg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appliance-cfg'}{'port'}{'tcp'} = '2898'	; 
#	$srvcobjects_ref->{'appliance-cfg'}{'ports'}{'tcp'}{'2898'}++	; 
#	$ports_ref->{'tcp'}{'2898'}{'name'} = 'appliance-cfg'		; 
#	$srvcobjects_ref->{'initlsmsad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'initlsmsad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'initlsmsad'}{'port'}{'udp'} = '2793'	; 
#	$srvcobjects_ref->{'initlsmsad'}{'ports'}{'udp'}{'2793'}++	; 
#	$ports_ref->{'udp'}{'2793'}{'name'} = 'initlsmsad'		; 
#	$srvcobjects_ref->{'initlsmsad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'initlsmsad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'initlsmsad'}{'port'}{'tcp'} = '2793'	; 
#	$srvcobjects_ref->{'initlsmsad'}{'ports'}{'tcp'}{'2793'}++	; 
#	$ports_ref->{'tcp'}{'2793'}{'name'} = 'initlsmsad'		; 
#	$srvcobjects_ref->{'netcomm1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netcomm1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netcomm1'}{'port'}{'tcp'} = '1676'	; 
#	$srvcobjects_ref->{'netcomm1'}{'ports'}{'tcp'}{'1676'}++	; 
#	$ports_ref->{'tcp'}{'1676'}{'name'} = 'netcomm1'		; 
#	$srvcobjects_ref->{'must-p2p'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'must-p2p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'must-p2p'}{'port'}{'udp'} = '3514'	; 
#	$srvcobjects_ref->{'must-p2p'}{'ports'}{'udp'}{'3514'}++	; 
#	$ports_ref->{'udp'}{'3514'}{'name'} = 'must-p2p'		; 
#	$srvcobjects_ref->{'must-p2p'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'must-p2p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'must-p2p'}{'port'}{'tcp'} = '3514'	; 
#	$srvcobjects_ref->{'must-p2p'}{'ports'}{'tcp'}{'3514'}++	; 
#	$ports_ref->{'tcp'}{'3514'}{'name'} = 'must-p2p'		; 
#	$srvcobjects_ref->{'whosockami'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'whosockami'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whosockami'}{'port'}{'udp'} = '2009'	; 
#	$srvcobjects_ref->{'whosockami'}{'ports'}{'udp'}{'2009'}++	; 
#	$ports_ref->{'udp'}{'2009'}{'name'} = 'whosockami'		; 
#	$srvcobjects_ref->{'whosockami'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'whosockami'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whosockami'}{'port'}{'tcp'} = '2019'	; 
#	$srvcobjects_ref->{'whosockami'}{'ports'}{'tcp'}{'2019'}++	; 
#	$ports_ref->{'tcp'}{'2019'}{'name'} = 'whosockami'		; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'port'}{'udp'} = '2827'	; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'ports'}{'udp'}{'2827'}++	; 
#	$ports_ref->{'udp'}{'2827'}{'name'} = 'slc-ctrlrloops'		; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'port'}{'tcp'} = '2827'	; 
#	$srvcobjects_ref->{'slc-ctrlrloops'}{'ports'}{'tcp'}{'2827'}++	; 
#	$ports_ref->{'tcp'}{'2827'}{'name'} = 'slc-ctrlrloops'		; 
#	$srvcobjects_ref->{'lan900_remote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lan900_remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lan900_remote'}{'port'}{'udp'} = '2395'	; 
#	$srvcobjects_ref->{'lan900_remote'}{'ports'}{'udp'}{'2395'}++	; 
#	$ports_ref->{'udp'}{'2395'}{'name'} = 'lan900_remote'		; 
#	$srvcobjects_ref->{'lan900_remote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lan900_remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lan900_remote'}{'port'}{'tcp'} = '2395'	; 
#	$srvcobjects_ref->{'lan900_remote'}{'ports'}{'tcp'}{'2395'}++	; 
#	$ports_ref->{'tcp'}{'2395'}{'name'} = 'lan900_remote'		; 
#	$srvcobjects_ref->{'aaftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aaftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aaftp'}{'port'}{'udp'} = '2794'	; 
#	$srvcobjects_ref->{'aaftp'}{'ports'}{'udp'}{'2794'}++	; 
#	$ports_ref->{'udp'}{'2794'}{'name'} = 'aaftp'		; 
#	$srvcobjects_ref->{'aaftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aaftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aaftp'}{'port'}{'tcp'} = '2794'	; 
#	$srvcobjects_ref->{'aaftp'}{'ports'}{'tcp'}{'2794'}++	; 
#	$ports_ref->{'tcp'}{'2794'}{'name'} = 'aaftp'		; 
#	$srvcobjects_ref->{'mcp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcp-port'}{'port'}{'udp'} = '3558'	; 
#	$srvcobjects_ref->{'mcp-port'}{'ports'}{'udp'}{'3558'}++	; 
#	$ports_ref->{'udp'}{'3558'}{'name'} = 'mcp-port'		; 
#	$srvcobjects_ref->{'mcp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcp-port'}{'port'}{'tcp'} = '3558'	; 
#	$srvcobjects_ref->{'mcp-port'}{'ports'}{'tcp'}{'3558'}++	; 
#	$ports_ref->{'tcp'}{'3558'}{'name'} = 'mcp-port'		; 
#	$srvcobjects_ref->{'sns-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-admin'}{'port'}{'udp'} = '2658'	; 
#	$srvcobjects_ref->{'sns-admin'}{'ports'}{'udp'}{'2658'}++	; 
#	$ports_ref->{'udp'}{'2658'}{'name'} = 'sns-admin'		; 
#	$srvcobjects_ref->{'sns-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-admin'}{'port'}{'tcp'} = '2658'	; 
#	$srvcobjects_ref->{'sns-admin'}{'ports'}{'tcp'}{'2658'}++	; 
#	$ports_ref->{'tcp'}{'2658'}{'name'} = 'sns-admin'		; 
#	$srvcobjects_ref->{'bdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bdp'}{'port'}{'udp'} = '581'	; 
#	$srvcobjects_ref->{'bdp'}{'ports'}{'udp'}{'581'}++	; 
#	$ports_ref->{'udp'}{'581'}{'name'} = 'bdp'		; 
#	$srvcobjects_ref->{'bdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bdp'}{'port'}{'tcp'} = '581'	; 
#	$srvcobjects_ref->{'bdp'}{'ports'}{'tcp'}{'581'}++	; 
#	$ports_ref->{'tcp'}{'581'}{'name'} = 'bdp'		; 
#	$srvcobjects_ref->{'ccmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ccmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmail'}{'port'}{'udp'} = '3264'	; 
#	$srvcobjects_ref->{'ccmail'}{'ports'}{'udp'}{'3264'}++	; 
#	$ports_ref->{'udp'}{'3264'}{'name'} = 'ccmail'		; 
#	$srvcobjects_ref->{'ccmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ccmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmail'}{'port'}{'tcp'} = '3264'	; 
#	$srvcobjects_ref->{'ccmail'}{'ports'}{'tcp'}{'3264'}++	; 
#	$ports_ref->{'tcp'}{'3264'}{'name'} = 'ccmail'		; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'port'}{'udp'} = '3054'	; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'ports'}{'udp'}{'3054'}++	; 
#	$ports_ref->{'udp'}{'3054'}{'name'} = 'amt-cnf-prot'		; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'port'}{'tcp'} = '3054'	; 
#	$srvcobjects_ref->{'amt-cnf-prot'}{'ports'}{'tcp'}{'3054'}++	; 
#	$ports_ref->{'tcp'}{'3054'}{'name'} = 'amt-cnf-prot'		; 
#	$srvcobjects_ref->{'legent-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'legent-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'legent-2'}{'port'}{'udp'} = '374'	; 
#	$srvcobjects_ref->{'legent-2'}{'ports'}{'udp'}{'374'}++	; 
#	$ports_ref->{'udp'}{'374'}{'name'} = 'legent-2'		; 
#	$srvcobjects_ref->{'legent-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'legent-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'legent-2'}{'port'}{'tcp'} = '374'	; 
#	$srvcobjects_ref->{'legent-2'}{'ports'}{'tcp'}{'374'}++	; 
#	$ports_ref->{'tcp'}{'374'}{'name'} = 'legent-2'		; 
#	$srvcobjects_ref->{'swrmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swrmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swrmi'}{'port'}{'udp'} = '1866'	; 
#	$srvcobjects_ref->{'swrmi'}{'ports'}{'udp'}{'1866'}++	; 
#	$ports_ref->{'udp'}{'1866'}{'name'} = 'swrmi'		; 
#	$srvcobjects_ref->{'swrmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swrmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swrmi'}{'port'}{'tcp'} = '1866'	; 
#	$srvcobjects_ref->{'swrmi'}{'ports'}{'tcp'}{'1866'}++	; 
#	$ports_ref->{'tcp'}{'1866'}{'name'} = 'swrmi'		; 
#	$srvcobjects_ref->{'telnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telnet'}{'port'}{'udp'} = '23'	; 
#	$srvcobjects_ref->{'telnet'}{'ports'}{'udp'}{'23'}++	; 
#	$ports_ref->{'udp'}{'23'}{'name'} = 'telnet'		; 
#	$srvcobjects_ref->{'telnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telnet'}{'port'}{'tcp'} = '23'	; 
#	$srvcobjects_ref->{'telnet'}{'ports'}{'tcp'}{'23'}++	; 
#	$ports_ref->{'tcp'}{'23'}{'name'} = 'telnet'		; 
#	$srvcobjects_ref->{'lanner-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lanner-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lanner-lm'}{'port'}{'udp'} = '4547'	; 
#	$srvcobjects_ref->{'lanner-lm'}{'ports'}{'udp'}{'4547'}++	; 
#	$ports_ref->{'udp'}{'4547'}{'name'} = 'lanner-lm'		; 
#	$srvcobjects_ref->{'lanner-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lanner-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lanner-lm'}{'port'}{'tcp'} = '4547'	; 
#	$srvcobjects_ref->{'lanner-lm'}{'ports'}{'tcp'}{'4547'}++	; 
#	$ports_ref->{'tcp'}{'4547'}{'name'} = 'lanner-lm'		; 
#	$srvcobjects_ref->{'dsdn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsdn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsdn'}{'port'}{'udp'} = '1292'	; 
#	$srvcobjects_ref->{'dsdn'}{'ports'}{'udp'}{'1292'}++	; 
#	$ports_ref->{'udp'}{'1292'}{'name'} = 'dsdn'		; 
#	$srvcobjects_ref->{'dsdn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsdn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsdn'}{'port'}{'tcp'} = '1292'	; 
#	$srvcobjects_ref->{'dsdn'}{'ports'}{'tcp'}{'1292'}++	; 
#	$ports_ref->{'tcp'}{'1292'}{'name'} = 'dsdn'		; 
#	$srvcobjects_ref->{'mindfilesys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mindfilesys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mindfilesys'}{'port'}{'udp'} = '7391'	; 
#	$srvcobjects_ref->{'mindfilesys'}{'ports'}{'udp'}{'7391'}++	; 
#	$ports_ref->{'udp'}{'7391'}{'name'} = 'mindfilesys'		; 
#	$srvcobjects_ref->{'mindfilesys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mindfilesys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mindfilesys'}{'port'}{'tcp'} = '7391'	; 
#	$srvcobjects_ref->{'mindfilesys'}{'ports'}{'tcp'}{'7391'}++	; 
#	$ports_ref->{'tcp'}{'7391'}{'name'} = 'mindfilesys'		; 
#	$srvcobjects_ref->{'prosharevideo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prosharevideo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharevideo'}{'port'}{'udp'} = '5714'	; 
#	$srvcobjects_ref->{'prosharevideo'}{'ports'}{'udp'}{'5714'}++	; 
#	$ports_ref->{'udp'}{'5714'}{'name'} = 'prosharevideo'		; 
#	$srvcobjects_ref->{'prosharevideo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prosharevideo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharevideo'}{'port'}{'tcp'} = '5714'	; 
#	$srvcobjects_ref->{'prosharevideo'}{'ports'}{'tcp'}{'5714'}++	; 
#	$ports_ref->{'tcp'}{'5714'}{'name'} = 'prosharevideo'		; 
#	$srvcobjects_ref->{'netlock1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netlock1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock1'}{'port'}{'udp'} = '9160'	; 
#	$srvcobjects_ref->{'netlock1'}{'ports'}{'udp'}{'9160'}++	; 
#	$ports_ref->{'udp'}{'9160'}{'name'} = 'netlock1'		; 
#	$srvcobjects_ref->{'netlock1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netlock1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock1'}{'port'}{'tcp'} = '9160'	; 
#	$srvcobjects_ref->{'netlock1'}{'ports'}{'tcp'}{'9160'}++	; 
#	$ports_ref->{'tcp'}{'9160'}{'name'} = 'netlock1'		; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'port'}{'udp'} = '3495'	; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'ports'}{'udp'}{'3495'}++	; 
#	$ports_ref->{'udp'}{'3495'}{'name'} = 'seclayer-tcp'		; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'port'}{'tcp'} = '3495'	; 
#	$srvcobjects_ref->{'seclayer-tcp'}{'ports'}{'tcp'}{'3495'}++	; 
#	$ports_ref->{'tcp'}{'3495'}{'name'} = 'seclayer-tcp'		; 
#	$srvcobjects_ref->{'rrilwm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrilwm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrilwm'}{'port'}{'udp'} = '1695'	; 
#	$srvcobjects_ref->{'rrilwm'}{'ports'}{'udp'}{'1695'}++	; 
#	$ports_ref->{'udp'}{'1695'}{'name'} = 'rrilwm'		; 
#	$srvcobjects_ref->{'rrilwm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrilwm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrilwm'}{'port'}{'tcp'} = '1695'	; 
#	$srvcobjects_ref->{'rrilwm'}{'ports'}{'tcp'}{'1695'}++	; 
#	$ports_ref->{'tcp'}{'1695'}{'name'} = 'rrilwm'		; 
#	$srvcobjects_ref->{'gtp-user'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gtp-user'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtp-user'}{'port'}{'udp'} = '2152'	; 
#	$srvcobjects_ref->{'gtp-user'}{'ports'}{'udp'}{'2152'}++	; 
#	$ports_ref->{'udp'}{'2152'}{'name'} = 'gtp-user'		; 
#	$srvcobjects_ref->{'gtp-user'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gtp-user'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtp-user'}{'port'}{'tcp'} = '2152'	; 
#	$srvcobjects_ref->{'gtp-user'}{'ports'}{'tcp'}{'2152'}++	; 
#	$ports_ref->{'tcp'}{'2152'}{'name'} = 'gtp-user'		; 
#	$srvcobjects_ref->{'magicom'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'magicom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magicom'}{'port'}{'udp'} = '2243'	; 
#	$srvcobjects_ref->{'magicom'}{'ports'}{'udp'}{'2243'}++	; 
#	$ports_ref->{'udp'}{'2243'}{'name'} = 'magicom'		; 
#	$srvcobjects_ref->{'magicom'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'magicom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magicom'}{'port'}{'tcp'} = '2243'	; 
#	$srvcobjects_ref->{'magicom'}{'ports'}{'tcp'}{'2243'}++	; 
#	$ports_ref->{'tcp'}{'2243'}{'name'} = 'magicom'		; 
#	$srvcobjects_ref->{'rtnt-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtnt-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtnt-2'}{'port'}{'udp'} = '3138'	; 
#	$srvcobjects_ref->{'rtnt-2'}{'ports'}{'udp'}{'3138'}++	; 
#	$ports_ref->{'udp'}{'3138'}{'name'} = 'rtnt-2'		; 
#	$srvcobjects_ref->{'rtnt-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtnt-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtnt-2'}{'port'}{'tcp'} = '3138'	; 
#	$srvcobjects_ref->{'rtnt-2'}{'ports'}{'tcp'}{'3138'}++	; 
#	$ports_ref->{'tcp'}{'3138'}{'name'} = 'rtnt-2'		; 
#	$srvcobjects_ref->{'pda-gate'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pda-gate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pda-gate'}{'port'}{'udp'} = '4012'	; 
#	$srvcobjects_ref->{'pda-gate'}{'ports'}{'udp'}{'4012'}++	; 
#	$ports_ref->{'udp'}{'4012'}{'name'} = 'pda-gate'		; 
#	$srvcobjects_ref->{'pda-gate'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pda-gate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pda-gate'}{'port'}{'tcp'} = '4012'	; 
#	$srvcobjects_ref->{'pda-gate'}{'ports'}{'tcp'}{'4012'}++	; 
#	$ports_ref->{'tcp'}{'4012'}{'name'} = 'pda-gate'		; 
#	$srvcobjects_ref->{'roboeda'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'roboeda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roboeda'}{'port'}{'udp'} = '2920'	; 
#	$srvcobjects_ref->{'roboeda'}{'ports'}{'udp'}{'2920'}++	; 
#	$ports_ref->{'udp'}{'2920'}{'name'} = 'roboeda'		; 
#	$srvcobjects_ref->{'roboeda'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'roboeda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roboeda'}{'port'}{'tcp'} = '2920'	; 
#	$srvcobjects_ref->{'roboeda'}{'ports'}{'tcp'}{'2920'}++	; 
#	$ports_ref->{'tcp'}{'2920'}{'name'} = 'roboeda'		; 
#	$srvcobjects_ref->{'netserialext1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netserialext1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext1'}{'port'}{'udp'} = '16360'	; 
#	$srvcobjects_ref->{'netserialext1'}{'ports'}{'udp'}{'16360'}++	; 
#	$ports_ref->{'udp'}{'16360'}{'name'} = 'netserialext1'		; 
#	$srvcobjects_ref->{'netserialext1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netserialext1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext1'}{'port'}{'tcp'} = '16360'	; 
#	$srvcobjects_ref->{'netserialext1'}{'ports'}{'tcp'}{'16360'}++	; 
#	$ports_ref->{'tcp'}{'16360'}{'name'} = 'netserialext1'		; 
#	$srvcobjects_ref->{'bdir_pub'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bdir_pub'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bdir_pub'}{'port'}{'udp'} = '6508'	; 
#	$srvcobjects_ref->{'bdir_pub'}{'ports'}{'udp'}{'6508'}++	; 
#	$ports_ref->{'udp'}{'6508'}{'name'} = 'bdir_pub'		; 
#	$srvcobjects_ref->{'bdir_pub'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bdir_pub'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bdir_pub'}{'port'}{'tcp'} = '6508'	; 
#	$srvcobjects_ref->{'bdir_pub'}{'ports'}{'tcp'}{'6508'}++	; 
#	$ports_ref->{'tcp'}{'6508'}{'name'} = 'bdir_pub'		; 
#	$srvcobjects_ref->{'composit-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'composit-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'composit-server'}{'port'}{'udp'} = '2417'	; 
#	$srvcobjects_ref->{'composit-server'}{'ports'}{'udp'}{'2417'}++	; 
#	$ports_ref->{'udp'}{'2417'}{'name'} = 'composit-server'		; 
#	$srvcobjects_ref->{'composit-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'composit-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'composit-server'}{'port'}{'tcp'} = '2417'	; 
#	$srvcobjects_ref->{'composit-server'}{'ports'}{'tcp'}{'2417'}++	; 
#	$ports_ref->{'tcp'}{'2417'}{'name'} = 'composit-server'		; 
#	$srvcobjects_ref->{'dialog-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dialog-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialog-port'}{'port'}{'udp'} = '2098'	; 
#	$srvcobjects_ref->{'dialog-port'}{'ports'}{'udp'}{'2098'}++	; 
#	$ports_ref->{'udp'}{'2098'}{'name'} = 'dialog-port'		; 
#	$srvcobjects_ref->{'dialog-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dialog-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialog-port'}{'port'}{'tcp'} = '2098'	; 
#	$srvcobjects_ref->{'dialog-port'}{'ports'}{'tcp'}{'2098'}++	; 
#	$ports_ref->{'tcp'}{'2098'}{'name'} = 'dialog-port'		; 
#	$srvcobjects_ref->{'snapenetio'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snapenetio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snapenetio'}{'port'}{'udp'} = '22000'	; 
#	$srvcobjects_ref->{'snapenetio'}{'ports'}{'udp'}{'22000'}++	; 
#	$ports_ref->{'udp'}{'22000'}{'name'} = 'snapenetio'		; 
#	$srvcobjects_ref->{'snapenetio'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snapenetio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snapenetio'}{'port'}{'tcp'} = '22000'	; 
#	$srvcobjects_ref->{'snapenetio'}{'ports'}{'tcp'}{'22000'}++	; 
#	$ports_ref->{'tcp'}{'22000'}{'name'} = 'snapenetio'		; 
#	$srvcobjects_ref->{'netobjects2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netobjects2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netobjects2'}{'port'}{'udp'} = '2486'	; 
#	$srvcobjects_ref->{'netobjects2'}{'ports'}{'udp'}{'2486'}++	; 
#	$ports_ref->{'udp'}{'2486'}{'name'} = 'netobjects2'		; 
#	$srvcobjects_ref->{'netobjects2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netobjects2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netobjects2'}{'port'}{'tcp'} = '2486'	; 
#	$srvcobjects_ref->{'netobjects2'}{'ports'}{'tcp'}{'2486'}++	; 
#	$ports_ref->{'tcp'}{'2486'}{'name'} = 'netobjects2'		; 
#	$srvcobjects_ref->{'tvbus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tvbus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tvbus'}{'port'}{'udp'} = '2191'	; 
#	$srvcobjects_ref->{'tvbus'}{'ports'}{'udp'}{'2191'}++	; 
#	$ports_ref->{'udp'}{'2191'}{'name'} = 'tvbus'		; 
#	$srvcobjects_ref->{'tvbus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tvbus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tvbus'}{'port'}{'tcp'} = '2191'	; 
#	$srvcobjects_ref->{'tvbus'}{'ports'}{'tcp'}{'2191'}++	; 
#	$ports_ref->{'tcp'}{'2191'}{'name'} = 'tvbus'		; 
#	$srvcobjects_ref->{'remotefs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remotefs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remotefs'}{'port'}{'udp'} = '556'	; 
#	$srvcobjects_ref->{'remotefs'}{'ports'}{'udp'}{'556'}++	; 
#	$ports_ref->{'udp'}{'556'}{'name'} = 'remotefs'		; 
#	$srvcobjects_ref->{'remotefs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remotefs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remotefs'}{'port'}{'tcp'} = '556'	; 
#	$srvcobjects_ref->{'remotefs'}{'ports'}{'tcp'}{'556'}++	; 
#	$ports_ref->{'tcp'}{'556'}{'name'} = 'remotefs'		; 
#	$srvcobjects_ref->{'saft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'saft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saft'}{'port'}{'udp'} = '487'	; 
#	$srvcobjects_ref->{'saft'}{'ports'}{'udp'}{'487'}++	; 
#	$ports_ref->{'udp'}{'487'}{'name'} = 'saft'		; 
#	$srvcobjects_ref->{'saft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'saft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'saft'}{'port'}{'tcp'} = '487'	; 
#	$srvcobjects_ref->{'saft'}{'ports'}{'tcp'}{'487'}++	; 
#	$ports_ref->{'tcp'}{'487'}{'name'} = 'saft'		; 
#	$srvcobjects_ref->{'ident'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ident'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ident'}{'port'}{'tcp'} = '113'	; 
#	$srvcobjects_ref->{'ident'}{'ports'}{'tcp'}{'113'}++	; 
#	$ports_ref->{'tcp'}{'113'}{'name'} = 'ident'		; 
#	$srvcobjects_ref->{'glrpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'glrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glrpc'}{'port'}{'udp'} = '9080'	; 
#	$srvcobjects_ref->{'glrpc'}{'ports'}{'udp'}{'9080'}++	; 
#	$ports_ref->{'udp'}{'9080'}{'name'} = 'glrpc'		; 
#	$srvcobjects_ref->{'glrpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'glrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glrpc'}{'port'}{'tcp'} = '9080'	; 
#	$srvcobjects_ref->{'glrpc'}{'ports'}{'tcp'}{'9080'}++	; 
#	$ports_ref->{'tcp'}{'9080'}{'name'} = 'glrpc'		; 
#	$srvcobjects_ref->{'directv-web'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directv-web'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-web'}{'port'}{'udp'} = '3334'	; 
#	$srvcobjects_ref->{'directv-web'}{'ports'}{'udp'}{'3334'}++	; 
#	$ports_ref->{'udp'}{'3334'}{'name'} = 'directv-web'		; 
#	$srvcobjects_ref->{'directv-web'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directv-web'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directv-web'}{'port'}{'tcp'} = '3334'	; 
#	$srvcobjects_ref->{'directv-web'}{'ports'}{'tcp'}{'3334'}++	; 
#	$ports_ref->{'tcp'}{'3334'}{'name'} = 'directv-web'		; 
#	$srvcobjects_ref->{'powerguardian'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'powerguardian'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerguardian'}{'port'}{'udp'} = '1777'	; 
#	$srvcobjects_ref->{'powerguardian'}{'ports'}{'udp'}{'1777'}++	; 
#	$ports_ref->{'udp'}{'1777'}{'name'} = 'powerguardian'		; 
#	$srvcobjects_ref->{'powerguardian'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'powerguardian'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerguardian'}{'port'}{'tcp'} = '1777'	; 
#	$srvcobjects_ref->{'powerguardian'}{'ports'}{'tcp'}{'1777'}++	; 
#	$ports_ref->{'tcp'}{'1777'}{'name'} = 'powerguardian'		; 
#	$srvcobjects_ref->{'xprint-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xprint-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xprint-server'}{'port'}{'udp'} = '8100'	; 
#	$srvcobjects_ref->{'xprint-server'}{'ports'}{'udp'}{'8100'}++	; 
#	$ports_ref->{'udp'}{'8100'}{'name'} = 'xprint-server'		; 
#	$srvcobjects_ref->{'xprint-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xprint-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xprint-server'}{'port'}{'tcp'} = '8100'	; 
#	$srvcobjects_ref->{'xprint-server'}{'ports'}{'tcp'}{'8100'}++	; 
#	$ports_ref->{'tcp'}{'8100'}{'name'} = 'xprint-server'		; 
#	$srvcobjects_ref->{'ap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ap'}{'port'}{'udp'} = '47806'	; 
#	$srvcobjects_ref->{'ap'}{'ports'}{'udp'}{'47806'}++	; 
#	$ports_ref->{'udp'}{'47806'}{'name'} = 'ap'		; 
#	$srvcobjects_ref->{'ap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ap'}{'port'}{'tcp'} = '47806'	; 
#	$srvcobjects_ref->{'ap'}{'ports'}{'tcp'}{'47806'}++	; 
#	$ports_ref->{'tcp'}{'47806'}{'name'} = 'ap'		; 
#	$srvcobjects_ref->{'dpserveadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dpserveadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpserveadmin'}{'port'}{'udp'} = '7021'	; 
#	$srvcobjects_ref->{'dpserveadmin'}{'ports'}{'udp'}{'7021'}++	; 
#	$ports_ref->{'udp'}{'7021'}{'name'} = 'dpserveadmin'		; 
#	$srvcobjects_ref->{'dpserveadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dpserveadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dpserveadmin'}{'port'}{'tcp'} = '7021'	; 
#	$srvcobjects_ref->{'dpserveadmin'}{'ports'}{'tcp'}{'7021'}++	; 
#	$ports_ref->{'tcp'}{'7021'}{'name'} = 'dpserveadmin'		; 
#	$srvcobjects_ref->{'tn-tl-w1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tn-tl-w1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-w1'}{'port'}{'tcp'} = '474'	; 
#	$srvcobjects_ref->{'tn-tl-w1'}{'ports'}{'tcp'}{'474'}++	; 
#	$ports_ref->{'tcp'}{'474'}{'name'} = 'tn-tl-w1'		; 
#	$srvcobjects_ref->{'rtsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsp'}{'port'}{'udp'} = '554'	; 
#	$srvcobjects_ref->{'rtsp'}{'ports'}{'udp'}{'554'}++	; 
#	$ports_ref->{'udp'}{'554'}{'name'} = 'rtsp'		; 
#	$srvcobjects_ref->{'rtsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsp'}{'port'}{'tcp'} = '554'	; 
#	$srvcobjects_ref->{'rtsp'}{'ports'}{'tcp'}{'554'}++	; 
#	$ports_ref->{'tcp'}{'554'}{'name'} = 'rtsp'		; 
#	$srvcobjects_ref->{'opequus-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opequus-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opequus-server'}{'port'}{'udp'} = '2400'	; 
#	$srvcobjects_ref->{'opequus-server'}{'ports'}{'udp'}{'2400'}++	; 
#	$ports_ref->{'udp'}{'2400'}{'name'} = 'opequus-server'		; 
#	$srvcobjects_ref->{'opequus-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opequus-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opequus-server'}{'port'}{'tcp'} = '2400'	; 
#	$srvcobjects_ref->{'opequus-server'}{'ports'}{'tcp'}{'2400'}++	; 
#	$ports_ref->{'tcp'}{'2400'}{'name'} = 'opequus-server'		; 
#	$srvcobjects_ref->{'smc-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smc-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smc-http'}{'port'}{'udp'} = '6788'	; 
#	$srvcobjects_ref->{'smc-http'}{'ports'}{'udp'}{'6788'}++	; 
#	$ports_ref->{'udp'}{'6788'}{'name'} = 'smc-http'		; 
#	$srvcobjects_ref->{'smc-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smc-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smc-http'}{'port'}{'tcp'} = '6788'	; 
#	$srvcobjects_ref->{'smc-http'}{'ports'}{'tcp'}{'6788'}++	; 
#	$ports_ref->{'tcp'}{'6788'}{'name'} = 'smc-http'		; 
#	$srvcobjects_ref->{'citrixima'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'citrixima'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citrixima'}{'port'}{'udp'} = '2512'	; 
#	$srvcobjects_ref->{'citrixima'}{'ports'}{'udp'}{'2512'}++	; 
#	$ports_ref->{'udp'}{'2512'}{'name'} = 'citrixima'		; 
#	$srvcobjects_ref->{'citrixima'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'citrixima'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citrixima'}{'port'}{'tcp'} = '2512'	; 
#	$srvcobjects_ref->{'citrixima'}{'ports'}{'tcp'}{'2512'}++	; 
#	$ports_ref->{'tcp'}{'2512'}{'name'} = 'citrixima'		; 
#	$srvcobjects_ref->{'idxp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idxp'}{'port'}{'udp'} = '603'	; 
#	$srvcobjects_ref->{'idxp'}{'ports'}{'udp'}{'603'}++	; 
#	$ports_ref->{'udp'}{'603'}{'name'} = 'idxp'		; 
#	$srvcobjects_ref->{'idxp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idxp'}{'port'}{'tcp'} = '603'	; 
#	$srvcobjects_ref->{'idxp'}{'ports'}{'tcp'}{'603'}++	; 
#	$ports_ref->{'tcp'}{'603'}{'name'} = 'idxp'		; 
#	$srvcobjects_ref->{'spearway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spearway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spearway'}{'port'}{'udp'} = '2440'	; 
#	$srvcobjects_ref->{'spearway'}{'ports'}{'udp'}{'2440'}++	; 
#	$ports_ref->{'udp'}{'2440'}{'name'} = 'spearway'		; 
#	$srvcobjects_ref->{'spearway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spearway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spearway'}{'port'}{'tcp'} = '2440'	; 
#	$srvcobjects_ref->{'spearway'}{'ports'}{'tcp'}{'2440'}++	; 
#	$ports_ref->{'tcp'}{'2440'}{'name'} = 'spearway'		; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'port'}{'udp'} = '580'	; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'ports'}{'udp'}{'580'}++	; 
#	$ports_ref->{'udp'}{'580'}{'name'} = 'sntp-heartbeat'		; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'port'}{'tcp'} = '580'	; 
#	$srvcobjects_ref->{'sntp-heartbeat'}{'ports'}{'tcp'}{'580'}++	; 
#	$ports_ref->{'tcp'}{'580'}{'name'} = 'sntp-heartbeat'		; 
#	$srvcobjects_ref->{'atm-zip-office'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'atm-zip-office'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atm-zip-office'}{'port'}{'udp'} = '1520'	; 
#	$srvcobjects_ref->{'atm-zip-office'}{'ports'}{'udp'}{'1520'}++	; 
#	$ports_ref->{'udp'}{'1520'}{'name'} = 'atm-zip-office'		; 
#	$srvcobjects_ref->{'atm-zip-office'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'atm-zip-office'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atm-zip-office'}{'port'}{'tcp'} = '1520'	; 
#	$srvcobjects_ref->{'atm-zip-office'}{'ports'}{'tcp'}{'1520'}++	; 
#	$ports_ref->{'tcp'}{'1520'}{'name'} = 'atm-zip-office'		; 
#	$srvcobjects_ref->{'mcidas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcidas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcidas'}{'port'}{'udp'} = '112'	; 
#	$srvcobjects_ref->{'mcidas'}{'ports'}{'udp'}{'112'}++	; 
#	$ports_ref->{'udp'}{'112'}{'name'} = 'mcidas'		; 
#	$srvcobjects_ref->{'mcidas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcidas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcidas'}{'port'}{'tcp'} = '112'	; 
#	$srvcobjects_ref->{'mcidas'}{'ports'}{'tcp'}{'112'}++	; 
#	$ports_ref->{'tcp'}{'112'}{'name'} = 'mcidas'		; 
#	$srvcobjects_ref->{'cambertx-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cambertx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cambertx-lm'}{'port'}{'udp'} = '1734'	; 
#	$srvcobjects_ref->{'cambertx-lm'}{'ports'}{'udp'}{'1734'}++	; 
#	$ports_ref->{'udp'}{'1734'}{'name'} = 'cambertx-lm'		; 
#	$srvcobjects_ref->{'cambertx-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cambertx-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cambertx-lm'}{'port'}{'tcp'} = '1734'	; 
#	$srvcobjects_ref->{'cambertx-lm'}{'ports'}{'tcp'}{'1734'}++	; 
#	$ports_ref->{'tcp'}{'1734'}{'name'} = 'cambertx-lm'		; 
#	$srvcobjects_ref->{'answersoft-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'answersoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'answersoft-lm'}{'port'}{'udp'} = '1781'	; 
#	$srvcobjects_ref->{'answersoft-lm'}{'ports'}{'udp'}{'1781'}++	; 
#	$ports_ref->{'udp'}{'1781'}{'name'} = 'answersoft-lm'		; 
#	$srvcobjects_ref->{'answersoft-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'answersoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'answersoft-lm'}{'port'}{'tcp'} = '1781'	; 
#	$srvcobjects_ref->{'answersoft-lm'}{'ports'}{'tcp'}{'1781'}++	; 
#	$ports_ref->{'tcp'}{'1781'}{'name'} = 'answersoft-lm'		; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'port'}{'udp'} = '475'	; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'ports'}{'udp'}{'475'}++	; 
#	$ports_ref->{'udp'}{'475'}{'name'} = 'tcpnethaspsrv'		; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'port'}{'tcp'} = '475'	; 
#	$srvcobjects_ref->{'tcpnethaspsrv'}{'ports'}{'tcp'}{'475'}++	; 
#	$ports_ref->{'tcp'}{'475'}{'name'} = 'tcpnethaspsrv'		; 
#	$srvcobjects_ref->{'ottp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ottp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ottp'}{'port'}{'udp'} = '2951'	; 
#	$srvcobjects_ref->{'ottp'}{'ports'}{'udp'}{'2951'}++	; 
#	$ports_ref->{'udp'}{'2951'}{'name'} = 'ottp'		; 
#	$srvcobjects_ref->{'ottp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ottp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ottp'}{'port'}{'tcp'} = '2951'	; 
#	$srvcobjects_ref->{'ottp'}{'ports'}{'tcp'}{'2951'}++	; 
#	$ports_ref->{'tcp'}{'2951'}{'name'} = 'ottp'		; 
#	$srvcobjects_ref->{'dns2go'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dns2go'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dns2go'}{'port'}{'udp'} = '1227'	; 
#	$srvcobjects_ref->{'dns2go'}{'ports'}{'udp'}{'1227'}++	; 
#	$ports_ref->{'udp'}{'1227'}{'name'} = 'dns2go'		; 
#	$srvcobjects_ref->{'dns2go'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dns2go'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dns2go'}{'port'}{'tcp'} = '1227'	; 
#	$srvcobjects_ref->{'dns2go'}{'ports'}{'tcp'}{'1227'}++	; 
#	$ports_ref->{'tcp'}{'1227'}{'name'} = 'dns2go'		; 
#	$srvcobjects_ref->{'sdclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdclient'}{'port'}{'udp'} = '2310'	; 
#	$srvcobjects_ref->{'sdclient'}{'ports'}{'udp'}{'2310'}++	; 
#	$ports_ref->{'udp'}{'2310'}{'name'} = 'sdclient'		; 
#	$srvcobjects_ref->{'sdclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdclient'}{'port'}{'tcp'} = '2310'	; 
#	$srvcobjects_ref->{'sdclient'}{'ports'}{'tcp'}{'2310'}++	; 
#	$ports_ref->{'tcp'}{'2310'}{'name'} = 'sdclient'		; 
#	$srvcobjects_ref->{'netspeak-acd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netspeak-acd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-acd'}{'port'}{'udp'} = '21848'	; 
#	$srvcobjects_ref->{'netspeak-acd'}{'ports'}{'udp'}{'21848'}++	; 
#	$ports_ref->{'udp'}{'21848'}{'name'} = 'netspeak-acd'		; 
#	$srvcobjects_ref->{'netspeak-acd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netspeak-acd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netspeak-acd'}{'port'}{'tcp'} = '21848'	; 
#	$srvcobjects_ref->{'netspeak-acd'}{'ports'}{'tcp'}{'21848'}++	; 
#	$ports_ref->{'tcp'}{'21848'}{'name'} = 'netspeak-acd'		; 
#	$srvcobjects_ref->{'hacl-probe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-probe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-probe'}{'port'}{'udp'} = '5303'	; 
#	$srvcobjects_ref->{'hacl-probe'}{'ports'}{'udp'}{'5303'}++	; 
#	$ports_ref->{'udp'}{'5303'}{'name'} = 'hacl-probe'		; 
#	$srvcobjects_ref->{'hacl-probe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-probe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-probe'}{'port'}{'tcp'} = '5303'	; 
#	$srvcobjects_ref->{'hacl-probe'}{'ports'}{'tcp'}{'5303'}++	; 
#	$ports_ref->{'tcp'}{'5303'}{'name'} = 'hacl-probe'		; 
#	$srvcobjects_ref->{'g-talk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'g-talk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'g-talk'}{'port'}{'udp'} = '2421'	; 
#	$srvcobjects_ref->{'g-talk'}{'ports'}{'udp'}{'2421'}++	; 
#	$ports_ref->{'udp'}{'2421'}{'name'} = 'g-talk'		; 
#	$srvcobjects_ref->{'g-talk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'g-talk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'g-talk'}{'port'}{'tcp'} = '2421'	; 
#	$srvcobjects_ref->{'g-talk'}{'ports'}{'tcp'}{'2421'}++	; 
#	$ports_ref->{'tcp'}{'2421'}{'name'} = 'g-talk'		; 
#	$srvcobjects_ref->{'scservp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scservp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scservp'}{'port'}{'udp'} = '3637'	; 
#	$srvcobjects_ref->{'scservp'}{'ports'}{'udp'}{'3637'}++	; 
#	$ports_ref->{'udp'}{'3637'}{'name'} = 'scservp'		; 
#	$srvcobjects_ref->{'scservp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scservp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scservp'}{'port'}{'tcp'} = '3637'	; 
#	$srvcobjects_ref->{'scservp'}{'ports'}{'tcp'}{'3637'}++	; 
#	$ports_ref->{'tcp'}{'3637'}{'name'} = 'scservp'		; 
#	$srvcobjects_ref->{'davsrc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'davsrc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'davsrc'}{'port'}{'udp'} = '9800'	; 
#	$srvcobjects_ref->{'davsrc'}{'ports'}{'udp'}{'9800'}++	; 
#	$ports_ref->{'udp'}{'9800'}{'name'} = 'davsrc'		; 
#	$srvcobjects_ref->{'davsrc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'davsrc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'davsrc'}{'port'}{'tcp'} = '9800'	; 
#	$srvcobjects_ref->{'davsrc'}{'ports'}{'tcp'}{'9800'}++	; 
#	$ports_ref->{'tcp'}{'9800'}{'name'} = 'davsrc'		; 
#	$srvcobjects_ref->{'alarm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alarm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alarm'}{'port'}{'udp'} = '2740'	; 
#	$srvcobjects_ref->{'alarm'}{'ports'}{'udp'}{'2740'}++	; 
#	$ports_ref->{'udp'}{'2740'}{'name'} = 'alarm'		; 
#	$srvcobjects_ref->{'alarm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alarm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alarm'}{'port'}{'tcp'} = '2740'	; 
#	$srvcobjects_ref->{'alarm'}{'ports'}{'tcp'}{'2740'}++	; 
#	$ports_ref->{'tcp'}{'2740'}{'name'} = 'alarm'		; 
#	$srvcobjects_ref->{'ns-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ns-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ns-server'}{'port'}{'udp'} = '5415'	; 
#	$srvcobjects_ref->{'ns-server'}{'ports'}{'udp'}{'5415'}++	; 
#	$ports_ref->{'udp'}{'5415'}{'name'} = 'ns-server'		; 
#	$srvcobjects_ref->{'ns-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ns-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ns-server'}{'port'}{'tcp'} = '5415'	; 
#	$srvcobjects_ref->{'ns-server'}{'ports'}{'tcp'}{'5415'}++	; 
#	$ports_ref->{'tcp'}{'5415'}{'name'} = 'ns-server'		; 
#	$srvcobjects_ref->{'multiplex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'multiplex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'multiplex'}{'port'}{'udp'} = '171'	; 
#	$srvcobjects_ref->{'multiplex'}{'ports'}{'udp'}{'171'}++	; 
#	$ports_ref->{'udp'}{'171'}{'name'} = 'multiplex'		; 
#	$srvcobjects_ref->{'multiplex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'multiplex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'multiplex'}{'port'}{'tcp'} = '171'	; 
#	$srvcobjects_ref->{'multiplex'}{'ports'}{'tcp'}{'171'}++	; 
#	$ports_ref->{'tcp'}{'171'}{'name'} = 'multiplex'		; 
#	$srvcobjects_ref->{'embl-ndt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'embl-ndt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'embl-ndt'}{'port'}{'udp'} = '394'	; 
#	$srvcobjects_ref->{'embl-ndt'}{'ports'}{'udp'}{'394'}++	; 
#	$ports_ref->{'udp'}{'394'}{'name'} = 'embl-ndt'		; 
#	$srvcobjects_ref->{'embl-ndt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'embl-ndt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'embl-ndt'}{'port'}{'tcp'} = '394'	; 
#	$srvcobjects_ref->{'embl-ndt'}{'ports'}{'tcp'}{'394'}++	; 
#	$ports_ref->{'tcp'}{'394'}{'name'} = 'embl-ndt'		; 
#	$srvcobjects_ref->{'iberiagames'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iberiagames'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iberiagames'}{'port'}{'udp'} = '1726'	; 
#	$srvcobjects_ref->{'iberiagames'}{'ports'}{'udp'}{'1726'}++	; 
#	$ports_ref->{'udp'}{'1726'}{'name'} = 'iberiagames'		; 
#	$srvcobjects_ref->{'iberiagames'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iberiagames'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iberiagames'}{'port'}{'tcp'} = '1726'	; 
#	$srvcobjects_ref->{'iberiagames'}{'ports'}{'tcp'}{'1726'}++	; 
#	$ports_ref->{'tcp'}{'1726'}{'name'} = 'iberiagames'		; 
#	$srvcobjects_ref->{'smpnameres'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smpnameres'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpnameres'}{'port'}{'udp'} = '901'	; 
#	$srvcobjects_ref->{'smpnameres'}{'ports'}{'udp'}{'901'}++	; 
#	$ports_ref->{'udp'}{'901'}{'name'} = 'smpnameres'		; 
#	$srvcobjects_ref->{'smpnameres'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smpnameres'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpnameres'}{'port'}{'tcp'} = '901'	; 
#	$srvcobjects_ref->{'smpnameres'}{'ports'}{'tcp'}{'901'}++	; 
#	$ports_ref->{'tcp'}{'901'}{'name'} = 'smpnameres'		; 
#	$srvcobjects_ref->{'silkmeter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'silkmeter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkmeter'}{'port'}{'udp'} = '5461'	; 
#	$srvcobjects_ref->{'silkmeter'}{'ports'}{'udp'}{'5461'}++	; 
#	$ports_ref->{'udp'}{'5461'}{'name'} = 'silkmeter'		; 
#	$srvcobjects_ref->{'silkmeter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'silkmeter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkmeter'}{'port'}{'tcp'} = '5461'	; 
#	$srvcobjects_ref->{'silkmeter'}{'ports'}{'tcp'}{'5461'}++	; 
#	$ports_ref->{'tcp'}{'5461'}{'name'} = 'silkmeter'		; 
#	$srvcobjects_ref->{'unifyadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unifyadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unifyadmin'}{'port'}{'udp'} = '2696'	; 
#	$srvcobjects_ref->{'unifyadmin'}{'ports'}{'udp'}{'2696'}++	; 
#	$ports_ref->{'udp'}{'2696'}{'name'} = 'unifyadmin'		; 
#	$srvcobjects_ref->{'unifyadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unifyadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unifyadmin'}{'port'}{'tcp'} = '2696'	; 
#	$srvcobjects_ref->{'unifyadmin'}{'ports'}{'tcp'}{'2696'}++	; 
#	$ports_ref->{'tcp'}{'2696'}{'name'} = 'unifyadmin'		; 
#	$srvcobjects_ref->{'statusd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'statusd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statusd'}{'port'}{'udp'} = '5414'	; 
#	$srvcobjects_ref->{'statusd'}{'ports'}{'udp'}{'5414'}++	; 
#	$ports_ref->{'udp'}{'5414'}{'name'} = 'statusd'		; 
#	$srvcobjects_ref->{'statusd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'statusd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'statusd'}{'port'}{'tcp'} = '5414'	; 
#	$srvcobjects_ref->{'statusd'}{'ports'}{'tcp'}{'5414'}++	; 
#	$ports_ref->{'tcp'}{'5414'}{'name'} = 'statusd'		; 
#	$srvcobjects_ref->{'prm-sm-np'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prm-sm-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-sm-np'}{'port'}{'udp'} = '1402'	; 
#	$srvcobjects_ref->{'prm-sm-np'}{'ports'}{'udp'}{'1402'}++	; 
#	$ports_ref->{'udp'}{'1402'}{'name'} = 'prm-sm-np'		; 
#	$srvcobjects_ref->{'prm-sm-np'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prm-sm-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-sm-np'}{'port'}{'tcp'} = '1402'	; 
#	$srvcobjects_ref->{'prm-sm-np'}{'ports'}{'tcp'}{'1402'}++	; 
#	$ports_ref->{'tcp'}{'1402'}{'name'} = 'prm-sm-np'		; 
#	$srvcobjects_ref->{'vpvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpvc'}{'port'}{'udp'} = '1519'	; 
#	$srvcobjects_ref->{'vpvc'}{'ports'}{'udp'}{'1519'}++	; 
#	$ports_ref->{'udp'}{'1519'}{'name'} = 'vpvc'		; 
#	$srvcobjects_ref->{'vpvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpvc'}{'port'}{'tcp'} = '1519'	; 
#	$srvcobjects_ref->{'vpvc'}{'ports'}{'tcp'}{'1519'}++	; 
#	$ports_ref->{'tcp'}{'1519'}{'name'} = 'vpvc'		; 
#	$srvcobjects_ref->{'callbook'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'callbook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'callbook'}{'port'}{'udp'} = '2000'	; 
#	$srvcobjects_ref->{'callbook'}{'ports'}{'udp'}{'2000'}++	; 
#	$ports_ref->{'udp'}{'2000'}{'name'} = 'callbook'		; 
#	$srvcobjects_ref->{'callbook'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'callbook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'callbook'}{'port'}{'tcp'} = '2000'	; 
#	$srvcobjects_ref->{'callbook'}{'ports'}{'tcp'}{'2000'}++	; 
#	$ports_ref->{'tcp'}{'2000'}{'name'} = 'callbook'		; 
#	$srvcobjects_ref->{'juxml-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'juxml-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'juxml-port'}{'port'}{'udp'} = '3642'	; 
#	$srvcobjects_ref->{'juxml-port'}{'ports'}{'udp'}{'3642'}++	; 
#	$ports_ref->{'udp'}{'3642'}{'name'} = 'juxml-port'		; 
#	$srvcobjects_ref->{'juxml-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'juxml-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'juxml-port'}{'port'}{'tcp'} = '3642'	; 
#	$srvcobjects_ref->{'juxml-port'}{'ports'}{'tcp'}{'3642'}++	; 
#	$ports_ref->{'tcp'}{'3642'}{'name'} = 'juxml-port'		; 
#	$srvcobjects_ref->{'collaborator'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'collaborator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'collaborator'}{'port'}{'udp'} = '622'	; 
#	$srvcobjects_ref->{'collaborator'}{'ports'}{'udp'}{'622'}++	; 
#	$ports_ref->{'udp'}{'622'}{'name'} = 'collaborator'		; 
#	$srvcobjects_ref->{'collaborator'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'collaborator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'collaborator'}{'port'}{'tcp'} = '622'	; 
#	$srvcobjects_ref->{'collaborator'}{'ports'}{'tcp'}{'622'}++	; 
#	$ports_ref->{'tcp'}{'622'}{'name'} = 'collaborator'		; 
#	$srvcobjects_ref->{'gamegen1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gamegen1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gamegen1'}{'port'}{'udp'} = '1738'	; 
#	$srvcobjects_ref->{'gamegen1'}{'ports'}{'udp'}{'1738'}++	; 
#	$ports_ref->{'udp'}{'1738'}{'name'} = 'gamegen1'		; 
#	$srvcobjects_ref->{'gamegen1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gamegen1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gamegen1'}{'port'}{'tcp'} = '1738'	; 
#	$srvcobjects_ref->{'gamegen1'}{'ports'}{'tcp'}{'1738'}++	; 
#	$ports_ref->{'tcp'}{'1738'}{'name'} = 'gamegen1'		; 
#	$srvcobjects_ref->{'murx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'murx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'murx'}{'port'}{'udp'} = '2743'	; 
#	$srvcobjects_ref->{'murx'}{'ports'}{'udp'}{'2743'}++	; 
#	$ports_ref->{'udp'}{'2743'}{'name'} = 'murx'		; 
#	$srvcobjects_ref->{'murx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'murx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'murx'}{'port'}{'tcp'} = '2743'	; 
#	$srvcobjects_ref->{'murx'}{'ports'}{'tcp'}{'2743'}++	; 
#	$ports_ref->{'tcp'}{'2743'}{'name'} = 'murx'		; 
#	$srvcobjects_ref->{'mgxswitch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mgxswitch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mgxswitch'}{'port'}{'udp'} = '3070'	; 
#	$srvcobjects_ref->{'mgxswitch'}{'ports'}{'udp'}{'3070'}++	; 
#	$ports_ref->{'udp'}{'3070'}{'name'} = 'mgxswitch'		; 
#	$srvcobjects_ref->{'mgxswitch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mgxswitch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mgxswitch'}{'port'}{'tcp'} = '3070'	; 
#	$srvcobjects_ref->{'mgxswitch'}{'ports'}{'tcp'}{'3070'}++	; 
#	$ports_ref->{'tcp'}{'3070'}{'name'} = 'mgxswitch'		; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'port'}{'udp'} = '5674'	; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'ports'}{'udp'}{'5674'}++	; 
#	$ports_ref->{'udp'}{'5674'}{'name'} = 'hyperscsi-port'		; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'port'}{'tcp'} = '5674'	; 
#	$srvcobjects_ref->{'hyperscsi-port'}{'ports'}{'tcp'}{'5674'}++	; 
#	$ports_ref->{'tcp'}{'5674'}{'name'} = 'hyperscsi-port'		; 
#	$srvcobjects_ref->{'sftu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sftu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftu'}{'port'}{'udp'} = '3326'	; 
#	$srvcobjects_ref->{'sftu'}{'ports'}{'udp'}{'3326'}++	; 
#	$ports_ref->{'udp'}{'3326'}{'name'} = 'sftu'		; 
#	$srvcobjects_ref->{'sftu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sftu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftu'}{'port'}{'tcp'} = '3326'	; 
#	$srvcobjects_ref->{'sftu'}{'ports'}{'tcp'}{'3326'}++	; 
#	$ports_ref->{'tcp'}{'3326'}{'name'} = 'sftu'		; 
#	$srvcobjects_ref->{'ddi-udp-5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddi-udp-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-udp-5'}{'port'}{'udp'} = '8892'	; 
#	$srvcobjects_ref->{'ddi-udp-5'}{'ports'}{'udp'}{'8892'}++	; 
#	$ports_ref->{'udp'}{'8892'}{'name'} = 'ddi-udp-5'		; 
#	$srvcobjects_ref->{'cslistener'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cslistener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cslistener'}{'port'}{'udp'} = '9000'	; 
#	$srvcobjects_ref->{'cslistener'}{'ports'}{'udp'}{'9000'}++	; 
#	$ports_ref->{'udp'}{'9000'}{'name'} = 'cslistener'		; 
#	$srvcobjects_ref->{'cslistener'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cslistener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cslistener'}{'port'}{'tcp'} = '9000'	; 
#	$srvcobjects_ref->{'cslistener'}{'ports'}{'tcp'}{'9000'}++	; 
#	$ports_ref->{'tcp'}{'9000'}{'name'} = 'cslistener'		; 
#	$srvcobjects_ref->{'sdp-id-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdp-id-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdp-id-port'}{'port'}{'udp'} = '3242'	; 
#	$srvcobjects_ref->{'sdp-id-port'}{'ports'}{'udp'}{'3242'}++	; 
#	$ports_ref->{'udp'}{'3242'}{'name'} = 'sdp-id-port'		; 
#	$srvcobjects_ref->{'sdp-id-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdp-id-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdp-id-port'}{'port'}{'tcp'} = '3242'	; 
#	$srvcobjects_ref->{'sdp-id-port'}{'ports'}{'tcp'}{'3242'}++	; 
#	$ports_ref->{'tcp'}{'3242'}{'name'} = 'sdp-id-port'		; 
#	$srvcobjects_ref->{'priority-e-com'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'priority-e-com'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'priority-e-com'}{'port'}{'udp'} = '2618'	; 
#	$srvcobjects_ref->{'priority-e-com'}{'ports'}{'udp'}{'2618'}++	; 
#	$ports_ref->{'udp'}{'2618'}{'name'} = 'priority-e-com'		; 
#	$srvcobjects_ref->{'priority-e-com'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'priority-e-com'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'priority-e-com'}{'port'}{'tcp'} = '2618'	; 
#	$srvcobjects_ref->{'priority-e-com'}{'ports'}{'tcp'}{'2618'}++	; 
#	$ports_ref->{'tcp'}{'2618'}{'name'} = 'priority-e-com'		; 
#	$srvcobjects_ref->{'fastechnologlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fastechnologlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fastechnologlm'}{'port'}{'udp'} = '1074'	; 
#	$srvcobjects_ref->{'fastechnologlm'}{'ports'}{'udp'}{'1074'}++	; 
#	$ports_ref->{'udp'}{'1074'}{'name'} = 'fastechnologlm'		; 
#	$srvcobjects_ref->{'fastechnologlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fastechnologlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fastechnologlm'}{'port'}{'tcp'} = '1074'	; 
#	$srvcobjects_ref->{'fastechnologlm'}{'ports'}{'tcp'}{'1074'}++	; 
#	$ports_ref->{'tcp'}{'1074'}{'name'} = 'fastechnologlm'		; 
#	$srvcobjects_ref->{'navisphere'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'navisphere'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navisphere'}{'port'}{'udp'} = '2162'	; 
#	$srvcobjects_ref->{'navisphere'}{'ports'}{'udp'}{'2162'}++	; 
#	$ports_ref->{'udp'}{'2162'}{'name'} = 'navisphere'		; 
#	$srvcobjects_ref->{'navisphere'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'navisphere'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'navisphere'}{'port'}{'tcp'} = '2162'	; 
#	$srvcobjects_ref->{'navisphere'}{'ports'}{'tcp'}{'2162'}++	; 
#	$ports_ref->{'tcp'}{'2162'}{'name'} = 'navisphere'		; 
#	$srvcobjects_ref->{'faximum'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'faximum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'faximum'}{'port'}{'udp'} = '7437'	; 
#	$srvcobjects_ref->{'faximum'}{'ports'}{'udp'}{'7437'}++	; 
#	$ports_ref->{'udp'}{'7437'}{'name'} = 'faximum'		; 
#	$srvcobjects_ref->{'faximum'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'faximum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'faximum'}{'port'}{'tcp'} = '7437'	; 
#	$srvcobjects_ref->{'faximum'}{'ports'}{'tcp'}{'7437'}++	; 
#	$ports_ref->{'tcp'}{'7437'}{'name'} = 'faximum'		; 
#	$srvcobjects_ref->{'allstorcns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'allstorcns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'allstorcns'}{'port'}{'udp'} = '2901'	; 
#	$srvcobjects_ref->{'allstorcns'}{'ports'}{'udp'}{'2901'}++	; 
#	$ports_ref->{'udp'}{'2901'}{'name'} = 'allstorcns'		; 
#	$srvcobjects_ref->{'allstorcns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'allstorcns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'allstorcns'}{'port'}{'tcp'} = '2901'	; 
#	$srvcobjects_ref->{'allstorcns'}{'ports'}{'tcp'}{'2901'}++	; 
#	$ports_ref->{'tcp'}{'2901'}{'name'} = 'allstorcns'		; 
#	$srvcobjects_ref->{'pcsync-https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcsync-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcsync-https'}{'port'}{'udp'} = '8443'	; 
#	$srvcobjects_ref->{'pcsync-https'}{'ports'}{'udp'}{'8443'}++	; 
#	$ports_ref->{'udp'}{'8443'}{'name'} = 'pcsync-https'		; 
#	$srvcobjects_ref->{'pcsync-https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcsync-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcsync-https'}{'port'}{'tcp'} = '8443'	; 
#	$srvcobjects_ref->{'pcsync-https'}{'ports'}{'tcp'}{'8443'}++	; 
#	$ports_ref->{'tcp'}{'8443'}{'name'} = 'pcsync-https'		; 
#	$srvcobjects_ref->{'radmin-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radmin-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radmin-port'}{'port'}{'udp'} = '4899'	; 
#	$srvcobjects_ref->{'radmin-port'}{'ports'}{'udp'}{'4899'}++	; 
#	$ports_ref->{'udp'}{'4899'}{'name'} = 'radmin-port'		; 
#	$srvcobjects_ref->{'radmin-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radmin-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radmin-port'}{'port'}{'tcp'} = '4899'	; 
#	$srvcobjects_ref->{'radmin-port'}{'ports'}{'tcp'}{'4899'}++	; 
#	$ports_ref->{'tcp'}{'4899'}{'name'} = 'radmin-port'		; 
#	$srvcobjects_ref->{'cableport-ax'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cableport-ax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cableport-ax'}{'port'}{'udp'} = '282'	; 
#	$srvcobjects_ref->{'cableport-ax'}{'ports'}{'udp'}{'282'}++	; 
#	$ports_ref->{'udp'}{'282'}{'name'} = 'cableport-ax'		; 
#	$srvcobjects_ref->{'cableport-ax'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cableport-ax'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cableport-ax'}{'port'}{'tcp'} = '282'	; 
#	$srvcobjects_ref->{'cableport-ax'}{'ports'}{'tcp'}{'282'}++	; 
#	$ports_ref->{'tcp'}{'282'}{'name'} = 'cableport-ax'		; 
#	$srvcobjects_ref->{'ultimad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ultimad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultimad'}{'port'}{'udp'} = '1737'	; 
#	$srvcobjects_ref->{'ultimad'}{'ports'}{'udp'}{'1737'}++	; 
#	$ports_ref->{'udp'}{'1737'}{'name'} = 'ultimad'		; 
#	$srvcobjects_ref->{'ultimad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ultimad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultimad'}{'port'}{'tcp'} = '1737'	; 
#	$srvcobjects_ref->{'ultimad'}{'ports'}{'tcp'}{'1737'}++	; 
#	$ports_ref->{'tcp'}{'1737'}{'name'} = 'ultimad'		; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'port'}{'udp'} = '476'	; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'ports'}{'udp'}{'476'}++	; 
#	$ports_ref->{'udp'}{'476'}{'name'} = 'tn-tl-fd1'		; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'port'}{'tcp'} = '476'	; 
#	$srvcobjects_ref->{'tn-tl-fd1'}{'ports'}{'tcp'}{'476'}++	; 
#	$ports_ref->{'tcp'}{'476'}{'name'} = 'tn-tl-fd1'		; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'port'}{'udp'} = '1220'	; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'ports'}{'udp'}{'1220'}++	; 
#	$ports_ref->{'udp'}{'1220'}{'name'} = 'qt-serveradmin'		; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'port'}{'tcp'} = '1220'	; 
#	$srvcobjects_ref->{'qt-serveradmin'}{'ports'}{'tcp'}{'1220'}++	; 
#	$ports_ref->{'tcp'}{'1220'}{'name'} = 'qt-serveradmin'		; 
#	$srvcobjects_ref->{'ivcollector'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ivcollector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivcollector'}{'port'}{'udp'} = '1275'	; 
#	$srvcobjects_ref->{'ivcollector'}{'ports'}{'udp'}{'1275'}++	; 
#	$ports_ref->{'udp'}{'1275'}{'name'} = 'ivcollector'		; 
#	$srvcobjects_ref->{'ivcollector'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ivcollector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivcollector'}{'port'}{'tcp'} = '1275'	; 
#	$srvcobjects_ref->{'ivcollector'}{'ports'}{'tcp'}{'1275'}++	; 
#	$ports_ref->{'tcp'}{'1275'}{'name'} = 'ivcollector'		; 
#	$srvcobjects_ref->{'xns-auth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xns-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-auth'}{'port'}{'udp'} = '56'	; 
#	$srvcobjects_ref->{'xns-auth'}{'ports'}{'udp'}{'56'}++	; 
#	$ports_ref->{'udp'}{'56'}{'name'} = 'xns-auth'		; 
#	$srvcobjects_ref->{'xns-auth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xns-auth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-auth'}{'port'}{'tcp'} = '56'	; 
#	$srvcobjects_ref->{'xns-auth'}{'ports'}{'tcp'}{'56'}++	; 
#	$ports_ref->{'tcp'}{'56'}{'name'} = 'xns-auth'		; 
#	$srvcobjects_ref->{'objectmanager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'objectmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'objectmanager'}{'port'}{'udp'} = '2038'	; 
#	$srvcobjects_ref->{'objectmanager'}{'ports'}{'udp'}{'2038'}++	; 
#	$ports_ref->{'udp'}{'2038'}{'name'} = 'objectmanager'		; 
#	$srvcobjects_ref->{'objectmanager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'objectmanager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'objectmanager'}{'port'}{'tcp'} = '2038'	; 
#	$srvcobjects_ref->{'objectmanager'}{'ports'}{'tcp'}{'2038'}++	; 
#	$ports_ref->{'tcp'}{'2038'}{'name'} = 'objectmanager'		; 
#	$srvcobjects_ref->{'hicp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hicp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hicp'}{'port'}{'udp'} = '3250'	; 
#	$srvcobjects_ref->{'hicp'}{'ports'}{'udp'}{'3250'}++	; 
#	$ports_ref->{'udp'}{'3250'}{'name'} = 'hicp'		; 
#	$srvcobjects_ref->{'hicp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hicp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hicp'}{'port'}{'tcp'} = '3250'	; 
#	$srvcobjects_ref->{'hicp'}{'ports'}{'tcp'}{'3250'}++	; 
#	$ports_ref->{'tcp'}{'3250'}{'name'} = 'hicp'		; 
#	$srvcobjects_ref->{'ibp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibp'}{'port'}{'udp'} = '2572'	; 
#	$srvcobjects_ref->{'ibp'}{'ports'}{'udp'}{'2572'}++	; 
#	$ports_ref->{'udp'}{'2572'}{'name'} = 'ibp'		; 
#	$srvcobjects_ref->{'ibp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibp'}{'port'}{'tcp'} = '2572'	; 
#	$srvcobjects_ref->{'ibp'}{'ports'}{'tcp'}{'2572'}++	; 
#	$ports_ref->{'tcp'}{'2572'}{'name'} = 'ibp'		; 
#	$srvcobjects_ref->{'ibm-res'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-res'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-res'}{'port'}{'udp'} = '1405'	; 
#	$srvcobjects_ref->{'ibm-res'}{'ports'}{'udp'}{'1405'}++	; 
#	$ports_ref->{'udp'}{'1405'}{'name'} = 'ibm-res'		; 
#	$srvcobjects_ref->{'ibm-res'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-res'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-res'}{'port'}{'tcp'} = '1405'	; 
#	$srvcobjects_ref->{'ibm-res'}{'ports'}{'tcp'}{'1405'}++	; 
#	$ports_ref->{'tcp'}{'1405'}{'name'} = 'ibm-res'		; 
#	$srvcobjects_ref->{'shivahose'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shivahose'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shivahose'}{'port'}{'tcp'} = '1549'	; 
#	$srvcobjects_ref->{'shivahose'}{'ports'}{'tcp'}{'1549'}++	; 
#	$ports_ref->{'tcp'}{'1549'}{'name'} = 'shivahose'		; 
#	$srvcobjects_ref->{'designspace-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'designspace-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'designspace-lm'}{'port'}{'udp'} = '2325'	; 
#	$srvcobjects_ref->{'designspace-lm'}{'ports'}{'udp'}{'2325'}++	; 
#	$ports_ref->{'udp'}{'2325'}{'name'} = 'designspace-lm'		; 
#	$srvcobjects_ref->{'designspace-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'designspace-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'designspace-lm'}{'port'}{'tcp'} = '2325'	; 
#	$srvcobjects_ref->{'designspace-lm'}{'ports'}{'tcp'}{'2325'}++	; 
#	$ports_ref->{'tcp'}{'2325'}{'name'} = 'designspace-lm'		; 
#	$srvcobjects_ref->{'ndsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndsp'}{'port'}{'udp'} = '2881'	; 
#	$srvcobjects_ref->{'ndsp'}{'ports'}{'udp'}{'2881'}++	; 
#	$ports_ref->{'udp'}{'2881'}{'name'} = 'ndsp'		; 
#	$srvcobjects_ref->{'ndsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndsp'}{'port'}{'tcp'} = '2881'	; 
#	$srvcobjects_ref->{'ndsp'}{'ports'}{'tcp'}{'2881'}++	; 
#	$ports_ref->{'tcp'}{'2881'}{'name'} = 'ndsp'		; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'port'}{'udp'} = '3086'	; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'ports'}{'udp'}{'3086'}++	; 
#	$ports_ref->{'udp'}{'3086'}{'name'} = 'jdl-dbkitchen'		; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'port'}{'tcp'} = '3086'	; 
#	$srvcobjects_ref->{'jdl-dbkitchen'}{'ports'}{'tcp'}{'3086'}++	; 
#	$ports_ref->{'tcp'}{'3086'}{'name'} = 'jdl-dbkitchen'		; 
#	$srvcobjects_ref->{'med-ci'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'med-ci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-ci'}{'port'}{'udp'} = '24005'	; 
#	$srvcobjects_ref->{'med-ci'}{'ports'}{'udp'}{'24005'}++	; 
#	$ports_ref->{'udp'}{'24005'}{'name'} = 'med-ci'		; 
#	$srvcobjects_ref->{'med-ci'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'med-ci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-ci'}{'port'}{'tcp'} = '24005'	; 
#	$srvcobjects_ref->{'med-ci'}{'ports'}{'tcp'}{'24005'}++	; 
#	$ports_ref->{'tcp'}{'24005'}{'name'} = 'med-ci'		; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'port'}{'udp'} = '3034'	; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'ports'}{'udp'}{'3034'}++	; 
#	$ports_ref->{'udp'}{'3034'}{'name'} = 'osmosis-aeea'		; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'port'}{'tcp'} = '3034'	; 
#	$srvcobjects_ref->{'osmosis-aeea'}{'ports'}{'tcp'}{'3034'}++	; 
#	$ports_ref->{'tcp'}{'3034'}{'name'} = 'osmosis-aeea'		; 
#	$srvcobjects_ref->{'six-degrees'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'six-degrees'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'six-degrees'}{'port'}{'udp'} = '3611'	; 
#	$srvcobjects_ref->{'six-degrees'}{'ports'}{'udp'}{'3611'}++	; 
#	$ports_ref->{'udp'}{'3611'}{'name'} = 'six-degrees'		; 
#	$srvcobjects_ref->{'six-degrees'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'six-degrees'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'six-degrees'}{'port'}{'tcp'} = '3611'	; 
#	$srvcobjects_ref->{'six-degrees'}{'ports'}{'tcp'}{'3611'}++	; 
#	$ports_ref->{'tcp'}{'3611'}{'name'} = 'six-degrees'		; 
#	$srvcobjects_ref->{'rsisysaccess'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsisysaccess'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsisysaccess'}{'port'}{'udp'} = '2752'	; 
#	$srvcobjects_ref->{'rsisysaccess'}{'ports'}{'udp'}{'2752'}++	; 
#	$ports_ref->{'udp'}{'2752'}{'name'} = 'rsisysaccess'		; 
#	$srvcobjects_ref->{'rsisysaccess'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsisysaccess'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsisysaccess'}{'port'}{'tcp'} = '2752'	; 
#	$srvcobjects_ref->{'rsisysaccess'}{'ports'}{'tcp'}{'2752'}++	; 
#	$ports_ref->{'tcp'}{'2752'}{'name'} = 'rsisysaccess'		; 
#	$srvcobjects_ref->{'vslmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vslmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vslmp'}{'port'}{'udp'} = '312'	; 
#	$srvcobjects_ref->{'vslmp'}{'ports'}{'udp'}{'312'}++	; 
#	$ports_ref->{'udp'}{'312'}{'name'} = 'vslmp'		; 
#	$srvcobjects_ref->{'vslmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vslmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vslmp'}{'port'}{'tcp'} = '312'	; 
#	$srvcobjects_ref->{'vslmp'}{'ports'}{'tcp'}{'312'}++	; 
#	$ports_ref->{'tcp'}{'312'}{'name'} = 'vslmp'		; 
#	$srvcobjects_ref->{'apple-sasl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apple-sasl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apple-sasl'}{'port'}{'udp'} = '3659'	; 
#	$srvcobjects_ref->{'apple-sasl'}{'ports'}{'udp'}{'3659'}++	; 
#	$ports_ref->{'udp'}{'3659'}{'name'} = 'apple-sasl'		; 
#	$srvcobjects_ref->{'apple-sasl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apple-sasl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apple-sasl'}{'port'}{'tcp'} = '3659'	; 
#	$srvcobjects_ref->{'apple-sasl'}{'ports'}{'tcp'}{'3659'}++	; 
#	$ports_ref->{'tcp'}{'3659'}{'name'} = 'apple-sasl'		; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'port'}{'udp'} = '2080'	; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'ports'}{'udp'}{'2080'}++	; 
#	$ports_ref->{'udp'}{'2080'}{'name'} = 'autodesk-nlm'		; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'port'}{'tcp'} = '2080'	; 
#	$srvcobjects_ref->{'autodesk-nlm'}{'ports'}{'tcp'}{'2080'}++	; 
#	$ports_ref->{'tcp'}{'2080'}{'name'} = 'autodesk-nlm'		; 
#	$srvcobjects_ref->{'gdbremote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gdbremote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdbremote'}{'port'}{'udp'} = '2159'	; 
#	$srvcobjects_ref->{'gdbremote'}{'ports'}{'udp'}{'2159'}++	; 
#	$ports_ref->{'udp'}{'2159'}{'name'} = 'gdbremote'		; 
#	$srvcobjects_ref->{'gdbremote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gdbremote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gdbremote'}{'port'}{'tcp'} = '2159'	; 
#	$srvcobjects_ref->{'gdbremote'}{'ports'}{'tcp'}{'2159'}++	; 
#	$ports_ref->{'tcp'}{'2159'}{'name'} = 'gdbremote'		; 
#	$srvcobjects_ref->{'netopia-vo2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netopia-vo2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo2'}{'port'}{'udp'} = '1840'	; 
#	$srvcobjects_ref->{'netopia-vo2'}{'ports'}{'udp'}{'1840'}++	; 
#	$ports_ref->{'udp'}{'1840'}{'name'} = 'netopia-vo2'		; 
#	$srvcobjects_ref->{'netopia-vo2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netopia-vo2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netopia-vo2'}{'port'}{'tcp'} = '1840'	; 
#	$srvcobjects_ref->{'netopia-vo2'}{'ports'}{'tcp'}{'1840'}++	; 
#	$ports_ref->{'tcp'}{'1840'}{'name'} = 'netopia-vo2'		; 
#	$srvcobjects_ref->{'ff-fms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ff-fms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-fms'}{'port'}{'udp'} = '1090'	; 
#	$srvcobjects_ref->{'ff-fms'}{'ports'}{'udp'}{'1090'}++	; 
#	$ports_ref->{'udp'}{'1090'}{'name'} = 'ff-fms'		; 
#	$srvcobjects_ref->{'ff-fms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ff-fms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-fms'}{'port'}{'tcp'} = '1090'	; 
#	$srvcobjects_ref->{'ff-fms'}{'ports'}{'tcp'}{'1090'}++	; 
#	$ports_ref->{'tcp'}{'1090'}{'name'} = 'ff-fms'		; 
#	$srvcobjects_ref->{'questnotify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'questnotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'questnotify'}{'port'}{'udp'} = '3554'	; 
#	$srvcobjects_ref->{'questnotify'}{'ports'}{'udp'}{'3554'}++	; 
#	$ports_ref->{'udp'}{'3554'}{'name'} = 'questnotify'		; 
#	$srvcobjects_ref->{'questnotify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'questnotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'questnotify'}{'port'}{'tcp'} = '3554'	; 
#	$srvcobjects_ref->{'questnotify'}{'ports'}{'tcp'}{'3554'}++	; 
#	$ports_ref->{'tcp'}{'3554'}{'name'} = 'questnotify'		; 
#	$srvcobjects_ref->{'mphlpdmc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mphlpdmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mphlpdmc'}{'port'}{'udp'} = '9344'	; 
#	$srvcobjects_ref->{'mphlpdmc'}{'ports'}{'udp'}{'9344'}++	; 
#	$ports_ref->{'udp'}{'9344'}{'name'} = 'mphlpdmc'		; 
#	$srvcobjects_ref->{'mphlpdmc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mphlpdmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mphlpdmc'}{'port'}{'tcp'} = '9344'	; 
#	$srvcobjects_ref->{'mphlpdmc'}{'ports'}{'tcp'}{'9344'}++	; 
#	$ports_ref->{'tcp'}{'9344'}{'name'} = 'mphlpdmc'		; 
#	$srvcobjects_ref->{'zannet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zannet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zannet'}{'port'}{'udp'} = '317'	; 
#	$srvcobjects_ref->{'zannet'}{'ports'}{'udp'}{'317'}++	; 
#	$ports_ref->{'udp'}{'317'}{'name'} = 'zannet'		; 
#	$srvcobjects_ref->{'zannet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zannet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zannet'}{'port'}{'tcp'} = '317'	; 
#	$srvcobjects_ref->{'zannet'}{'ports'}{'tcp'}{'317'}++	; 
#	$ports_ref->{'tcp'}{'317'}{'name'} = 'zannet'		; 
#	$srvcobjects_ref->{'foliocorp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'foliocorp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'foliocorp'}{'port'}{'udp'} = '2242'	; 
#	$srvcobjects_ref->{'foliocorp'}{'ports'}{'udp'}{'2242'}++	; 
#	$ports_ref->{'udp'}{'2242'}{'name'} = 'foliocorp'		; 
#	$srvcobjects_ref->{'foliocorp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'foliocorp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'foliocorp'}{'port'}{'tcp'} = '2242'	; 
#	$srvcobjects_ref->{'foliocorp'}{'ports'}{'tcp'}{'2242'}++	; 
#	$ports_ref->{'tcp'}{'2242'}{'name'} = 'foliocorp'		; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'port'}{'udp'} = '3078'	; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'ports'}{'udp'}{'3078'}++	; 
#	$ports_ref->{'udp'}{'3078'}{'name'} = 'orbix-cfg-ssl'		; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'port'}{'tcp'} = '3078'	; 
#	$srvcobjects_ref->{'orbix-cfg-ssl'}{'ports'}{'tcp'}{'3078'}++	; 
#	$ports_ref->{'tcp'}{'3078'}{'name'} = 'orbix-cfg-ssl'		; 
#	$srvcobjects_ref->{'gss-xlicen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gss-xlicen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gss-xlicen'}{'port'}{'udp'} = '128'	; 
#	$srvcobjects_ref->{'gss-xlicen'}{'ports'}{'udp'}{'128'}++	; 
#	$ports_ref->{'udp'}{'128'}{'name'} = 'gss-xlicen'		; 
#	$srvcobjects_ref->{'gss-xlicen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gss-xlicen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gss-xlicen'}{'port'}{'tcp'} = '128'	; 
#	$srvcobjects_ref->{'gss-xlicen'}{'ports'}{'tcp'}{'128'}++	; 
#	$ports_ref->{'tcp'}{'128'}{'name'} = 'gss-xlicen'		; 
#	$srvcobjects_ref->{'sbook'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sbook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sbook'}{'port'}{'udp'} = '1349'	; 
#	$srvcobjects_ref->{'sbook'}{'ports'}{'udp'}{'1349'}++	; 
#	$ports_ref->{'udp'}{'1349'}{'name'} = 'sbook'		; 
#	$srvcobjects_ref->{'sbook'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sbook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sbook'}{'port'}{'tcp'} = '1349'	; 
#	$srvcobjects_ref->{'sbook'}{'ports'}{'tcp'}{'1349'}++	; 
#	$ports_ref->{'tcp'}{'1349'}{'name'} = 'sbook'		; 
#	$srvcobjects_ref->{'solve'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'solve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'solve'}{'port'}{'udp'} = '2636'	; 
#	$srvcobjects_ref->{'solve'}{'ports'}{'udp'}{'2636'}++	; 
#	$ports_ref->{'udp'}{'2636'}{'name'} = 'solve'		; 
#	$srvcobjects_ref->{'solve'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'solve'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'solve'}{'port'}{'tcp'} = '2636'	; 
#	$srvcobjects_ref->{'solve'}{'ports'}{'tcp'}{'2636'}++	; 
#	$ports_ref->{'tcp'}{'2636'}{'name'} = 'solve'		; 
#	$srvcobjects_ref->{'swift-rvf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swift-rvf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swift-rvf'}{'port'}{'udp'} = '97'	; 
#	$srvcobjects_ref->{'swift-rvf'}{'ports'}{'udp'}{'97'}++	; 
#	$ports_ref->{'udp'}{'97'}{'name'} = 'swift-rvf'		; 
#	$srvcobjects_ref->{'swift-rvf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swift-rvf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swift-rvf'}{'port'}{'tcp'} = '97'	; 
#	$srvcobjects_ref->{'swift-rvf'}{'ports'}{'tcp'}{'97'}++	; 
#	$ports_ref->{'tcp'}{'97'}{'name'} = 'swift-rvf'		; 
#	$srvcobjects_ref->{'apc-necmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-necmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-necmp'}{'port'}{'udp'} = '18888'	; 
#	$srvcobjects_ref->{'apc-necmp'}{'ports'}{'udp'}{'18888'}++	; 
#	$ports_ref->{'udp'}{'18888'}{'name'} = 'apc-necmp'		; 
#	$srvcobjects_ref->{'apc-necmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-necmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-necmp'}{'port'}{'tcp'} = '18888'	; 
#	$srvcobjects_ref->{'apc-necmp'}{'ports'}{'tcp'}{'18888'}++	; 
#	$ports_ref->{'tcp'}{'18888'}{'name'} = 'apc-necmp'		; 
#	$srvcobjects_ref->{'tellumat-nms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tellumat-nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tellumat-nms'}{'port'}{'udp'} = '3549'	; 
#	$srvcobjects_ref->{'tellumat-nms'}{'ports'}{'udp'}{'3549'}++	; 
#	$ports_ref->{'udp'}{'3549'}{'name'} = 'tellumat-nms'		; 
#	$srvcobjects_ref->{'tellumat-nms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tellumat-nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tellumat-nms'}{'port'}{'tcp'} = '3549'	; 
#	$srvcobjects_ref->{'tellumat-nms'}{'ports'}{'tcp'}{'3549'}++	; 
#	$ports_ref->{'tcp'}{'3549'}{'name'} = 'tellumat-nms'		; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'port'}{'udp'} = '3422'	; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'ports'}{'udp'}{'3422'}++	; 
#	$ports_ref->{'udp'}{'3422'}{'name'} = 'rusb-sys-port'		; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'port'}{'tcp'} = '3422'	; 
#	$srvcobjects_ref->{'rusb-sys-port'}{'ports'}{'tcp'}{'3422'}++	; 
#	$ports_ref->{'tcp'}{'3422'}{'name'} = 'rusb-sys-port'		; 
#	$srvcobjects_ref->{'manage-exec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'manage-exec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'manage-exec'}{'port'}{'udp'} = '2342'	; 
#	$srvcobjects_ref->{'manage-exec'}{'ports'}{'udp'}{'2342'}++	; 
#	$ports_ref->{'udp'}{'2342'}{'name'} = 'manage-exec'		; 
#	$srvcobjects_ref->{'manage-exec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'manage-exec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'manage-exec'}{'port'}{'tcp'} = '2342'	; 
#	$srvcobjects_ref->{'manage-exec'}{'ports'}{'tcp'}{'2342'}++	; 
#	$ports_ref->{'tcp'}{'2342'}{'name'} = 'manage-exec'		; 
#	$srvcobjects_ref->{'blueberry-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'blueberry-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blueberry-lm'}{'port'}{'udp'} = '1432'	; 
#	$srvcobjects_ref->{'blueberry-lm'}{'ports'}{'udp'}{'1432'}++	; 
#	$ports_ref->{'udp'}{'1432'}{'name'} = 'blueberry-lm'		; 
#	$srvcobjects_ref->{'blueberry-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'blueberry-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blueberry-lm'}{'port'}{'tcp'} = '1432'	; 
#	$srvcobjects_ref->{'blueberry-lm'}{'ports'}{'tcp'}{'1432'}++	; 
#	$ports_ref->{'tcp'}{'1432'}{'name'} = 'blueberry-lm'		; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'port'}{'udp'} = '1581'	; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'ports'}{'udp'}{'1581'}++	; 
#	$ports_ref->{'udp'}{'1581'}{'name'} = 'mil-2045-47001'		; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'port'}{'tcp'} = '1581'	; 
#	$srvcobjects_ref->{'mil-2045-47001'}{'ports'}{'tcp'}{'1581'}++	; 
#	$ports_ref->{'tcp'}{'1581'}{'name'} = 'mil-2045-47001'		; 
#	$srvcobjects_ref->{'uacs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uacs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uacs'}{'port'}{'udp'} = '2768'	; 
#	$srvcobjects_ref->{'uacs'}{'ports'}{'udp'}{'2768'}++	; 
#	$ports_ref->{'udp'}{'2768'}{'name'} = 'uacs'		; 
#	$srvcobjects_ref->{'uacs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uacs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uacs'}{'port'}{'tcp'} = '2768'	; 
#	$srvcobjects_ref->{'uacs'}{'ports'}{'tcp'}{'2768'}++	; 
#	$ports_ref->{'tcp'}{'2768'}{'name'} = 'uacs'		; 
#	$srvcobjects_ref->{'vsinet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsinet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsinet'}{'port'}{'udp'} = '996'	; 
#	$srvcobjects_ref->{'vsinet'}{'ports'}{'udp'}{'996'}++	; 
#	$ports_ref->{'udp'}{'996'}{'name'} = 'vsinet'		; 
#	$srvcobjects_ref->{'vsinet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsinet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsinet'}{'port'}{'tcp'} = '996'	; 
#	$srvcobjects_ref->{'vsinet'}{'ports'}{'tcp'}{'996'}++	; 
#	$ports_ref->{'tcp'}{'996'}{'name'} = 'vsinet'		; 
#	$srvcobjects_ref->{'sapv1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sapv1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sapv1'}{'port'}{'udp'} = '9875'	; 
#	$srvcobjects_ref->{'sapv1'}{'ports'}{'udp'}{'9875'}++	; 
#	$srvcobjects_ref->{'cas-mapi'}{'port'}{'tcp'} = '3682'	; 
#	$srvcobjects_ref->{'cas-mapi'}{'ports'}{'tcp'}{'3682'}++	; 
#	$ports_ref->{'tcp'}{'3682'}{'name'} = 'cas-mapi'		; 
#	$srvcobjects_ref->{'discard'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'discard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discard'}{'port'}{'udp'} = '9'	; 
#	$srvcobjects_ref->{'discard'}{'ports'}{'udp'}{'9'}++	; 
#	$ports_ref->{'udp'}{'9'}{'name'} = 'discard'		; 
#	$srvcobjects_ref->{'discard'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'discard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discard'}{'port'}{'tcp'} = '9'	; 
#	$srvcobjects_ref->{'discard'}{'ports'}{'tcp'}{'9'}++	; 
#	$ports_ref->{'tcp'}{'9'}{'name'} = 'discard'		; 
#	$srvcobjects_ref->{'epc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'epc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epc'}{'port'}{'udp'} = '1267'	; 
#	$srvcobjects_ref->{'epc'}{'ports'}{'udp'}{'1267'}++	; 
#	$ports_ref->{'udp'}{'1267'}{'name'} = 'epc'		; 
#	$srvcobjects_ref->{'epc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'epc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epc'}{'port'}{'tcp'} = '1267'	; 
#	$srvcobjects_ref->{'epc'}{'ports'}{'tcp'}{'1267'}++	; 
#	$ports_ref->{'tcp'}{'1267'}{'name'} = 'epc'		; 
#	$srvcobjects_ref->{'sqlserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sqlserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sqlserv'}{'port'}{'udp'} = '118'	; 
#	$srvcobjects_ref->{'sqlserv'}{'ports'}{'udp'}{'118'}++	; 
#	$ports_ref->{'udp'}{'118'}{'name'} = 'sqlserv'		; 
#	$srvcobjects_ref->{'sqlserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sqlserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sqlserv'}{'port'}{'tcp'} = '118'	; 
#	$srvcobjects_ref->{'sqlserv'}{'ports'}{'tcp'}{'118'}++	; 
#	$ports_ref->{'tcp'}{'118'}{'name'} = 'sqlserv'		; 
#	$srvcobjects_ref->{'ncld'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncld'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncld'}{'port'}{'udp'} = '405'	; 
#	$srvcobjects_ref->{'ncld'}{'ports'}{'udp'}{'405'}++	; 
#	$ports_ref->{'udp'}{'405'}{'name'} = 'ncld'		; 
#	$srvcobjects_ref->{'ncld'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncld'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncld'}{'port'}{'tcp'} = '405'	; 
#	$srvcobjects_ref->{'ncld'}{'ports'}{'tcp'}{'405'}++	; 
#	$ports_ref->{'tcp'}{'405'}{'name'} = 'ncld'		; 
#	$srvcobjects_ref->{'ultrex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ultrex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultrex'}{'port'}{'udp'} = '1327'	; 
#	$srvcobjects_ref->{'ultrex'}{'ports'}{'udp'}{'1327'}++	; 
#	$ports_ref->{'udp'}{'1327'}{'name'} = 'ultrex'		; 
#	$srvcobjects_ref->{'ultrex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ultrex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultrex'}{'port'}{'tcp'} = '1327'	; 
#	$srvcobjects_ref->{'ultrex'}{'ports'}{'tcp'}{'1327'}++	; 
#	$ports_ref->{'tcp'}{'1327'}{'name'} = 'ultrex'		; 
#	$srvcobjects_ref->{'xmlblaster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xmlblaster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmlblaster'}{'port'}{'udp'} = '3412'	; 
#	$srvcobjects_ref->{'xmlblaster'}{'ports'}{'udp'}{'3412'}++	; 
#	$ports_ref->{'udp'}{'3412'}{'name'} = 'xmlblaster'		; 
#	$srvcobjects_ref->{'xmlblaster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xmlblaster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmlblaster'}{'port'}{'tcp'} = '3412'	; 
#	$srvcobjects_ref->{'xmlblaster'}{'ports'}{'tcp'}{'3412'}++	; 
#	$ports_ref->{'tcp'}{'3412'}{'name'} = 'xmlblaster'		; 
#	$srvcobjects_ref->{'facelink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'facelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facelink'}{'port'}{'udp'} = '1915'	; 
#	$srvcobjects_ref->{'facelink'}{'ports'}{'udp'}{'1915'}++	; 
#	$ports_ref->{'udp'}{'1915'}{'name'} = 'facelink'		; 
#	$srvcobjects_ref->{'facelink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'facelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facelink'}{'port'}{'tcp'} = '1915'	; 
#	$srvcobjects_ref->{'facelink'}{'ports'}{'tcp'}{'1915'}++	; 
#	$ports_ref->{'tcp'}{'1915'}{'name'} = 'facelink'		; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'port'}{'udp'} = '2538'	; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'ports'}{'udp'}{'2538'}++	; 
#	$ports_ref->{'udp'}{'2538'}{'name'} = 'vnwk-prapi'		; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'port'}{'tcp'} = '2538'	; 
#	$srvcobjects_ref->{'vnwk-prapi'}{'ports'}{'tcp'}{'2538'}++	; 
#	$ports_ref->{'tcp'}{'2538'}{'name'} = 'vnwk-prapi'		; 
#	$srvcobjects_ref->{'snmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snmp'}{'port'}{'udp'} = '161'	; 
#	$srvcobjects_ref->{'snmp'}{'ports'}{'udp'}{'161'}++	; 
#	$ports_ref->{'udp'}{'161'}{'name'} = 'snmp'		; 
#	$srvcobjects_ref->{'snmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snmp'}{'port'}{'tcp'} = '161'	; 
#	$srvcobjects_ref->{'snmp'}{'ports'}{'tcp'}{'161'}++	; 
#	$ports_ref->{'tcp'}{'161'}{'name'} = 'snmp'		; 
#	$srvcobjects_ref->{'ctt-broker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctt-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctt-broker'}{'port'}{'udp'} = '1932'	; 
#	$srvcobjects_ref->{'ctt-broker'}{'ports'}{'udp'}{'1932'}++	; 
#	$ports_ref->{'udp'}{'1932'}{'name'} = 'ctt-broker'		; 
#	$srvcobjects_ref->{'ctt-broker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctt-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctt-broker'}{'port'}{'tcp'} = '1932'	; 
#	$srvcobjects_ref->{'ctt-broker'}{'ports'}{'tcp'}{'1932'}++	; 
#	$ports_ref->{'tcp'}{'1932'}{'name'} = 'ctt-broker'		; 
#	$srvcobjects_ref->{'natd'}{'type'} = 'divert'	; 
#	$srvcobjects_ref->{'natd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'natd'}{'port'}{'divert'} = '8668'	; 
#	$srvcobjects_ref->{'natd'}{'ports'}{'divert'}{'8668'}++	; 
#	$ports_ref->{'divert'}{'8668'}{'name'} = 'natd'		; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'port'}{'udp'} = '1935'	; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'ports'}{'udp'}{'1935'}++	; 
#	$ports_ref->{'udp'}{'1935'}{'name'} = 'macromedia-fcs'		; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'port'}{'tcp'} = '1935'	; 
#	$srvcobjects_ref->{'macromedia-fcs'}{'ports'}{'tcp'}{'1935'}++	; 
#	$ports_ref->{'tcp'}{'1935'}{'name'} = 'macromedia-fcs'		; 
#	$srvcobjects_ref->{'seispoc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'seispoc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seispoc'}{'port'}{'udp'} = '2254'	; 
#	$srvcobjects_ref->{'seispoc'}{'ports'}{'udp'}{'2254'}++	; 
#	$ports_ref->{'udp'}{'2254'}{'name'} = 'seispoc'		; 
#	$srvcobjects_ref->{'seispoc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'seispoc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seispoc'}{'port'}{'tcp'} = '2254'	; 
#	$srvcobjects_ref->{'seispoc'}{'ports'}{'tcp'}{'2254'}++	; 
#	$ports_ref->{'tcp'}{'2254'}{'name'} = 'seispoc'		; 
#	$srvcobjects_ref->{'nsiiops'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsiiops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsiiops'}{'port'}{'udp'} = '261'	; 
#	$srvcobjects_ref->{'nsiiops'}{'ports'}{'udp'}{'261'}++	; 
#	$ports_ref->{'udp'}{'261'}{'name'} = 'nsiiops'		; 
#	$srvcobjects_ref->{'nsiiops'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsiiops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsiiops'}{'port'}{'tcp'} = '261'	; 
#	$srvcobjects_ref->{'nsiiops'}{'ports'}{'tcp'}{'261'}++	; 
#	$ports_ref->{'tcp'}{'261'}{'name'} = 'nsiiops'		; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'port'}{'udp'} = '1996'	; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'ports'}{'udp'}{'1996'}++	; 
#	$ports_ref->{'udp'}{'1996'}{'name'} = 'tr-rsrb-port'		; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'port'}{'tcp'} = '1996'	; 
#	$srvcobjects_ref->{'tr-rsrb-port'}{'ports'}{'tcp'}{'1996'}++	; 
#	$ports_ref->{'tcp'}{'1996'}{'name'} = 'tr-rsrb-port'		; 
#	$srvcobjects_ref->{'cichild-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cichild-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cichild-lm'}{'port'}{'udp'} = '1523'	; 
#	$srvcobjects_ref->{'cichild-lm'}{'ports'}{'udp'}{'1523'}++	; 
#	$ports_ref->{'udp'}{'1523'}{'name'} = 'cichild-lm'		; 
#	$srvcobjects_ref->{'cichild-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cichild-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cichild-lm'}{'port'}{'tcp'} = '1523'	; 
#	$srvcobjects_ref->{'cichild-lm'}{'ports'}{'tcp'}{'1523'}++	; 
#	$ports_ref->{'tcp'}{'1523'}{'name'} = 'cichild-lm'		; 
#	$srvcobjects_ref->{'ardt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ardt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardt'}{'port'}{'udp'} = '1826'	; 
#	$srvcobjects_ref->{'ardt'}{'ports'}{'udp'}{'1826'}++	; 
#	$ports_ref->{'udp'}{'1826'}{'name'} = 'ardt'		; 
#	$srvcobjects_ref->{'ardt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ardt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardt'}{'port'}{'tcp'} = '1826'	; 
#	$srvcobjects_ref->{'ardt'}{'ports'}{'tcp'}{'1826'}++	; 
#	$ports_ref->{'tcp'}{'1826'}{'name'} = 'ardt'		; 
#	$srvcobjects_ref->{'lm-perfworks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lm-perfworks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-perfworks'}{'port'}{'udp'} = '8204'	; 
#	$srvcobjects_ref->{'lm-perfworks'}{'ports'}{'udp'}{'8204'}++	; 
#	$ports_ref->{'udp'}{'8204'}{'name'} = 'lm-perfworks'		; 
#	$srvcobjects_ref->{'lm-perfworks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lm-perfworks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-perfworks'}{'port'}{'tcp'} = '8204'	; 
#	$srvcobjects_ref->{'lm-perfworks'}{'ports'}{'tcp'}{'8204'}++	; 
#	$ports_ref->{'tcp'}{'8204'}{'name'} = 'lm-perfworks'		; 
#	$srvcobjects_ref->{'panagolin-ident'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'panagolin-ident'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panagolin-ident'}{'port'}{'udp'} = '9021'	; 
#	$srvcobjects_ref->{'panagolin-ident'}{'ports'}{'udp'}{'9021'}++	; 
#	$ports_ref->{'udp'}{'9021'}{'name'} = 'panagolin-ident'		; 
#	$srvcobjects_ref->{'panagolin-ident'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'panagolin-ident'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'panagolin-ident'}{'port'}{'tcp'} = '9021'	; 
#	$srvcobjects_ref->{'panagolin-ident'}{'ports'}{'tcp'}{'9021'}++	; 
#	$ports_ref->{'tcp'}{'9021'}{'name'} = 'panagolin-ident'		; 
#	$srvcobjects_ref->{'actnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'actnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'actnet'}{'port'}{'udp'} = '5411'	; 
#	$srvcobjects_ref->{'actnet'}{'ports'}{'udp'}{'5411'}++	; 
#	$ports_ref->{'udp'}{'5411'}{'name'} = 'actnet'		; 
#	$srvcobjects_ref->{'actnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'actnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'actnet'}{'port'}{'tcp'} = '5411'	; 
#	$srvcobjects_ref->{'actnet'}{'ports'}{'tcp'}{'5411'}++	; 
#	$ports_ref->{'tcp'}{'5411'}{'name'} = 'actnet'		; 
#	$srvcobjects_ref->{'cruise-enum'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cruise-enum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-enum'}{'port'}{'udp'} = '8376'	; 
#	$srvcobjects_ref->{'cruise-enum'}{'ports'}{'udp'}{'8376'}++	; 
#	$ports_ref->{'udp'}{'8376'}{'name'} = 'cruise-enum'		; 
#	$srvcobjects_ref->{'cruise-enum'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cruise-enum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-enum'}{'port'}{'tcp'} = '8376'	; 
#	$srvcobjects_ref->{'cruise-enum'}{'ports'}{'tcp'}{'8376'}++	; 
#	$ports_ref->{'tcp'}{'8376'}{'name'} = 'cruise-enum'		; 
#	$srvcobjects_ref->{'parallel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'parallel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parallel'}{'port'}{'udp'} = '4989'	; 
#	$srvcobjects_ref->{'parallel'}{'ports'}{'udp'}{'4989'}++	; 
#	$ports_ref->{'udp'}{'4989'}{'name'} = 'parallel'		; 
#	$srvcobjects_ref->{'parallel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'parallel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parallel'}{'port'}{'tcp'} = '4989'	; 
#	$srvcobjects_ref->{'parallel'}{'ports'}{'tcp'}{'4989'}++	; 
#	$ports_ref->{'tcp'}{'4989'}{'name'} = 'parallel'		; 
#	$srvcobjects_ref->{'esp-encap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esp-encap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esp-encap'}{'port'}{'udp'} = '2797'	; 
#	$srvcobjects_ref->{'esp-encap'}{'ports'}{'udp'}{'2797'}++	; 
#	$ports_ref->{'udp'}{'2797'}{'name'} = 'esp-encap'		; 
#	$srvcobjects_ref->{'esp-encap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esp-encap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esp-encap'}{'port'}{'tcp'} = '2797'	; 
#	$srvcobjects_ref->{'esp-encap'}{'ports'}{'tcp'}{'2797'}++	; 
#	$ports_ref->{'tcp'}{'2797'}{'name'} = 'esp-encap'		; 
#	$srvcobjects_ref->{'rnrp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rnrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rnrp'}{'port'}{'udp'} = '2423'	; 
#	$srvcobjects_ref->{'rnrp'}{'ports'}{'udp'}{'2423'}++	; 
#	$ports_ref->{'udp'}{'2423'}{'name'} = 'rnrp'		; 
#	$srvcobjects_ref->{'rnrp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rnrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rnrp'}{'port'}{'tcp'} = '2423'	; 
#	$srvcobjects_ref->{'rnrp'}{'ports'}{'tcp'}{'2423'}++	; 
#	$ports_ref->{'tcp'}{'2423'}{'name'} = 'rnrp'		; 
#	$srvcobjects_ref->{'netrek'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrek'}{'port'}{'udp'} = '2592'	; 
#	$srvcobjects_ref->{'netrek'}{'ports'}{'udp'}{'2592'}++	; 
#	$ports_ref->{'udp'}{'2592'}{'name'} = 'netrek'		; 
#	$srvcobjects_ref->{'netrek'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrek'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrek'}{'port'}{'tcp'} = '2592'	; 
#	$srvcobjects_ref->{'netrek'}{'ports'}{'tcp'}{'2592'}++	; 
#	$ports_ref->{'tcp'}{'2592'}{'name'} = 'netrek'		; 
#	$srvcobjects_ref->{'vhd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vhd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vhd'}{'port'}{'udp'} = '3802'	; 
#	$srvcobjects_ref->{'vhd'}{'ports'}{'udp'}{'3802'}++	; 
#	$ports_ref->{'udp'}{'3802'}{'name'} = 'vhd'		; 
#	$srvcobjects_ref->{'vhd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vhd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vhd'}{'port'}{'tcp'} = '3802'	; 
#	$srvcobjects_ref->{'vhd'}{'ports'}{'tcp'}{'3802'}++	; 
#	$ports_ref->{'tcp'}{'3802'}{'name'} = 'vhd'		; 
#	$srvcobjects_ref->{'ptp-event'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ptp-event'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptp-event'}{'port'}{'udp'} = '319'	; 
#	$srvcobjects_ref->{'ptp-event'}{'ports'}{'udp'}{'319'}++	; 
#	$ports_ref->{'udp'}{'319'}{'name'} = 'ptp-event'		; 
#	$srvcobjects_ref->{'ptp-event'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ptp-event'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ptp-event'}{'port'}{'tcp'} = '319'	; 
#	$srvcobjects_ref->{'ptp-event'}{'ports'}{'tcp'}{'319'}++	; 
#	$ports_ref->{'tcp'}{'319'}{'name'} = 'ptp-event'		; 
#	$srvcobjects_ref->{'airs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'airs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'airs'}{'port'}{'udp'} = '1481'	; 
#	$srvcobjects_ref->{'airs'}{'ports'}{'udp'}{'1481'}++	; 
#	$ports_ref->{'udp'}{'1481'}{'name'} = 'airs'		; 
#	$srvcobjects_ref->{'airs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'airs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'airs'}{'port'}{'tcp'} = '1481'	; 
#	$srvcobjects_ref->{'airs'}{'ports'}{'tcp'}{'1481'}++	; 
#	$ports_ref->{'tcp'}{'1481'}{'name'} = 'airs'		; 
#	$srvcobjects_ref->{'pdap-np'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdap-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdap-np'}{'port'}{'udp'} = '1526'	; 
#	$srvcobjects_ref->{'pdap-np'}{'ports'}{'udp'}{'1526'}++	; 
#	$ports_ref->{'udp'}{'1526'}{'name'} = 'pdap-np'		; 
#	$srvcobjects_ref->{'pdap-np'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdap-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdap-np'}{'port'}{'tcp'} = '1526'	; 
#	$srvcobjects_ref->{'pdap-np'}{'ports'}{'tcp'}{'1526'}++	; 
#	$ports_ref->{'tcp'}{'1526'}{'name'} = 'pdap-np'		; 
#	$srvcobjects_ref->{'ca-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ca-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ca-2'}{'port'}{'udp'} = '5065'	; 
#	$srvcobjects_ref->{'ca-2'}{'ports'}{'udp'}{'5065'}++	; 
#	$ports_ref->{'udp'}{'5065'}{'name'} = 'ca-2'		; 
#	$srvcobjects_ref->{'ca-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ca-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ca-2'}{'port'}{'tcp'} = '5065'	; 
#	$srvcobjects_ref->{'ca-2'}{'ports'}{'tcp'}{'5065'}++	; 
#	$ports_ref->{'tcp'}{'5065'}{'name'} = 'ca-2'		; 
#	$srvcobjects_ref->{'swistrap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swistrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swistrap'}{'port'}{'udp'} = '6965'	; 
#	$srvcobjects_ref->{'swistrap'}{'ports'}{'udp'}{'6965'}++	; 
#	$ports_ref->{'udp'}{'6965'}{'name'} = 'swistrap'		; 
#	$srvcobjects_ref->{'swistrap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swistrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swistrap'}{'port'}{'tcp'} = '6965'	; 
#	$srvcobjects_ref->{'swistrap'}{'ports'}{'tcp'}{'6965'}++	; 
#	$ports_ref->{'tcp'}{'6965'}{'name'} = 'swistrap'		; 
#	$srvcobjects_ref->{'tpdu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tpdu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tpdu'}{'port'}{'udp'} = '1430'	; 
#	$srvcobjects_ref->{'tpdu'}{'ports'}{'udp'}{'1430'}++	; 
#	$ports_ref->{'udp'}{'1430'}{'name'} = 'tpdu'		; 
#	$srvcobjects_ref->{'tpdu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tpdu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tpdu'}{'port'}{'tcp'} = '1430'	; 
#	$srvcobjects_ref->{'tpdu'}{'ports'}{'tcp'}{'1430'}++	; 
#	$ports_ref->{'tcp'}{'1430'}{'name'} = 'tpdu'		; 
#	$srvcobjects_ref->{'l3-ranger'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'l3-ranger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l3-ranger'}{'port'}{'udp'} = '2841'	; 
#	$srvcobjects_ref->{'l3-ranger'}{'ports'}{'udp'}{'2841'}++	; 
#	$ports_ref->{'udp'}{'2841'}{'name'} = 'l3-ranger'		; 
#	$srvcobjects_ref->{'l3-ranger'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'l3-ranger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l3-ranger'}{'port'}{'tcp'} = '2841'	; 
#	$srvcobjects_ref->{'l3-ranger'}{'ports'}{'tcp'}{'2841'}++	; 
#	$ports_ref->{'tcp'}{'2841'}{'name'} = 'l3-ranger'		; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'port'}{'udp'} = '10260'	; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'ports'}{'udp'}{'10260'}++	; 
#	$ports_ref->{'udp'}{'10260'}{'name'} = 'axis-wimp-port'		; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'port'}{'tcp'} = '10260'	; 
#	$srvcobjects_ref->{'axis-wimp-port'}{'ports'}{'tcp'}{'10260'}++	; 
#	$ports_ref->{'tcp'}{'10260'}{'name'} = 'axis-wimp-port'		; 
#	$srvcobjects_ref->{'nsc-posa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsc-posa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsc-posa'}{'port'}{'udp'} = '2605'	; 
#	$srvcobjects_ref->{'nsc-posa'}{'ports'}{'udp'}{'2605'}++	; 
#	$ports_ref->{'udp'}{'2605'}{'name'} = 'nsc-posa'		; 
#	$srvcobjects_ref->{'nsc-posa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsc-posa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsc-posa'}{'port'}{'tcp'} = '2605'	; 
#	$srvcobjects_ref->{'nsc-posa'}{'ports'}{'tcp'}{'2605'}++	; 
#	$ports_ref->{'tcp'}{'2605'}{'name'} = 'nsc-posa'		; 
#	$srvcobjects_ref->{'policyserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'policyserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'policyserver'}{'port'}{'udp'} = '3055'	; 
#	$srvcobjects_ref->{'policyserver'}{'ports'}{'udp'}{'3055'}++	; 
#	$ports_ref->{'udp'}{'3055'}{'name'} = 'policyserver'		; 
#	$srvcobjects_ref->{'policyserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'policyserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'policyserver'}{'port'}{'tcp'} = '3055'	; 
#	$srvcobjects_ref->{'policyserver'}{'ports'}{'tcp'}{'3055'}++	; 
#	$ports_ref->{'tcp'}{'3055'}{'name'} = 'policyserver'		; 
#	$srvcobjects_ref->{'hap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hap'}{'port'}{'udp'} = '661'	; 
#	$srvcobjects_ref->{'hap'}{'ports'}{'udp'}{'661'}++	; 
#	$ports_ref->{'udp'}{'661'}{'name'} = 'hap'		; 
#	$srvcobjects_ref->{'hap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hap'}{'port'}{'tcp'} = '661'	; 
#	$srvcobjects_ref->{'hap'}{'ports'}{'tcp'}{'661'}++	; 
#	$ports_ref->{'tcp'}{'661'}{'name'} = 'hap'		; 
#	$srvcobjects_ref->{'linx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'linx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'linx'}{'port'}{'udp'} = '1361'	; 
#	$srvcobjects_ref->{'linx'}{'ports'}{'udp'}{'1361'}++	; 
#	$ports_ref->{'udp'}{'1361'}{'name'} = 'linx'		; 
#	$srvcobjects_ref->{'linx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'linx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'linx'}{'port'}{'tcp'} = '1361'	; 
#	$srvcobjects_ref->{'linx'}{'ports'}{'tcp'}{'1361'}++	; 
#	$ports_ref->{'tcp'}{'1361'}{'name'} = 'linx'		; 
#	$srvcobjects_ref->{'nessus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nessus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nessus'}{'port'}{'udp'} = '1241'	; 
#	$srvcobjects_ref->{'nessus'}{'ports'}{'udp'}{'1241'}++	; 
#	$ports_ref->{'udp'}{'1241'}{'name'} = 'nessus'		; 
#	$srvcobjects_ref->{'nessus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nessus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nessus'}{'port'}{'tcp'} = '1241'	; 
#	$srvcobjects_ref->{'nessus'}{'ports'}{'tcp'}{'1241'}++	; 
#	$ports_ref->{'tcp'}{'1241'}{'name'} = 'nessus'		; 
#	$srvcobjects_ref->{'sdt-lmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdt-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdt-lmd'}{'port'}{'udp'} = '3319'	; 
#	$srvcobjects_ref->{'sdt-lmd'}{'ports'}{'udp'}{'3319'}++	; 
#	$ports_ref->{'udp'}{'3319'}{'name'} = 'sdt-lmd'		; 
#	$srvcobjects_ref->{'sdt-lmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdt-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdt-lmd'}{'port'}{'tcp'} = '3319'	; 
#	$srvcobjects_ref->{'sdt-lmd'}{'ports'}{'tcp'}{'3319'}++	; 
#	$ports_ref->{'tcp'}{'3319'}{'name'} = 'sdt-lmd'		; 
#	$srvcobjects_ref->{'nsjtp-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsjtp-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsjtp-data'}{'port'}{'udp'} = '1688'	; 
#	$srvcobjects_ref->{'nsjtp-data'}{'ports'}{'udp'}{'1688'}++	; 
#	$ports_ref->{'udp'}{'1688'}{'name'} = 'nsjtp-data'		; 
#	$srvcobjects_ref->{'nsjtp-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsjtp-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsjtp-data'}{'port'}{'tcp'} = '1688'	; 
#	$srvcobjects_ref->{'nsjtp-data'}{'ports'}{'tcp'}{'1688'}++	; 
#	$ports_ref->{'tcp'}{'1688'}{'name'} = 'nsjtp-data'		; 
#	$srvcobjects_ref->{'rfio'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rfio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfio'}{'port'}{'udp'} = '3147'	; 
#	$srvcobjects_ref->{'rfio'}{'ports'}{'udp'}{'3147'}++	; 
#	$ports_ref->{'udp'}{'3147'}{'name'} = 'rfio'		; 
#	$srvcobjects_ref->{'rfio'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rfio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfio'}{'port'}{'tcp'} = '3147'	; 
#	$srvcobjects_ref->{'rfio'}{'ports'}{'tcp'}{'3147'}++	; 
#	$ports_ref->{'tcp'}{'3147'}{'name'} = 'rfio'		; 
#	$srvcobjects_ref->{'talnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talnet'}{'port'}{'udp'} = '1838'	; 
#	$srvcobjects_ref->{'talnet'}{'ports'}{'udp'}{'1838'}++	; 
#	$ports_ref->{'udp'}{'1838'}{'name'} = 'talnet'		; 
#	$srvcobjects_ref->{'talnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talnet'}{'port'}{'tcp'} = '1838'	; 
#	$srvcobjects_ref->{'talnet'}{'ports'}{'tcp'}{'1838'}++	; 
#	$ports_ref->{'tcp'}{'1838'}{'name'} = 'talnet'		; 
#	$srvcobjects_ref->{'corelvideo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'corelvideo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corelvideo'}{'port'}{'udp'} = '1566'	; 
#	$srvcobjects_ref->{'corelvideo'}{'ports'}{'udp'}{'1566'}++	; 
#	$ports_ref->{'udp'}{'1566'}{'name'} = 'corelvideo'		; 
#	$srvcobjects_ref->{'corelvideo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'corelvideo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corelvideo'}{'port'}{'tcp'} = '1566'	; 
#	$srvcobjects_ref->{'corelvideo'}{'ports'}{'tcp'}{'1566'}++	; 
#	$ports_ref->{'tcp'}{'1566'}{'name'} = 'corelvideo'		; 
#	$srvcobjects_ref->{'iden-ralp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iden-ralp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iden-ralp'}{'port'}{'udp'} = '1725'	; 
#	$srvcobjects_ref->{'iden-ralp'}{'ports'}{'udp'}{'1725'}++	; 
#	$ports_ref->{'udp'}{'1725'}{'name'} = 'iden-ralp'		; 
#	$srvcobjects_ref->{'iden-ralp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iden-ralp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iden-ralp'}{'port'}{'tcp'} = '1725'	; 
#	$srvcobjects_ref->{'iden-ralp'}{'ports'}{'tcp'}{'1725'}++	; 
#	$ports_ref->{'tcp'}{'1725'}{'name'} = 'iden-ralp'		; 
#	$srvcobjects_ref->{'conclave-cpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'conclave-cpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'conclave-cpp'}{'port'}{'udp'} = '2491'	; 
#	$srvcobjects_ref->{'conclave-cpp'}{'ports'}{'udp'}{'2491'}++	; 
#	$ports_ref->{'udp'}{'2491'}{'name'} = 'conclave-cpp'		; 
#	$srvcobjects_ref->{'conclave-cpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'conclave-cpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'conclave-cpp'}{'port'}{'tcp'} = '2491'	; 
#	$srvcobjects_ref->{'conclave-cpp'}{'ports'}{'tcp'}{'2491'}++	; 
#	$ports_ref->{'tcp'}{'2491'}{'name'} = 'conclave-cpp'		; 
#	$srvcobjects_ref->{'mvel-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mvel-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mvel-lm'}{'port'}{'udp'} = '1574'	; 
#	$srvcobjects_ref->{'mvel-lm'}{'ports'}{'udp'}{'1574'}++	; 
#	$ports_ref->{'udp'}{'1574'}{'name'} = 'mvel-lm'		; 
#	$srvcobjects_ref->{'mvel-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mvel-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mvel-lm'}{'port'}{'tcp'} = '1574'	; 
#	$srvcobjects_ref->{'mvel-lm'}{'ports'}{'tcp'}{'1574'}++	; 
#	$ports_ref->{'tcp'}{'1574'}{'name'} = 'mvel-lm'		; 
#	$srvcobjects_ref->{'cognex-insight'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cognex-insight'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cognex-insight'}{'port'}{'udp'} = '1069'	; 
#	$srvcobjects_ref->{'cognex-insight'}{'ports'}{'udp'}{'1069'}++	; 
#	$ports_ref->{'udp'}{'1069'}{'name'} = 'cognex-insight'		; 
#	$srvcobjects_ref->{'cognex-insight'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cognex-insight'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cognex-insight'}{'port'}{'tcp'} = '1069'	; 
#	$srvcobjects_ref->{'cognex-insight'}{'ports'}{'tcp'}{'1069'}++	; 
#	$ports_ref->{'tcp'}{'1069'}{'name'} = 'cognex-insight'		; 
#	$srvcobjects_ref->{'esnm-zoning'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esnm-zoning'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esnm-zoning'}{'port'}{'udp'} = '4023'	; 
#	$srvcobjects_ref->{'esnm-zoning'}{'ports'}{'udp'}{'4023'}++	; 
#	$ports_ref->{'udp'}{'4023'}{'name'} = 'esnm-zoning'		; 
#	$srvcobjects_ref->{'esnm-zoning'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esnm-zoning'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esnm-zoning'}{'port'}{'tcp'} = '4023'	; 
#	$srvcobjects_ref->{'esnm-zoning'}{'ports'}{'tcp'}{'4023'}++	; 
#	$ports_ref->{'tcp'}{'4023'}{'name'} = 'esnm-zoning'		; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'port'}{'udp'} = '1401'	; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'ports'}{'udp'}{'1401'}++	; 
#	$ports_ref->{'udp'}{'1401'}{'name'} = 'goldleaf-licman'		; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'port'}{'tcp'} = '1401'	; 
#	$srvcobjects_ref->{'goldleaf-licman'}{'ports'}{'tcp'}{'1401'}++	; 
#	$ports_ref->{'tcp'}{'1401'}{'name'} = 'goldleaf-licman'		; 
#	$srvcobjects_ref->{'net-device'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'net-device'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net-device'}{'port'}{'udp'} = '4350'	; 
#	$srvcobjects_ref->{'net-device'}{'ports'}{'udp'}{'4350'}++	; 
#	$ports_ref->{'udp'}{'4350'}{'name'} = 'net-device'		; 
#	$srvcobjects_ref->{'net-device'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'net-device'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net-device'}{'port'}{'tcp'} = '4350'	; 
#	$srvcobjects_ref->{'net-device'}{'ports'}{'tcp'}{'4350'}++	; 
#	$ports_ref->{'tcp'}{'4350'}{'name'} = 'net-device'		; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'port'}{'udp'} = '1856'	; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'ports'}{'udp'}{'1856'}++	; 
#	$ports_ref->{'udp'}{'1856'}{'name'} = 'fiorano-msgsvc'		; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'port'}{'tcp'} = '1856'	; 
#	$srvcobjects_ref->{'fiorano-msgsvc'}{'ports'}{'tcp'}{'1856'}++	; 
#	$ports_ref->{'tcp'}{'1856'}{'name'} = 'fiorano-msgsvc'		; 
#	$srvcobjects_ref->{'urm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'urm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'urm'}{'port'}{'udp'} = '606'	; 
#	$srvcobjects_ref->{'urm'}{'ports'}{'udp'}{'606'}++	; 
#	$ports_ref->{'udp'}{'606'}{'name'} = 'urm'		; 
#	$srvcobjects_ref->{'urm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'urm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'urm'}{'port'}{'tcp'} = '606'	; 
#	$srvcobjects_ref->{'urm'}{'ports'}{'tcp'}{'606'}++	; 
#	$ports_ref->{'tcp'}{'606'}{'name'} = 'urm'		; 
#	$srvcobjects_ref->{'tksocket'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tksocket'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tksocket'}{'port'}{'udp'} = '2915'	; 
#	$srvcobjects_ref->{'tksocket'}{'ports'}{'udp'}{'2915'}++	; 
#	$ports_ref->{'udp'}{'2915'}{'name'} = 'tksocket'		; 
#	$srvcobjects_ref->{'tksocket'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tksocket'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tksocket'}{'port'}{'tcp'} = '2915'	; 
#	$srvcobjects_ref->{'tksocket'}{'ports'}{'tcp'}{'2915'}++	; 
#	$ports_ref->{'tcp'}{'2915'}{'name'} = 'tksocket'		; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'port'}{'udp'} = '660'	; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'ports'}{'udp'}{'660'}++	; 
#	$ports_ref->{'udp'}{'660'}{'name'} = 'mac-srvr-admin'		; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'port'}{'tcp'} = '660'	; 
#	$srvcobjects_ref->{'mac-srvr-admin'}{'ports'}{'tcp'}{'660'}++	; 
#	$ports_ref->{'tcp'}{'660'}{'name'} = 'mac-srvr-admin'		; 
#	$srvcobjects_ref->{'shivasound'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shivasound'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shivasound'}{'port'}{'udp'} = '1549'	; 
#	$srvcobjects_ref->{'shivasound'}{'ports'}{'udp'}{'1549'}++	; 
#	$ports_ref->{'udp'}{'1549'}{'name'} = 'shivasound'		; 
#	$srvcobjects_ref->{'etlservicemgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'etlservicemgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etlservicemgr'}{'port'}{'udp'} = '9001'	; 
#	$srvcobjects_ref->{'etlservicemgr'}{'ports'}{'udp'}{'9001'}++	; 
#	$ports_ref->{'udp'}{'9001'}{'name'} = 'etlservicemgr'		; 
#	$srvcobjects_ref->{'etlservicemgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'etlservicemgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etlservicemgr'}{'port'}{'tcp'} = '9001'	; 
#	$srvcobjects_ref->{'etlservicemgr'}{'ports'}{'tcp'}{'9001'}++	; 
#	$ports_ref->{'tcp'}{'9001'}{'name'} = 'etlservicemgr'		; 
#	$srvcobjects_ref->{'xnm-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xnm-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xnm-ssl'}{'port'}{'udp'} = '3220'	; 
#	$srvcobjects_ref->{'xnm-ssl'}{'ports'}{'udp'}{'3220'}++	; 
#	$ports_ref->{'udp'}{'3220'}{'name'} = 'xnm-ssl'		; 
#	$srvcobjects_ref->{'xnm-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xnm-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xnm-ssl'}{'port'}{'tcp'} = '3220'	; 
#	$srvcobjects_ref->{'xnm-ssl'}{'ports'}{'tcp'}{'3220'}++	; 
#	$ports_ref->{'tcp'}{'3220'}{'name'} = 'xnm-ssl'		; 
#	$srvcobjects_ref->{'razor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'razor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'razor'}{'port'}{'udp'} = '3555'	; 
#	$srvcobjects_ref->{'razor'}{'ports'}{'udp'}{'3555'}++	; 
#	$ports_ref->{'udp'}{'3555'}{'name'} = 'razor'		; 
#	$srvcobjects_ref->{'razor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'razor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'razor'}{'port'}{'tcp'} = '3555'	; 
#	$srvcobjects_ref->{'razor'}{'ports'}{'tcp'}{'3555'}++	; 
#	$ports_ref->{'tcp'}{'3555'}{'name'} = 'razor'		; 
#	$srvcobjects_ref->{'marcam-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'marcam-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'marcam-lm'}{'port'}{'udp'} = '1444'	; 
#	$srvcobjects_ref->{'marcam-lm'}{'ports'}{'udp'}{'1444'}++	; 
#	$ports_ref->{'udp'}{'1444'}{'name'} = 'marcam-lm'		; 
#	$srvcobjects_ref->{'marcam-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'marcam-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'marcam-lm'}{'port'}{'tcp'} = '1444'	; 
#	$srvcobjects_ref->{'marcam-lm'}{'ports'}{'tcp'}{'1444'}++	; 
#	$ports_ref->{'tcp'}{'1444'}{'name'} = 'marcam-lm'		; 
#	$srvcobjects_ref->{'viziblebrowser'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'viziblebrowser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'viziblebrowser'}{'port'}{'udp'} = '1868'	; 
#	$srvcobjects_ref->{'viziblebrowser'}{'ports'}{'udp'}{'1868'}++	; 
#	$ports_ref->{'udp'}{'1868'}{'name'} = 'viziblebrowser'		; 
#	$srvcobjects_ref->{'viziblebrowser'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'viziblebrowser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'viziblebrowser'}{'port'}{'tcp'} = '1868'	; 
#	$srvcobjects_ref->{'viziblebrowser'}{'ports'}{'tcp'}{'1868'}++	; 
#	$ports_ref->{'tcp'}{'1868'}{'name'} = 'viziblebrowser'		; 
#	$srvcobjects_ref->{'tacticalauth'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tacticalauth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacticalauth'}{'port'}{'udp'} = '2392'	; 
#	$srvcobjects_ref->{'tacticalauth'}{'ports'}{'udp'}{'2392'}++	; 
#	$ports_ref->{'udp'}{'2392'}{'name'} = 'tacticalauth'		; 
#	$srvcobjects_ref->{'tacticalauth'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tacticalauth'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacticalauth'}{'port'}{'tcp'} = '2392'	; 
#	$srvcobjects_ref->{'tacticalauth'}{'ports'}{'tcp'}{'2392'}++	; 
#	$ports_ref->{'tcp'}{'2392'}{'name'} = 'tacticalauth'		; 
#	$srvcobjects_ref->{'odette-ftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'odette-ftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odette-ftp'}{'port'}{'udp'} = '3305'	; 
#	$srvcobjects_ref->{'odette-ftp'}{'ports'}{'udp'}{'3305'}++	; 
#	$ports_ref->{'udp'}{'3305'}{'name'} = 'odette-ftp'		; 
#	$srvcobjects_ref->{'odette-ftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'odette-ftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odette-ftp'}{'port'}{'tcp'} = '3305'	; 
#	$srvcobjects_ref->{'odette-ftp'}{'ports'}{'tcp'}{'3305'}++	; 
#	$ports_ref->{'tcp'}{'3305'}{'name'} = 'odette-ftp'		; 
#	$srvcobjects_ref->{'sxmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sxmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sxmp'}{'port'}{'udp'} = '3273'	; 
#	$srvcobjects_ref->{'sxmp'}{'ports'}{'udp'}{'3273'}++	; 
#	$ports_ref->{'udp'}{'3273'}{'name'} = 'sxmp'		; 
#	$srvcobjects_ref->{'sxmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sxmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sxmp'}{'port'}{'tcp'} = '3273'	; 
#	$srvcobjects_ref->{'sxmp'}{'ports'}{'tcp'}{'3273'}++	; 
#	$ports_ref->{'tcp'}{'3273'}{'name'} = 'sxmp'		; 
#	$srvcobjects_ref->{'iw-mmogame'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iw-mmogame'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iw-mmogame'}{'port'}{'udp'} = '3596'	; 
#	$srvcobjects_ref->{'iw-mmogame'}{'ports'}{'udp'}{'3596'}++	; 
#	$ports_ref->{'udp'}{'3596'}{'name'} = 'iw-mmogame'		; 
#	$srvcobjects_ref->{'iw-mmogame'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iw-mmogame'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iw-mmogame'}{'port'}{'tcp'} = '3596'	; 
#	$srvcobjects_ref->{'iw-mmogame'}{'ports'}{'tcp'}{'3596'}++	; 
#	$ports_ref->{'tcp'}{'3596'}{'name'} = 'iw-mmogame'		; 
#	$srvcobjects_ref->{'activememory'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'activememory'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'activememory'}{'port'}{'udp'} = '2859'	; 
#	$srvcobjects_ref->{'activememory'}{'ports'}{'udp'}{'2859'}++	; 
#	$ports_ref->{'udp'}{'2859'}{'name'} = 'activememory'		; 
#	$srvcobjects_ref->{'activememory'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'activememory'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'activememory'}{'port'}{'tcp'} = '2859'	; 
#	$srvcobjects_ref->{'activememory'}{'ports'}{'tcp'}{'2859'}++	; 
#	$ports_ref->{'tcp'}{'2859'}{'name'} = 'activememory'		; 
#	$srvcobjects_ref->{'at-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-3'}{'port'}{'udp'} = '203'	; 
#	$srvcobjects_ref->{'at-3'}{'ports'}{'udp'}{'203'}++	; 
#	$ports_ref->{'udp'}{'203'}{'name'} = 'at-3'		; 
#	$srvcobjects_ref->{'at-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-3'}{'port'}{'tcp'} = '203'	; 
#	$srvcobjects_ref->{'at-3'}{'ports'}{'tcp'}{'203'}++	; 
#	$ports_ref->{'tcp'}{'203'}{'name'} = 'at-3'		; 
#	$srvcobjects_ref->{'moy-corp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'moy-corp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'moy-corp'}{'port'}{'udp'} = '2488'	; 
#	$srvcobjects_ref->{'moy-corp'}{'ports'}{'udp'}{'2488'}++	; 
#	$ports_ref->{'udp'}{'2488'}{'name'} = 'moy-corp'		; 
#	$srvcobjects_ref->{'moy-corp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'moy-corp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'moy-corp'}{'port'}{'tcp'} = '2488'	; 
#	$srvcobjects_ref->{'moy-corp'}{'ports'}{'tcp'}{'2488'}++	; 
#	$ports_ref->{'tcp'}{'2488'}{'name'} = 'moy-corp'		; 
#	$srvcobjects_ref->{'sde-discovery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sde-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sde-discovery'}{'port'}{'udp'} = '5152'	; 
#	$srvcobjects_ref->{'sde-discovery'}{'ports'}{'udp'}{'5152'}++	; 
#	$ports_ref->{'udp'}{'5152'}{'name'} = 'sde-discovery'		; 
#	$srvcobjects_ref->{'sde-discovery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sde-discovery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sde-discovery'}{'port'}{'tcp'} = '5152'	; 
#	$srvcobjects_ref->{'sde-discovery'}{'ports'}{'tcp'}{'5152'}++	; 
#	$ports_ref->{'tcp'}{'5152'}{'name'} = 'sde-discovery'		; 
#	$srvcobjects_ref->{'telaconsole'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telaconsole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telaconsole'}{'port'}{'udp'} = '5428'	; 
#	$srvcobjects_ref->{'telaconsole'}{'ports'}{'udp'}{'5428'}++	; 
#	$ports_ref->{'udp'}{'5428'}{'name'} = 'telaconsole'		; 
#	$srvcobjects_ref->{'telaconsole'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telaconsole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telaconsole'}{'port'}{'tcp'} = '5428'	; 
#	$srvcobjects_ref->{'telaconsole'}{'ports'}{'tcp'}{'5428'}++	; 
#	$ports_ref->{'tcp'}{'5428'}{'name'} = 'telaconsole'		; 
#	$srvcobjects_ref->{'surf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'surf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'surf'}{'port'}{'udp'} = '1010'	; 
#	$srvcobjects_ref->{'surf'}{'ports'}{'udp'}{'1010'}++	; 
#	$ports_ref->{'udp'}{'1010'}{'name'} = 'surf'		; 
#	$srvcobjects_ref->{'surf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'surf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'surf'}{'port'}{'tcp'} = '1010'	; 
#	$srvcobjects_ref->{'surf'}{'ports'}{'tcp'}{'1010'}++	; 
#	$ports_ref->{'tcp'}{'1010'}{'name'} = 'surf'		; 
#	$srvcobjects_ref->{'attachmate-g32'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'attachmate-g32'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'attachmate-g32'}{'port'}{'udp'} = '2317'	; 
#	$srvcobjects_ref->{'attachmate-g32'}{'ports'}{'udp'}{'2317'}++	; 
#	$ports_ref->{'udp'}{'2317'}{'name'} = 'attachmate-g32'		; 
#	$srvcobjects_ref->{'attachmate-g32'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'attachmate-g32'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'attachmate-g32'}{'port'}{'tcp'} = '2317'	; 
#	$srvcobjects_ref->{'attachmate-g32'}{'ports'}{'tcp'}{'2317'}++	; 
#	$ports_ref->{'tcp'}{'2317'}{'name'} = 'attachmate-g32'		; 
#	$srvcobjects_ref->{'dyna-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dyna-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dyna-lm'}{'port'}{'udp'} = '3395'	; 
#	$srvcobjects_ref->{'dyna-lm'}{'ports'}{'udp'}{'3395'}++	; 
#	$ports_ref->{'udp'}{'3395'}{'name'} = 'dyna-lm'		; 
#	$srvcobjects_ref->{'dyna-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dyna-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dyna-lm'}{'port'}{'tcp'} = '3395'	; 
#	$srvcobjects_ref->{'dyna-lm'}{'ports'}{'tcp'}{'3395'}++	; 
#	$ports_ref->{'tcp'}{'3395'}{'name'} = 'dyna-lm'		; 
#	$srvcobjects_ref->{'sitaradir'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sitaradir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sitaradir'}{'port'}{'udp'} = '2631'	; 
#	$srvcobjects_ref->{'sitaradir'}{'ports'}{'udp'}{'2631'}++	; 
#	$ports_ref->{'udp'}{'2631'}{'name'} = 'sitaradir'		; 
#	$srvcobjects_ref->{'sitaradir'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sitaradir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sitaradir'}{'port'}{'tcp'} = '2631'	; 
#	$srvcobjects_ref->{'sitaradir'}{'ports'}{'tcp'}{'2631'}++	; 
#	$ports_ref->{'tcp'}{'2631'}{'name'} = 'sitaradir'		; 
#	$srvcobjects_ref->{'nm-game-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nm-game-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-game-admin'}{'port'}{'udp'} = '3148'	; 
#	$srvcobjects_ref->{'nm-game-admin'}{'ports'}{'udp'}{'3148'}++	; 
#	$ports_ref->{'udp'}{'3148'}{'name'} = 'nm-game-admin'		; 
#	$srvcobjects_ref->{'nm-game-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nm-game-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nm-game-admin'}{'port'}{'tcp'} = '3148'	; 
#	$srvcobjects_ref->{'nm-game-admin'}{'ports'}{'tcp'}{'3148'}++	; 
#	$ports_ref->{'tcp'}{'3148'}{'name'} = 'nm-game-admin'		; 
#	$srvcobjects_ref->{'asprovatalk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asprovatalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asprovatalk'}{'port'}{'udp'} = '1079'	; 
#	$srvcobjects_ref->{'asprovatalk'}{'ports'}{'udp'}{'1079'}++	; 
#	$ports_ref->{'udp'}{'1079'}{'name'} = 'asprovatalk'		; 
#	$srvcobjects_ref->{'asprovatalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asprovatalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asprovatalk'}{'port'}{'tcp'} = '1079'	; 
#	$srvcobjects_ref->{'asprovatalk'}{'ports'}{'tcp'}{'1079'}++	; 
#	$ports_ref->{'tcp'}{'1079'}{'name'} = 'asprovatalk'		; 
#	$srvcobjects_ref->{'d-fence'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'d-fence'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d-fence'}{'port'}{'udp'} = '8555'	; 
#	$srvcobjects_ref->{'d-fence'}{'ports'}{'udp'}{'8555'}++	; 
#	$ports_ref->{'udp'}{'8555'}{'name'} = 'd-fence'		; 
#	$srvcobjects_ref->{'d-fence'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'d-fence'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'d-fence'}{'port'}{'tcp'} = '8555'	; 
#	$srvcobjects_ref->{'d-fence'}{'ports'}{'tcp'}{'8555'}++	; 
#	$ports_ref->{'tcp'}{'8555'}{'name'} = 'd-fence'		; 
#	$srvcobjects_ref->{'netviewdm3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netviewdm3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netviewdm3'}{'port'}{'udp'} = '731'	; 
#	$srvcobjects_ref->{'netviewdm3'}{'ports'}{'udp'}{'731'}++	; 
#	$ports_ref->{'udp'}{'731'}{'name'} = 'netviewdm3'		; 
#	$srvcobjects_ref->{'netviewdm3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netviewdm3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netviewdm3'}{'port'}{'tcp'} = '731'	; 
#	$srvcobjects_ref->{'netviewdm3'}{'ports'}{'tcp'}{'731'}++	; 
#	$ports_ref->{'tcp'}{'731'}{'name'} = 'netviewdm3'		; 
#	$srvcobjects_ref->{'metastorm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metastorm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metastorm'}{'port'}{'udp'} = '2511'	; 
#	$srvcobjects_ref->{'metastorm'}{'ports'}{'udp'}{'2511'}++	; 
#	$ports_ref->{'udp'}{'2511'}{'name'} = 'metastorm'		; 
#	$srvcobjects_ref->{'metastorm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metastorm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metastorm'}{'port'}{'tcp'} = '2511'	; 
#	$srvcobjects_ref->{'metastorm'}{'ports'}{'tcp'}{'2511'}++	; 
#	$ports_ref->{'tcp'}{'2511'}{'name'} = 'metastorm'		; 
#	$srvcobjects_ref->{'index-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'index-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'index-net'}{'port'}{'udp'} = '2970'	; 
#	$srvcobjects_ref->{'index-net'}{'ports'}{'udp'}{'2970'}++	; 
#	$ports_ref->{'udp'}{'2970'}{'name'} = 'index-net'		; 
#	$srvcobjects_ref->{'index-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'index-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'index-net'}{'port'}{'tcp'} = '2970'	; 
#	$srvcobjects_ref->{'index-net'}{'ports'}{'tcp'}{'2970'}++	; 
#	$ports_ref->{'tcp'}{'2970'}{'name'} = 'index-net'		; 
#	$srvcobjects_ref->{'boks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks'}{'port'}{'udp'} = '6500'	; 
#	$srvcobjects_ref->{'boks'}{'ports'}{'udp'}{'6500'}++	; 
#	$ports_ref->{'udp'}{'6500'}{'name'} = 'boks'		; 
#	$srvcobjects_ref->{'boks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks'}{'port'}{'tcp'} = '6500'	; 
#	$srvcobjects_ref->{'boks'}{'ports'}{'tcp'}{'6500'}++	; 
#	$ports_ref->{'tcp'}{'6500'}{'name'} = 'boks'		; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'port'}{'udp'} = '10128'	; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'ports'}{'udp'}{'10128'}++	; 
#	$ports_ref->{'udp'}{'10128'}{'name'} = 'bmc-perf-sd'		; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'port'}{'tcp'} = '10128'	; 
#	$srvcobjects_ref->{'bmc-perf-sd'}{'ports'}{'tcp'}{'10128'}++	; 
#	$ports_ref->{'tcp'}{'10128'}{'name'} = 'bmc-perf-sd'		; 
#	$srvcobjects_ref->{'cdn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cdn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdn'}{'port'}{'udp'} = '2412'	; 
#	$srvcobjects_ref->{'cdn'}{'ports'}{'udp'}{'2412'}++	; 
#	$ports_ref->{'udp'}{'2412'}{'name'} = 'cdn'		; 
#	$srvcobjects_ref->{'cdn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cdn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cdn'}{'port'}{'tcp'} = '2412'	; 
#	$srvcobjects_ref->{'cdn'}{'ports'}{'tcp'}{'2412'}++	; 
#	$ports_ref->{'tcp'}{'2412'}{'name'} = 'cdn'		; 
#	$srvcobjects_ref->{'backburner'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'backburner'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'backburner'}{'port'}{'udp'} = '2635'	; 
#	$srvcobjects_ref->{'backburner'}{'ports'}{'udp'}{'2635'}++	; 
#	$ports_ref->{'udp'}{'2635'}{'name'} = 'backburner'		; 
#	$srvcobjects_ref->{'backburner'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'backburner'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'backburner'}{'port'}{'tcp'} = '2635'	; 
#	$srvcobjects_ref->{'backburner'}{'ports'}{'tcp'}{'2635'}++	; 
#	$ports_ref->{'tcp'}{'2635'}{'name'} = 'backburner'		; 
#	$srvcobjects_ref->{'netview-aix-6'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-6'}{'port'}{'udp'} = '1666'	; 
#	$srvcobjects_ref->{'netview-aix-6'}{'ports'}{'udp'}{'1666'}++	; 
#	$ports_ref->{'udp'}{'1666'}{'name'} = 'netview-aix-6'		; 
#	$srvcobjects_ref->{'netview-aix-6'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-6'}{'port'}{'tcp'} = '1666'	; 
#	$srvcobjects_ref->{'netview-aix-6'}{'ports'}{'tcp'}{'1666'}++	; 
#	$ports_ref->{'tcp'}{'1666'}{'name'} = 'netview-aix-6'		; 
#	$srvcobjects_ref->{'reachout'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'reachout'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'reachout'}{'port'}{'udp'} = '43188'	; 
#	$srvcobjects_ref->{'reachout'}{'ports'}{'udp'}{'43188'}++	; 
#	$ports_ref->{'udp'}{'43188'}{'name'} = 'reachout'		; 
#	$srvcobjects_ref->{'reachout'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'reachout'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'reachout'}{'port'}{'tcp'} = '43188'	; 
#	$srvcobjects_ref->{'reachout'}{'ports'}{'tcp'}{'43188'}++	; 
#	$ports_ref->{'tcp'}{'43188'}{'name'} = 'reachout'		; 
#	$srvcobjects_ref->{'castorproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'castorproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'castorproxy'}{'port'}{'udp'} = '3450'	; 
#	$srvcobjects_ref->{'castorproxy'}{'ports'}{'udp'}{'3450'}++	; 
#	$ports_ref->{'udp'}{'3450'}{'name'} = 'castorproxy'		; 
#	$srvcobjects_ref->{'castorproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'castorproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'castorproxy'}{'port'}{'tcp'} = '3450'	; 
#	$srvcobjects_ref->{'castorproxy'}{'ports'}{'tcp'}{'3450'}++	; 
#	$ports_ref->{'tcp'}{'3450'}{'name'} = 'castorproxy'		; 
#	$srvcobjects_ref->{'iad2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iad2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iad2'}{'port'}{'udp'} = '1031'	; 
#	$srvcobjects_ref->{'iad2'}{'ports'}{'udp'}{'1031'}++	; 
#	$ports_ref->{'udp'}{'1031'}{'name'} = 'iad2'		; 
#	$srvcobjects_ref->{'iad2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iad2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iad2'}{'port'}{'tcp'} = '1031'	; 
#	$srvcobjects_ref->{'iad2'}{'ports'}{'tcp'}{'1031'}++	; 
#	$ports_ref->{'tcp'}{'1031'}{'name'} = 'iad2'		; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'port'}{'udp'} = '3029'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'ports'}{'udp'}{'3029'}++	; 
#	$ports_ref->{'udp'}{'3029'}{'name'} = 'LiebDevMgmt_A'		; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'port'}{'tcp'} = '3029'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_A'}{'ports'}{'tcp'}{'3029'}++	; 
#	$ports_ref->{'tcp'}{'3029'}{'name'} = 'LiebDevMgmt_A'		; 
#	$srvcobjects_ref->{'lotusmtap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lotusmtap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lotusmtap'}{'port'}{'udp'} = '3007'	; 
#	$srvcobjects_ref->{'lotusmtap'}{'ports'}{'udp'}{'3007'}++	; 
#	$ports_ref->{'udp'}{'3007'}{'name'} = 'lotusmtap'		; 
#	$srvcobjects_ref->{'lotusmtap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lotusmtap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lotusmtap'}{'port'}{'tcp'} = '3007'	; 
#	$srvcobjects_ref->{'lotusmtap'}{'ports'}{'tcp'}{'3007'}++	; 
#	$ports_ref->{'tcp'}{'3007'}{'name'} = 'lotusmtap'		; 
#	$srvcobjects_ref->{'hp-webadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-webadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-webadmin'}{'port'}{'udp'} = '1188'	; 
#	$srvcobjects_ref->{'hp-webadmin'}{'ports'}{'udp'}{'1188'}++	; 
#	$ports_ref->{'udp'}{'1188'}{'name'} = 'hp-webadmin'		; 
#	$srvcobjects_ref->{'hp-webadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-webadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-webadmin'}{'port'}{'tcp'} = '1188'	; 
#	$srvcobjects_ref->{'hp-webadmin'}{'ports'}{'tcp'}{'1188'}++	; 
#	$ports_ref->{'tcp'}{'1188'}{'name'} = 'hp-webadmin'		; 
#	$srvcobjects_ref->{'sdbproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdbproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdbproxy'}{'port'}{'udp'} = '3562'	; 
#	$srvcobjects_ref->{'sdbproxy'}{'ports'}{'udp'}{'3562'}++	; 
#	$ports_ref->{'udp'}{'3562'}{'name'} = 'sdbproxy'		; 
#	$srvcobjects_ref->{'sdbproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdbproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdbproxy'}{'port'}{'tcp'} = '3562'	; 
#	$srvcobjects_ref->{'sdbproxy'}{'ports'}{'tcp'}{'3562'}++	; 
#	$ports_ref->{'tcp'}{'3562'}{'name'} = 'sdbproxy'		; 
#	$srvcobjects_ref->{'fg-gip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fg-gip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fg-gip'}{'port'}{'udp'} = '3294'	; 
#	$srvcobjects_ref->{'fg-gip'}{'ports'}{'udp'}{'3294'}++	; 
#	$ports_ref->{'udp'}{'3294'}{'name'} = 'fg-gip'		; 
#	$srvcobjects_ref->{'fg-gip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fg-gip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fg-gip'}{'port'}{'tcp'} = '3294'	; 
#	$srvcobjects_ref->{'fg-gip'}{'ports'}{'tcp'}{'3294'}++	; 
#	$ports_ref->{'tcp'}{'3294'}{'name'} = 'fg-gip'		; 
#	$srvcobjects_ref->{'sah-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sah-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sah-lm'}{'port'}{'udp'} = '3291'	; 
#	$srvcobjects_ref->{'sah-lm'}{'ports'}{'udp'}{'3291'}++	; 
#	$ports_ref->{'udp'}{'3291'}{'name'} = 'sah-lm'		; 
#	$srvcobjects_ref->{'sah-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sah-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sah-lm'}{'port'}{'tcp'} = '3291'	; 
#	$srvcobjects_ref->{'sah-lm'}{'ports'}{'tcp'}{'3291'}++	; 
#	$ports_ref->{'tcp'}{'3291'}{'name'} = 'sah-lm'		; 
#	$srvcobjects_ref->{'rmiregistry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmiregistry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmiregistry'}{'port'}{'udp'} = '1099'	; 
#	$srvcobjects_ref->{'rmiregistry'}{'ports'}{'udp'}{'1099'}++	; 
#	$ports_ref->{'udp'}{'1099'}{'name'} = 'rmiregistry'		; 
#	$srvcobjects_ref->{'rmiregistry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmiregistry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmiregistry'}{'port'}{'tcp'} = '1099'	; 
#	$srvcobjects_ref->{'rmiregistry'}{'ports'}{'tcp'}{'1099'}++	; 
#	$ports_ref->{'tcp'}{'1099'}{'name'} = 'rmiregistry'		; 
#	$srvcobjects_ref->{'telelpathattack'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telelpathattack'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telelpathattack'}{'port'}{'udp'} = '5011'	; 
#	$srvcobjects_ref->{'telelpathattack'}{'ports'}{'udp'}{'5011'}++	; 
#	$ports_ref->{'udp'}{'5011'}{'name'} = 'telelpathattack'		; 
#	$srvcobjects_ref->{'telelpathattack'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telelpathattack'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telelpathattack'}{'port'}{'tcp'} = '5011'	; 
#	$srvcobjects_ref->{'telelpathattack'}{'ports'}{'tcp'}{'5011'}++	; 
#	$ports_ref->{'tcp'}{'5011'}{'name'} = 'telelpathattack'		; 
#	$srvcobjects_ref->{'icpv2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icpv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icpv2'}{'port'}{'udp'} = '3130'	; 
#	$srvcobjects_ref->{'icpv2'}{'ports'}{'udp'}{'3130'}++	; 
#	$ports_ref->{'udp'}{'3130'}{'name'} = 'icpv2'		; 
#	$srvcobjects_ref->{'icpv2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icpv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icpv2'}{'port'}{'tcp'} = '3130'	; 
#	$srvcobjects_ref->{'icpv2'}{'ports'}{'tcp'}{'3130'}++	; 
#	$ports_ref->{'tcp'}{'3130'}{'name'} = 'icpv2'		; 
#	$srvcobjects_ref->{'icg-swp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icg-swp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icg-swp'}{'port'}{'udp'} = '2062'	; 
#	$srvcobjects_ref->{'icg-swp'}{'ports'}{'udp'}{'2062'}++	; 
#	$ports_ref->{'udp'}{'2062'}{'name'} = 'icg-swp'		; 
#	$srvcobjects_ref->{'icg-swp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icg-swp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icg-swp'}{'port'}{'tcp'} = '2062'	; 
#	$srvcobjects_ref->{'icg-swp'}{'ports'}{'tcp'}{'2062'}++	; 
#	$ports_ref->{'tcp'}{'2062'}{'name'} = 'icg-swp'		; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'port'}{'udp'} = '2727'	; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'ports'}{'udp'}{'2727'}++	; 
#	$ports_ref->{'udp'}{'2727'}{'name'} = 'mgcp-callagent'		; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'port'}{'tcp'} = '2727'	; 
#	$srvcobjects_ref->{'mgcp-callagent'}{'ports'}{'tcp'}{'2727'}++	; 
#	$ports_ref->{'tcp'}{'2727'}{'name'} = 'mgcp-callagent'		; 
#	$srvcobjects_ref->{'imaps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imaps'}{'port'}{'udp'} = '993'	; 
#	$srvcobjects_ref->{'imaps'}{'ports'}{'udp'}{'993'}++	; 
#	$ports_ref->{'udp'}{'993'}{'name'} = 'imaps'		; 
#	$srvcobjects_ref->{'imaps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imaps'}{'port'}{'tcp'} = '993'	; 
#	$srvcobjects_ref->{'imaps'}{'ports'}{'tcp'}{'993'}++	; 
#	$ports_ref->{'tcp'}{'993'}{'name'} = 'imaps'		; 
#	$srvcobjects_ref->{'vrts-registry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrts-registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-registry'}{'port'}{'udp'} = '2410'	; 
#	$srvcobjects_ref->{'vrts-registry'}{'ports'}{'udp'}{'2410'}++	; 
#	$ports_ref->{'udp'}{'2410'}{'name'} = 'vrts-registry'		; 
#	$srvcobjects_ref->{'vrts-registry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrts-registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-registry'}{'port'}{'tcp'} = '2410'	; 
#	$srvcobjects_ref->{'vrts-registry'}{'ports'}{'tcp'}{'2410'}++	; 
#	$ports_ref->{'tcp'}{'2410'}{'name'} = 'vrts-registry'		; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'port'}{'udp'} = '6701'	; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'ports'}{'udp'}{'6701'}++	; 
#	$ports_ref->{'udp'}{'6701'}{'name'} = 'kti-icad-srvr'		; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'port'}{'tcp'} = '6701'	; 
#	$srvcobjects_ref->{'kti-icad-srvr'}{'ports'}{'tcp'}{'6701'}++	; 
#	$ports_ref->{'tcp'}{'6701'}{'name'} = 'kti-icad-srvr'		; 
#	$srvcobjects_ref->{'armi-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'armi-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'armi-server'}{'port'}{'udp'} = '3174'	; 
#	$srvcobjects_ref->{'armi-server'}{'ports'}{'udp'}{'3174'}++	; 
#	$ports_ref->{'udp'}{'3174'}{'name'} = 'armi-server'		; 
#	$srvcobjects_ref->{'armi-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'armi-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'armi-server'}{'port'}{'tcp'} = '3174'	; 
#	$srvcobjects_ref->{'armi-server'}{'ports'}{'tcp'}{'3174'}++	; 
#	$ports_ref->{'tcp'}{'3174'}{'name'} = 'armi-server'		; 
#	$srvcobjects_ref->{'dvl-activemail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dvl-activemail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dvl-activemail'}{'port'}{'udp'} = '1396'	; 
#	$srvcobjects_ref->{'dvl-activemail'}{'ports'}{'udp'}{'1396'}++	; 
#	$ports_ref->{'udp'}{'1396'}{'name'} = 'dvl-activemail'		; 
#	$srvcobjects_ref->{'dvl-activemail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dvl-activemail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dvl-activemail'}{'port'}{'tcp'} = '1396'	; 
#	$srvcobjects_ref->{'dvl-activemail'}{'ports'}{'tcp'}{'1396'}++	; 
#	$ports_ref->{'tcp'}{'1396'}{'name'} = 'dvl-activemail'		; 
#	$srvcobjects_ref->{'sis-emt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sis-emt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sis-emt'}{'port'}{'udp'} = '2545'	; 
#	$srvcobjects_ref->{'sis-emt'}{'ports'}{'udp'}{'2545'}++	; 
#	$ports_ref->{'udp'}{'2545'}{'name'} = 'sis-emt'		; 
#	$srvcobjects_ref->{'sis-emt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sis-emt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sis-emt'}{'port'}{'tcp'} = '2545'	; 
#	$srvcobjects_ref->{'sis-emt'}{'ports'}{'tcp'}{'2545'}++	; 
#	$ports_ref->{'tcp'}{'2545'}{'name'} = 'sis-emt'		; 
#	$srvcobjects_ref->{'apc-9950'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-9950'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-9950'}{'port'}{'udp'} = '9950'	; 
#	$srvcobjects_ref->{'apc-9950'}{'ports'}{'udp'}{'9950'}++	; 
#	$ports_ref->{'udp'}{'9950'}{'name'} = 'apc-9950'		; 
#	$srvcobjects_ref->{'apc-9950'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-9950'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-9950'}{'port'}{'tcp'} = '9950'	; 
#	$srvcobjects_ref->{'apc-9950'}{'ports'}{'tcp'}{'9950'}++	; 
#	$ports_ref->{'tcp'}{'9950'}{'name'} = 'apc-9950'		; 
#	$srvcobjects_ref->{'asci-val'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asci-val'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asci-val'}{'port'}{'udp'} = '1560'	; 
#	$srvcobjects_ref->{'asci-val'}{'ports'}{'udp'}{'1560'}++	; 
#	$ports_ref->{'udp'}{'1560'}{'name'} = 'asci-val'		; 
#	$srvcobjects_ref->{'asci-val'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asci-val'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asci-val'}{'port'}{'tcp'} = '1560'	; 
#	$srvcobjects_ref->{'asci-val'}{'ports'}{'tcp'}{'1560'}++	; 
#	$ports_ref->{'tcp'}{'1560'}{'name'} = 'asci-val'		; 
#	$srvcobjects_ref->{'esro-emsdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esro-emsdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esro-emsdp'}{'port'}{'udp'} = '642'	; 
#	$srvcobjects_ref->{'esro-emsdp'}{'ports'}{'udp'}{'642'}++	; 
#	$ports_ref->{'udp'}{'642'}{'name'} = 'esro-emsdp'		; 
#	$srvcobjects_ref->{'esro-emsdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esro-emsdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esro-emsdp'}{'port'}{'tcp'} = '642'	; 
#	$srvcobjects_ref->{'esro-emsdp'}{'ports'}{'tcp'}{'642'}++	; 
#	$ports_ref->{'tcp'}{'642'}{'name'} = 'esro-emsdp'		; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'port'}{'udp'} = '3652'	; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'ports'}{'udp'}{'3652'}++	; 
#	$ports_ref->{'udp'}{'3652'}{'name'} = 'vxcrnbuport'		; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'port'}{'tcp'} = '3652'	; 
#	$srvcobjects_ref->{'vxcrnbuport'}{'ports'}{'tcp'}{'3652'}++	; 
#	$ports_ref->{'tcp'}{'3652'}{'name'} = 'vxcrnbuport'		; 
#	$srvcobjects_ref->{'ironmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ironmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ironmail'}{'port'}{'udp'} = '3206'	; 
#	$srvcobjects_ref->{'ironmail'}{'ports'}{'udp'}{'3206'}++	; 
#	$ports_ref->{'udp'}{'3206'}{'name'} = 'ironmail'		; 
#	$srvcobjects_ref->{'ironmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ironmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ironmail'}{'port'}{'tcp'} = '3206'	; 
#	$srvcobjects_ref->{'ironmail'}{'ports'}{'tcp'}{'3206'}++	; 
#	$ports_ref->{'tcp'}{'3206'}{'name'} = 'ironmail'		; 
#	$srvcobjects_ref->{'ups-onlinet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ups-onlinet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ups-onlinet'}{'port'}{'udp'} = '7010'	; 
#	$srvcobjects_ref->{'ups-onlinet'}{'ports'}{'udp'}{'7010'}++	; 
#	$ports_ref->{'udp'}{'7010'}{'name'} = 'ups-onlinet'		; 
#	$srvcobjects_ref->{'ups-onlinet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ups-onlinet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ups-onlinet'}{'port'}{'tcp'} = '7010'	; 
#	$srvcobjects_ref->{'ups-onlinet'}{'ports'}{'tcp'}{'7010'}++	; 
#	$ports_ref->{'tcp'}{'7010'}{'name'} = 'ups-onlinet'		; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'port'}{'udp'} = '2411'	; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'ports'}{'udp'}{'2411'}++	; 
#	$ports_ref->{'udp'}{'2411'}{'name'} = 'netwave-ap-mgmt'		; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'port'}{'tcp'} = '2411'	; 
#	$srvcobjects_ref->{'netwave-ap-mgmt'}{'ports'}{'tcp'}{'2411'}++	; 
#	$ports_ref->{'tcp'}{'2411'}{'name'} = 'netwave-ap-mgmt'		; 
#	$srvcobjects_ref->{'tw-auth-key'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tw-auth-key'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tw-auth-key'}{'port'}{'udp'} = '27999'	; 
#	$srvcobjects_ref->{'tw-auth-key'}{'ports'}{'udp'}{'27999'}++	; 
#	$ports_ref->{'udp'}{'27999'}{'name'} = 'tw-auth-key'		; 
#	$srvcobjects_ref->{'tw-auth-key'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tw-auth-key'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tw-auth-key'}{'port'}{'tcp'} = '27999'	; 
#	$srvcobjects_ref->{'tw-auth-key'}{'ports'}{'tcp'}{'27999'}++	; 
#	$ports_ref->{'tcp'}{'27999'}{'name'} = 'tw-auth-key'		; 
#	$srvcobjects_ref->{'csregagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csregagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csregagent'}{'port'}{'udp'} = '3022'	; 
#	$srvcobjects_ref->{'csregagent'}{'ports'}{'udp'}{'3022'}++	; 
#	$ports_ref->{'udp'}{'3022'}{'name'} = 'csregagent'		; 
#	$srvcobjects_ref->{'csregagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csregagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csregagent'}{'port'}{'tcp'} = '3022'	; 
#	$srvcobjects_ref->{'csregagent'}{'ports'}{'tcp'}{'3022'}++	; 
#	$ports_ref->{'tcp'}{'3022'}{'name'} = 'csregagent'		; 
#	$srvcobjects_ref->{'piccolo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'piccolo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'piccolo'}{'port'}{'udp'} = '2787'	; 
#	$srvcobjects_ref->{'piccolo'}{'ports'}{'udp'}{'2787'}++	; 
#	$ports_ref->{'udp'}{'2787'}{'name'} = 'piccolo'		; 
#	$srvcobjects_ref->{'piccolo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'piccolo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'piccolo'}{'port'}{'tcp'} = '2787'	; 
#	$srvcobjects_ref->{'piccolo'}{'ports'}{'tcp'}{'2787'}++	; 
#	$ports_ref->{'tcp'}{'2787'}{'name'} = 'piccolo'		; 
#	$srvcobjects_ref->{'rich-cp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rich-cp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rich-cp'}{'port'}{'udp'} = '2057'	; 
#	$srvcobjects_ref->{'rich-cp'}{'ports'}{'udp'}{'2057'}++	; 
#	$ports_ref->{'udp'}{'2057'}{'name'} = 'rich-cp'		; 
#	$srvcobjects_ref->{'rich-cp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rich-cp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rich-cp'}{'port'}{'tcp'} = '2057'	; 
#	$srvcobjects_ref->{'rich-cp'}{'ports'}{'tcp'}{'2057'}++	; 
#	$ports_ref->{'tcp'}{'2057'}{'name'} = 'rich-cp'		; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'port'}{'udp'} = '2237'	; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'ports'}{'udp'}{'2237'}++	; 
#	$ports_ref->{'udp'}{'2237'}{'name'} = 'optech-port1-lm'		; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'port'}{'tcp'} = '2237'	; 
#	$srvcobjects_ref->{'optech-port1-lm'}{'ports'}{'tcp'}{'2237'}++	; 
#	$ports_ref->{'tcp'}{'2237'}{'name'} = 'optech-port1-lm'		; 
#	$srvcobjects_ref->{'lbm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lbm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbm'}{'port'}{'udp'} = '2465'	; 
#	$srvcobjects_ref->{'lbm'}{'ports'}{'udp'}{'2465'}++	; 
#	$ports_ref->{'udp'}{'2465'}{'name'} = 'lbm'		; 
#	$srvcobjects_ref->{'lbm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lbm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbm'}{'port'}{'tcp'} = '2465'	; 
#	$srvcobjects_ref->{'lbm'}{'ports'}{'tcp'}{'2465'}++	; 
#	$ports_ref->{'tcp'}{'2465'}{'name'} = 'lbm'		; 
#	$srvcobjects_ref->{'megaregsvrport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'megaregsvrport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'megaregsvrport'}{'port'}{'udp'} = '3572'	; 
#	$srvcobjects_ref->{'megaregsvrport'}{'ports'}{'udp'}{'3572'}++	; 
#	$ports_ref->{'udp'}{'3572'}{'name'} = 'megaregsvrport'		; 
#	$srvcobjects_ref->{'megaregsvrport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'megaregsvrport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'megaregsvrport'}{'port'}{'tcp'} = '3572'	; 
#	$srvcobjects_ref->{'megaregsvrport'}{'ports'}{'tcp'}{'3572'}++	; 
#	$ports_ref->{'tcp'}{'3572'}{'name'} = 'megaregsvrport'		; 
#	$srvcobjects_ref->{'ardusuni'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ardusuni'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardusuni'}{'port'}{'udp'} = '1834'	; 
#	$srvcobjects_ref->{'ardusuni'}{'ports'}{'udp'}{'1834'}++	; 
#	$ports_ref->{'udp'}{'1834'}{'name'} = 'ardusuni'		; 
#	$srvcobjects_ref->{'ardusuni'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ardusuni'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardusuni'}{'port'}{'tcp'} = '1834'	; 
#	$srvcobjects_ref->{'ardusuni'}{'ports'}{'tcp'}{'1834'}++	; 
#	$ports_ref->{'tcp'}{'1834'}{'name'} = 'ardusuni'		; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'port'}{'udp'} = '2819'	; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'ports'}{'udp'}{'2819'}++	; 
#	$ports_ref->{'udp'}{'2819'}{'name'} = 'fc-faultnotify'		; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'port'}{'tcp'} = '2819'	; 
#	$srvcobjects_ref->{'fc-faultnotify'}{'ports'}{'tcp'}{'2819'}++	; 
#	$ports_ref->{'tcp'}{'2819'}{'name'} = 'fc-faultnotify'		; 
#	$srvcobjects_ref->{'xns-courier'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xns-courier'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-courier'}{'port'}{'udp'} = '165'	; 
#	$srvcobjects_ref->{'xns-courier'}{'ports'}{'udp'}{'165'}++	; 
#	$ports_ref->{'udp'}{'165'}{'name'} = 'xns-courier'		; 
#	$srvcobjects_ref->{'xns-courier'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xns-courier'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-courier'}{'port'}{'tcp'} = '165'	; 
#	$srvcobjects_ref->{'xns-courier'}{'ports'}{'tcp'}{'165'}++	; 
#	$ports_ref->{'tcp'}{'165'}{'name'} = 'xns-courier'		; 
#	$srvcobjects_ref->{'notify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'notify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'notify'}{'port'}{'udp'} = '773'	; 
#	$srvcobjects_ref->{'notify'}{'ports'}{'udp'}{'773'}++	; 
#	$ports_ref->{'udp'}{'773'}{'name'} = 'notify'		; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'port'}{'udp'} = '1613'	; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'ports'}{'udp'}{'1613'}++	; 
#	$ports_ref->{'udp'}{'1613'}{'name'} = 'netbill-keyrep'		; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'port'}{'tcp'} = '1613'	; 
#	$srvcobjects_ref->{'netbill-keyrep'}{'ports'}{'tcp'}{'1613'}++	; 
#	$ports_ref->{'tcp'}{'1613'}{'name'} = 'netbill-keyrep'		; 
#	$srvcobjects_ref->{'adobeserver-4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adobeserver-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-4'}{'port'}{'udp'} = '3704'	; 
#	$srvcobjects_ref->{'adobeserver-4'}{'ports'}{'udp'}{'3704'}++	; 
#	$ports_ref->{'udp'}{'3704'}{'name'} = 'adobeserver-4'		; 
#	$srvcobjects_ref->{'adobeserver-4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adobeserver-4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-4'}{'port'}{'tcp'} = '3704'	; 
#	$srvcobjects_ref->{'adobeserver-4'}{'ports'}{'tcp'}{'3704'}++	; 
#	$ports_ref->{'tcp'}{'3704'}{'name'} = 'adobeserver-4'		; 
#	$srvcobjects_ref->{'mck-ivpip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mck-ivpip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mck-ivpip'}{'port'}{'udp'} = '2698'	; 
#	$srvcobjects_ref->{'mck-ivpip'}{'ports'}{'udp'}{'2698'}++	; 
#	$ports_ref->{'udp'}{'2698'}{'name'} = 'mck-ivpip'		; 
#	$srvcobjects_ref->{'mck-ivpip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mck-ivpip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mck-ivpip'}{'port'}{'tcp'} = '2698'	; 
#	$srvcobjects_ref->{'mck-ivpip'}{'ports'}{'tcp'}{'2698'}++	; 
#	$ports_ref->{'tcp'}{'2698'}{'name'} = 'mck-ivpip'		; 
#	$srvcobjects_ref->{'isis-bcast'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isis-bcast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isis-bcast'}{'port'}{'udp'} = '2043'	; 
#	$srvcobjects_ref->{'isis-bcast'}{'ports'}{'udp'}{'2043'}++	; 
#	$ports_ref->{'udp'}{'2043'}{'name'} = 'isis-bcast'		; 
#	$srvcobjects_ref->{'isis-bcast'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isis-bcast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isis-bcast'}{'port'}{'tcp'} = '2043'	; 
#	$srvcobjects_ref->{'isis-bcast'}{'ports'}{'tcp'}{'2043'}++	; 
#	$ports_ref->{'tcp'}{'2043'}{'name'} = 'isis-bcast'		; 
#	$srvcobjects_ref->{'cnap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cnap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnap'}{'port'}{'udp'} = '1637'	; 
#	$srvcobjects_ref->{'cnap'}{'ports'}{'udp'}{'1637'}++	; 
#	$ports_ref->{'udp'}{'1637'}{'name'} = 'cnap'		; 
#	$srvcobjects_ref->{'cnap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cnap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnap'}{'port'}{'tcp'} = '1637'	; 
#	$srvcobjects_ref->{'cnap'}{'ports'}{'tcp'}{'1637'}++	; 
#	$ports_ref->{'tcp'}{'1637'}{'name'} = 'cnap'		; 
#	$srvcobjects_ref->{'web2host'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'web2host'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'web2host'}{'port'}{'udp'} = '1559'	; 
#	$srvcobjects_ref->{'web2host'}{'ports'}{'udp'}{'1559'}++	; 
#	$ports_ref->{'udp'}{'1559'}{'name'} = 'web2host'		; 
#	$srvcobjects_ref->{'web2host'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'web2host'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'web2host'}{'port'}{'tcp'} = '1559'	; 
#	$srvcobjects_ref->{'web2host'}{'ports'}{'tcp'}{'1559'}++	; 
#	$ports_ref->{'tcp'}{'1559'}{'name'} = 'web2host'		; 
#	$srvcobjects_ref->{'dixie'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dixie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dixie'}{'port'}{'udp'} = '96'	; 
#	$srvcobjects_ref->{'dixie'}{'ports'}{'udp'}{'96'}++	; 
#	$ports_ref->{'udp'}{'96'}{'name'} = 'dixie'		; 
#	$srvcobjects_ref->{'dixie'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dixie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dixie'}{'port'}{'tcp'} = '96'	; 
#	$srvcobjects_ref->{'dixie'}{'ports'}{'tcp'}{'96'}++	; 
#	$ports_ref->{'tcp'}{'96'}{'name'} = 'dixie'		; 
#	$srvcobjects_ref->{'f5-globalsite'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'f5-globalsite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'f5-globalsite'}{'port'}{'udp'} = '2792'	; 
#	$srvcobjects_ref->{'f5-globalsite'}{'ports'}{'udp'}{'2792'}++	; 
#	$ports_ref->{'udp'}{'2792'}{'name'} = 'f5-globalsite'		; 
#	$srvcobjects_ref->{'f5-globalsite'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'f5-globalsite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'f5-globalsite'}{'port'}{'tcp'} = '2792'	; 
#	$srvcobjects_ref->{'f5-globalsite'}{'ports'}{'tcp'}{'2792'}++	; 
#	$ports_ref->{'tcp'}{'2792'}{'name'} = 'f5-globalsite'		; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'port'}{'udp'} = '1300'	; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'ports'}{'udp'}{'1300'}++	; 
#	$ports_ref->{'udp'}{'1300'}{'name'} = 'h323hostcallsc'		; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'port'}{'tcp'} = '1300'	; 
#	$srvcobjects_ref->{'h323hostcallsc'}{'ports'}{'tcp'}{'1300'}++	; 
#	$ports_ref->{'tcp'}{'1300'}{'name'} = 'h323hostcallsc'		; 
#	$srvcobjects_ref->{'daap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'daap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'daap'}{'port'}{'udp'} = '3689'	; 
#	$srvcobjects_ref->{'daap'}{'ports'}{'udp'}{'3689'}++	; 
#	$ports_ref->{'udp'}{'3689'}{'name'} = 'daap'		; 
#	$srvcobjects_ref->{'daap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'daap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'daap'}{'port'}{'tcp'} = '3689'	; 
#	$srvcobjects_ref->{'daap'}{'ports'}{'tcp'}{'3689'}++	; 
#	$ports_ref->{'tcp'}{'3689'}{'name'} = 'daap'		; 
#	$srvcobjects_ref->{'csnotify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csnotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csnotify'}{'port'}{'udp'} = '2955'	; 
#	$srvcobjects_ref->{'csnotify'}{'ports'}{'udp'}{'2955'}++	; 
#	$ports_ref->{'udp'}{'2955'}{'name'} = 'csnotify'		; 
#	$srvcobjects_ref->{'csnotify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csnotify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csnotify'}{'port'}{'tcp'} = '2955'	; 
#	$srvcobjects_ref->{'csnotify'}{'ports'}{'tcp'}{'2955'}++	; 
#	$ports_ref->{'tcp'}{'2955'}{'name'} = 'csnotify'		; 
#	$srvcobjects_ref->{'swa-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swa-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-1'}{'port'}{'udp'} = '9023'	; 
#	$srvcobjects_ref->{'swa-1'}{'ports'}{'udp'}{'9023'}++	; 
#	$ports_ref->{'udp'}{'9023'}{'name'} = 'swa-1'		; 
#	$srvcobjects_ref->{'swa-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swa-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swa-1'}{'port'}{'tcp'} = '9023'	; 
#	$srvcobjects_ref->{'swa-1'}{'ports'}{'tcp'}{'9023'}++	; 
#	$ports_ref->{'tcp'}{'9023'}{'name'} = 'swa-1'		; 
#	$srvcobjects_ref->{'mcntp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mcntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcntp'}{'port'}{'udp'} = '5418'	; 
#	$srvcobjects_ref->{'mcntp'}{'ports'}{'udp'}{'5418'}++	; 
#	$ports_ref->{'udp'}{'5418'}{'name'} = 'mcntp'		; 
#	$srvcobjects_ref->{'mcntp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mcntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mcntp'}{'port'}{'tcp'} = '5418'	; 
#	$srvcobjects_ref->{'mcntp'}{'ports'}{'tcp'}{'5418'}++	; 
#	$ports_ref->{'tcp'}{'5418'}{'name'} = 'mcntp'		; 
#	$srvcobjects_ref->{'wkstn-mon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wkstn-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wkstn-mon'}{'port'}{'udp'} = '2991'	; 
#	$srvcobjects_ref->{'wkstn-mon'}{'ports'}{'udp'}{'2991'}++	; 
#	$ports_ref->{'udp'}{'2991'}{'name'} = 'wkstn-mon'		; 
#	$srvcobjects_ref->{'wkstn-mon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wkstn-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wkstn-mon'}{'port'}{'tcp'} = '2991'	; 
#	$srvcobjects_ref->{'wkstn-mon'}{'ports'}{'tcp'}{'2991'}++	; 
#	$ports_ref->{'tcp'}{'2991'}{'name'} = 'wkstn-mon'		; 
#	$srvcobjects_ref->{'oraclenames'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oraclenames'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oraclenames'}{'port'}{'udp'} = '1575'	; 
#	$srvcobjects_ref->{'oraclenames'}{'ports'}{'udp'}{'1575'}++	; 
#	$ports_ref->{'udp'}{'1575'}{'name'} = 'oraclenames'		; 
#	$srvcobjects_ref->{'oraclenames'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oraclenames'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oraclenames'}{'port'}{'tcp'} = '1575'	; 
#	$srvcobjects_ref->{'oraclenames'}{'ports'}{'tcp'}{'1575'}++	; 
#	$ports_ref->{'tcp'}{'1575'}{'name'} = 'oraclenames'		; 
#	$srvcobjects_ref->{'netrjs-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrjs-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-2'}{'port'}{'udp'} = '72'	; 
#	$srvcobjects_ref->{'netrjs-2'}{'ports'}{'udp'}{'72'}++	; 
#	$ports_ref->{'udp'}{'72'}{'name'} = 'netrjs-2'		; 
#	$srvcobjects_ref->{'netrjs-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrjs-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrjs-2'}{'port'}{'tcp'} = '72'	; 
#	$srvcobjects_ref->{'netrjs-2'}{'ports'}{'tcp'}{'72'}++	; 
#	$ports_ref->{'tcp'}{'72'}{'name'} = 'netrjs-2'		; 
#	$srvcobjects_ref->{'isbconference1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isbconference1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isbconference1'}{'port'}{'udp'} = '1244'	; 
#	$srvcobjects_ref->{'isbconference1'}{'ports'}{'udp'}{'1244'}++	; 
#	$ports_ref->{'udp'}{'1244'}{'name'} = 'isbconference1'		; 
#	$srvcobjects_ref->{'isbconference1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isbconference1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isbconference1'}{'port'}{'tcp'} = '1244'	; 
#	$srvcobjects_ref->{'isbconference1'}{'ports'}{'tcp'}{'1244'}++	; 
#	$ports_ref->{'tcp'}{'1244'}{'name'} = 'isbconference1'		; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'port'}{'udp'} = '2574'	; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'ports'}{'udp'}{'2574'}++	; 
#	$ports_ref->{'udp'}{'2574'}{'name'} = 'blockade-bpsp'		; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'port'}{'tcp'} = '2574'	; 
#	$srvcobjects_ref->{'blockade-bpsp'}{'ports'}{'tcp'}{'2574'}++	; 
#	$ports_ref->{'tcp'}{'2574'}{'name'} = 'blockade-bpsp'		; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'port'}{'udp'} = '3256'	; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'ports'}{'udp'}{'3256'}++	; 
#	$ports_ref->{'udp'}{'3256'}{'name'} = 'cpqrpm-agent'		; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'port'}{'tcp'} = '3256'	; 
#	$srvcobjects_ref->{'cpqrpm-agent'}{'ports'}{'tcp'}{'3256'}++	; 
#	$ports_ref->{'tcp'}{'3256'}{'name'} = 'cpqrpm-agent'		; 
#	$srvcobjects_ref->{'entrust-ash'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entrust-ash'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-ash'}{'port'}{'udp'} = '710'	; 
#	$srvcobjects_ref->{'entrust-ash'}{'ports'}{'udp'}{'710'}++	; 
#	$ports_ref->{'udp'}{'710'}{'name'} = 'entrust-ash'		; 
#	$srvcobjects_ref->{'entrust-ash'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entrust-ash'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entrust-ash'}{'port'}{'tcp'} = '710'	; 
#	$srvcobjects_ref->{'entrust-ash'}{'ports'}{'tcp'}{'710'}++	; 
#	$ports_ref->{'tcp'}{'710'}{'name'} = 'entrust-ash'		; 
#	$srvcobjects_ref->{'smc-https'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smc-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smc-https'}{'port'}{'udp'} = '6789'	; 
#	$srvcobjects_ref->{'smc-https'}{'ports'}{'udp'}{'6789'}++	; 
#	$ports_ref->{'udp'}{'6789'}{'name'} = 'smc-https'		; 
#	$srvcobjects_ref->{'smc-https'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smc-https'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smc-https'}{'port'}{'tcp'} = '6789'	; 
#	$srvcobjects_ref->{'smc-https'}{'ports'}{'tcp'}{'6789'}++	; 
#	$ports_ref->{'tcp'}{'6789'}{'name'} = 'smc-https'		; 
#	$srvcobjects_ref->{'ctp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctp'}{'port'}{'udp'} = '3772'	; 
#	$srvcobjects_ref->{'ctp'}{'ports'}{'udp'}{'3772'}++	; 
#	$ports_ref->{'udp'}{'3772'}{'name'} = 'ctp'		; 
#	$srvcobjects_ref->{'ctp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctp'}{'port'}{'tcp'} = '3772'	; 
#	$srvcobjects_ref->{'ctp'}{'ports'}{'tcp'}{'3772'}++	; 
#	$ports_ref->{'tcp'}{'3772'}{'name'} = 'ctp'		; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'port'}{'udp'} = '2725'	; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'ports'}{'udp'}{'2725'}++	; 
#	$ports_ref->{'udp'}{'2725'}{'name'} = 'msolap-ptp2'		; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'port'}{'tcp'} = '2725'	; 
#	$srvcobjects_ref->{'msolap-ptp2'}{'ports'}{'tcp'}{'2725'}++	; 
#	$ports_ref->{'tcp'}{'2725'}{'name'} = 'msolap-ptp2'		; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'port'}{'udp'} = '2221'	; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'ports'}{'udp'}{'2221'}++	; 
#	$ports_ref->{'udp'}{'2221'}{'name'} = 'rockwell-csp1'		; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'port'}{'tcp'} = '2221'	; 
#	$srvcobjects_ref->{'rockwell-csp1'}{'ports'}{'tcp'}{'2221'}++	; 
#	$ports_ref->{'tcp'}{'2221'}{'name'} = 'rockwell-csp1'		; 
#	$srvcobjects_ref->{'snapd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snapd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snapd'}{'port'}{'udp'} = '2599'	; 
#	$srvcobjects_ref->{'snapd'}{'ports'}{'udp'}{'2599'}++	; 
#	$ports_ref->{'udp'}{'2599'}{'name'} = 'snapd'		; 
#	$srvcobjects_ref->{'snapd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snapd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snapd'}{'port'}{'tcp'} = '2599'	; 
#	$srvcobjects_ref->{'snapd'}{'ports'}{'tcp'}{'2599'}++	; 
#	$ports_ref->{'tcp'}{'2599'}{'name'} = 'snapd'		; 
#	$srvcobjects_ref->{'mercantile'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mercantile'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mercantile'}{'port'}{'udp'} = '3398'	; 
#	$srvcobjects_ref->{'mercantile'}{'ports'}{'udp'}{'3398'}++	; 
#	$ports_ref->{'udp'}{'3398'}{'name'} = 'mercantile'		; 
#	$srvcobjects_ref->{'mercantile'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mercantile'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mercantile'}{'port'}{'tcp'} = '3398'	; 
#	$srvcobjects_ref->{'mercantile'}{'ports'}{'tcp'}{'3398'}++	; 
#	$ports_ref->{'tcp'}{'3398'}{'name'} = 'mercantile'		; 
#	$srvcobjects_ref->{'psdbserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'psdbserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psdbserver'}{'port'}{'udp'} = '2355'	; 
#	$srvcobjects_ref->{'psdbserver'}{'ports'}{'udp'}{'2355'}++	; 
#	$ports_ref->{'udp'}{'2355'}{'name'} = 'psdbserver'		; 
#	$srvcobjects_ref->{'psdbserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'psdbserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psdbserver'}{'port'}{'tcp'} = '2355'	; 
#	$srvcobjects_ref->{'psdbserver'}{'ports'}{'tcp'}{'2355'}++	; 
#	$ports_ref->{'tcp'}{'2355'}{'name'} = 'psdbserver'		; 
#	$srvcobjects_ref->{'ingreslock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ingreslock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ingreslock'}{'port'}{'udp'} = '1524'	; 
#	$srvcobjects_ref->{'ingreslock'}{'ports'}{'udp'}{'1524'}++	; 
#	$ports_ref->{'udp'}{'1524'}{'name'} = 'ingreslock'		; 
#	$srvcobjects_ref->{'ingreslock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ingreslock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ingreslock'}{'port'}{'tcp'} = '1524'	; 
#	$srvcobjects_ref->{'ingreslock'}{'ports'}{'tcp'}{'1524'}++	; 
#	$ports_ref->{'tcp'}{'1524'}{'name'} = 'ingreslock'		; 
#	$srvcobjects_ref->{'pmdfmgt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pmdfmgt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmdfmgt'}{'port'}{'udp'} = '7633'	; 
#	$srvcobjects_ref->{'pmdfmgt'}{'ports'}{'udp'}{'7633'}++	; 
#	$ports_ref->{'udp'}{'7633'}{'name'} = 'pmdfmgt'		; 
#	$srvcobjects_ref->{'pmdfmgt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pmdfmgt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmdfmgt'}{'port'}{'tcp'} = '7633'	; 
#	$srvcobjects_ref->{'pmdfmgt'}{'ports'}{'tcp'}{'7633'}++	; 
#	$ports_ref->{'tcp'}{'7633'}{'name'} = 'pmdfmgt'		; 
#	$srvcobjects_ref->{'powerschool'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'powerschool'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerschool'}{'port'}{'udp'} = '5071'	; 
#	$srvcobjects_ref->{'powerschool'}{'ports'}{'udp'}{'5071'}++	; 
#	$ports_ref->{'udp'}{'5071'}{'name'} = 'powerschool'		; 
#	$srvcobjects_ref->{'powerschool'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'powerschool'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powerschool'}{'port'}{'tcp'} = '5071'	; 
#	$srvcobjects_ref->{'powerschool'}{'ports'}{'tcp'}{'5071'}++	; 
#	$ports_ref->{'tcp'}{'5071'}{'name'} = 'powerschool'		; 
#	$srvcobjects_ref->{'emp-server1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emp-server1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emp-server1'}{'port'}{'udp'} = '6321'	; 
#	$srvcobjects_ref->{'emp-server1'}{'ports'}{'udp'}{'6321'}++	; 
#	$ports_ref->{'udp'}{'6321'}{'name'} = 'emp-server1'		; 
#	$srvcobjects_ref->{'emp-server1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emp-server1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emp-server1'}{'port'}{'tcp'} = '6321'	; 
#	$srvcobjects_ref->{'emp-server1'}{'ports'}{'tcp'}{'6321'}++	; 
#	$ports_ref->{'tcp'}{'6321'}{'name'} = 'emp-server1'		; 
#	$srvcobjects_ref->{'taligent-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'taligent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taligent-lm'}{'port'}{'udp'} = '1475'	; 
#	$srvcobjects_ref->{'taligent-lm'}{'ports'}{'udp'}{'1475'}++	; 
#	$ports_ref->{'udp'}{'1475'}{'name'} = 'taligent-lm'		; 
#	$srvcobjects_ref->{'taligent-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'taligent-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taligent-lm'}{'port'}{'tcp'} = '1475'	; 
#	$srvcobjects_ref->{'taligent-lm'}{'ports'}{'tcp'}{'1475'}++	; 
#	$ports_ref->{'tcp'}{'1475'}{'name'} = 'taligent-lm'		; 
#	$srvcobjects_ref->{'invision-ag'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'invision-ag'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'invision-ag'}{'port'}{'udp'} = '45054'	; 
#	$srvcobjects_ref->{'invision-ag'}{'ports'}{'udp'}{'45054'}++	; 
#	$ports_ref->{'udp'}{'45054'}{'name'} = 'invision-ag'		; 
#	$srvcobjects_ref->{'invision-ag'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'invision-ag'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'invision-ag'}{'port'}{'tcp'} = '45054'	; 
#	$srvcobjects_ref->{'invision-ag'}{'ports'}{'tcp'}{'45054'}++	; 
#	$ports_ref->{'tcp'}{'45054'}{'name'} = 'invision-ag'		; 
#	$srvcobjects_ref->{'darcorp-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'darcorp-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'darcorp-lm'}{'port'}{'udp'} = '1679'	; 
#	$srvcobjects_ref->{'darcorp-lm'}{'ports'}{'udp'}{'1679'}++	; 
#	$ports_ref->{'udp'}{'1679'}{'name'} = 'darcorp-lm'		; 
#	$srvcobjects_ref->{'darcorp-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'darcorp-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'darcorp-lm'}{'port'}{'tcp'} = '1679'	; 
#	$srvcobjects_ref->{'darcorp-lm'}{'ports'}{'tcp'}{'1679'}++	; 
#	$ports_ref->{'tcp'}{'1679'}{'name'} = 'darcorp-lm'		; 
#	$srvcobjects_ref->{'unisql'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unisql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unisql'}{'port'}{'udp'} = '1978'	; 
#	$srvcobjects_ref->{'unisql'}{'ports'}{'udp'}{'1978'}++	; 
#	$ports_ref->{'udp'}{'1978'}{'name'} = 'unisql'		; 
#	$srvcobjects_ref->{'unisql'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unisql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unisql'}{'port'}{'tcp'} = '1978'	; 
#	$srvcobjects_ref->{'unisql'}{'ports'}{'tcp'}{'1978'}++	; 
#	$ports_ref->{'tcp'}{'1978'}{'name'} = 'unisql'		; 
#	$srvcobjects_ref->{'sype-transport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sype-transport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sype-transport'}{'port'}{'udp'} = '9911'	; 
#	$srvcobjects_ref->{'sype-transport'}{'ports'}{'udp'}{'9911'}++	; 
#	$ports_ref->{'udp'}{'9911'}{'name'} = 'sype-transport'		; 
#	$srvcobjects_ref->{'sype-transport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sype-transport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sype-transport'}{'port'}{'tcp'} = '9911'	; 
#	$srvcobjects_ref->{'sype-transport'}{'ports'}{'tcp'}{'9911'}++	; 
#	$ports_ref->{'tcp'}{'9911'}{'name'} = 'sype-transport'		; 
#	$srvcobjects_ref->{'netsupport2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netsupport2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsupport2'}{'port'}{'udp'} = '5421'	; 
#	$srvcobjects_ref->{'netsupport2'}{'ports'}{'udp'}{'5421'}++	; 
#	$ports_ref->{'udp'}{'5421'}{'name'} = 'netsupport2'		; 
#	$srvcobjects_ref->{'netsupport2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netsupport2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsupport2'}{'port'}{'tcp'} = '5421'	; 
#	$srvcobjects_ref->{'netsupport2'}{'ports'}{'tcp'}{'5421'}++	; 
#	$ports_ref->{'tcp'}{'5421'}{'name'} = 'netsupport2'		; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'port'}{'udp'} = '2977'	; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'ports'}{'udp'}{'2977'}++	; 
#	$ports_ref->{'udp'}{'2977'}{'name'} = 'ttc-etap-ns'		; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'port'}{'tcp'} = '2977'	; 
#	$srvcobjects_ref->{'ttc-etap-ns'}{'ports'}{'tcp'}{'2977'}++	; 
#	$ports_ref->{'tcp'}{'2977'}{'name'} = 'ttc-etap-ns'		; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'port'}{'udp'} = '451'	; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'ports'}{'udp'}{'451'}++	; 
#	$ports_ref->{'udp'}{'451'}{'name'} = 'sfs-smp-net'		; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'port'}{'tcp'} = '451'	; 
#	$srvcobjects_ref->{'sfs-smp-net'}{'ports'}{'tcp'}{'451'}++	; 
#	$ports_ref->{'tcp'}{'451'}{'name'} = 'sfs-smp-net'		; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'port'}{'udp'} = '2644'	; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'ports'}{'udp'}{'2644'}++	; 
#	$ports_ref->{'udp'}{'2644'}{'name'} = 'travsoft-ipx-t'		; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'port'}{'tcp'} = '2644'	; 
#	$srvcobjects_ref->{'travsoft-ipx-t'}{'ports'}{'tcp'}{'2644'}++	; 
#	$ports_ref->{'tcp'}{'2644'}{'name'} = 'travsoft-ipx-t'		; 
#	$srvcobjects_ref->{'dmaf-caster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dmaf-caster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmaf-caster'}{'port'}{'udp'} = '3574'	; 
#	$srvcobjects_ref->{'dmaf-caster'}{'ports'}{'udp'}{'3574'}++	; 
#	$ports_ref->{'udp'}{'3574'}{'name'} = 'dmaf-caster'		; 
#	$srvcobjects_ref->{'magbind'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'magbind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magbind'}{'port'}{'udp'} = '3194'	; 
#	$srvcobjects_ref->{'magbind'}{'ports'}{'udp'}{'3194'}++	; 
#	$ports_ref->{'udp'}{'3194'}{'name'} = 'magbind'		; 
#	$srvcobjects_ref->{'magbind'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'magbind'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'magbind'}{'port'}{'tcp'} = '3194'	; 
#	$srvcobjects_ref->{'magbind'}{'ports'}{'tcp'}{'3194'}++	; 
#	$ports_ref->{'tcp'}{'3194'}{'name'} = 'magbind'		; 
#	$srvcobjects_ref->{'doc1lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'doc1lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'doc1lm'}{'port'}{'udp'} = '3161'	; 
#	$srvcobjects_ref->{'doc1lm'}{'ports'}{'udp'}{'3161'}++	; 
#	$ports_ref->{'udp'}{'3161'}{'name'} = 'doc1lm'		; 
#	$srvcobjects_ref->{'doc1lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'doc1lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'doc1lm'}{'port'}{'tcp'} = '3161'	; 
#	$srvcobjects_ref->{'doc1lm'}{'ports'}{'tcp'}{'3161'}++	; 
#	$ports_ref->{'tcp'}{'3161'}{'name'} = 'doc1lm'		; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'port'}{'udp'} = '5500'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'ports'}{'udp'}{'5500'}++	; 
#	$ports_ref->{'udp'}{'5500'}{'name'} = 'fcp-addr-srvr1'		; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'port'}{'tcp'} = '5500'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr1'}{'ports'}{'tcp'}{'5500'}++	; 
#	$ports_ref->{'tcp'}{'5500'}{'name'} = 'fcp-addr-srvr1'		; 
#	$srvcobjects_ref->{'sdnskmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdnskmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdnskmp'}{'port'}{'udp'} = '558'	; 
#	$srvcobjects_ref->{'sdnskmp'}{'ports'}{'udp'}{'558'}++	; 
#	$ports_ref->{'udp'}{'558'}{'name'} = 'sdnskmp'		; 
#	$srvcobjects_ref->{'sdnskmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdnskmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdnskmp'}{'port'}{'tcp'} = '558'	; 
#	$srvcobjects_ref->{'sdnskmp'}{'ports'}{'tcp'}{'558'}++	; 
#	$ports_ref->{'tcp'}{'558'}{'name'} = 'sdnskmp'		; 
#	$srvcobjects_ref->{'echo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'echo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'echo'}{'port'}{'udp'} = '7'	; 
#	$srvcobjects_ref->{'echo'}{'ports'}{'udp'}{'7'}++	; 
#	$ports_ref->{'udp'}{'7'}{'name'} = 'echo'		; 
#	$srvcobjects_ref->{'echo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'echo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'echo'}{'port'}{'tcp'} = '7'	; 
#	$srvcobjects_ref->{'echo'}{'ports'}{'tcp'}{'7'}++	; 
#	$ports_ref->{'tcp'}{'7'}{'name'} = 'echo'		; 
#	$srvcobjects_ref->{'echo'}{'type'} = 'ddp'	; 
#	$srvcobjects_ref->{'echo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'echo'}{'port'}{'ddp'} = '4'	; 
#	$srvcobjects_ref->{'echo'}{'ports'}{'ddp'}{'4'}++	; 
#	$ports_ref->{'ddp'}{'4'}{'name'} = 'echo'		; 
#	$srvcobjects_ref->{'interbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interbase'}{'port'}{'udp'} = '2041'	; 
#	$srvcobjects_ref->{'interbase'}{'ports'}{'udp'}{'2041'}++	; 
#	$ports_ref->{'udp'}{'2041'}{'name'} = 'interbase'		; 
#	$srvcobjects_ref->{'interbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interbase'}{'port'}{'tcp'} = '2041'	; 
#	$srvcobjects_ref->{'interbase'}{'ports'}{'tcp'}{'2041'}++	; 
#	$ports_ref->{'tcp'}{'2041'}{'name'} = 'interbase'		; 
#	$srvcobjects_ref->{'cti-redwood'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cti-redwood'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cti-redwood'}{'port'}{'udp'} = '2563'	; 
#	$srvcobjects_ref->{'cti-redwood'}{'ports'}{'udp'}{'2563'}++	; 
#	$ports_ref->{'udp'}{'2563'}{'name'} = 'cti-redwood'		; 
#	$srvcobjects_ref->{'cti-redwood'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cti-redwood'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cti-redwood'}{'port'}{'tcp'} = '2563'	; 
#	$srvcobjects_ref->{'cti-redwood'}{'ports'}{'tcp'}{'2563'}++	; 
#	$ports_ref->{'tcp'}{'2563'}{'name'} = 'cti-redwood'		; 
#	$srvcobjects_ref->{'cft-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-2'}{'port'}{'udp'} = '1763'	; 
#	$srvcobjects_ref->{'cft-2'}{'ports'}{'udp'}{'1763'}++	; 
#	$ports_ref->{'udp'}{'1763'}{'name'} = 'cft-2'		; 
#	$srvcobjects_ref->{'cft-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-2'}{'port'}{'tcp'} = '1763'	; 
#	$srvcobjects_ref->{'cft-2'}{'ports'}{'tcp'}{'1763'}++	; 
#	$ports_ref->{'tcp'}{'1763'}{'name'} = 'cft-2'		; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'port'}{'udp'} = '3486'	; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'ports'}{'udp'}{'3486'}++	; 
#	$ports_ref->{'udp'}{'3486'}{'name'} = 'ifsf-hb-port'		; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'port'}{'tcp'} = '3486'	; 
#	$srvcobjects_ref->{'ifsf-hb-port'}{'ports'}{'tcp'}{'3486'}++	; 
#	$ports_ref->{'tcp'}{'3486'}{'name'} = 'ifsf-hb-port'		; 
#	$srvcobjects_ref->{'sky-transport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sky-transport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sky-transport'}{'port'}{'udp'} = '3556'	; 
#	$srvcobjects_ref->{'sky-transport'}{'ports'}{'udp'}{'3556'}++	; 
#	$ports_ref->{'udp'}{'3556'}{'name'} = 'sky-transport'		; 
#	$srvcobjects_ref->{'sky-transport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sky-transport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sky-transport'}{'port'}{'tcp'} = '3556'	; 
#	$srvcobjects_ref->{'sky-transport'}{'ports'}{'tcp'}{'3556'}++	; 
#	$ports_ref->{'tcp'}{'3556'}{'name'} = 'sky-transport'		; 
#	$srvcobjects_ref->{'ischat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ischat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ischat'}{'port'}{'udp'} = '1336'	; 
#	$srvcobjects_ref->{'ischat'}{'ports'}{'udp'}{'1336'}++	; 
#	$ports_ref->{'udp'}{'1336'}{'name'} = 'ischat'		; 
#	$srvcobjects_ref->{'ischat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ischat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ischat'}{'port'}{'tcp'} = '1336'	; 
#	$srvcobjects_ref->{'ischat'}{'ports'}{'tcp'}{'1336'}++	; 
#	$ports_ref->{'tcp'}{'1336'}{'name'} = 'ischat'		; 
#	$srvcobjects_ref->{'smpppd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smpppd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpppd'}{'port'}{'udp'} = '3185'	; 
#	$srvcobjects_ref->{'smpppd'}{'ports'}{'udp'}{'3185'}++	; 
#	$ports_ref->{'udp'}{'3185'}{'name'} = 'smpppd'		; 
#	$srvcobjects_ref->{'smpppd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smpppd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpppd'}{'port'}{'tcp'} = '3185'	; 
#	$srvcobjects_ref->{'smpppd'}{'ports'}{'tcp'}{'3185'}++	; 
#	$ports_ref->{'tcp'}{'3185'}{'name'} = 'smpppd'		; 
#	$srvcobjects_ref->{'asa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asa'}{'port'}{'udp'} = '386'	; 
#	$srvcobjects_ref->{'asa'}{'ports'}{'udp'}{'386'}++	; 
#	$ports_ref->{'udp'}{'386'}{'name'} = 'asa'		; 
#	$srvcobjects_ref->{'asa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asa'}{'port'}{'tcp'} = '386'	; 
#	$srvcobjects_ref->{'asa'}{'ports'}{'tcp'}{'386'}++	; 
#	$ports_ref->{'tcp'}{'386'}{'name'} = 'asa'		; 
#	$srvcobjects_ref->{'signal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'signal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'signal'}{'port'}{'udp'} = '2974'	; 
#	$srvcobjects_ref->{'signal'}{'ports'}{'udp'}{'2974'}++	; 
#	$ports_ref->{'udp'}{'2974'}{'name'} = 'signal'		; 
#	$srvcobjects_ref->{'signal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'signal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'signal'}{'port'}{'tcp'} = '2974'	; 
#	$srvcobjects_ref->{'signal'}{'ports'}{'tcp'}{'2974'}++	; 
#	$ports_ref->{'tcp'}{'2974'}{'name'} = 'signal'		; 
#	$srvcobjects_ref->{'iniserve-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iniserve-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iniserve-port'}{'port'}{'udp'} = '3560'	; 
#	$srvcobjects_ref->{'iniserve-port'}{'ports'}{'udp'}{'3560'}++	; 
#	$ports_ref->{'udp'}{'3560'}{'name'} = 'iniserve-port'		; 
#	$srvcobjects_ref->{'iniserve-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iniserve-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iniserve-port'}{'port'}{'tcp'} = '3560'	; 
#	$srvcobjects_ref->{'iniserve-port'}{'ports'}{'tcp'}{'3560'}++	; 
#	$ports_ref->{'tcp'}{'3560'}{'name'} = 'iniserve-port'		; 
#	$srvcobjects_ref->{'servicemeter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'servicemeter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servicemeter'}{'port'}{'udp'} = '2603'	; 
#	$srvcobjects_ref->{'servicemeter'}{'ports'}{'udp'}{'2603'}++	; 
#	$ports_ref->{'udp'}{'2603'}{'name'} = 'servicemeter'		; 
#	$srvcobjects_ref->{'servicemeter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'servicemeter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'servicemeter'}{'port'}{'tcp'} = '2603'	; 
#	$srvcobjects_ref->{'servicemeter'}{'ports'}{'tcp'}{'2603'}++	; 
#	$ports_ref->{'tcp'}{'2603'}{'name'} = 'servicemeter'		; 
#	$srvcobjects_ref->{'iclpv-sc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclpv-sc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-sc'}{'port'}{'udp'} = '1390'	; 
#	$srvcobjects_ref->{'iclpv-sc'}{'ports'}{'udp'}{'1390'}++	; 
#	$ports_ref->{'udp'}{'1390'}{'name'} = 'iclpv-sc'		; 
#	$srvcobjects_ref->{'iclpv-sc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclpv-sc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-sc'}{'port'}{'tcp'} = '1390'	; 
#	$srvcobjects_ref->{'iclpv-sc'}{'ports'}{'tcp'}{'1390'}++	; 
#	$ports_ref->{'tcp'}{'1390'}{'name'} = 'iclpv-sc'		; 
#	$srvcobjects_ref->{'n2nremote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'n2nremote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n2nremote'}{'port'}{'udp'} = '1685'	; 
#	$srvcobjects_ref->{'n2nremote'}{'ports'}{'udp'}{'1685'}++	; 
#	$ports_ref->{'udp'}{'1685'}{'name'} = 'n2nremote'		; 
#	$srvcobjects_ref->{'n2nremote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'n2nremote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n2nremote'}{'port'}{'tcp'} = '1685'	; 
#	$srvcobjects_ref->{'n2nremote'}{'ports'}{'tcp'}{'1685'}++	; 
#	$ports_ref->{'tcp'}{'1685'}{'name'} = 'n2nremote'		; 
#	$srvcobjects_ref->{'jamserverport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jamserverport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jamserverport'}{'port'}{'udp'} = '3627'	; 
#	$srvcobjects_ref->{'jamserverport'}{'ports'}{'udp'}{'3627'}++	; 
#	$ports_ref->{'udp'}{'3627'}{'name'} = 'jamserverport'		; 
#	$srvcobjects_ref->{'jamserverport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jamserverport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jamserverport'}{'port'}{'tcp'} = '3627'	; 
#	$srvcobjects_ref->{'jamserverport'}{'ports'}{'tcp'}{'3627'}++	; 
#	$ports_ref->{'tcp'}{'3627'}{'name'} = 'jamserverport'		; 
#	$srvcobjects_ref->{'dicom-tls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dicom-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dicom-tls'}{'port'}{'udp'} = '2762'	; 
#	$srvcobjects_ref->{'dicom-tls'}{'ports'}{'udp'}{'2762'}++	; 
#	$ports_ref->{'udp'}{'2762'}{'name'} = 'dicom-tls'		; 
#	$srvcobjects_ref->{'dicom-tls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dicom-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dicom-tls'}{'port'}{'tcp'} = '2762'	; 
#	$srvcobjects_ref->{'dicom-tls'}{'ports'}{'tcp'}{'2762'}++	; 
#	$ports_ref->{'tcp'}{'2762'}{'name'} = 'dicom-tls'		; 
#	$srvcobjects_ref->{'ironstorm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ironstorm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ironstorm'}{'port'}{'udp'} = '3504'	; 
#	$srvcobjects_ref->{'ironstorm'}{'ports'}{'udp'}{'3504'}++	; 
#	$ports_ref->{'udp'}{'3504'}{'name'} = 'ironstorm'		; 
#	$srvcobjects_ref->{'ironstorm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ironstorm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ironstorm'}{'port'}{'tcp'} = '3504'	; 
#	$srvcobjects_ref->{'ironstorm'}{'ports'}{'tcp'}{'3504'}++	; 
#	$ports_ref->{'tcp'}{'3504'}{'name'} = 'ironstorm'		; 
#	$srvcobjects_ref->{'uorb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uorb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uorb'}{'port'}{'udp'} = '3313'	; 
#	$srvcobjects_ref->{'uorb'}{'ports'}{'udp'}{'3313'}++	; 
#	$ports_ref->{'udp'}{'3313'}{'name'} = 'uorb'		; 
#	$srvcobjects_ref->{'uorb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uorb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uorb'}{'port'}{'tcp'} = '3313'	; 
#	$srvcobjects_ref->{'uorb'}{'ports'}{'tcp'}{'3313'}++	; 
#	$ports_ref->{'tcp'}{'3313'}{'name'} = 'uorb'		; 
#	$srvcobjects_ref->{'periscope'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'periscope'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'periscope'}{'port'}{'udp'} = '1230'	; 
#	$srvcobjects_ref->{'periscope'}{'ports'}{'udp'}{'1230'}++	; 
#	$ports_ref->{'udp'}{'1230'}{'name'} = 'periscope'		; 
#	$srvcobjects_ref->{'periscope'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'periscope'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'periscope'}{'port'}{'tcp'} = '1230'	; 
#	$srvcobjects_ref->{'periscope'}{'ports'}{'tcp'}{'1230'}++	; 
#	$ports_ref->{'tcp'}{'1230'}{'name'} = 'periscope'		; 
#	$srvcobjects_ref->{'cadencecontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadencecontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadencecontrol'}{'port'}{'udp'} = '2318'	; 
#	$srvcobjects_ref->{'cadencecontrol'}{'ports'}{'udp'}{'2318'}++	; 
#	$ports_ref->{'udp'}{'2318'}{'name'} = 'cadencecontrol'		; 
#	$srvcobjects_ref->{'cadencecontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadencecontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadencecontrol'}{'port'}{'tcp'} = '2318'	; 
#	$srvcobjects_ref->{'cadencecontrol'}{'ports'}{'tcp'}{'2318'}++	; 
#	$ports_ref->{'tcp'}{'2318'}{'name'} = 'cadencecontrol'		; 
#	$srvcobjects_ref->{'plgproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'plgproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plgproxy'}{'port'}{'udp'} = '2790'	; 
#	$srvcobjects_ref->{'plgproxy'}{'ports'}{'udp'}{'2790'}++	; 
#	$ports_ref->{'udp'}{'2790'}{'name'} = 'plgproxy'		; 
#	$srvcobjects_ref->{'plgproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'plgproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plgproxy'}{'port'}{'tcp'} = '2790'	; 
#	$srvcobjects_ref->{'plgproxy'}{'ports'}{'tcp'}{'2790'}++	; 
#	$ports_ref->{'tcp'}{'2790'}{'name'} = 'plgproxy'		; 
#	$srvcobjects_ref->{'alpes'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alpes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alpes'}{'port'}{'udp'} = '463'	; 
#	$srvcobjects_ref->{'alpes'}{'ports'}{'udp'}{'463'}++	; 
#	$ports_ref->{'udp'}{'463'}{'name'} = 'alpes'		; 
#	$srvcobjects_ref->{'alpes'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alpes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alpes'}{'port'}{'tcp'} = '463'	; 
#	$srvcobjects_ref->{'alpes'}{'ports'}{'tcp'}{'463'}++	; 
#	$ports_ref->{'tcp'}{'463'}{'name'} = 'alpes'		; 
#	$srvcobjects_ref->{'opencm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opencm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opencm'}{'port'}{'udp'} = '3434'	; 
#	$srvcobjects_ref->{'opencm'}{'ports'}{'udp'}{'3434'}++	; 
#	$ports_ref->{'udp'}{'3434'}{'name'} = 'opencm'		; 
#	$srvcobjects_ref->{'opencm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opencm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opencm'}{'port'}{'tcp'} = '3434'	; 
#	$srvcobjects_ref->{'opencm'}{'ports'}{'tcp'}{'3434'}++	; 
#	$ports_ref->{'tcp'}{'3434'}{'name'} = 'opencm'		; 
#	$srvcobjects_ref->{'new-rwho'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'new-rwho'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'new-rwho'}{'port'}{'udp'} = '550'	; 
#	$srvcobjects_ref->{'new-rwho'}{'ports'}{'udp'}{'550'}++	; 
#	$ports_ref->{'udp'}{'550'}{'name'} = 'new-rwho'		; 
#	$srvcobjects_ref->{'new-rwho'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'new-rwho'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'new-rwho'}{'port'}{'tcp'} = '550'	; 
#	$srvcobjects_ref->{'new-rwho'}{'ports'}{'tcp'}{'550'}++	; 
#	$ports_ref->{'tcp'}{'550'}{'name'} = 'new-rwho'		; 
#	$srvcobjects_ref->{'honyaku'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'honyaku'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'honyaku'}{'port'}{'udp'} = '2744'	; 
#	$srvcobjects_ref->{'honyaku'}{'ports'}{'udp'}{'2744'}++	; 
#	$ports_ref->{'udp'}{'2744'}{'name'} = 'honyaku'		; 
#	$srvcobjects_ref->{'honyaku'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'honyaku'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'honyaku'}{'port'}{'tcp'} = '2744'	; 
#	$srvcobjects_ref->{'honyaku'}{'ports'}{'tcp'}{'2744'}++	; 
#	$ports_ref->{'tcp'}{'2744'}{'name'} = 'honyaku'		; 
#	$srvcobjects_ref->{'sst'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sst'}{'port'}{'udp'} = '266'	; 
#	$srvcobjects_ref->{'sst'}{'ports'}{'udp'}{'266'}++	; 
#	$ports_ref->{'udp'}{'266'}{'name'} = 'sst'		; 
#	$srvcobjects_ref->{'sst'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sst'}{'port'}{'tcp'} = '266'	; 
#	$srvcobjects_ref->{'sst'}{'ports'}{'tcp'}{'266'}++	; 
#	$ports_ref->{'tcp'}{'266'}{'name'} = 'sst'		; 
#	$srvcobjects_ref->{'jwserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jwserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jwserver'}{'port'}{'udp'} = '1937'	; 
#	$srvcobjects_ref->{'jwserver'}{'ports'}{'udp'}{'1937'}++	; 
#	$ports_ref->{'udp'}{'1937'}{'name'} = 'jwserver'		; 
#	$srvcobjects_ref->{'jwserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jwserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jwserver'}{'port'}{'tcp'} = '1937'	; 
#	$srvcobjects_ref->{'jwserver'}{'ports'}{'tcp'}{'1937'}++	; 
#	$ports_ref->{'tcp'}{'1937'}{'name'} = 'jwserver'		; 
#	$srvcobjects_ref->{'mrm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mrm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mrm'}{'port'}{'udp'} = '679'	; 
#	$srvcobjects_ref->{'mrm'}{'ports'}{'udp'}{'679'}++	; 
#	$ports_ref->{'udp'}{'679'}{'name'} = 'mrm'		; 
#	$srvcobjects_ref->{'mrm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mrm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mrm'}{'port'}{'tcp'} = '679'	; 
#	$srvcobjects_ref->{'mrm'}{'ports'}{'tcp'}{'679'}++	; 
#	$ports_ref->{'tcp'}{'679'}{'name'} = 'mrm'		; 
#	$srvcobjects_ref->{'ttl-publisher'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttl-publisher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttl-publisher'}{'port'}{'udp'} = '5462'	; 
#	$srvcobjects_ref->{'ttl-publisher'}{'ports'}{'udp'}{'5462'}++	; 
#	$ports_ref->{'udp'}{'5462'}{'name'} = 'ttl-publisher'		; 
#	$srvcobjects_ref->{'ttl-publisher'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttl-publisher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttl-publisher'}{'port'}{'tcp'} = '5462'	; 
#	$srvcobjects_ref->{'ttl-publisher'}{'ports'}{'tcp'}{'5462'}++	; 
#	$ports_ref->{'tcp'}{'5462'}{'name'} = 'ttl-publisher'		; 
#	$srvcobjects_ref->{'smar-se-port2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smar-se-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smar-se-port2'}{'port'}{'udp'} = '4988'	; 
#	$srvcobjects_ref->{'smar-se-port2'}{'ports'}{'udp'}{'4988'}++	; 
#	$ports_ref->{'udp'}{'4988'}{'name'} = 'smar-se-port2'		; 
#	$srvcobjects_ref->{'smar-se-port2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smar-se-port2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smar-se-port2'}{'port'}{'tcp'} = '4988'	; 
#	$srvcobjects_ref->{'smar-se-port2'}{'ports'}{'tcp'}{'4988'}++	; 
#	$ports_ref->{'tcp'}{'4988'}{'name'} = 'smar-se-port2'		; 
#	$srvcobjects_ref->{'ecsqdmn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ecsqdmn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecsqdmn'}{'port'}{'udp'} = '1882'	; 
#	$srvcobjects_ref->{'ecsqdmn'}{'ports'}{'udp'}{'1882'}++	; 
#	$ports_ref->{'udp'}{'1882'}{'name'} = 'ecsqdmn'		; 
#	$srvcobjects_ref->{'ecsqdmn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ecsqdmn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecsqdmn'}{'port'}{'tcp'} = '1882'	; 
#	$srvcobjects_ref->{'ecsqdmn'}{'ports'}{'tcp'}{'1882'}++	; 
#	$ports_ref->{'tcp'}{'1882'}{'name'} = 'ecsqdmn'		; 
#	$srvcobjects_ref->{'bb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bb'}{'port'}{'udp'} = '1984'	; 
#	$srvcobjects_ref->{'bb'}{'ports'}{'udp'}{'1984'}++	; 
#	$ports_ref->{'udp'}{'1984'}{'name'} = 'bb'		; 
#	$srvcobjects_ref->{'bb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bb'}{'port'}{'tcp'} = '1984'	; 
#	$srvcobjects_ref->{'bb'}{'ports'}{'tcp'}{'1984'}++	; 
#	$ports_ref->{'tcp'}{'1984'}{'name'} = 'bb'		; 
#	$srvcobjects_ref->{'stx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stx'}{'port'}{'udp'} = '527'	; 
#	$srvcobjects_ref->{'stx'}{'ports'}{'udp'}{'527'}++	; 
#	$ports_ref->{'udp'}{'527'}{'name'} = 'stx'		; 
#	$srvcobjects_ref->{'stx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stx'}{'port'}{'tcp'} = '527'	; 
#	$srvcobjects_ref->{'stx'}{'ports'}{'tcp'}{'527'}++	; 
#	$ports_ref->{'tcp'}{'527'}{'name'} = 'stx'		; 
#	$srvcobjects_ref->{'smpte'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smpte'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpte'}{'port'}{'udp'} = '420'	; 
#	$srvcobjects_ref->{'smpte'}{'ports'}{'udp'}{'420'}++	; 
#	$ports_ref->{'udp'}{'420'}{'name'} = 'smpte'		; 
#	$srvcobjects_ref->{'smpte'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smpte'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smpte'}{'port'}{'tcp'} = '420'	; 
#	$srvcobjects_ref->{'smpte'}{'ports'}{'tcp'}{'420'}++	; 
#	$ports_ref->{'tcp'}{'420'}{'name'} = 'smpte'		; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'port'}{'udp'} = '3570'	; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'ports'}{'udp'}{'3570'}++	; 
#	$ports_ref->{'udp'}{'3570'}{'name'} = 'mccwebsvr-port'		; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'port'}{'tcp'} = '3570'	; 
#	$srvcobjects_ref->{'mccwebsvr-port'}{'ports'}{'tcp'}{'3570'}++	; 
#	$ports_ref->{'tcp'}{'3570'}{'name'} = 'mccwebsvr-port'		; 
#	$srvcobjects_ref->{'ici'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ici'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ici'}{'port'}{'udp'} = '2200'	; 
#	$srvcobjects_ref->{'ici'}{'ports'}{'udp'}{'2200'}++	; 
#	$ports_ref->{'udp'}{'2200'}{'name'} = 'ici'		; 
#	$srvcobjects_ref->{'ici'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ici'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ici'}{'port'}{'tcp'} = '2200'	; 
#	$srvcobjects_ref->{'ici'}{'ports'}{'tcp'}{'2200'}++	; 
#	$ports_ref->{'tcp'}{'2200'}{'name'} = 'ici'		; 
#	$srvcobjects_ref->{'ip-provision'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ip-provision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ip-provision'}{'port'}{'udp'} = '43190'	; 
#	$srvcobjects_ref->{'ip-provision'}{'ports'}{'udp'}{'43190'}++	; 
#	$ports_ref->{'udp'}{'43190'}{'name'} = 'ip-provision'		; 
#	$srvcobjects_ref->{'ip-provision'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ip-provision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ip-provision'}{'port'}{'tcp'} = '43190'	; 
#	$srvcobjects_ref->{'ip-provision'}{'ports'}{'tcp'}{'43190'}++	; 
#	$ports_ref->{'tcp'}{'43190'}{'name'} = 'ip-provision'		; 
#	$srvcobjects_ref->{'netbill-trans'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbill-trans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-trans'}{'port'}{'udp'} = '1612'	; 
#	$srvcobjects_ref->{'netbill-trans'}{'ports'}{'udp'}{'1612'}++	; 
#	$ports_ref->{'udp'}{'1612'}{'name'} = 'netbill-trans'		; 
#	$srvcobjects_ref->{'netbill-trans'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbill-trans'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbill-trans'}{'port'}{'tcp'} = '1612'	; 
#	$srvcobjects_ref->{'netbill-trans'}{'ports'}{'tcp'}{'1612'}++	; 
#	$ports_ref->{'tcp'}{'1612'}{'name'} = 'netbill-trans'		; 
#	$srvcobjects_ref->{'phonebook'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'phonebook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phonebook'}{'port'}{'udp'} = '767'	; 
#	$srvcobjects_ref->{'phonebook'}{'ports'}{'udp'}{'767'}++	; 
#	$ports_ref->{'udp'}{'767'}{'name'} = 'phonebook'		; 
#	$srvcobjects_ref->{'phonebook'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'phonebook'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phonebook'}{'port'}{'tcp'} = '767'	; 
#	$srvcobjects_ref->{'phonebook'}{'ports'}{'tcp'}{'767'}++	; 
#	$ports_ref->{'tcp'}{'767'}{'name'} = 'phonebook'		; 
#	$srvcobjects_ref->{'oidocsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oidocsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oidocsvc'}{'port'}{'udp'} = '4142'	; 
#	$srvcobjects_ref->{'oidocsvc'}{'ports'}{'udp'}{'4142'}++	; 
#	$ports_ref->{'udp'}{'4142'}{'name'} = 'oidocsvc'		; 
#	$srvcobjects_ref->{'oidocsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oidocsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oidocsvc'}{'port'}{'tcp'} = '4142'	; 
#	$srvcobjects_ref->{'oidocsvc'}{'ports'}{'tcp'}{'4142'}++	; 
#	$ports_ref->{'tcp'}{'4142'}{'name'} = 'oidocsvc'		; 
#	$srvcobjects_ref->{'openport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openport'}{'port'}{'udp'} = '260'	; 
#	$srvcobjects_ref->{'openport'}{'ports'}{'udp'}{'260'}++	; 
#	$ports_ref->{'udp'}{'260'}{'name'} = 'openport'		; 
#	$srvcobjects_ref->{'openport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openport'}{'port'}{'tcp'} = '260'	; 
#	$srvcobjects_ref->{'openport'}{'ports'}{'tcp'}{'260'}++	; 
#	$ports_ref->{'tcp'}{'260'}{'name'} = 'openport'		; 
#	$srvcobjects_ref->{'leoip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'leoip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'leoip'}{'port'}{'udp'} = '1886'	; 
#	$srvcobjects_ref->{'leoip'}{'ports'}{'udp'}{'1886'}++	; 
#	$ports_ref->{'udp'}{'1886'}{'name'} = 'leoip'		; 
#	$srvcobjects_ref->{'leoip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'leoip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'leoip'}{'port'}{'tcp'} = '1886'	; 
#	$srvcobjects_ref->{'leoip'}{'ports'}{'tcp'}{'1886'}++	; 
#	$ports_ref->{'tcp'}{'1886'}{'name'} = 'leoip'		; 
#	$srvcobjects_ref->{'ms-streaming'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-streaming'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-streaming'}{'port'}{'udp'} = '1755'	; 
#	$srvcobjects_ref->{'ms-streaming'}{'ports'}{'udp'}{'1755'}++	; 
#	$ports_ref->{'udp'}{'1755'}{'name'} = 'ms-streaming'		; 
#	$srvcobjects_ref->{'ms-streaming'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-streaming'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-streaming'}{'port'}{'tcp'} = '1755'	; 
#	$srvcobjects_ref->{'ms-streaming'}{'ports'}{'tcp'}{'1755'}++	; 
#	$ports_ref->{'tcp'}{'1755'}{'name'} = 'ms-streaming'		; 
#	$srvcobjects_ref->{'dif-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dif-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dif-port'}{'port'}{'udp'} = '2251'	; 
#	$srvcobjects_ref->{'dif-port'}{'ports'}{'udp'}{'2251'}++	; 
#	$ports_ref->{'udp'}{'2251'}{'name'} = 'dif-port'		; 
#	$srvcobjects_ref->{'dif-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dif-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dif-port'}{'port'}{'tcp'} = '2251'	; 
#	$srvcobjects_ref->{'dif-port'}{'ports'}{'tcp'}{'2251'}++	; 
#	$ports_ref->{'tcp'}{'2251'}{'name'} = 'dif-port'		; 
#	$srvcobjects_ref->{'caupc-remote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'caupc-remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caupc-remote'}{'port'}{'udp'} = '2122'	; 
#	$srvcobjects_ref->{'caupc-remote'}{'ports'}{'udp'}{'2122'}++	; 
#	$ports_ref->{'udp'}{'2122'}{'name'} = 'caupc-remote'		; 
#	$srvcobjects_ref->{'caupc-remote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'caupc-remote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caupc-remote'}{'port'}{'tcp'} = '2122'	; 
#	$srvcobjects_ref->{'caupc-remote'}{'ports'}{'tcp'}{'2122'}++	; 
#	$ports_ref->{'tcp'}{'2122'}{'name'} = 'caupc-remote'		; 
#	$srvcobjects_ref->{'ibm-app'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-app'}{'port'}{'udp'} = '385'	; 
#	$srvcobjects_ref->{'ibm-app'}{'ports'}{'udp'}{'385'}++	; 
#	$ports_ref->{'udp'}{'385'}{'name'} = 'ibm-app'		; 
#	$srvcobjects_ref->{'ibm-app'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-app'}{'port'}{'tcp'} = '385'	; 
#	$srvcobjects_ref->{'ibm-app'}{'ports'}{'tcp'}{'385'}++	; 
#	$ports_ref->{'tcp'}{'385'}{'name'} = 'ibm-app'		; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'port'}{'udp'} = '48556'	; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'ports'}{'udp'}{'48556'}++	; 
#	$ports_ref->{'udp'}{'48556'}{'name'} = 'com-bardac-dw'		; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'port'}{'tcp'} = '48556'	; 
#	$srvcobjects_ref->{'com-bardac-dw'}{'ports'}{'tcp'}{'48556'}++	; 
#	$ports_ref->{'tcp'}{'48556'}{'name'} = 'com-bardac-dw'		; 
#	$srvcobjects_ref->{'nta-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nta-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nta-ds'}{'port'}{'udp'} = '7544'	; 
#	$srvcobjects_ref->{'nta-ds'}{'ports'}{'udp'}{'7544'}++	; 
#	$ports_ref->{'udp'}{'7544'}{'name'} = 'nta-ds'		; 
#	$srvcobjects_ref->{'nta-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nta-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nta-ds'}{'port'}{'tcp'} = '7544'	; 
#	$srvcobjects_ref->{'nta-ds'}{'ports'}{'tcp'}{'7544'}++	; 
#	$ports_ref->{'tcp'}{'7544'}{'name'} = 'nta-ds'		; 
#	$srvcobjects_ref->{'afs3-update'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-update'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-update'}{'port'}{'udp'} = '7008'	; 
#	$srvcobjects_ref->{'afs3-update'}{'ports'}{'udp'}{'7008'}++	; 
#	$ports_ref->{'udp'}{'7008'}{'name'} = 'afs3-update'		; 
#	$srvcobjects_ref->{'afs3-update'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-update'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-update'}{'port'}{'tcp'} = '7008'	; 
#	$srvcobjects_ref->{'afs3-update'}{'ports'}{'tcp'}{'7008'}++	; 
#	$ports_ref->{'tcp'}{'7008'}{'name'} = 'afs3-update'		; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'port'}{'udp'} = '1117'	; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'ports'}{'udp'}{'1117'}++	; 
#	$ports_ref->{'udp'}{'1117'}{'name'} = 'ardus-mtrns'		; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'port'}{'tcp'} = '1117'	; 
#	$srvcobjects_ref->{'ardus-mtrns'}{'ports'}{'tcp'}{'1117'}++	; 
#	$ports_ref->{'tcp'}{'1117'}{'name'} = 'ardus-mtrns'		; 
#	$srvcobjects_ref->{'rap-service'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rap-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap-service'}{'port'}{'udp'} = '1530'	; 
#	$srvcobjects_ref->{'rap-service'}{'ports'}{'udp'}{'1530'}++	; 
#	$ports_ref->{'udp'}{'1530'}{'name'} = 'rap-service'		; 
#	$srvcobjects_ref->{'rap-service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rap-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap-service'}{'port'}{'tcp'} = '1530'	; 
#	$srvcobjects_ref->{'rap-service'}{'ports'}{'tcp'}{'1530'}++	; 
#	$ports_ref->{'tcp'}{'1530'}{'name'} = 'rap-service'		; 
#	$srvcobjects_ref->{'nimgtw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nimgtw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimgtw'}{'port'}{'udp'} = '48003'	; 
#	$srvcobjects_ref->{'nimgtw'}{'ports'}{'udp'}{'48003'}++	; 
#	$ports_ref->{'udp'}{'48003'}{'name'} = 'nimgtw'		; 
#	$srvcobjects_ref->{'nimgtw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nimgtw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimgtw'}{'port'}{'tcp'} = '48003'	; 
#	$srvcobjects_ref->{'nimgtw'}{'ports'}{'tcp'}{'48003'}++	; 
#	$ports_ref->{'tcp'}{'48003'}{'name'} = 'nimgtw'		; 
#	$srvcobjects_ref->{'persona'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'persona'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'persona'}{'port'}{'udp'} = '1916'	; 
#	$srvcobjects_ref->{'persona'}{'ports'}{'udp'}{'1916'}++	; 
#	$ports_ref->{'udp'}{'1916'}{'name'} = 'persona'		; 
#	$srvcobjects_ref->{'persona'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'persona'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'persona'}{'port'}{'tcp'} = '1916'	; 
#	$srvcobjects_ref->{'persona'}{'ports'}{'tcp'}{'1916'}++	; 
#	$ports_ref->{'tcp'}{'1916'}{'name'} = 'persona'		; 
#	$srvcobjects_ref->{'perf-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'perf-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'perf-port'}{'port'}{'udp'} = '1995'	; 
#	$srvcobjects_ref->{'perf-port'}{'ports'}{'udp'}{'1995'}++	; 
#	$ports_ref->{'udp'}{'1995'}{'name'} = 'perf-port'		; 
#	$srvcobjects_ref->{'perf-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'perf-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'perf-port'}{'port'}{'tcp'} = '1995'	; 
#	$srvcobjects_ref->{'perf-port'}{'ports'}{'tcp'}{'1995'}++	; 
#	$ports_ref->{'tcp'}{'1995'}{'name'} = 'perf-port'		; 
#	$srvcobjects_ref->{'3com-njack-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3com-njack-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-njack-1'}{'port'}{'udp'} = '5264'	; 
#	$srvcobjects_ref->{'3com-njack-1'}{'ports'}{'udp'}{'5264'}++	; 
#	$ports_ref->{'udp'}{'5264'}{'name'} = '3com-njack-1'		; 
#	$srvcobjects_ref->{'3com-njack-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3com-njack-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-njack-1'}{'port'}{'tcp'} = '5264'	; 
#	$srvcobjects_ref->{'3com-njack-1'}{'ports'}{'tcp'}{'5264'}++	; 
#	$ports_ref->{'tcp'}{'5264'}{'name'} = '3com-njack-1'		; 
#	$srvcobjects_ref->{'csoft1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csoft1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoft1'}{'port'}{'udp'} = '1837'	; 
#	$srvcobjects_ref->{'csoft1'}{'ports'}{'udp'}{'1837'}++	; 
#	$ports_ref->{'udp'}{'1837'}{'name'} = 'csoft1'		; 
#	$srvcobjects_ref->{'csoft1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csoft1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csoft1'}{'port'}{'tcp'} = '1837'	; 
#	$srvcobjects_ref->{'csoft1'}{'ports'}{'tcp'}{'1837'}++	; 
#	$ports_ref->{'tcp'}{'1837'}{'name'} = 'csoft1'		; 
#	$srvcobjects_ref->{'netrix-sftm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrix-sftm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrix-sftm'}{'port'}{'udp'} = '2328'	; 
#	$srvcobjects_ref->{'netrix-sftm'}{'ports'}{'udp'}{'2328'}++	; 
#	$ports_ref->{'udp'}{'2328'}{'name'} = 'netrix-sftm'		; 
#	$srvcobjects_ref->{'netrix-sftm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrix-sftm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrix-sftm'}{'port'}{'tcp'} = '2328'	; 
#	$srvcobjects_ref->{'netrix-sftm'}{'ports'}{'tcp'}{'2328'}++	; 
#	$ports_ref->{'tcp'}{'2328'}{'name'} = 'netrix-sftm'		; 
#	$srvcobjects_ref->{'mentaclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mentaclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mentaclient'}{'port'}{'udp'} = '2117'	; 
#	$srvcobjects_ref->{'mentaclient'}{'ports'}{'udp'}{'2117'}++	; 
#	$ports_ref->{'udp'}{'2117'}{'name'} = 'mentaclient'		; 
#	$srvcobjects_ref->{'mentaclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mentaclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mentaclient'}{'port'}{'tcp'} = '2117'	; 
#	$srvcobjects_ref->{'mentaclient'}{'ports'}{'tcp'}{'2117'}++	; 
#	$ports_ref->{'tcp'}{'2117'}{'name'} = 'mentaclient'		; 
#	$srvcobjects_ref->{'hacl-poll'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-poll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-poll'}{'port'}{'udp'} = '5315'	; 
#	$srvcobjects_ref->{'hacl-poll'}{'ports'}{'udp'}{'5315'}++	; 
#	$ports_ref->{'udp'}{'5315'}{'name'} = 'hacl-poll'		; 
#	$srvcobjects_ref->{'hacl-poll'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-poll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-poll'}{'port'}{'tcp'} = '5315'	; 
#	$srvcobjects_ref->{'hacl-poll'}{'ports'}{'tcp'}{'5315'}++	; 
#	$ports_ref->{'tcp'}{'5315'}{'name'} = 'hacl-poll'		; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'port'}{'udp'} = '3661'	; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'ports'}{'udp'}{'3661'}++	; 
#	$ports_ref->{'udp'}{'3661'}{'name'} = 'can-ferret-ssl'		; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'port'}{'tcp'} = '3661'	; 
#	$srvcobjects_ref->{'can-ferret-ssl'}{'ports'}{'tcp'}{'3661'}++	; 
#	$ports_ref->{'tcp'}{'3661'}{'name'} = 'can-ferret-ssl'		; 
#	$srvcobjects_ref->{'dna'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dna'}{'port'}{'udp'} = '2287'	; 
#	$srvcobjects_ref->{'dna'}{'ports'}{'udp'}{'2287'}++	; 
#	$ports_ref->{'udp'}{'2287'}{'name'} = 'dna'		; 
#	$srvcobjects_ref->{'dna'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dna'}{'port'}{'tcp'} = '2287'	; 
#	$srvcobjects_ref->{'dna'}{'ports'}{'tcp'}{'2287'}++	; 
#	$ports_ref->{'tcp'}{'2287'}{'name'} = 'dna'		; 
#	$srvcobjects_ref->{'netmo-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netmo-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmo-http'}{'port'}{'udp'} = '6842'	; 
#	$srvcobjects_ref->{'netmo-http'}{'ports'}{'udp'}{'6842'}++	; 
#	$ports_ref->{'udp'}{'6842'}{'name'} = 'netmo-http'		; 
#	$srvcobjects_ref->{'netmo-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netmo-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmo-http'}{'port'}{'tcp'} = '6842'	; 
#	$srvcobjects_ref->{'netmo-http'}{'ports'}{'tcp'}{'6842'}++	; 
#	$ports_ref->{'tcp'}{'6842'}{'name'} = 'netmo-http'		; 
#	$srvcobjects_ref->{'smart-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smart-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smart-lm'}{'port'}{'udp'} = '1608'	; 
#	$srvcobjects_ref->{'smart-lm'}{'ports'}{'udp'}{'1608'}++	; 
#	$ports_ref->{'udp'}{'1608'}{'name'} = 'smart-lm'		; 
#	$srvcobjects_ref->{'smart-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smart-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smart-lm'}{'port'}{'tcp'} = '1608'	; 
#	$srvcobjects_ref->{'smart-lm'}{'ports'}{'tcp'}{'1608'}++	; 
#	$ports_ref->{'tcp'}{'1608'}{'name'} = 'smart-lm'		; 
#	$srvcobjects_ref->{'rrimwm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrimwm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrimwm'}{'port'}{'udp'} = '1694'	; 
#	$srvcobjects_ref->{'rrimwm'}{'ports'}{'udp'}{'1694'}++	; 
#	$ports_ref->{'udp'}{'1694'}{'name'} = 'rrimwm'		; 
#	$srvcobjects_ref->{'rrimwm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrimwm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrimwm'}{'port'}{'tcp'} = '1694'	; 
#	$srvcobjects_ref->{'rrimwm'}{'ports'}{'tcp'}{'1694'}++	; 
#	$ports_ref->{'tcp'}{'1694'}{'name'} = 'rrimwm'		; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'port'}{'udp'} = '1741'	; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'ports'}{'udp'}{'1741'}++	; 
#	$ports_ref->{'udp'}{'1741'}{'name'} = 'cisco-net-mgmt'		; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'port'}{'tcp'} = '1741'	; 
#	$srvcobjects_ref->{'cisco-net-mgmt'}{'ports'}{'tcp'}{'1741'}++	; 
#	$ports_ref->{'tcp'}{'1741'}{'name'} = 'cisco-net-mgmt'		; 
#	$srvcobjects_ref->{'isis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isis'}{'port'}{'udp'} = '2042'	; 
#	$srvcobjects_ref->{'isis'}{'ports'}{'udp'}{'2042'}++	; 
#	$ports_ref->{'udp'}{'2042'}{'name'} = 'isis'		; 
#	$srvcobjects_ref->{'isis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isis'}{'port'}{'tcp'} = '2042'	; 
#	$srvcobjects_ref->{'isis'}{'ports'}{'tcp'}{'2042'}++	; 
#	$ports_ref->{'tcp'}{'2042'}{'name'} = 'isis'		; 
#	$srvcobjects_ref->{'uma'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uma'}{'port'}{'udp'} = '144'	; 
#	$srvcobjects_ref->{'uma'}{'ports'}{'udp'}{'144'}++	; 
#	$ports_ref->{'udp'}{'144'}{'name'} = 'uma'		; 
#	$srvcobjects_ref->{'uma'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uma'}{'port'}{'udp'} = '1797'	; 
#	$srvcobjects_ref->{'uma'}{'ports'}{'udp'}{'1797'}++	; 
#	$ports_ref->{'udp'}{'1797'}{'name'} = 'uma'		; 
#	$srvcobjects_ref->{'uma'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uma'}{'port'}{'tcp'} = '144'	; 
#	$srvcobjects_ref->{'uma'}{'ports'}{'tcp'}{'144'}++	; 
#	$ports_ref->{'tcp'}{'144'}{'name'} = 'uma'		; 
#	$srvcobjects_ref->{'uma'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uma'}{'port'}{'tcp'} = '1797'	; 
#	$srvcobjects_ref->{'uma'}{'ports'}{'tcp'}{'1797'}++	; 
#	$ports_ref->{'tcp'}{'1797'}{'name'} = 'uma'		; 
#	$srvcobjects_ref->{'ip-qsig'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ip-qsig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ip-qsig'}{'port'}{'udp'} = '4029'	; 
#	$srvcobjects_ref->{'ip-qsig'}{'ports'}{'udp'}{'4029'}++	; 
#	$ports_ref->{'udp'}{'4029'}{'name'} = 'ip-qsig'		; 
#	$srvcobjects_ref->{'ip-qsig'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ip-qsig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ip-qsig'}{'port'}{'tcp'} = '4029'	; 
#	$srvcobjects_ref->{'ip-qsig'}{'ports'}{'tcp'}{'4029'}++	; 
#	$ports_ref->{'tcp'}{'4029'}{'name'} = 'ip-qsig'		; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'port'}{'udp'} = '1796'	; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'ports'}{'udp'}{'1796'}++	; 
#	$ports_ref->{'udp'}{'1796'}{'name'} = 'vocaltec-admin'		; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'port'}{'tcp'} = '1796'	; 
#	$srvcobjects_ref->{'vocaltec-admin'}{'ports'}{'tcp'}{'1796'}++	; 
#	$ports_ref->{'tcp'}{'1796'}{'name'} = 'vocaltec-admin'		; 
#	$srvcobjects_ref->{'trivnet1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trivnet1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trivnet1'}{'port'}{'udp'} = '8200'	; 
#	$srvcobjects_ref->{'trivnet1'}{'ports'}{'udp'}{'8200'}++	; 
#	$ports_ref->{'udp'}{'8200'}{'name'} = 'trivnet1'		; 
#	$srvcobjects_ref->{'trivnet1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trivnet1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trivnet1'}{'port'}{'tcp'} = '8200'	; 
#	$srvcobjects_ref->{'trivnet1'}{'ports'}{'tcp'}{'8200'}++	; 
#	$ports_ref->{'tcp'}{'8200'}{'name'} = 'trivnet1'		; 
#	$srvcobjects_ref->{'tram'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tram'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tram'}{'port'}{'udp'} = '4567'	; 
#	$srvcobjects_ref->{'tram'}{'ports'}{'udp'}{'4567'}++	; 
#	$ports_ref->{'udp'}{'4567'}{'name'} = 'tram'		; 
#	$srvcobjects_ref->{'tram'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tram'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tram'}{'port'}{'tcp'} = '4567'	; 
#	$srvcobjects_ref->{'tram'}{'ports'}{'tcp'}{'4567'}++	; 
#	$ports_ref->{'tcp'}{'4567'}{'name'} = 'tram'		; 
#	$srvcobjects_ref->{'gbs-stp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gbs-stp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gbs-stp'}{'port'}{'udp'} = '3484'	; 
#	$srvcobjects_ref->{'gbs-stp'}{'ports'}{'udp'}{'3484'}++	; 
#	$ports_ref->{'udp'}{'3484'}{'name'} = 'gbs-stp'		; 
#	$srvcobjects_ref->{'gbs-stp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gbs-stp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gbs-stp'}{'port'}{'tcp'} = '3484'	; 
#	$srvcobjects_ref->{'gbs-stp'}{'ports'}{'tcp'}{'3484'}++	; 
#	$ports_ref->{'tcp'}{'3484'}{'name'} = 'gbs-stp'		; 
#	$srvcobjects_ref->{'serverview-as'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'serverview-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-as'}{'port'}{'udp'} = '3169'	; 
#	$srvcobjects_ref->{'serverview-as'}{'ports'}{'udp'}{'3169'}++	; 
#	$ports_ref->{'udp'}{'3169'}{'name'} = 'serverview-as'		; 
#	$srvcobjects_ref->{'serverview-as'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'serverview-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-as'}{'port'}{'tcp'} = '3169'	; 
#	$srvcobjects_ref->{'serverview-as'}{'ports'}{'tcp'}{'3169'}++	; 
#	$ports_ref->{'tcp'}{'3169'}{'name'} = 'serverview-as'		; 
#	$srvcobjects_ref->{'ttc-etap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttc-etap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-etap'}{'port'}{'udp'} = '2675'	; 
#	$srvcobjects_ref->{'ttc-etap'}{'ports'}{'udp'}{'2675'}++	; 
#	$ports_ref->{'udp'}{'2675'}{'name'} = 'ttc-etap'		; 
#	$srvcobjects_ref->{'ttc-etap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttc-etap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-etap'}{'port'}{'tcp'} = '2675'	; 
#	$srvcobjects_ref->{'ttc-etap'}{'ports'}{'tcp'}{'2675'}++	; 
#	$ports_ref->{'tcp'}{'2675'}{'name'} = 'ttc-etap'		; 
#	$srvcobjects_ref->{'legent-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'legent-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'legent-1'}{'port'}{'udp'} = '373'	; 
#	$srvcobjects_ref->{'legent-1'}{'ports'}{'udp'}{'373'}++	; 
#	$ports_ref->{'udp'}{'373'}{'name'} = 'legent-1'		; 
#	$srvcobjects_ref->{'legent-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'legent-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'legent-1'}{'port'}{'tcp'} = '373'	; 
#	$srvcobjects_ref->{'legent-1'}{'ports'}{'tcp'}{'373'}++	; 
#	$ports_ref->{'tcp'}{'373'}{'name'} = 'legent-1'		; 
#	$srvcobjects_ref->{'dsatp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsatp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsatp'}{'port'}{'udp'} = '2111'	; 
#	$srvcobjects_ref->{'dsatp'}{'ports'}{'udp'}{'2111'}++	; 
#	$ports_ref->{'udp'}{'2111'}{'name'} = 'dsatp'		; 
#	$srvcobjects_ref->{'dsatp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsatp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsatp'}{'port'}{'tcp'} = '2111'	; 
#	$srvcobjects_ref->{'dsatp'}{'ports'}{'tcp'}{'2111'}++	; 
#	$ports_ref->{'tcp'}{'2111'}{'name'} = 'dsatp'		; 
#	$srvcobjects_ref->{'rtsp-alt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtsp-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsp-alt'}{'port'}{'udp'} = '8554'	; 
#	$srvcobjects_ref->{'rtsp-alt'}{'ports'}{'udp'}{'8554'}++	; 
#	$ports_ref->{'udp'}{'8554'}{'name'} = 'rtsp-alt'		; 
#	$srvcobjects_ref->{'rtsp-alt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtsp-alt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsp-alt'}{'port'}{'tcp'} = '8554'	; 
#	$srvcobjects_ref->{'rtsp-alt'}{'ports'}{'tcp'}{'8554'}++	; 
#	$ports_ref->{'tcp'}{'8554'}{'name'} = 'rtsp-alt'		; 
#	$srvcobjects_ref->{'spsc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spsc'}{'port'}{'udp'} = '478'	; 
#	$srvcobjects_ref->{'spsc'}{'ports'}{'udp'}{'478'}++	; 
#	$ports_ref->{'udp'}{'478'}{'name'} = 'spsc'		; 
#	$srvcobjects_ref->{'spsc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spsc'}{'port'}{'tcp'} = '478'	; 
#	$srvcobjects_ref->{'spsc'}{'ports'}{'tcp'}{'478'}++	; 
#	$ports_ref->{'tcp'}{'478'}{'name'} = 'spsc'		; 
#	$srvcobjects_ref->{'acl-manager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acl-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acl-manager'}{'port'}{'udp'} = '4013'	; 
#	$srvcobjects_ref->{'acl-manager'}{'ports'}{'udp'}{'4013'}++	; 
#	$ports_ref->{'udp'}{'4013'}{'name'} = 'acl-manager'		; 
#	$srvcobjects_ref->{'acl-manager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acl-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acl-manager'}{'port'}{'tcp'} = '4013'	; 
#	$srvcobjects_ref->{'acl-manager'}{'ports'}{'tcp'}{'4013'}++	; 
#	$ports_ref->{'tcp'}{'4013'}{'name'} = 'acl-manager'		; 
#	$srvcobjects_ref->{'bsquare-voip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bsquare-voip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bsquare-voip'}{'port'}{'udp'} = '1071'	; 
#	$srvcobjects_ref->{'bsquare-voip'}{'ports'}{'udp'}{'1071'}++	; 
#	$ports_ref->{'udp'}{'1071'}{'name'} = 'bsquare-voip'		; 
#	$srvcobjects_ref->{'bsquare-voip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bsquare-voip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bsquare-voip'}{'port'}{'tcp'} = '1071'	; 
#	$srvcobjects_ref->{'bsquare-voip'}{'ports'}{'tcp'}{'1071'}++	; 
#	$ports_ref->{'tcp'}{'1071'}{'name'} = 'bsquare-voip'		; 
#	$srvcobjects_ref->{'micromuse-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'micromuse-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micromuse-lm'}{'port'}{'udp'} = '1534'	; 
#	$srvcobjects_ref->{'micromuse-lm'}{'ports'}{'udp'}{'1534'}++	; 
#	$ports_ref->{'udp'}{'1534'}{'name'} = 'micromuse-lm'		; 
#	$srvcobjects_ref->{'micromuse-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'micromuse-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micromuse-lm'}{'port'}{'tcp'} = '1534'	; 
#	$srvcobjects_ref->{'micromuse-lm'}{'ports'}{'tcp'}{'1534'}++	; 
#	$ports_ref->{'tcp'}{'1534'}{'name'} = 'micromuse-lm'		; 
#	$srvcobjects_ref->{'apple-licman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apple-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apple-licman'}{'port'}{'udp'} = '1381'	; 
#	$srvcobjects_ref->{'apple-licman'}{'ports'}{'udp'}{'1381'}++	; 
#	$ports_ref->{'udp'}{'1381'}{'name'} = 'apple-licman'		; 
#	$srvcobjects_ref->{'apple-licman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apple-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apple-licman'}{'port'}{'tcp'} = '1381'	; 
#	$srvcobjects_ref->{'apple-licman'}{'ports'}{'tcp'}{'1381'}++	; 
#	$ports_ref->{'tcp'}{'1381'}{'name'} = 'apple-licman'		; 
#	$srvcobjects_ref->{'aspen-services'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aspen-services'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aspen-services'}{'port'}{'udp'} = '1749'	; 
#	$srvcobjects_ref->{'aspen-services'}{'ports'}{'udp'}{'1749'}++	; 
#	$ports_ref->{'udp'}{'1749'}{'name'} = 'aspen-services'		; 
#	$srvcobjects_ref->{'aspen-services'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aspen-services'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aspen-services'}{'port'}{'tcp'} = '1749'	; 
#	$srvcobjects_ref->{'aspen-services'}{'ports'}{'tcp'}{'1749'}++	; 
#	$ports_ref->{'tcp'}{'1749'}{'name'} = 'aspen-services'		; 
#	$srvcobjects_ref->{'hsl-storm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hsl-storm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hsl-storm'}{'port'}{'udp'} = '2113'	; 
#	$srvcobjects_ref->{'hsl-storm'}{'ports'}{'udp'}{'2113'}++	; 
#	$ports_ref->{'udp'}{'2113'}{'name'} = 'hsl-storm'		; 
#	$srvcobjects_ref->{'hsl-storm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hsl-storm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hsl-storm'}{'port'}{'tcp'} = '2113'	; 
#	$srvcobjects_ref->{'hsl-storm'}{'ports'}{'tcp'}{'2113'}++	; 
#	$ports_ref->{'tcp'}{'2113'}{'name'} = 'hsl-storm'		; 
#	$srvcobjects_ref->{'g5m'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'g5m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'g5m'}{'port'}{'udp'} = '2732'	; 
#	$srvcobjects_ref->{'g5m'}{'ports'}{'udp'}{'2732'}++	; 
#	$ports_ref->{'udp'}{'2732'}{'name'} = 'g5m'		; 
#	$srvcobjects_ref->{'g5m'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'g5m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'g5m'}{'port'}{'tcp'} = '2732'	; 
#	$srvcobjects_ref->{'g5m'}{'ports'}{'tcp'}{'2732'}++	; 
#	$ports_ref->{'tcp'}{'2732'}{'name'} = 'g5m'		; 
#	$srvcobjects_ref->{'kmscontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kmscontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kmscontrol'}{'port'}{'udp'} = '1773'	; 
#	$srvcobjects_ref->{'kmscontrol'}{'ports'}{'udp'}{'1773'}++	; 
#	$ports_ref->{'udp'}{'1773'}{'name'} = 'kmscontrol'		; 
#	$srvcobjects_ref->{'kmscontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kmscontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kmscontrol'}{'port'}{'tcp'} = '1773'	; 
#	$srvcobjects_ref->{'kmscontrol'}{'ports'}{'tcp'}{'1773'}++	; 
#	$ports_ref->{'tcp'}{'1773'}{'name'} = 'kmscontrol'		; 
#	$srvcobjects_ref->{'netmount'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netmount'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmount'}{'port'}{'udp'} = '2061'	; 
#	$srvcobjects_ref->{'netmount'}{'ports'}{'udp'}{'2061'}++	; 
#	$ports_ref->{'udp'}{'2061'}{'name'} = 'netmount'		; 
#	$srvcobjects_ref->{'netmount'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netmount'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmount'}{'port'}{'tcp'} = '2061'	; 
#	$srvcobjects_ref->{'netmount'}{'ports'}{'tcp'}{'2061'}++	; 
#	$ports_ref->{'tcp'}{'2061'}{'name'} = 'netmount'		; 
#	$srvcobjects_ref->{'miteksys-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'miteksys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miteksys-lm'}{'port'}{'udp'} = '1482'	; 
#	$srvcobjects_ref->{'miteksys-lm'}{'ports'}{'udp'}{'1482'}++	; 
#	$ports_ref->{'udp'}{'1482'}{'name'} = 'miteksys-lm'		; 
#	$srvcobjects_ref->{'miteksys-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'miteksys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miteksys-lm'}{'port'}{'tcp'} = '1482'	; 
#	$srvcobjects_ref->{'miteksys-lm'}{'ports'}{'tcp'}{'1482'}++	; 
#	$ports_ref->{'tcp'}{'1482'}{'name'} = 'miteksys-lm'		; 
#	$srvcobjects_ref->{'ccmcomm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ccmcomm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmcomm'}{'port'}{'udp'} = '3505'	; 
#	$srvcobjects_ref->{'ccmcomm'}{'ports'}{'udp'}{'3505'}++	; 
#	$ports_ref->{'udp'}{'3505'}{'name'} = 'ccmcomm'		; 
#	$srvcobjects_ref->{'ccmcomm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ccmcomm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccmcomm'}{'port'}{'tcp'} = '3505'	; 
#	$srvcobjects_ref->{'ccmcomm'}{'ports'}{'tcp'}{'3505'}++	; 
#	$ports_ref->{'tcp'}{'3505'}{'name'} = 'ccmcomm'		; 
#	$srvcobjects_ref->{'sdo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdo'}{'port'}{'udp'} = '3635'	; 
#	$srvcobjects_ref->{'sdo'}{'ports'}{'udp'}{'3635'}++	; 
#	$ports_ref->{'udp'}{'3635'}{'name'} = 'sdo'		; 
#	$srvcobjects_ref->{'sdo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdo'}{'port'}{'tcp'} = '3635'	; 
#	$srvcobjects_ref->{'sdo'}{'ports'}{'tcp'}{'3635'}++	; 
#	$ports_ref->{'tcp'}{'3635'}{'name'} = 'sdo'		; 
#	$srvcobjects_ref->{'tserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tserver'}{'port'}{'udp'} = '450'	; 
#	$srvcobjects_ref->{'tserver'}{'ports'}{'udp'}{'450'}++	; 
#	$ports_ref->{'udp'}{'450'}{'name'} = 'tserver'		; 
#	$srvcobjects_ref->{'tserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tserver'}{'port'}{'tcp'} = '450'	; 
#	$srvcobjects_ref->{'tserver'}{'ports'}{'tcp'}{'450'}++	; 
#	$ports_ref->{'tcp'}{'450'}{'name'} = 'tserver'		; 
#	$srvcobjects_ref->{'dhe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dhe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhe'}{'port'}{'udp'} = '3252'	; 
#	$srvcobjects_ref->{'dhe'}{'ports'}{'udp'}{'3252'}++	; 
#	$ports_ref->{'udp'}{'3252'}{'name'} = 'dhe'		; 
#	$srvcobjects_ref->{'dhe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dhe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhe'}{'port'}{'tcp'} = '3252'	; 
#	$srvcobjects_ref->{'dhe'}{'ports'}{'tcp'}{'3252'}++	; 
#	$ports_ref->{'tcp'}{'3252'}{'name'} = 'dhe'		; 
#	$srvcobjects_ref->{'laplink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'laplink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'laplink'}{'port'}{'udp'} = '1547'	; 
#	$srvcobjects_ref->{'laplink'}{'ports'}{'udp'}{'1547'}++	; 
#	$ports_ref->{'udp'}{'1547'}{'name'} = 'laplink'		; 
#	$srvcobjects_ref->{'laplink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'laplink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'laplink'}{'port'}{'tcp'} = '1547'	; 
#	$srvcobjects_ref->{'laplink'}{'ports'}{'tcp'}{'1547'}++	; 
#	$ports_ref->{'tcp'}{'1547'}{'name'} = 'laplink'		; 
#	$srvcobjects_ref->{'mentaserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mentaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mentaserver'}{'port'}{'udp'} = '2118'	; 
#	$srvcobjects_ref->{'mentaserver'}{'ports'}{'udp'}{'2118'}++	; 
#	$ports_ref->{'udp'}{'2118'}{'name'} = 'mentaserver'		; 
#	$srvcobjects_ref->{'mentaserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mentaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mentaserver'}{'port'}{'tcp'} = '2118'	; 
#	$srvcobjects_ref->{'mentaserver'}{'ports'}{'tcp'}{'2118'}++	; 
#	$ports_ref->{'tcp'}{'2118'}{'name'} = 'mentaserver'		; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'port'}{'udp'} = '1346'	; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'ports'}{'udp'}{'1346'}++	; 
#	$ports_ref->{'udp'}{'1346'}{'name'} = 'alta-ana-lm'		; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'port'}{'tcp'} = '1346'	; 
#	$srvcobjects_ref->{'alta-ana-lm'}{'ports'}{'tcp'}{'1346'}++	; 
#	$ports_ref->{'tcp'}{'1346'}{'name'} = 'alta-ana-lm'		; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'port'}{'udp'} = '1514'	; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'ports'}{'udp'}{'1514'}++	; 
#	$ports_ref->{'udp'}{'1514'}{'name'} = 'fujitsu-dtcns'		; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'port'}{'tcp'} = '1514'	; 
#	$srvcobjects_ref->{'fujitsu-dtcns'}{'ports'}{'tcp'}{'1514'}++	; 
#	$ports_ref->{'tcp'}{'1514'}{'name'} = 'fujitsu-dtcns'		; 
#	$srvcobjects_ref->{'tripwire'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tripwire'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tripwire'}{'port'}{'udp'} = '1169'	; 
#	$srvcobjects_ref->{'tripwire'}{'ports'}{'udp'}{'1169'}++	; 
#	$ports_ref->{'udp'}{'1169'}{'name'} = 'tripwire'		; 
#	$srvcobjects_ref->{'tripwire'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tripwire'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tripwire'}{'port'}{'tcp'} = '1169'	; 
#	$srvcobjects_ref->{'tripwire'}{'ports'}{'tcp'}{'1169'}++	; 
#	$ports_ref->{'tcp'}{'1169'}{'name'} = 'tripwire'		; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'port'}{'udp'} = '3465'	; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'ports'}{'udp'}{'3465'}++	; 
#	$ports_ref->{'udp'}{'3465'}{'name'} = 'edm-mgr-cntrl'		; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'port'}{'tcp'} = '3465'	; 
#	$srvcobjects_ref->{'edm-mgr-cntrl'}{'ports'}{'tcp'}{'3465'}++	; 
#	$ports_ref->{'tcp'}{'3465'}{'name'} = 'edm-mgr-cntrl'		; 
#	$srvcobjects_ref->{'icg-iprelay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icg-iprelay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icg-iprelay'}{'port'}{'udp'} = '2064'	; 
#	$srvcobjects_ref->{'icg-iprelay'}{'ports'}{'udp'}{'2064'}++	; 
#	$ports_ref->{'udp'}{'2064'}{'name'} = 'icg-iprelay'		; 
#	$srvcobjects_ref->{'icg-iprelay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icg-iprelay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icg-iprelay'}{'port'}{'tcp'} = '2064'	; 
#	$srvcobjects_ref->{'icg-iprelay'}{'ports'}{'tcp'}{'2064'}++	; 
#	$ports_ref->{'tcp'}{'2064'}{'name'} = 'icg-iprelay'		; 
#	$srvcobjects_ref->{'tl1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tl1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1'}{'port'}{'udp'} = '2361'	; 
#	$srvcobjects_ref->{'tl1'}{'ports'}{'udp'}{'2361'}++	; 
#	$ports_ref->{'udp'}{'2361'}{'name'} = 'tl1'		; 
#	$srvcobjects_ref->{'tl1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tl1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1'}{'port'}{'tcp'} = '2361'	; 
#	$srvcobjects_ref->{'tl1'}{'ports'}{'tcp'}{'2361'}++	; 
#	$ports_ref->{'tcp'}{'2361'}{'name'} = 'tl1'		; 
#	$srvcobjects_ref->{'jbroker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jbroker'}{'port'}{'udp'} = '2506'	; 
#	$srvcobjects_ref->{'jbroker'}{'ports'}{'udp'}{'2506'}++	; 
#	$ports_ref->{'udp'}{'2506'}{'name'} = 'jbroker'		; 
#	$srvcobjects_ref->{'jbroker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jbroker'}{'port'}{'tcp'} = '2506'	; 
#	$srvcobjects_ref->{'jbroker'}{'ports'}{'tcp'}{'2506'}++	; 
#	$ports_ref->{'tcp'}{'2506'}{'name'} = 'jbroker'		; 
#	$srvcobjects_ref->{'snpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snpp'}{'port'}{'udp'} = '444'	; 
#	$srvcobjects_ref->{'snpp'}{'ports'}{'udp'}{'444'}++	; 
#	$ports_ref->{'udp'}{'444'}{'name'} = 'snpp'		; 
#	$srvcobjects_ref->{'snpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snpp'}{'port'}{'tcp'} = '444'	; 
#	$srvcobjects_ref->{'snpp'}{'ports'}{'tcp'}{'444'}++	; 
#	$ports_ref->{'tcp'}{'444'}{'name'} = 'snpp'		; 
#	$srvcobjects_ref->{'ldaps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ldaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldaps'}{'port'}{'udp'} = '636'	; 
#	$srvcobjects_ref->{'ldaps'}{'ports'}{'udp'}{'636'}++	; 
#	$ports_ref->{'udp'}{'636'}{'name'} = 'ldaps'		; 
#	$srvcobjects_ref->{'ldaps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ldaps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldaps'}{'port'}{'tcp'} = '636'	; 
#	$srvcobjects_ref->{'ldaps'}{'ports'}{'tcp'}{'636'}++	; 
#	$ports_ref->{'tcp'}{'636'}{'name'} = 'ldaps'		; 
#	$srvcobjects_ref->{'rblcheckd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rblcheckd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rblcheckd'}{'port'}{'udp'} = '3768'	; 
#	$srvcobjects_ref->{'rblcheckd'}{'ports'}{'udp'}{'3768'}++	; 
#	$ports_ref->{'udp'}{'3768'}{'name'} = 'rblcheckd'		; 
#	$srvcobjects_ref->{'rblcheckd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rblcheckd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rblcheckd'}{'port'}{'tcp'} = '3768'	; 
#	$srvcobjects_ref->{'rblcheckd'}{'ports'}{'tcp'}{'3768'}++	; 
#	$ports_ref->{'tcp'}{'3768'}{'name'} = 'rblcheckd'		; 
#	$srvcobjects_ref->{'talarian-tcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talarian-tcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-tcp'}{'port'}{'tcp'} = '5101'	; 
#	$srvcobjects_ref->{'talarian-tcp'}{'ports'}{'tcp'}{'5101'}++	; 
#	$ports_ref->{'tcp'}{'5101'}{'name'} = 'talarian-tcp'		; 
#	$srvcobjects_ref->{'celatalk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'celatalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'celatalk'}{'port'}{'udp'} = '3485'	; 
#	$srvcobjects_ref->{'celatalk'}{'ports'}{'udp'}{'3485'}++	; 
#	$ports_ref->{'udp'}{'3485'}{'name'} = 'celatalk'		; 
#	$srvcobjects_ref->{'celatalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'celatalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'celatalk'}{'port'}{'tcp'} = '3485'	; 
#	$srvcobjects_ref->{'celatalk'}{'ports'}{'tcp'}{'3485'}++	; 
#	$ports_ref->{'tcp'}{'3485'}{'name'} = 'celatalk'		; 
#	$srvcobjects_ref->{'utmpsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'utmpsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utmpsd'}{'port'}{'udp'} = '430'	; 
#	$srvcobjects_ref->{'utmpsd'}{'ports'}{'udp'}{'430'}++	; 
#	$ports_ref->{'udp'}{'430'}{'name'} = 'utmpsd'		; 
#	$srvcobjects_ref->{'utmpsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'utmpsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'utmpsd'}{'port'}{'tcp'} = '430'	; 
#	$srvcobjects_ref->{'utmpsd'}{'ports'}{'tcp'}{'430'}++	; 
#	$ports_ref->{'tcp'}{'430'}{'name'} = 'utmpsd'		; 
#	$srvcobjects_ref->{'lonworks2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lonworks2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lonworks2'}{'port'}{'udp'} = '2541'	; 
#	$srvcobjects_ref->{'lonworks2'}{'ports'}{'udp'}{'2541'}++	; 
#	$ports_ref->{'udp'}{'2541'}{'name'} = 'lonworks2'		; 
#	$srvcobjects_ref->{'lonworks2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lonworks2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lonworks2'}{'port'}{'tcp'} = '2541'	; 
#	$srvcobjects_ref->{'lonworks2'}{'ports'}{'tcp'}{'2541'}++	; 
#	$ports_ref->{'tcp'}{'2541'}{'name'} = 'lonworks2'		; 
#	$srvcobjects_ref->{'salient-mux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'salient-mux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'salient-mux'}{'port'}{'udp'} = '5422'	; 
#	$srvcobjects_ref->{'salient-mux'}{'ports'}{'udp'}{'5422'}++	; 
#	$ports_ref->{'udp'}{'5422'}{'name'} = 'salient-mux'		; 
#	$srvcobjects_ref->{'salient-mux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'salient-mux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'salient-mux'}{'port'}{'tcp'} = '5422'	; 
#	$srvcobjects_ref->{'salient-mux'}{'ports'}{'tcp'}{'5422'}++	; 
#	$ports_ref->{'tcp'}{'5422'}{'name'} = 'salient-mux'		; 
#	$srvcobjects_ref->{'ulpnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ulpnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ulpnet'}{'port'}{'udp'} = '483'	; 
#	$srvcobjects_ref->{'ulpnet'}{'ports'}{'udp'}{'483'}++	; 
#	$ports_ref->{'udp'}{'483'}{'name'} = 'ulpnet'		; 
#	$srvcobjects_ref->{'ulpnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ulpnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ulpnet'}{'port'}{'tcp'} = '483'	; 
#	$srvcobjects_ref->{'ulpnet'}{'ports'}{'tcp'}{'483'}++	; 
#	$ports_ref->{'tcp'}{'483'}{'name'} = 'ulpnet'		; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'port'}{'udp'} = '5969'	; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'ports'}{'udp'}{'5969'}++	; 
#	$ports_ref->{'udp'}{'5969'}{'name'} = 'mppolicy-mgr'		; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'port'}{'tcp'} = '5969'	; 
#	$srvcobjects_ref->{'mppolicy-mgr'}{'ports'}{'tcp'}{'5969'}++	; 
#	$ports_ref->{'tcp'}{'5969'}{'name'} = 'mppolicy-mgr'		; 
#	$srvcobjects_ref->{'svrloc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'svrloc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svrloc'}{'port'}{'udp'} = '427'	; 
#	$srvcobjects_ref->{'svrloc'}{'ports'}{'udp'}{'427'}++	; 
#	$ports_ref->{'udp'}{'427'}{'name'} = 'svrloc'		; 
#	$srvcobjects_ref->{'svrloc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'svrloc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svrloc'}{'port'}{'tcp'} = '427'	; 
#	$srvcobjects_ref->{'svrloc'}{'ports'}{'tcp'}{'427'}++	; 
#	$ports_ref->{'tcp'}{'427'}{'name'} = 'svrloc'		; 
#	$srvcobjects_ref->{'ggz'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ggz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ggz'}{'port'}{'udp'} = '5688'	; 
#	$srvcobjects_ref->{'ggz'}{'ports'}{'udp'}{'5688'}++	; 
#	$ports_ref->{'udp'}{'5688'}{'name'} = 'ggz'		; 
#	$srvcobjects_ref->{'ggz'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ggz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ggz'}{'port'}{'tcp'} = '5688'	; 
#	$srvcobjects_ref->{'ggz'}{'ports'}{'tcp'}{'5688'}++	; 
#	$ports_ref->{'tcp'}{'5688'}{'name'} = 'ggz'		; 
#	$srvcobjects_ref->{'ecmport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ecmport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecmport'}{'port'}{'udp'} = '3524'	; 
#	$srvcobjects_ref->{'ecmport'}{'ports'}{'udp'}{'3524'}++	; 
#	$ports_ref->{'udp'}{'3524'}{'name'} = 'ecmport'		; 
#	$srvcobjects_ref->{'ecmport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ecmport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecmport'}{'port'}{'tcp'} = '3524'	; 
#	$srvcobjects_ref->{'ecmport'}{'ports'}{'tcp'}{'3524'}++	; 
#	$ports_ref->{'tcp'}{'3524'}{'name'} = 'ecmport'		; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'port'}{'udp'} = '3464'	; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'ports'}{'udp'}{'3464'}++	; 
#	$ports_ref->{'udp'}{'3464'}{'name'} = 'edm-mgr-sync'		; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'port'}{'tcp'} = '3464'	; 
#	$srvcobjects_ref->{'edm-mgr-sync'}{'ports'}{'tcp'}{'3464'}++	; 
#	$ports_ref->{'tcp'}{'3464'}{'name'} = 'edm-mgr-sync'		; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'port'}{'udp'} = '2963'	; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'ports'}{'udp'}{'2963'}++	; 
#	$ports_ref->{'udp'}{'2963'}{'name'} = 'iph-policy-adm'		; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'port'}{'tcp'} = '2963'	; 
#	$srvcobjects_ref->{'iph-policy-adm'}{'ports'}{'tcp'}{'2963'}++	; 
#	$ports_ref->{'tcp'}{'2963'}{'name'} = 'iph-policy-adm'		; 
#	$srvcobjects_ref->{'cnhrp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cnhrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnhrp'}{'port'}{'udp'} = '1757'	; 
#	$srvcobjects_ref->{'cnhrp'}{'ports'}{'udp'}{'1757'}++	; 
#	$ports_ref->{'udp'}{'1757'}{'name'} = 'cnhrp'		; 
#	$srvcobjects_ref->{'cnhrp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cnhrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnhrp'}{'port'}{'tcp'} = '1757'	; 
#	$srvcobjects_ref->{'cnhrp'}{'ports'}{'tcp'}{'1757'}++	; 
#	$ports_ref->{'tcp'}{'1757'}{'name'} = 'cnhrp'		; 
#	$srvcobjects_ref->{'tl1-lv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tl1-lv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1-lv'}{'port'}{'udp'} = '3081'	; 
#	$srvcobjects_ref->{'tl1-lv'}{'ports'}{'udp'}{'3081'}++	; 
#	$ports_ref->{'udp'}{'3081'}{'name'} = 'tl1-lv'		; 
#	$srvcobjects_ref->{'tl1-lv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tl1-lv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tl1-lv'}{'port'}{'tcp'} = '3081'	; 
#	$srvcobjects_ref->{'tl1-lv'}{'ports'}{'tcp'}{'3081'}++	; 
#	$ports_ref->{'tcp'}{'3081'}{'name'} = 'tl1-lv'		; 
#	$srvcobjects_ref->{'dsom-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsom-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsom-server'}{'port'}{'udp'} = '3053'	; 
#	$srvcobjects_ref->{'dsom-server'}{'ports'}{'udp'}{'3053'}++	; 
#	$ports_ref->{'udp'}{'3053'}{'name'} = 'dsom-server'		; 
#	$srvcobjects_ref->{'dsom-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsom-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsom-server'}{'port'}{'tcp'} = '3053'	; 
#	$srvcobjects_ref->{'dsom-server'}{'ports'}{'tcp'}{'3053'}++	; 
#	$ports_ref->{'tcp'}{'3053'}{'name'} = 'dsom-server'		; 
#	$srvcobjects_ref->{'windb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'windb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'windb'}{'port'}{'udp'} = '2522'	; 
#	$srvcobjects_ref->{'windb'}{'ports'}{'udp'}{'2522'}++	; 
#	$ports_ref->{'udp'}{'2522'}{'name'} = 'windb'		; 
#	$srvcobjects_ref->{'windb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'windb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'windb'}{'port'}{'tcp'} = '2522'	; 
#	$srvcobjects_ref->{'windb'}{'ports'}{'tcp'}{'2522'}++	; 
#	$ports_ref->{'tcp'}{'2522'}{'name'} = 'windb'		; 
#	$srvcobjects_ref->{'optimanet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'optimanet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optimanet'}{'port'}{'udp'} = '2408'	; 
#	$srvcobjects_ref->{'optimanet'}{'ports'}{'udp'}{'2408'}++	; 
#	$ports_ref->{'udp'}{'2408'}{'name'} = 'optimanet'		; 
#	$srvcobjects_ref->{'optimanet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'optimanet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optimanet'}{'port'}{'tcp'} = '2408'	; 
#	$srvcobjects_ref->{'optimanet'}{'ports'}{'tcp'}{'2408'}++	; 
#	$ports_ref->{'tcp'}{'2408'}{'name'} = 'optimanet'		; 
#	$srvcobjects_ref->{'ttat3lb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttat3lb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttat3lb'}{'port'}{'udp'} = '3579'	; 
#	$srvcobjects_ref->{'ttat3lb'}{'ports'}{'udp'}{'3579'}++	; 
#	$ports_ref->{'udp'}{'3579'}{'name'} = 'ttat3lb'		; 
#	$srvcobjects_ref->{'ttat3lb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttat3lb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttat3lb'}{'port'}{'tcp'} = '3579'	; 
#	$srvcobjects_ref->{'ttat3lb'}{'ports'}{'tcp'}{'3579'}++	; 
#	$ports_ref->{'tcp'}{'3579'}{'name'} = 'ttat3lb'		; 
#	$srvcobjects_ref->{'arepa-cas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arepa-cas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arepa-cas'}{'port'}{'udp'} = '3030'	; 
#	$srvcobjects_ref->{'arepa-cas'}{'ports'}{'udp'}{'3030'}++	; 
#	$ports_ref->{'udp'}{'3030'}{'name'} = 'arepa-cas'		; 
#	$srvcobjects_ref->{'arepa-cas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arepa-cas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arepa-cas'}{'port'}{'tcp'} = '3030'	; 
#	$srvcobjects_ref->{'arepa-cas'}{'ports'}{'tcp'}{'3030'}++	; 
#	$ports_ref->{'tcp'}{'3030'}{'name'} = 'arepa-cas'		; 
#	$srvcobjects_ref->{'sdproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sdproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdproxy'}{'port'}{'udp'} = '1297'	; 
#	$srvcobjects_ref->{'sdproxy'}{'ports'}{'udp'}{'1297'}++	; 
#	$ports_ref->{'udp'}{'1297'}{'name'} = 'sdproxy'		; 
#	$srvcobjects_ref->{'sdproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sdproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sdproxy'}{'port'}{'tcp'} = '1297'	; 
#	$srvcobjects_ref->{'sdproxy'}{'ports'}{'tcp'}{'1297'}++	; 
#	$ports_ref->{'tcp'}{'1297'}{'name'} = 'sdproxy'		; 
#	$srvcobjects_ref->{'l3-exprt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'l3-exprt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l3-exprt'}{'port'}{'udp'} = '2840'	; 
#	$srvcobjects_ref->{'l3-exprt'}{'ports'}{'udp'}{'2840'}++	; 
#	$ports_ref->{'udp'}{'2840'}{'name'} = 'l3-exprt'		; 
#	$srvcobjects_ref->{'l3-exprt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'l3-exprt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'l3-exprt'}{'port'}{'tcp'} = '2840'	; 
#	$srvcobjects_ref->{'l3-exprt'}{'ports'}{'tcp'}{'2840'}++	; 
#	$ports_ref->{'tcp'}{'2840'}{'name'} = 'l3-exprt'		; 
#	$srvcobjects_ref->{'rap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap'}{'port'}{'udp'} = '38'	; 
#	$srvcobjects_ref->{'rap'}{'ports'}{'udp'}{'38'}++	; 
#	$ports_ref->{'udp'}{'38'}{'name'} = 'rap'		; 
#	$srvcobjects_ref->{'rap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap'}{'port'}{'udp'} = '256'	; 
#	$srvcobjects_ref->{'rap'}{'ports'}{'udp'}{'256'}++	; 
#	$ports_ref->{'udp'}{'256'}{'name'} = 'rap'		; 
#	$srvcobjects_ref->{'rap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap'}{'port'}{'tcp'} = '38'	; 
#	$srvcobjects_ref->{'rap'}{'ports'}{'tcp'}{'38'}++	; 
#	$ports_ref->{'tcp'}{'38'}{'name'} = 'rap'		; 
#	$srvcobjects_ref->{'rap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap'}{'port'}{'tcp'} = '256'	; 
#	$srvcobjects_ref->{'rap'}{'ports'}{'tcp'}{'256'}++	; 
#	$ports_ref->{'tcp'}{'256'}{'name'} = 'rap'		; 
#	$srvcobjects_ref->{'netml'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netml'}{'port'}{'udp'} = '2288'	; 
#	$srvcobjects_ref->{'netml'}{'ports'}{'udp'}{'2288'}++	; 
#	$ports_ref->{'udp'}{'2288'}{'name'} = 'netml'		; 
#	$srvcobjects_ref->{'netml'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netml'}{'port'}{'tcp'} = '2288'	; 
#	$srvcobjects_ref->{'netml'}{'ports'}{'tcp'}{'2288'}++	; 
#	$ports_ref->{'tcp'}{'2288'}{'name'} = 'netml'		; 
#	$srvcobjects_ref->{'apparenet-ts'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apparenet-ts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-ts'}{'port'}{'udp'} = '3236'	; 
#	$srvcobjects_ref->{'apparenet-ts'}{'ports'}{'udp'}{'3236'}++	; 
#	$ports_ref->{'udp'}{'3236'}{'name'} = 'apparenet-ts'		; 
#	$srvcobjects_ref->{'apparenet-ts'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apparenet-ts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-ts'}{'port'}{'tcp'} = '3236'	; 
#	$srvcobjects_ref->{'apparenet-ts'}{'ports'}{'tcp'}{'3236'}++	; 
#	$ports_ref->{'tcp'}{'3236'}{'name'} = 'apparenet-ts'		; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'port'}{'udp'} = '2937'	; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'ports'}{'udp'}{'2937'}++	; 
#	$ports_ref->{'udp'}{'2937'}{'name'} = 'pnaconsult-lm'		; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'port'}{'tcp'} = '2937'	; 
#	$srvcobjects_ref->{'pnaconsult-lm'}{'ports'}{'tcp'}{'2937'}++	; 
#	$ports_ref->{'tcp'}{'2937'}{'name'} = 'pnaconsult-lm'		; 
#	$srvcobjects_ref->{'netlock2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netlock2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock2'}{'port'}{'udp'} = '9161'	; 
#	$srvcobjects_ref->{'netlock2'}{'ports'}{'udp'}{'9161'}++	; 
#	$ports_ref->{'udp'}{'9161'}{'name'} = 'netlock2'		; 
#	$srvcobjects_ref->{'netlock2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netlock2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock2'}{'port'}{'tcp'} = '9161'	; 
#	$srvcobjects_ref->{'netlock2'}{'ports'}{'tcp'}{'9161'}++	; 
#	$ports_ref->{'tcp'}{'9161'}{'name'} = 'netlock2'		; 
#	$srvcobjects_ref->{'ezproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ezproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezproxy'}{'port'}{'udp'} = '26260'	; 
#	$srvcobjects_ref->{'ezproxy'}{'ports'}{'udp'}{'26260'}++	; 
#	$ports_ref->{'udp'}{'26260'}{'name'} = 'ezproxy'		; 
#	$srvcobjects_ref->{'ezproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ezproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezproxy'}{'port'}{'tcp'} = '26260'	; 
#	$srvcobjects_ref->{'ezproxy'}{'ports'}{'tcp'}{'26260'}++	; 
#	$ports_ref->{'tcp'}{'26260'}{'name'} = 'ezproxy'		; 
#	$srvcobjects_ref->{'ddi-tcp-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddi-tcp-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-tcp-1'}{'port'}{'tcp'} = '8888'	; 
#	$srvcobjects_ref->{'ddi-tcp-1'}{'ports'}{'tcp'}{'8888'}++	; 
#	$ports_ref->{'tcp'}{'8888'}{'name'} = 'ddi-tcp-1'		; 
#	$srvcobjects_ref->{'npmp-gui'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'npmp-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp-gui'}{'port'}{'udp'} = '611'	; 
#	$srvcobjects_ref->{'npmp-gui'}{'ports'}{'udp'}{'611'}++	; 
#	$ports_ref->{'udp'}{'611'}{'name'} = 'npmp-gui'		; 
#	$srvcobjects_ref->{'npmp-gui'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'npmp-gui'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npmp-gui'}{'port'}{'tcp'} = '611'	; 
#	$srvcobjects_ref->{'npmp-gui'}{'ports'}{'tcp'}{'611'}++	; 
#	$ports_ref->{'tcp'}{'611'}{'name'} = 'npmp-gui'		; 
#	$srvcobjects_ref->{'ridgeway2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ridgeway2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ridgeway2'}{'port'}{'udp'} = '2777'	; 
#	$srvcobjects_ref->{'ridgeway2'}{'ports'}{'udp'}{'2777'}++	; 
#	$ports_ref->{'udp'}{'2777'}{'name'} = 'ridgeway2'		; 
#	$srvcobjects_ref->{'ridgeway2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ridgeway2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ridgeway2'}{'port'}{'tcp'} = '2777'	; 
#	$srvcobjects_ref->{'ridgeway2'}{'ports'}{'tcp'}{'2777'}++	; 
#	$ports_ref->{'tcp'}{'2777'}{'name'} = 'ridgeway2'		; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'port'}{'udp'} = '1458'	; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'ports'}{'udp'}{'1458'}++	; 
#	$ports_ref->{'udp'}{'1458'}{'name'} = 'nrcabq-lm'		; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'port'}{'tcp'} = '1458'	; 
#	$srvcobjects_ref->{'nrcabq-lm'}{'ports'}{'tcp'}{'1458'}++	; 
#	$ports_ref->{'tcp'}{'1458'}{'name'} = 'nrcabq-lm'		; 
#	$srvcobjects_ref->{'dasp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dasp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dasp'}{'port'}{'udp'} = '439'	; 
#	$srvcobjects_ref->{'dasp'}{'ports'}{'udp'}{'439'}++	; 
#	$ports_ref->{'udp'}{'439'}{'name'} = 'dasp'		; 
#	$srvcobjects_ref->{'dasp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dasp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dasp'}{'port'}{'tcp'} = '439'	; 
#	$srvcobjects_ref->{'dasp'}{'ports'}{'tcp'}{'439'}++	; 
#	$ports_ref->{'tcp'}{'439'}{'name'} = 'dasp'		; 
#	$srvcobjects_ref->{'proshare2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proshare2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare2'}{'port'}{'udp'} = '1460'	; 
#	$srvcobjects_ref->{'proshare2'}{'ports'}{'udp'}{'1460'}++	; 
#	$ports_ref->{'udp'}{'1460'}{'name'} = 'proshare2'		; 
#	$srvcobjects_ref->{'proshare2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proshare2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare2'}{'port'}{'tcp'} = '1460'	; 
#	$srvcobjects_ref->{'proshare2'}{'ports'}{'tcp'}{'1460'}++	; 
#	$ports_ref->{'tcp'}{'1460'}{'name'} = 'proshare2'		; 
#	$srvcobjects_ref->{'maytagshuffle'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'maytagshuffle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maytagshuffle'}{'port'}{'udp'} = '2591'	; 
#	$srvcobjects_ref->{'maytagshuffle'}{'ports'}{'udp'}{'2591'}++	; 
#	$ports_ref->{'udp'}{'2591'}{'name'} = 'maytagshuffle'		; 
#	$srvcobjects_ref->{'maytagshuffle'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'maytagshuffle'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'maytagshuffle'}{'port'}{'tcp'} = '2591'	; 
#	$srvcobjects_ref->{'maytagshuffle'}{'ports'}{'tcp'}{'2591'}++	; 
#	$ports_ref->{'tcp'}{'2591'}{'name'} = 'maytagshuffle'		; 
#	$srvcobjects_ref->{'integral'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'integral'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'integral'}{'port'}{'udp'} = '3459'	; 
#	$srvcobjects_ref->{'integral'}{'ports'}{'udp'}{'3459'}++	; 
#	$ports_ref->{'udp'}{'3459'}{'name'} = 'integral'		; 
#	$srvcobjects_ref->{'integral'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'integral'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'integral'}{'port'}{'tcp'} = '3459'	; 
#	$srvcobjects_ref->{'integral'}{'ports'}{'tcp'}{'3459'}++	; 
#	$ports_ref->{'tcp'}{'3459'}{'name'} = 'integral'		; 
#	$srvcobjects_ref->{'gprs-sig'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gprs-sig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gprs-sig'}{'port'}{'udp'} = '3386'	; 
#	$srvcobjects_ref->{'gprs-sig'}{'ports'}{'udp'}{'3386'}++	; 
#	$ports_ref->{'udp'}{'3386'}{'name'} = 'gprs-sig'		; 
#	$srvcobjects_ref->{'cvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvc'}{'port'}{'udp'} = '1495'	; 
#	$srvcobjects_ref->{'cvc'}{'ports'}{'udp'}{'1495'}++	; 
#	$ports_ref->{'udp'}{'1495'}{'name'} = 'cvc'		; 
#	$srvcobjects_ref->{'cvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvc'}{'port'}{'tcp'} = '1495'	; 
#	$srvcobjects_ref->{'cvc'}{'ports'}{'tcp'}{'1495'}++	; 
#	$ports_ref->{'tcp'}{'1495'}{'name'} = 'cvc'		; 
#	$srvcobjects_ref->{'nbx-cc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nbx-cc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-cc'}{'port'}{'udp'} = '2093'	; 
#	$srvcobjects_ref->{'nbx-cc'}{'ports'}{'udp'}{'2093'}++	; 
#	$ports_ref->{'udp'}{'2093'}{'name'} = 'nbx-cc'		; 
#	$srvcobjects_ref->{'nbx-cc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nbx-cc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nbx-cc'}{'port'}{'tcp'} = '2093'	; 
#	$srvcobjects_ref->{'nbx-cc'}{'ports'}{'tcp'}{'2093'}++	; 
#	$ports_ref->{'tcp'}{'2093'}{'name'} = 'nbx-cc'		; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'port'}{'udp'} = '2536'	; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'ports'}{'udp'}{'2536'}++	; 
#	$ports_ref->{'udp'}{'2536'}{'name'} = 'btpp2audctr1'		; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'port'}{'tcp'} = '2536'	; 
#	$srvcobjects_ref->{'btpp2audctr1'}{'ports'}{'tcp'}{'2536'}++	; 
#	$ports_ref->{'tcp'}{'2536'}{'name'} = 'btpp2audctr1'		; 
#	$srvcobjects_ref->{'cisco-fna'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cisco-fna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-fna'}{'port'}{'udp'} = '130'	; 
#	$srvcobjects_ref->{'cisco-fna'}{'ports'}{'udp'}{'130'}++	; 
#	$ports_ref->{'udp'}{'130'}{'name'} = 'cisco-fna'		; 
#	$srvcobjects_ref->{'cisco-fna'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cisco-fna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-fna'}{'port'}{'tcp'} = '130'	; 
#	$srvcobjects_ref->{'cisco-fna'}{'ports'}{'tcp'}{'130'}++	; 
#	$ports_ref->{'tcp'}{'130'}{'name'} = 'cisco-fna'		; 
#	$srvcobjects_ref->{'plato-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'plato-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plato-lm'}{'port'}{'udp'} = '1819'	; 
#	$srvcobjects_ref->{'plato-lm'}{'ports'}{'udp'}{'1819'}++	; 
#	$ports_ref->{'udp'}{'1819'}{'name'} = 'plato-lm'		; 
#	$srvcobjects_ref->{'plato-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'plato-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plato-lm'}{'port'}{'tcp'} = '1819'	; 
#	$srvcobjects_ref->{'plato-lm'}{'ports'}{'tcp'}{'1819'}++	; 
#	$ports_ref->{'tcp'}{'1819'}{'name'} = 'plato-lm'		; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'port'}{'udp'} = '5007'	; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'ports'}{'udp'}{'5007'}++	; 
#	$ports_ref->{'udp'}{'5007'}{'name'} = 'wsm-server-ssl'		; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'port'}{'tcp'} = '5007'	; 
#	$srvcobjects_ref->{'wsm-server-ssl'}{'ports'}{'tcp'}{'5007'}++	; 
#	$ports_ref->{'tcp'}{'5007'}{'name'} = 'wsm-server-ssl'		; 
#	$srvcobjects_ref->{'hpstgmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpstgmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpstgmgr'}{'port'}{'udp'} = '2600'	; 
#	$srvcobjects_ref->{'hpstgmgr'}{'ports'}{'udp'}{'2600'}++	; 
#	$ports_ref->{'udp'}{'2600'}{'name'} = 'hpstgmgr'		; 
#	$srvcobjects_ref->{'hpstgmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpstgmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpstgmgr'}{'port'}{'tcp'} = '2600'	; 
#	$srvcobjects_ref->{'hpstgmgr'}{'ports'}{'tcp'}{'2600'}++	; 
#	$ports_ref->{'tcp'}{'2600'}{'name'} = 'hpstgmgr'		; 
#	$srvcobjects_ref->{'ampr-info'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ampr-info'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ampr-info'}{'port'}{'udp'} = '1535'	; 
#	$srvcobjects_ref->{'ampr-info'}{'ports'}{'udp'}{'1535'}++	; 
#	$ports_ref->{'udp'}{'1535'}{'name'} = 'ampr-info'		; 
#	$srvcobjects_ref->{'ampr-info'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ampr-info'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ampr-info'}{'port'}{'tcp'} = '1535'	; 
#	$srvcobjects_ref->{'ampr-info'}{'ports'}{'tcp'}{'1535'}++	; 
#	$ports_ref->{'tcp'}{'1535'}{'name'} = 'ampr-info'		; 
#	$srvcobjects_ref->{'n2h2server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'n2h2server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n2h2server'}{'port'}{'udp'} = '9285'	; 
#	$srvcobjects_ref->{'n2h2server'}{'ports'}{'udp'}{'9285'}++	; 
#	$ports_ref->{'udp'}{'9285'}{'name'} = 'n2h2server'		; 
#	$srvcobjects_ref->{'n2h2server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'n2h2server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'n2h2server'}{'port'}{'tcp'} = '9285'	; 
#	$srvcobjects_ref->{'n2h2server'}{'ports'}{'tcp'}{'9285'}++	; 
#	$ports_ref->{'tcp'}{'9285'}{'name'} = 'n2h2server'		; 
#	$srvcobjects_ref->{'neveroffline'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'neveroffline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neveroffline'}{'port'}{'udp'} = '2614'	; 
#	$srvcobjects_ref->{'neveroffline'}{'ports'}{'udp'}{'2614'}++	; 
#	$ports_ref->{'udp'}{'2614'}{'name'} = 'neveroffline'		; 
#	$srvcobjects_ref->{'neveroffline'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'neveroffline'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neveroffline'}{'port'}{'tcp'} = '2614'	; 
#	$srvcobjects_ref->{'neveroffline'}{'ports'}{'tcp'}{'2614'}++	; 
#	$ports_ref->{'tcp'}{'2614'}{'name'} = 'neveroffline'		; 
#	$srvcobjects_ref->{'rpc2portmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rpc2portmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rpc2portmap'}{'port'}{'udp'} = '369'	; 
#	$srvcobjects_ref->{'rpc2portmap'}{'ports'}{'udp'}{'369'}++	; 
#	$ports_ref->{'udp'}{'369'}{'name'} = 'rpc2portmap'		; 
#	$srvcobjects_ref->{'rpc2portmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rpc2portmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rpc2portmap'}{'port'}{'tcp'} = '369'	; 
#	$srvcobjects_ref->{'rpc2portmap'}{'ports'}{'tcp'}{'369'}++	; 
#	$ports_ref->{'tcp'}{'369'}{'name'} = 'rpc2portmap'		; 
#	$srvcobjects_ref->{'univ-appserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'univ-appserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'univ-appserver'}{'port'}{'udp'} = '1233'	; 
#	$srvcobjects_ref->{'univ-appserver'}{'ports'}{'udp'}{'1233'}++	; 
#	$ports_ref->{'udp'}{'1233'}{'name'} = 'univ-appserver'		; 
#	$srvcobjects_ref->{'univ-appserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'univ-appserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'univ-appserver'}{'port'}{'tcp'} = '1233'	; 
#	$srvcobjects_ref->{'univ-appserver'}{'ports'}{'tcp'}{'1233'}++	; 
#	$ports_ref->{'tcp'}{'1233'}{'name'} = 'univ-appserver'		; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'port'}{'udp'} = '1420'	; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'ports'}{'udp'}{'1420'}++	; 
#	$ports_ref->{'udp'}{'1420'}{'name'} = 'timbuktu-srv4'		; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'port'}{'tcp'} = '1420'	; 
#	$srvcobjects_ref->{'timbuktu-srv4'}{'ports'}{'tcp'}{'1420'}++	; 
#	$ports_ref->{'tcp'}{'1420'}{'name'} = 'timbuktu-srv4'		; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'port'}{'udp'} = '2824'	; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'ports'}{'udp'}{'2824'}++	; 
#	$ports_ref->{'udp'}{'2824'}{'name'} = 'cqg-netlan-1'		; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'port'}{'tcp'} = '2824'	; 
#	$srvcobjects_ref->{'cqg-netlan-1'}{'ports'}{'tcp'}{'2824'}++	; 
#	$ports_ref->{'tcp'}{'2824'}{'name'} = 'cqg-netlan-1'		; 
#	$srvcobjects_ref->{'service-ctrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'service-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'service-ctrl'}{'port'}{'udp'} = '2367'	; 
#	$srvcobjects_ref->{'service-ctrl'}{'ports'}{'udp'}{'2367'}++	; 
#	$ports_ref->{'udp'}{'2367'}{'name'} = 'service-ctrl'		; 
#	$srvcobjects_ref->{'service-ctrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'service-ctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'service-ctrl'}{'port'}{'tcp'} = '2367'	; 
#	$srvcobjects_ref->{'service-ctrl'}{'ports'}{'tcp'}{'2367'}++	; 
#	$ports_ref->{'tcp'}{'2367'}{'name'} = 'service-ctrl'		; 
#	$srvcobjects_ref->{'pacom'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pacom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pacom'}{'port'}{'udp'} = '3435'	; 
#	$srvcobjects_ref->{'pacom'}{'ports'}{'udp'}{'3435'}++	; 
#	$ports_ref->{'udp'}{'3435'}{'name'} = 'pacom'		; 
#	$srvcobjects_ref->{'pacom'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pacom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pacom'}{'port'}{'tcp'} = '3435'	; 
#	$srvcobjects_ref->{'pacom'}{'ports'}{'tcp'}{'3435'}++	; 
#	$ports_ref->{'tcp'}{'3435'}{'name'} = 'pacom'		; 
#	$srvcobjects_ref->{'aspeclmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aspeclmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aspeclmd'}{'port'}{'udp'} = '1544'	; 
#	$srvcobjects_ref->{'aspeclmd'}{'ports'}{'udp'}{'1544'}++	; 
#	$ports_ref->{'udp'}{'1544'}{'name'} = 'aspeclmd'		; 
#	$srvcobjects_ref->{'aspeclmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aspeclmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aspeclmd'}{'port'}{'tcp'} = '1544'	; 
#	$srvcobjects_ref->{'aspeclmd'}{'ports'}{'tcp'}{'1544'}++	; 
#	$ports_ref->{'tcp'}{'1544'}{'name'} = 'aspeclmd'		; 
#	$srvcobjects_ref->{'clutild'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'clutild'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clutild'}{'port'}{'udp'} = '7174'	; 
#	$srvcobjects_ref->{'clutild'}{'ports'}{'udp'}{'7174'}++	; 
#	$ports_ref->{'udp'}{'7174'}{'name'} = 'clutild'		; 
#	$srvcobjects_ref->{'clutild'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'clutild'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clutild'}{'port'}{'tcp'} = '7174'	; 
#	$srvcobjects_ref->{'clutild'}{'ports'}{'tcp'}{'7174'}++	; 
#	$ports_ref->{'tcp'}{'7174'}{'name'} = 'clutild'		; 
#	$srvcobjects_ref->{'lnvpoller'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lnvpoller'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvpoller'}{'port'}{'udp'} = '2280'	; 
#	$srvcobjects_ref->{'lnvpoller'}{'ports'}{'udp'}{'2280'}++	; 
#	$ports_ref->{'udp'}{'2280'}{'name'} = 'lnvpoller'		; 
#	$srvcobjects_ref->{'lnvpoller'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lnvpoller'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lnvpoller'}{'port'}{'tcp'} = '2280'	; 
#	$srvcobjects_ref->{'lnvpoller'}{'ports'}{'tcp'}{'2280'}++	; 
#	$ports_ref->{'tcp'}{'2280'}{'name'} = 'lnvpoller'		; 
#	$srvcobjects_ref->{'is99c'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'is99c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'is99c'}{'port'}{'udp'} = '379'	; 
#	$srvcobjects_ref->{'is99c'}{'ports'}{'udp'}{'379'}++	; 
#	$ports_ref->{'udp'}{'379'}{'name'} = 'is99c'		; 
#	$srvcobjects_ref->{'is99c'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'is99c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'is99c'}{'port'}{'tcp'} = '379'	; 
#	$srvcobjects_ref->{'is99c'}{'ports'}{'tcp'}{'379'}++	; 
#	$ports_ref->{'tcp'}{'379'}{'name'} = 'is99c'		; 
#	$srvcobjects_ref->{'ncpm-hip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncpm-hip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncpm-hip'}{'port'}{'udp'} = '1683'	; 
#	$srvcobjects_ref->{'ncpm-hip'}{'ports'}{'udp'}{'1683'}++	; 
#	$ports_ref->{'udp'}{'1683'}{'name'} = 'ncpm-hip'		; 
#	$srvcobjects_ref->{'ncpm-hip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncpm-hip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncpm-hip'}{'port'}{'tcp'} = '1683'	; 
#	$srvcobjects_ref->{'ncpm-hip'}{'ports'}{'tcp'}{'1683'}++	; 
#	$ports_ref->{'tcp'}{'1683'}{'name'} = 'ncpm-hip'		; 
#	$srvcobjects_ref->{'altav-tunnel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'altav-tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altav-tunnel'}{'port'}{'udp'} = '3265'	; 
#	$srvcobjects_ref->{'altav-tunnel'}{'ports'}{'udp'}{'3265'}++	; 
#	$ports_ref->{'udp'}{'3265'}{'name'} = 'altav-tunnel'		; 
#	$srvcobjects_ref->{'altav-tunnel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'altav-tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'altav-tunnel'}{'port'}{'tcp'} = '3265'	; 
#	$srvcobjects_ref->{'altav-tunnel'}{'ports'}{'tcp'}{'3265'}++	; 
#	$ports_ref->{'tcp'}{'3265'}{'name'} = 'altav-tunnel'		; 
#	$srvcobjects_ref->{'jtag-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jtag-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jtag-server'}{'port'}{'udp'} = '1309'	; 
#	$srvcobjects_ref->{'jtag-server'}{'ports'}{'udp'}{'1309'}++	; 
#	$ports_ref->{'udp'}{'1309'}{'name'} = 'jtag-server'		; 
#	$srvcobjects_ref->{'jtag-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jtag-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jtag-server'}{'port'}{'tcp'} = '1309'	; 
#	$srvcobjects_ref->{'jtag-server'}{'ports'}{'tcp'}{'1309'}++	; 
#	$ports_ref->{'tcp'}{'1309'}{'name'} = 'jtag-server'		; 
#	$srvcobjects_ref->{'e-woa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'e-woa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e-woa'}{'port'}{'udp'} = '3728'	; 
#	$srvcobjects_ref->{'e-woa'}{'ports'}{'udp'}{'3728'}++	; 
#	$ports_ref->{'udp'}{'3728'}{'name'} = 'e-woa'		; 
#	$srvcobjects_ref->{'e-woa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'e-woa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'e-woa'}{'port'}{'tcp'} = '3728'	; 
#	$srvcobjects_ref->{'e-woa'}{'ports'}{'tcp'}{'3728'}++	; 
#	$ports_ref->{'tcp'}{'3728'}{'name'} = 'e-woa'		; 
#	$srvcobjects_ref->{'rtsserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtsserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsserv'}{'port'}{'udp'} = '2500'	; 
#	$srvcobjects_ref->{'rtsserv'}{'ports'}{'udp'}{'2500'}++	; 
#	$ports_ref->{'udp'}{'2500'}{'name'} = 'rtsserv'		; 
#	$srvcobjects_ref->{'rtsserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtsserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsserv'}{'port'}{'tcp'} = '2500'	; 
#	$srvcobjects_ref->{'rtsserv'}{'ports'}{'tcp'}{'2500'}++	; 
#	$ports_ref->{'tcp'}{'2500'}{'name'} = 'rtsserv'		; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'port'}{'udp'} = '7004'	; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'ports'}{'udp'}{'7004'}++	; 
#	$ports_ref->{'udp'}{'7004'}{'name'} = 'afs3-kaserver'		; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'port'}{'tcp'} = '7004'	; 
#	$srvcobjects_ref->{'afs3-kaserver'}{'ports'}{'tcp'}{'7004'}++	; 
#	$ports_ref->{'tcp'}{'7004'}{'name'} = 'afs3-kaserver'		; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'port'}{'udp'} = '3382'	; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'ports'}{'udp'}{'3382'}++	; 
#	$ports_ref->{'udp'}{'3382'}{'name'} = 'fujitsu-neat'		; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'port'}{'tcp'} = '3382'	; 
#	$srvcobjects_ref->{'fujitsu-neat'}{'ports'}{'tcp'}{'3382'}++	; 
#	$ports_ref->{'tcp'}{'3382'}{'name'} = 'fujitsu-neat'		; 
#	$srvcobjects_ref->{'fjippol-port1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjippol-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-port1'}{'port'}{'udp'} = '2750'	; 
#	$srvcobjects_ref->{'fjippol-port1'}{'ports'}{'udp'}{'2750'}++	; 
#	$ports_ref->{'udp'}{'2750'}{'name'} = 'fjippol-port1'		; 
#	$srvcobjects_ref->{'fjippol-port1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjippol-port1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-port1'}{'port'}{'tcp'} = '2750'	; 
#	$srvcobjects_ref->{'fjippol-port1'}{'ports'}{'tcp'}{'2750'}++	; 
#	$ports_ref->{'tcp'}{'2750'}{'name'} = 'fjippol-port1'		; 
#	$srvcobjects_ref->{'pnet-enc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pnet-enc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnet-enc'}{'port'}{'udp'} = '7798'	; 
#	$srvcobjects_ref->{'pnet-enc'}{'ports'}{'udp'}{'7798'}++	; 
#	$ports_ref->{'udp'}{'7798'}{'name'} = 'pnet-enc'		; 
#	$srvcobjects_ref->{'pnet-enc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pnet-enc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pnet-enc'}{'port'}{'tcp'} = '7798'	; 
#	$srvcobjects_ref->{'pnet-enc'}{'ports'}{'tcp'}{'7798'}++	; 
#	$ports_ref->{'tcp'}{'7798'}{'name'} = 'pnet-enc'		; 
#	$srvcobjects_ref->{'silkp1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'silkp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp1'}{'port'}{'udp'} = '2829'	; 
#	$srvcobjects_ref->{'silkp1'}{'ports'}{'udp'}{'2829'}++	; 
#	$ports_ref->{'udp'}{'2829'}{'name'} = 'silkp1'		; 
#	$srvcobjects_ref->{'silkp1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'silkp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp1'}{'port'}{'tcp'} = '2829'	; 
#	$srvcobjects_ref->{'silkp1'}{'ports'}{'tcp'}{'2829'}++	; 
#	$ports_ref->{'tcp'}{'2829'}{'name'} = 'silkp1'		; 
#	$srvcobjects_ref->{'tacacs-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tacacs-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacacs-ds'}{'port'}{'udp'} = '65'	; 
#	$srvcobjects_ref->{'tacacs-ds'}{'ports'}{'udp'}{'65'}++	; 
#	$ports_ref->{'udp'}{'65'}{'name'} = 'tacacs-ds'		; 
#	$srvcobjects_ref->{'tacacs-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tacacs-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacacs-ds'}{'port'}{'tcp'} = '65'	; 
#	$srvcobjects_ref->{'tacacs-ds'}{'ports'}{'tcp'}{'65'}++	; 
#	$ports_ref->{'tcp'}{'65'}{'name'} = 'tacacs-ds'		; 
#	$srvcobjects_ref->{'aamp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aamp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aamp'}{'port'}{'udp'} = '3939'	; 
#	$srvcobjects_ref->{'aamp'}{'ports'}{'udp'}{'3939'}++	; 
#	$ports_ref->{'udp'}{'3939'}{'name'} = 'aamp'		; 
#	$srvcobjects_ref->{'aamp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aamp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aamp'}{'port'}{'tcp'} = '3939'	; 
#	$srvcobjects_ref->{'aamp'}{'ports'}{'tcp'}{'3939'}++	; 
#	$ports_ref->{'tcp'}{'3939'}{'name'} = 'aamp'		; 
#	$srvcobjects_ref->{'surveyinst'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'surveyinst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'surveyinst'}{'port'}{'udp'} = '3212'	; 
#	$srvcobjects_ref->{'surveyinst'}{'ports'}{'udp'}{'3212'}++	; 
#	$ports_ref->{'udp'}{'3212'}{'name'} = 'surveyinst'		; 
#	$srvcobjects_ref->{'surveyinst'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'surveyinst'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'surveyinst'}{'port'}{'tcp'} = '3212'	; 
#	$srvcobjects_ref->{'surveyinst'}{'ports'}{'tcp'}{'3212'}++	; 
#	$ports_ref->{'tcp'}{'3212'}{'name'} = 'surveyinst'		; 
#	$srvcobjects_ref->{'c-h-it-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'c-h-it-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'c-h-it-port'}{'port'}{'udp'} = '3778'	; 
#	$srvcobjects_ref->{'c-h-it-port'}{'ports'}{'udp'}{'3778'}++	; 
#	$ports_ref->{'udp'}{'3778'}{'name'} = 'c-h-it-port'		; 
#	$srvcobjects_ref->{'c-h-it-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'c-h-it-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'c-h-it-port'}{'port'}{'tcp'} = '3778'	; 
#	$srvcobjects_ref->{'c-h-it-port'}{'ports'}{'tcp'}{'3778'}++	; 
#	$ports_ref->{'tcp'}{'3778'}{'name'} = 'c-h-it-port'		; 
#	$srvcobjects_ref->{'esip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esip'}{'port'}{'udp'} = '2950'	; 
#	$srvcobjects_ref->{'esip'}{'ports'}{'udp'}{'2950'}++	; 
#	$ports_ref->{'udp'}{'2950'}{'name'} = 'esip'		; 
#	$srvcobjects_ref->{'esip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esip'}{'port'}{'tcp'} = '2950'	; 
#	$srvcobjects_ref->{'esip'}{'ports'}{'tcp'}{'2950'}++	; 
#	$ports_ref->{'tcp'}{'2950'}{'name'} = 'esip'		; 
#	$srvcobjects_ref->{'vvr-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vvr-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vvr-control'}{'port'}{'udp'} = '4145'	; 
#	$srvcobjects_ref->{'vvr-control'}{'ports'}{'udp'}{'4145'}++	; 
#	$ports_ref->{'udp'}{'4145'}{'name'} = 'vvr-control'		; 
#	$srvcobjects_ref->{'vvr-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vvr-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vvr-control'}{'port'}{'tcp'} = '4145'	; 
#	$srvcobjects_ref->{'vvr-control'}{'ports'}{'tcp'}{'4145'}++	; 
#	$ports_ref->{'tcp'}{'4145'}{'name'} = 'vvr-control'		; 
#	$srvcobjects_ref->{'softdataphone'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'softdataphone'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softdataphone'}{'port'}{'udp'} = '1621'	; 
#	$srvcobjects_ref->{'softdataphone'}{'ports'}{'udp'}{'1621'}++	; 
#	$ports_ref->{'udp'}{'1621'}{'name'} = 'softdataphone'		; 
#	$srvcobjects_ref->{'softdataphone'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'softdataphone'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'softdataphone'}{'port'}{'tcp'} = '1621'	; 
#	$srvcobjects_ref->{'softdataphone'}{'ports'}{'tcp'}{'1621'}++	; 
#	$ports_ref->{'tcp'}{'1621'}{'name'} = 'softdataphone'		; 
#	$srvcobjects_ref->{'varadero-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'varadero-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'varadero-2'}{'port'}{'udp'} = '4839'	; 
#	$srvcobjects_ref->{'varadero-2'}{'ports'}{'udp'}{'4839'}++	; 
#	$ports_ref->{'udp'}{'4839'}{'name'} = 'varadero-2'		; 
#	$srvcobjects_ref->{'varadero-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'varadero-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'varadero-2'}{'port'}{'tcp'} = '4839'	; 
#	$srvcobjects_ref->{'varadero-2'}{'ports'}{'tcp'}{'4839'}++	; 
#	$ports_ref->{'tcp'}{'4839'}{'name'} = 'varadero-2'		; 
#	$srvcobjects_ref->{'pmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmd'}{'port'}{'udp'} = '7431'	; 
#	$srvcobjects_ref->{'pmd'}{'ports'}{'udp'}{'7431'}++	; 
#	$ports_ref->{'udp'}{'7431'}{'name'} = 'pmd'		; 
#	$srvcobjects_ref->{'pmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmd'}{'port'}{'tcp'} = '7431'	; 
#	$srvcobjects_ref->{'pmd'}{'ports'}{'tcp'}{'7431'}++	; 
#	$ports_ref->{'tcp'}{'7431'}{'name'} = 'pmd'		; 
#	$srvcobjects_ref->{'dtn1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dtn1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtn1'}{'port'}{'udp'} = '2445'	; 
#	$srvcobjects_ref->{'dtn1'}{'ports'}{'udp'}{'2445'}++	; 
#	$ports_ref->{'udp'}{'2445'}{'name'} = 'dtn1'		; 
#	$srvcobjects_ref->{'dtn1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dtn1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtn1'}{'port'}{'tcp'} = '2445'	; 
#	$srvcobjects_ref->{'dtn1'}{'ports'}{'tcp'}{'2445'}++	; 
#	$ports_ref->{'tcp'}{'2445'}{'name'} = 'dtn1'		; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'port'}{'udp'} = '5145'	; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'ports'}{'udp'}{'5145'}++	; 
#	$ports_ref->{'udp'}{'5145'}{'name'} = 'rmonitor_secure'		; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'port'}{'tcp'} = '5145'	; 
#	$srvcobjects_ref->{'rmonitor_secure'}{'ports'}{'tcp'}{'5145'}++	; 
#	$ports_ref->{'tcp'}{'5145'}{'name'} = 'rmonitor_secure'		; 
#	$srvcobjects_ref->{'raadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raadmin'}{'port'}{'udp'} = '5676'	; 
#	$srvcobjects_ref->{'raadmin'}{'ports'}{'udp'}{'5676'}++	; 
#	$ports_ref->{'udp'}{'5676'}{'name'} = 'raadmin'		; 
#	$srvcobjects_ref->{'raadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raadmin'}{'port'}{'tcp'} = '5676'	; 
#	$srvcobjects_ref->{'raadmin'}{'ports'}{'tcp'}{'5676'}++	; 
#	$ports_ref->{'tcp'}{'5676'}{'name'} = 'raadmin'		; 
#	$srvcobjects_ref->{'iclpv-dm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclpv-dm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-dm'}{'port'}{'udp'} = '1389'	; 
#	$srvcobjects_ref->{'iclpv-dm'}{'ports'}{'udp'}{'1389'}++	; 
#	$ports_ref->{'udp'}{'1389'}{'name'} = 'iclpv-dm'		; 
#	$srvcobjects_ref->{'iclpv-dm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclpv-dm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-dm'}{'port'}{'tcp'} = '1389'	; 
#	$srvcobjects_ref->{'iclpv-dm'}{'ports'}{'tcp'}{'1389'}++	; 
#	$ports_ref->{'tcp'}{'1389'}{'name'} = 'iclpv-dm'		; 
#	$srvcobjects_ref->{'eba'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eba'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eba'}{'port'}{'udp'} = '45678'	; 
#	$srvcobjects_ref->{'eba'}{'ports'}{'udp'}{'45678'}++	; 
#	$ports_ref->{'udp'}{'45678'}{'name'} = 'eba'		; 
#	$srvcobjects_ref->{'eba'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eba'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eba'}{'port'}{'tcp'} = '45678'	; 
#	$srvcobjects_ref->{'eba'}{'ports'}{'tcp'}{'45678'}++	; 
#	$ports_ref->{'tcp'}{'45678'}{'name'} = 'eba'		; 
#	$srvcobjects_ref->{'journee'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'journee'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'journee'}{'port'}{'udp'} = '3042'	; 
#	$srvcobjects_ref->{'journee'}{'ports'}{'udp'}{'3042'}++	; 
#	$ports_ref->{'udp'}{'3042'}{'name'} = 'journee'		; 
#	$srvcobjects_ref->{'journee'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'journee'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'journee'}{'port'}{'tcp'} = '3042'	; 
#	$srvcobjects_ref->{'journee'}{'ports'}{'tcp'}{'3042'}++	; 
#	$ports_ref->{'tcp'}{'3042'}{'name'} = 'journee'		; 
#	$srvcobjects_ref->{'sgmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sgmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgmp'}{'port'}{'udp'} = '153'	; 
#	$srvcobjects_ref->{'sgmp'}{'ports'}{'udp'}{'153'}++	; 
#	$ports_ref->{'udp'}{'153'}{'name'} = 'sgmp'		; 
#	$srvcobjects_ref->{'sgmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sgmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgmp'}{'port'}{'tcp'} = '153'	; 
#	$srvcobjects_ref->{'sgmp'}{'ports'}{'tcp'}{'153'}++	; 
#	$ports_ref->{'tcp'}{'153'}{'name'} = 'sgmp'		; 
#	$srvcobjects_ref->{'bootclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bootclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bootclient'}{'port'}{'udp'} = '2017'	; 
#	$srvcobjects_ref->{'bootclient'}{'ports'}{'udp'}{'2017'}++	; 
#	$ports_ref->{'udp'}{'2017'}{'name'} = 'bootclient'		; 
#	$srvcobjects_ref->{'imsldoc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imsldoc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imsldoc'}{'port'}{'udp'} = '2035'	; 
#	$srvcobjects_ref->{'imsldoc'}{'ports'}{'udp'}{'2035'}++	; 
#	$ports_ref->{'udp'}{'2035'}{'name'} = 'imsldoc'		; 
#	$srvcobjects_ref->{'imsldoc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imsldoc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imsldoc'}{'port'}{'tcp'} = '2035'	; 
#	$srvcobjects_ref->{'imsldoc'}{'ports'}{'tcp'}{'2035'}++	; 
#	$ports_ref->{'tcp'}{'2035'}{'name'} = 'imsldoc'		; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'port'}{'udp'} = '3179'	; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'ports'}{'udp'}{'3179'}++	; 
#	$ports_ref->{'udp'}{'3179'}{'name'} = 'h2gf-w-2m'		; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'port'}{'tcp'} = '3179'	; 
#	$srvcobjects_ref->{'h2gf-w-2m'}{'ports'}{'tcp'}{'3179'}++	; 
#	$ports_ref->{'tcp'}{'3179'}{'name'} = 'h2gf-w-2m'		; 
#	$srvcobjects_ref->{'commandport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'commandport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commandport'}{'port'}{'udp'} = '3416'	; 
#	$srvcobjects_ref->{'commandport'}{'ports'}{'udp'}{'3416'}++	; 
#	$ports_ref->{'udp'}{'3416'}{'name'} = 'commandport'		; 
#	$srvcobjects_ref->{'commandport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'commandport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commandport'}{'port'}{'tcp'} = '3416'	; 
#	$srvcobjects_ref->{'commandport'}{'ports'}{'tcp'}{'3416'}++	; 
#	$ports_ref->{'tcp'}{'3416'}{'name'} = 'commandport'		; 
#	$srvcobjects_ref->{'resource_mgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'resource_mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'resource_mgr'}{'port'}{'udp'} = '3019'	; 
#	$srvcobjects_ref->{'resource_mgr'}{'ports'}{'udp'}{'3019'}++	; 
#	$ports_ref->{'udp'}{'3019'}{'name'} = 'resource_mgr'		; 
#	$srvcobjects_ref->{'resource_mgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'resource_mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'resource_mgr'}{'port'}{'tcp'} = '3019'	; 
#	$srvcobjects_ref->{'resource_mgr'}{'ports'}{'tcp'}{'3019'}++	; 
#	$ports_ref->{'tcp'}{'3019'}{'name'} = 'resource_mgr'		; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'port'}{'udp'} = '3210'	; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'ports'}{'udp'}{'3210'}++	; 
#	$ports_ref->{'udp'}{'3210'}{'name'} = 'flamenco-proxy'		; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'port'}{'tcp'} = '3210'	; 
#	$srvcobjects_ref->{'flamenco-proxy'}{'ports'}{'tcp'}{'3210'}++	; 
#	$ports_ref->{'tcp'}{'3210'}{'name'} = 'flamenco-proxy'		; 
#	$srvcobjects_ref->{'lyskom'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lyskom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lyskom'}{'port'}{'udp'} = '4894'	; 
#	$srvcobjects_ref->{'lyskom'}{'ports'}{'udp'}{'4894'}++	; 
#	$ports_ref->{'udp'}{'4894'}{'name'} = 'lyskom'		; 
#	$srvcobjects_ref->{'lyskom'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lyskom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lyskom'}{'port'}{'tcp'} = '4894'	; 
#	$srvcobjects_ref->{'lyskom'}{'ports'}{'tcp'}{'4894'}++	; 
#	$ports_ref->{'tcp'}{'4894'}{'name'} = 'lyskom'		; 
#	$srvcobjects_ref->{'ovtopmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovtopmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovtopmd'}{'port'}{'udp'} = '2532'	; 
#	$srvcobjects_ref->{'ovtopmd'}{'ports'}{'udp'}{'2532'}++	; 
#	$ports_ref->{'udp'}{'2532'}{'name'} = 'ovtopmd'		; 
#	$srvcobjects_ref->{'ovtopmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovtopmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovtopmd'}{'port'}{'tcp'} = '2532'	; 
#	$srvcobjects_ref->{'ovtopmd'}{'ports'}{'tcp'}{'2532'}++	; 
#	$ports_ref->{'tcp'}{'2532'}{'name'} = 'ovtopmd'		; 
#	$srvcobjects_ref->{'track'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'track'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'track'}{'port'}{'udp'} = '20670'	; 
#	$srvcobjects_ref->{'track'}{'ports'}{'udp'}{'20670'}++	; 
#	$ports_ref->{'udp'}{'20670'}{'name'} = 'track'		; 
#	$srvcobjects_ref->{'track'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'track'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'track'}{'port'}{'tcp'} = '20670'	; 
#	$srvcobjects_ref->{'track'}{'ports'}{'tcp'}{'20670'}++	; 
#	$ports_ref->{'tcp'}{'20670'}{'name'} = 'track'		; 
#	$srvcobjects_ref->{'trip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trip'}{'port'}{'udp'} = '6069'	; 
#	$srvcobjects_ref->{'trip'}{'ports'}{'udp'}{'6069'}++	; 
#	$ports_ref->{'udp'}{'6069'}{'name'} = 'trip'		; 
#	$srvcobjects_ref->{'trip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trip'}{'port'}{'tcp'} = '6069'	; 
#	$srvcobjects_ref->{'trip'}{'ports'}{'tcp'}{'6069'}++	; 
#	$ports_ref->{'tcp'}{'6069'}{'name'} = 'trip'		; 
#	$srvcobjects_ref->{'nsc-ccs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsc-ccs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsc-ccs'}{'port'}{'udp'} = '2604'	; 
#	$srvcobjects_ref->{'nsc-ccs'}{'ports'}{'udp'}{'2604'}++	; 
#	$ports_ref->{'udp'}{'2604'}{'name'} = 'nsc-ccs'		; 
#	$srvcobjects_ref->{'nsc-ccs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsc-ccs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsc-ccs'}{'port'}{'tcp'} = '2604'	; 
#	$srvcobjects_ref->{'nsc-ccs'}{'ports'}{'tcp'}{'2604'}++	; 
#	$ports_ref->{'tcp'}{'2604'}{'name'} = 'nsc-ccs'		; 
#	$srvcobjects_ref->{'lbc-measure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lbc-measure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-measure'}{'port'}{'udp'} = '2815'	; 
#	$srvcobjects_ref->{'lbc-measure'}{'ports'}{'udp'}{'2815'}++	; 
#	$ports_ref->{'udp'}{'2815'}{'name'} = 'lbc-measure'		; 
#	$srvcobjects_ref->{'lbc-measure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lbc-measure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-measure'}{'port'}{'tcp'} = '2815'	; 
#	$srvcobjects_ref->{'lbc-measure'}{'ports'}{'tcp'}{'2815'}++	; 
#	$ports_ref->{'tcp'}{'2815'}{'name'} = 'lbc-measure'		; 
#	$srvcobjects_ref->{'rlzdbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rlzdbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rlzdbase'}{'port'}{'udp'} = '635'	; 
#	$srvcobjects_ref->{'rlzdbase'}{'ports'}{'udp'}{'635'}++	; 
#	$ports_ref->{'udp'}{'635'}{'name'} = 'rlzdbase'		; 
#	$srvcobjects_ref->{'rlzdbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rlzdbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rlzdbase'}{'port'}{'tcp'} = '635'	; 
#	$srvcobjects_ref->{'rlzdbase'}{'ports'}{'tcp'}{'635'}++	; 
#	$ports_ref->{'tcp'}{'635'}{'name'} = 'rlzdbase'		; 
#	$srvcobjects_ref->{'vieo-fe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vieo-fe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vieo-fe'}{'port'}{'udp'} = '3245'	; 
#	$srvcobjects_ref->{'vieo-fe'}{'ports'}{'udp'}{'3245'}++	; 
#	$ports_ref->{'udp'}{'3245'}{'name'} = 'vieo-fe'		; 
#	$srvcobjects_ref->{'vieo-fe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vieo-fe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vieo-fe'}{'port'}{'tcp'} = '3245'	; 
#	$srvcobjects_ref->{'vieo-fe'}{'ports'}{'tcp'}{'3245'}++	; 
#	$ports_ref->{'tcp'}{'3245'}{'name'} = 'vieo-fe'		; 
#	$srvcobjects_ref->{'unify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unify'}{'port'}{'udp'} = '181'	; 
#	$srvcobjects_ref->{'unify'}{'ports'}{'udp'}{'181'}++	; 
#	$ports_ref->{'udp'}{'181'}{'name'} = 'unify'		; 
#	$srvcobjects_ref->{'unify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unify'}{'port'}{'tcp'} = '181'	; 
#	$srvcobjects_ref->{'unify'}{'ports'}{'tcp'}{'181'}++	; 
#	$ports_ref->{'tcp'}{'181'}{'name'} = 'unify'		; 
#	$srvcobjects_ref->{'av-emb-config'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'av-emb-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'av-emb-config'}{'port'}{'udp'} = '2050'	; 
#	$srvcobjects_ref->{'av-emb-config'}{'ports'}{'udp'}{'2050'}++	; 
#	$ports_ref->{'udp'}{'2050'}{'name'} = 'av-emb-config'		; 
#	$srvcobjects_ref->{'av-emb-config'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'av-emb-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'av-emb-config'}{'port'}{'tcp'} = '2050'	; 
#	$srvcobjects_ref->{'av-emb-config'}{'ports'}{'tcp'}{'2050'}++	; 
#	$ports_ref->{'tcp'}{'2050'}{'name'} = 'av-emb-config'		; 
#	$srvcobjects_ref->{'ncu-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncu-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncu-2'}{'port'}{'udp'} = '3196'	; 
#	$srvcobjects_ref->{'ncu-2'}{'ports'}{'udp'}{'3196'}++	; 
#	$ports_ref->{'udp'}{'3196'}{'name'} = 'ncu-2'		; 
#	$srvcobjects_ref->{'ncu-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncu-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncu-2'}{'port'}{'tcp'} = '3196'	; 
#	$srvcobjects_ref->{'ncu-2'}{'ports'}{'tcp'}{'3196'}++	; 
#	$ports_ref->{'tcp'}{'3196'}{'name'} = 'ncu-2'		; 
#	$srvcobjects_ref->{'synapse'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synapse'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synapse'}{'port'}{'udp'} = '2880'	; 
#	$srvcobjects_ref->{'synapse'}{'ports'}{'udp'}{'2880'}++	; 
#	$ports_ref->{'udp'}{'2880'}{'name'} = 'synapse'		; 
#	$srvcobjects_ref->{'synapse'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synapse'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synapse'}{'port'}{'tcp'} = '2880'	; 
#	$srvcobjects_ref->{'synapse'}{'ports'}{'tcp'}{'2880'}++	; 
#	$ports_ref->{'tcp'}{'2880'}{'name'} = 'synapse'		; 
#	$srvcobjects_ref->{'cft-6'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-6'}{'port'}{'udp'} = '1767'	; 
#	$srvcobjects_ref->{'cft-6'}{'ports'}{'udp'}{'1767'}++	; 
#	$ports_ref->{'udp'}{'1767'}{'name'} = 'cft-6'		; 
#	$srvcobjects_ref->{'cft-6'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-6'}{'port'}{'tcp'} = '1767'	; 
#	$srvcobjects_ref->{'cft-6'}{'ports'}{'tcp'}{'1767'}++	; 
#	$ports_ref->{'tcp'}{'1767'}{'name'} = 'cft-6'		; 
#	$srvcobjects_ref->{'news'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'news'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'news'}{'port'}{'tcp'} = '2009'	; 
#	$srvcobjects_ref->{'news'}{'ports'}{'tcp'}{'2009'}++	; 
#	$ports_ref->{'tcp'}{'2009'}{'name'} = 'news'		; 
#	$srvcobjects_ref->{'sns-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-agent'}{'port'}{'udp'} = '5417'	; 
#	$srvcobjects_ref->{'sns-agent'}{'ports'}{'udp'}{'5417'}++	; 
#	$ports_ref->{'udp'}{'5417'}{'name'} = 'sns-agent'		; 
#	$srvcobjects_ref->{'sns-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-agent'}{'port'}{'tcp'} = '5417'	; 
#	$srvcobjects_ref->{'sns-agent'}{'ports'}{'tcp'}{'5417'}++	; 
#	$ports_ref->{'tcp'}{'5417'}{'name'} = 'sns-agent'		; 
#	$srvcobjects_ref->{'itelserverport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itelserverport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itelserverport'}{'port'}{'udp'} = '3719'	; 
#	$srvcobjects_ref->{'itelserverport'}{'ports'}{'udp'}{'3719'}++	; 
#	$ports_ref->{'udp'}{'3719'}{'name'} = 'itelserverport'		; 
#	$srvcobjects_ref->{'itelserverport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itelserverport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itelserverport'}{'port'}{'tcp'} = '3719'	; 
#	$srvcobjects_ref->{'itelserverport'}{'ports'}{'tcp'}{'3719'}++	; 
#	$ports_ref->{'tcp'}{'3719'}{'name'} = 'itelserverport'		; 
#	$srvcobjects_ref->{'connendp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'connendp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connendp'}{'port'}{'udp'} = '693'	; 
#	$srvcobjects_ref->{'connendp'}{'ports'}{'udp'}{'693'}++	; 
#	$ports_ref->{'udp'}{'693'}{'name'} = 'connendp'		; 
#	$srvcobjects_ref->{'connendp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'connendp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connendp'}{'port'}{'tcp'} = '693'	; 
#	$srvcobjects_ref->{'connendp'}{'ports'}{'tcp'}{'693'}++	; 
#	$ports_ref->{'tcp'}{'693'}{'name'} = 'connendp'		; 
#	$srvcobjects_ref->{'poweroncontact'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'poweroncontact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'poweroncontact'}{'port'}{'udp'} = '3167'	; 
#	$srvcobjects_ref->{'poweroncontact'}{'ports'}{'udp'}{'3167'}++	; 
#	$ports_ref->{'udp'}{'3167'}{'name'} = 'poweroncontact'		; 
#	$srvcobjects_ref->{'poweroncontact'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'poweroncontact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'poweroncontact'}{'port'}{'tcp'} = '3167'	; 
#	$srvcobjects_ref->{'poweroncontact'}{'ports'}{'tcp'}{'3167'}++	; 
#	$ports_ref->{'tcp'}{'3167'}{'name'} = 'poweroncontact'		; 
#	$srvcobjects_ref->{'ivecon-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ivecon-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivecon-port'}{'port'}{'udp'} = '3258'	; 
#	$srvcobjects_ref->{'ivecon-port'}{'ports'}{'udp'}{'3258'}++	; 
#	$ports_ref->{'udp'}{'3258'}{'name'} = 'ivecon-port'		; 
#	$srvcobjects_ref->{'ivecon-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ivecon-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ivecon-port'}{'port'}{'tcp'} = '3258'	; 
#	$srvcobjects_ref->{'ivecon-port'}{'ports'}{'tcp'}{'3258'}++	; 
#	$ports_ref->{'tcp'}{'3258'}{'name'} = 'ivecon-port'		; 
#	$srvcobjects_ref->{'soap-beep'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'soap-beep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'soap-beep'}{'port'}{'udp'} = '605'	; 
#	$srvcobjects_ref->{'soap-beep'}{'ports'}{'udp'}{'605'}++	; 
#	$ports_ref->{'udp'}{'605'}{'name'} = 'soap-beep'		; 
#	$srvcobjects_ref->{'soap-beep'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'soap-beep'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'soap-beep'}{'port'}{'tcp'} = '605'	; 
#	$srvcobjects_ref->{'soap-beep'}{'ports'}{'tcp'}{'605'}++	; 
#	$ports_ref->{'tcp'}{'605'}{'name'} = 'soap-beep'		; 
#	$srvcobjects_ref->{'ldxp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ldxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldxp'}{'port'}{'udp'} = '4042'	; 
#	$srvcobjects_ref->{'ldxp'}{'ports'}{'udp'}{'4042'}++	; 
#	$ports_ref->{'udp'}{'4042'}{'name'} = 'ldxp'		; 
#	$srvcobjects_ref->{'ldxp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ldxp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldxp'}{'port'}{'tcp'} = '4042'	; 
#	$srvcobjects_ref->{'ldxp'}{'ports'}{'tcp'}{'4042'}++	; 
#	$ports_ref->{'tcp'}{'4042'}{'name'} = 'ldxp'		; 
#	$srvcobjects_ref->{'ctx-bridge'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctx-bridge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctx-bridge'}{'port'}{'udp'} = '3127'	; 
#	$srvcobjects_ref->{'ctx-bridge'}{'ports'}{'udp'}{'3127'}++	; 
#	$ports_ref->{'udp'}{'3127'}{'name'} = 'ctx-bridge'		; 
#	$srvcobjects_ref->{'ctx-bridge'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctx-bridge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctx-bridge'}{'port'}{'tcp'} = '3127'	; 
#	$srvcobjects_ref->{'ctx-bridge'}{'ports'}{'tcp'}{'3127'}++	; 
#	$ports_ref->{'tcp'}{'3127'}{'name'} = 'ctx-bridge'		; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'port'}{'udp'} = '3221'	; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'ports'}{'udp'}{'3221'}++	; 
#	$ports_ref->{'udp'}{'3221'}{'name'} = 'xnm-clear-text'		; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'port'}{'tcp'} = '3221'	; 
#	$srvcobjects_ref->{'xnm-clear-text'}{'ports'}{'tcp'}{'3221'}++	; 
#	$ports_ref->{'tcp'}{'3221'}{'name'} = 'xnm-clear-text'		; 
#	$srvcobjects_ref->{'rbakcup1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rbakcup1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rbakcup1'}{'port'}{'udp'} = '2773'	; 
#	$srvcobjects_ref->{'rbakcup1'}{'ports'}{'udp'}{'2773'}++	; 
#	$ports_ref->{'udp'}{'2773'}{'name'} = 'rbakcup1'		; 
#	$srvcobjects_ref->{'rbakcup1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rbakcup1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rbakcup1'}{'port'}{'tcp'} = '2773'	; 
#	$srvcobjects_ref->{'rbakcup1'}{'ports'}{'tcp'}{'2773'}++	; 
#	$ports_ref->{'tcp'}{'2773'}{'name'} = 'rbakcup1'		; 
#	$srvcobjects_ref->{'ss7ns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ss7ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ss7ns'}{'port'}{'udp'} = '477'	; 
#	$srvcobjects_ref->{'ss7ns'}{'ports'}{'udp'}{'477'}++	; 
#	$ports_ref->{'udp'}{'477'}{'name'} = 'ss7ns'		; 
#	$srvcobjects_ref->{'ss7ns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ss7ns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ss7ns'}{'port'}{'tcp'} = '477'	; 
#	$srvcobjects_ref->{'ss7ns'}{'ports'}{'tcp'}{'477'}++	; 
#	$ports_ref->{'tcp'}{'477'}{'name'} = 'ss7ns'		; 
#	$srvcobjects_ref->{'qnxnetman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qnxnetman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qnxnetman'}{'port'}{'udp'} = '3385'	; 
#	$srvcobjects_ref->{'qnxnetman'}{'ports'}{'udp'}{'3385'}++	; 
#	$ports_ref->{'udp'}{'3385'}{'name'} = 'qnxnetman'		; 
#	$srvcobjects_ref->{'qnxnetman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qnxnetman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qnxnetman'}{'port'}{'tcp'} = '3385'	; 
#	$srvcobjects_ref->{'qnxnetman'}{'ports'}{'tcp'}{'3385'}++	; 
#	$ports_ref->{'tcp'}{'3385'}{'name'} = 'qnxnetman'		; 
#	$srvcobjects_ref->{'pk-electronics'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pk-electronics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pk-electronics'}{'port'}{'udp'} = '2634'	; 
#	$srvcobjects_ref->{'pk-electronics'}{'ports'}{'udp'}{'2634'}++	; 
#	$ports_ref->{'udp'}{'2634'}{'name'} = 'pk-electronics'		; 
#	$srvcobjects_ref->{'pk-electronics'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pk-electronics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pk-electronics'}{'port'}{'tcp'} = '2634'	; 
#	$srvcobjects_ref->{'pk-electronics'}{'ports'}{'tcp'}{'2634'}++	; 
#	$ports_ref->{'tcp'}{'2634'}{'name'} = 'pk-electronics'		; 
#	$srvcobjects_ref->{'cnip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cnip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnip'}{'port'}{'udp'} = '1638'	; 
#	$srvcobjects_ref->{'cnip'}{'ports'}{'udp'}{'1638'}++	; 
#	$ports_ref->{'udp'}{'1638'}{'name'} = 'cnip'		; 
#	$srvcobjects_ref->{'cnip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cnip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnip'}{'port'}{'tcp'} = '1638'	; 
#	$srvcobjects_ref->{'cnip'}{'ports'}{'tcp'}{'1638'}++	; 
#	$ports_ref->{'tcp'}{'1638'}{'name'} = 'cnip'		; 
#	$srvcobjects_ref->{'pegboard'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pegboard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pegboard'}{'port'}{'udp'} = '1357'	; 
#	$srvcobjects_ref->{'pegboard'}{'ports'}{'udp'}{'1357'}++	; 
#	$ports_ref->{'udp'}{'1357'}{'name'} = 'pegboard'		; 
#	$srvcobjects_ref->{'pegboard'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pegboard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pegboard'}{'port'}{'tcp'} = '1357'	; 
#	$srvcobjects_ref->{'pegboard'}{'ports'}{'tcp'}{'1357'}++	; 
#	$ports_ref->{'tcp'}{'1357'}{'name'} = 'pegboard'		; 
#	$srvcobjects_ref->{'fpo-fns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fpo-fns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fpo-fns'}{'port'}{'udp'} = '1066'	; 
#	$srvcobjects_ref->{'fpo-fns'}{'ports'}{'udp'}{'1066'}++	; 
#	$ports_ref->{'udp'}{'1066'}{'name'} = 'fpo-fns'		; 
#	$srvcobjects_ref->{'fpo-fns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fpo-fns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fpo-fns'}{'port'}{'tcp'} = '1066'	; 
#	$srvcobjects_ref->{'fpo-fns'}{'ports'}{'tcp'}{'1066'}++	; 
#	$ports_ref->{'tcp'}{'1066'}{'name'} = 'fpo-fns'		; 
#	$srvcobjects_ref->{'osdcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'osdcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'osdcp'}{'port'}{'udp'} = '3432'	; 
#	$srvcobjects_ref->{'osdcp'}{'ports'}{'udp'}{'3432'}++	; 
#	$ports_ref->{'udp'}{'3432'}{'name'} = 'osdcp'		; 
#	$srvcobjects_ref->{'osdcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'osdcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'osdcp'}{'port'}{'tcp'} = '3432'	; 
#	$srvcobjects_ref->{'osdcp'}{'ports'}{'tcp'}{'3432'}++	; 
#	$ports_ref->{'tcp'}{'3432'}{'name'} = 'osdcp'		; 
#	$srvcobjects_ref->{'netbios-dgm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbios-dgm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbios-dgm'}{'port'}{'udp'} = '138'	; 
#	$srvcobjects_ref->{'netbios-dgm'}{'ports'}{'udp'}{'138'}++	; 
#	$ports_ref->{'udp'}{'138'}{'name'} = 'netbios-dgm'		; 
#	$srvcobjects_ref->{'netbios-dgm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbios-dgm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbios-dgm'}{'port'}{'tcp'} = '138'	; 
#	$srvcobjects_ref->{'netbios-dgm'}{'ports'}{'tcp'}{'138'}++	; 
#	$ports_ref->{'tcp'}{'138'}{'name'} = 'netbios-dgm'		; 
#	$srvcobjects_ref->{'wnn6'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wnn6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wnn6'}{'port'}{'udp'} = '22273'	; 
#	$srvcobjects_ref->{'wnn6'}{'ports'}{'udp'}{'22273'}++	; 
#	$ports_ref->{'udp'}{'22273'}{'name'} = 'wnn6'		; 
#	$srvcobjects_ref->{'wnn6'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wnn6'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wnn6'}{'port'}{'tcp'} = '22273'	; 
#	$srvcobjects_ref->{'wnn6'}{'ports'}{'tcp'}{'22273'}++	; 
#	$ports_ref->{'tcp'}{'22273'}{'name'} = 'wnn6'		; 
#	$srvcobjects_ref->{'a1-bs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'a1-bs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a1-bs'}{'port'}{'udp'} = '5603'	; 
#	$srvcobjects_ref->{'a1-bs'}{'ports'}{'udp'}{'5603'}++	; 
#	$ports_ref->{'udp'}{'5603'}{'name'} = 'a1-bs'		; 
#	$srvcobjects_ref->{'a1-bs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'a1-bs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a1-bs'}{'port'}{'tcp'} = '5603'	; 
#	$srvcobjects_ref->{'a1-bs'}{'ports'}{'tcp'}{'5603'}++	; 
#	$ports_ref->{'tcp'}{'5603'}{'name'} = 'a1-bs'		; 
#	$srvcobjects_ref->{'radius-acct'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radius-acct'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radius-acct'}{'port'}{'udp'} = '1813'	; 
#	$srvcobjects_ref->{'radius-acct'}{'ports'}{'udp'}{'1813'}++	; 
#	$ports_ref->{'udp'}{'1813'}{'name'} = 'radius-acct'		; 
#	$srvcobjects_ref->{'radius-acct'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radius-acct'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radius-acct'}{'port'}{'tcp'} = '1813'	; 
#	$srvcobjects_ref->{'radius-acct'}{'ports'}{'tcp'}{'1813'}++	; 
#	$ports_ref->{'tcp'}{'1813'}{'name'} = 'radius-acct'		; 
#	$srvcobjects_ref->{'at-echo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-echo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-echo'}{'port'}{'udp'} = '204'	; 
#	$srvcobjects_ref->{'at-echo'}{'ports'}{'udp'}{'204'}++	; 
#	$ports_ref->{'udp'}{'204'}{'name'} = 'at-echo'		; 
#	$srvcobjects_ref->{'at-echo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-echo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-echo'}{'port'}{'tcp'} = '204'	; 
#	$srvcobjects_ref->{'at-echo'}{'ports'}{'tcp'}{'204'}++	; 
#	$ports_ref->{'tcp'}{'204'}{'name'} = 'at-echo'		; 
#	$srvcobjects_ref->{'aker-cdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aker-cdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aker-cdp'}{'port'}{'udp'} = '2473'	; 
#	$srvcobjects_ref->{'aker-cdp'}{'ports'}{'udp'}{'2473'}++	; 
#	$ports_ref->{'udp'}{'2473'}{'name'} = 'aker-cdp'		; 
#	$srvcobjects_ref->{'aker-cdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aker-cdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aker-cdp'}{'port'}{'tcp'} = '2473'	; 
#	$srvcobjects_ref->{'aker-cdp'}{'ports'}{'tcp'}{'2473'}++	; 
#	$ports_ref->{'tcp'}{'2473'}{'name'} = 'aker-cdp'		; 
#	$srvcobjects_ref->{'niprobe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'niprobe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'niprobe'}{'port'}{'udp'} = '25903'	; 
#	$srvcobjects_ref->{'niprobe'}{'ports'}{'udp'}{'25903'}++	; 
#	$ports_ref->{'udp'}{'25903'}{'name'} = 'niprobe'		; 
#	$srvcobjects_ref->{'niprobe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'niprobe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'niprobe'}{'port'}{'tcp'} = '25903'	; 
#	$srvcobjects_ref->{'niprobe'}{'ports'}{'tcp'}{'25903'}++	; 
#	$ports_ref->{'tcp'}{'25903'}{'name'} = 'niprobe'		; 
#	$srvcobjects_ref->{'tqdata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tqdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tqdata'}{'port'}{'udp'} = '2700'	; 
#	$srvcobjects_ref->{'tqdata'}{'ports'}{'udp'}{'2700'}++	; 
#	$ports_ref->{'udp'}{'2700'}{'name'} = 'tqdata'		; 
#	$srvcobjects_ref->{'tqdata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tqdata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tqdata'}{'port'}{'tcp'} = '2700'	; 
#	$srvcobjects_ref->{'tqdata'}{'ports'}{'tcp'}{'2700'}++	; 
#	$ports_ref->{'tcp'}{'2700'}{'name'} = 'tqdata'		; 
#	$srvcobjects_ref->{'vstat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vstat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vstat'}{'port'}{'udp'} = '7779'	; 
#	$srvcobjects_ref->{'vstat'}{'ports'}{'udp'}{'7779'}++	; 
#	$ports_ref->{'udp'}{'7779'}{'name'} = 'vstat'		; 
#	$srvcobjects_ref->{'vstat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vstat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vstat'}{'port'}{'tcp'} = '7779'	; 
#	$srvcobjects_ref->{'vstat'}{'ports'}{'tcp'}{'7779'}++	; 
#	$ports_ref->{'tcp'}{'7779'}{'name'} = 'vstat'		; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'port'}{'udp'} = '5463'	; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'ports'}{'udp'}{'5463'}++	; 
#	$ports_ref->{'udp'}{'5463'}{'name'} = 'ttlpriceproxy'		; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'port'}{'tcp'} = '5463'	; 
#	$srvcobjects_ref->{'ttlpriceproxy'}{'ports'}{'tcp'}{'5463'}++	; 
#	$ports_ref->{'tcp'}{'5463'}{'name'} = 'ttlpriceproxy'		; 
#	$srvcobjects_ref->{'sf-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sf-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sf-lm'}{'port'}{'udp'} = '4546'	; 
#	$srvcobjects_ref->{'sf-lm'}{'ports'}{'udp'}{'4546'}++	; 
#	$ports_ref->{'udp'}{'4546'}{'name'} = 'sf-lm'		; 
#	$srvcobjects_ref->{'sf-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sf-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sf-lm'}{'port'}{'tcp'} = '4546'	; 
#	$srvcobjects_ref->{'sf-lm'}{'ports'}{'tcp'}{'4546'}++	; 
#	$ports_ref->{'tcp'}{'4546'}{'name'} = 'sf-lm'		; 
#	$srvcobjects_ref->{'pe-mike'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pe-mike'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pe-mike'}{'port'}{'udp'} = '1305'	; 
#	$srvcobjects_ref->{'pe-mike'}{'ports'}{'udp'}{'1305'}++	; 
#	$ports_ref->{'udp'}{'1305'}{'name'} = 'pe-mike'		; 
#	$srvcobjects_ref->{'pe-mike'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pe-mike'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pe-mike'}{'port'}{'tcp'} = '1305'	; 
#	$srvcobjects_ref->{'pe-mike'}{'ports'}{'tcp'}{'1305'}++	; 
#	$ports_ref->{'tcp'}{'1305'}{'name'} = 'pe-mike'		; 
#	$srvcobjects_ref->{'gopher'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gopher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gopher'}{'port'}{'udp'} = '70'	; 
#	$srvcobjects_ref->{'gopher'}{'ports'}{'udp'}{'70'}++	; 
#	$ports_ref->{'udp'}{'70'}{'name'} = 'gopher'		; 
#	$srvcobjects_ref->{'gopher'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gopher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gopher'}{'port'}{'tcp'} = '70'	; 
#	$srvcobjects_ref->{'gopher'}{'ports'}{'tcp'}{'70'}++	; 
#	$ports_ref->{'tcp'}{'70'}{'name'} = 'gopher'		; 
#	$srvcobjects_ref->{'ndl-aps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndl-aps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-aps'}{'port'}{'udp'} = '3096'	; 
#	$srvcobjects_ref->{'ndl-aps'}{'ports'}{'udp'}{'3096'}++	; 
#	$ports_ref->{'udp'}{'3096'}{'name'} = 'ndl-aps'		; 
#	$srvcobjects_ref->{'ndl-aps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndl-aps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndl-aps'}{'port'}{'tcp'} = '3096'	; 
#	$srvcobjects_ref->{'ndl-aps'}{'ports'}{'tcp'}{'3096'}++	; 
#	$ports_ref->{'tcp'}{'3096'}{'name'} = 'ndl-aps'		; 
#	$srvcobjects_ref->{'kryptolan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kryptolan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kryptolan'}{'port'}{'udp'} = '398'	; 
#	$srvcobjects_ref->{'kryptolan'}{'ports'}{'udp'}{'398'}++	; 
#	$ports_ref->{'udp'}{'398'}{'name'} = 'kryptolan'		; 
#	$srvcobjects_ref->{'kryptolan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kryptolan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kryptolan'}{'port'}{'tcp'} = '398'	; 
#	$srvcobjects_ref->{'kryptolan'}{'ports'}{'tcp'}{'398'}++	; 
#	$ports_ref->{'tcp'}{'398'}{'name'} = 'kryptolan'		; 
#	$srvcobjects_ref->{'rfa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rfa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfa'}{'port'}{'udp'} = '4672'	; 
#	$srvcobjects_ref->{'rfa'}{'ports'}{'udp'}{'4672'}++	; 
#	$ports_ref->{'udp'}{'4672'}{'name'} = 'rfa'		; 
#	$srvcobjects_ref->{'rfa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rfa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rfa'}{'port'}{'tcp'} = '4672'	; 
#	$srvcobjects_ref->{'rfa'}{'ports'}{'tcp'}{'4672'}++	; 
#	$ports_ref->{'tcp'}{'4672'}{'name'} = 'rfa'		; 
#	$srvcobjects_ref->{'isoft-p2p'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isoft-p2p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isoft-p2p'}{'port'}{'udp'} = '3501'	; 
#	$srvcobjects_ref->{'isoft-p2p'}{'ports'}{'udp'}{'3501'}++	; 
#	$ports_ref->{'udp'}{'3501'}{'name'} = 'isoft-p2p'		; 
#	$srvcobjects_ref->{'isoft-p2p'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isoft-p2p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isoft-p2p'}{'port'}{'tcp'} = '3501'	; 
#	$srvcobjects_ref->{'isoft-p2p'}{'ports'}{'tcp'}{'3501'}++	; 
#	$ports_ref->{'tcp'}{'3501'}{'name'} = 'isoft-p2p'		; 
#	$srvcobjects_ref->{'ovbus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovbus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovbus'}{'port'}{'udp'} = '7501'	; 
#	$srvcobjects_ref->{'ovbus'}{'ports'}{'udp'}{'7501'}++	; 
#	$ports_ref->{'udp'}{'7501'}{'name'} = 'ovbus'		; 
#	$srvcobjects_ref->{'ovbus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovbus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovbus'}{'port'}{'tcp'} = '7501'	; 
#	$srvcobjects_ref->{'ovbus'}{'ports'}{'tcp'}{'7501'}++	; 
#	$ports_ref->{'tcp'}{'7501'}{'name'} = 'ovbus'		; 
#	$srvcobjects_ref->{'wkars'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wkars'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wkars'}{'port'}{'udp'} = '2720'	; 
#	$srvcobjects_ref->{'wkars'}{'ports'}{'udp'}{'2720'}++	; 
#	$ports_ref->{'udp'}{'2720'}{'name'} = 'wkars'		; 
#	$srvcobjects_ref->{'wkars'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wkars'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wkars'}{'port'}{'tcp'} = '2720'	; 
#	$srvcobjects_ref->{'wkars'}{'ports'}{'tcp'}{'2720'}++	; 
#	$ports_ref->{'tcp'}{'2720'}{'name'} = 'wkars'		; 
#	$srvcobjects_ref->{'hl7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hl7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hl7'}{'port'}{'udp'} = '2575'	; 
#	$srvcobjects_ref->{'hl7'}{'ports'}{'udp'}{'2575'}++	; 
#	$ports_ref->{'udp'}{'2575'}{'name'} = 'hl7'		; 
#	$srvcobjects_ref->{'hl7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hl7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hl7'}{'port'}{'tcp'} = '2575'	; 
#	$srvcobjects_ref->{'hl7'}{'ports'}{'tcp'}{'2575'}++	; 
#	$ports_ref->{'tcp'}{'2575'}{'name'} = 'hl7'		; 
#	$srvcobjects_ref->{'boks_clntd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'boks_clntd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks_clntd'}{'port'}{'udp'} = '6503'	; 
#	$srvcobjects_ref->{'boks_clntd'}{'ports'}{'udp'}{'6503'}++	; 
#	$ports_ref->{'udp'}{'6503'}{'name'} = 'boks_clntd'		; 
#	$srvcobjects_ref->{'boks_clntd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'boks_clntd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'boks_clntd'}{'port'}{'tcp'} = '6503'	; 
#	$srvcobjects_ref->{'boks_clntd'}{'ports'}{'tcp'}{'6503'}++	; 
#	$ports_ref->{'tcp'}{'6503'}{'name'} = 'boks_clntd'		; 
#	$srvcobjects_ref->{'amx-weblinx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amx-weblinx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amx-weblinx'}{'port'}{'udp'} = '2930'	; 
#	$srvcobjects_ref->{'amx-weblinx'}{'ports'}{'udp'}{'2930'}++	; 
#	$ports_ref->{'udp'}{'2930'}{'name'} = 'amx-weblinx'		; 
#	$srvcobjects_ref->{'amx-weblinx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amx-weblinx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amx-weblinx'}{'port'}{'tcp'} = '2930'	; 
#	$srvcobjects_ref->{'amx-weblinx'}{'ports'}{'tcp'}{'2930'}++	; 
#	$ports_ref->{'tcp'}{'2930'}{'name'} = 'amx-weblinx'		; 
#	$srvcobjects_ref->{'msg-icp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msg-icp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msg-icp'}{'port'}{'udp'} = '29'	; 
#	$srvcobjects_ref->{'msg-icp'}{'ports'}{'udp'}{'29'}++	; 
#	$ports_ref->{'udp'}{'29'}{'name'} = 'msg-icp'		; 
#	$srvcobjects_ref->{'msg-icp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msg-icp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msg-icp'}{'port'}{'tcp'} = '29'	; 
#	$srvcobjects_ref->{'msg-icp'}{'ports'}{'tcp'}{'29'}++	; 
#	$ports_ref->{'tcp'}{'29'}{'name'} = 'msg-icp'		; 
#	$srvcobjects_ref->{'msync'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msync'}{'port'}{'udp'} = '2072'	; 
#	$srvcobjects_ref->{'msync'}{'ports'}{'udp'}{'2072'}++	; 
#	$ports_ref->{'udp'}{'2072'}{'name'} = 'msync'		; 
#	$srvcobjects_ref->{'msync'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msync'}{'port'}{'tcp'} = '2072'	; 
#	$srvcobjects_ref->{'msync'}{'ports'}{'tcp'}{'2072'}++	; 
#	$ports_ref->{'tcp'}{'2072'}{'name'} = 'msync'		; 
#	$srvcobjects_ref->{'wins'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wins'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wins'}{'port'}{'udp'} = '1512'	; 
#	$srvcobjects_ref->{'wins'}{'ports'}{'udp'}{'1512'}++	; 
#	$ports_ref->{'udp'}{'1512'}{'name'} = 'wins'		; 
#	$srvcobjects_ref->{'wins'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wins'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wins'}{'port'}{'tcp'} = '1512'	; 
#	$srvcobjects_ref->{'wins'}{'ports'}{'tcp'}{'1512'}++	; 
#	$ports_ref->{'tcp'}{'1512'}{'name'} = 'wins'		; 
#	$srvcobjects_ref->{'gris'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gris'}{'port'}{'udp'} = '2135'	; 
#	$srvcobjects_ref->{'gris'}{'ports'}{'udp'}{'2135'}++	; 
#	$ports_ref->{'udp'}{'2135'}{'name'} = 'gris'		; 
#	$srvcobjects_ref->{'gris'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gris'}{'port'}{'tcp'} = '2135'	; 
#	$srvcobjects_ref->{'gris'}{'ports'}{'tcp'}{'2135'}++	; 
#	$ports_ref->{'tcp'}{'2135'}{'name'} = 'gris'		; 
#	$srvcobjects_ref->{'bpdbm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bpdbm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpdbm'}{'port'}{'udp'} = '13721'	; 
#	$srvcobjects_ref->{'bpdbm'}{'ports'}{'udp'}{'13721'}++	; 
#	$ports_ref->{'udp'}{'13721'}{'name'} = 'bpdbm'		; 
#	$srvcobjects_ref->{'bpdbm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bpdbm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpdbm'}{'port'}{'tcp'} = '13721'	; 
#	$srvcobjects_ref->{'bpdbm'}{'ports'}{'tcp'}{'13721'}++	; 
#	$ports_ref->{'tcp'}{'13721'}{'name'} = 'bpdbm'		; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'port'}{'udp'} = '887'	; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'ports'}{'udp'}{'887'}++	; 
#	$ports_ref->{'udp'}{'887'}{'name'} = 'iclcnet_svinfo'		; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'port'}{'tcp'} = '887'	; 
#	$srvcobjects_ref->{'iclcnet_svinfo'}{'ports'}{'tcp'}{'887'}++	; 
#	$ports_ref->{'tcp'}{'887'}{'name'} = 'iclcnet_svinfo'		; 
#	$srvcobjects_ref->{'igcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'igcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igcp'}{'port'}{'udp'} = '2801'	; 
#	$srvcobjects_ref->{'igcp'}{'ports'}{'udp'}{'2801'}++	; 
#	$ports_ref->{'udp'}{'2801'}{'name'} = 'igcp'		; 
#	$srvcobjects_ref->{'igcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'igcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igcp'}{'port'}{'tcp'} = '2801'	; 
#	$srvcobjects_ref->{'igcp'}{'ports'}{'tcp'}{'2801'}++	; 
#	$ports_ref->{'tcp'}{'2801'}{'name'} = 'igcp'		; 
#	$srvcobjects_ref->{'synotics-relay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synotics-relay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synotics-relay'}{'port'}{'udp'} = '391'	; 
#	$srvcobjects_ref->{'synotics-relay'}{'ports'}{'udp'}{'391'}++	; 
#	$ports_ref->{'udp'}{'391'}{'name'} = 'synotics-relay'		; 
#	$srvcobjects_ref->{'synotics-relay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synotics-relay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synotics-relay'}{'port'}{'tcp'} = '391'	; 
#	$srvcobjects_ref->{'synotics-relay'}{'ports'}{'tcp'}{'391'}++	; 
#	$ports_ref->{'tcp'}{'391'}{'name'} = 'synotics-relay'		; 
#	$srvcobjects_ref->{'aal-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aal-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aal-lm'}{'port'}{'udp'} = '1469'	; 
#	$srvcobjects_ref->{'aal-lm'}{'ports'}{'udp'}{'1469'}++	; 
#	$ports_ref->{'udp'}{'1469'}{'name'} = 'aal-lm'		; 
#	$srvcobjects_ref->{'aal-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aal-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aal-lm'}{'port'}{'tcp'} = '1469'	; 
#	$srvcobjects_ref->{'aal-lm'}{'ports'}{'tcp'}{'1469'}++	; 
#	$ports_ref->{'tcp'}{'1469'}{'name'} = 'aal-lm'		; 
#	$srvcobjects_ref->{'oirtgsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oirtgsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oirtgsvc'}{'port'}{'udp'} = '4141'	; 
#	$srvcobjects_ref->{'oirtgsvc'}{'ports'}{'udp'}{'4141'}++	; 
#	$ports_ref->{'udp'}{'4141'}{'name'} = 'oirtgsvc'		; 
#	$srvcobjects_ref->{'oirtgsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oirtgsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oirtgsvc'}{'port'}{'tcp'} = '4141'	; 
#	$srvcobjects_ref->{'oirtgsvc'}{'ports'}{'tcp'}{'4141'}++	; 
#	$ports_ref->{'tcp'}{'4141'}{'name'} = 'oirtgsvc'		; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'port'}{'udp'} = '1660'	; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'ports'}{'udp'}{'1660'}++	; 
#	$ports_ref->{'udp'}{'1660'}{'name'} = 'skip-mc-gikreq'		; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'port'}{'tcp'} = '1660'	; 
#	$srvcobjects_ref->{'skip-mc-gikreq'}{'ports'}{'tcp'}{'1660'}++	; 
#	$ports_ref->{'tcp'}{'1660'}{'name'} = 'skip-mc-gikreq'		; 
#	$srvcobjects_ref->{'auditd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'auditd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'auditd'}{'port'}{'udp'} = '48'	; 
#	$srvcobjects_ref->{'auditd'}{'ports'}{'udp'}{'48'}++	; 
#	$ports_ref->{'udp'}{'48'}{'name'} = 'auditd'		; 
#	$srvcobjects_ref->{'auditd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'auditd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'auditd'}{'port'}{'tcp'} = '48'	; 
#	$srvcobjects_ref->{'auditd'}{'ports'}{'tcp'}{'48'}++	; 
#	$ports_ref->{'tcp'}{'48'}{'name'} = 'auditd'		; 
#	$srvcobjects_ref->{'rtelnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtelnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtelnet'}{'port'}{'udp'} = '107'	; 
#	$srvcobjects_ref->{'rtelnet'}{'ports'}{'udp'}{'107'}++	; 
#	$ports_ref->{'udp'}{'107'}{'name'} = 'rtelnet'		; 
#	$srvcobjects_ref->{'rtelnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtelnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtelnet'}{'port'}{'tcp'} = '107'	; 
#	$srvcobjects_ref->{'rtelnet'}{'ports'}{'tcp'}{'107'}++	; 
#	$ports_ref->{'tcp'}{'107'}{'name'} = 'rtelnet'		; 
#	$srvcobjects_ref->{'msexch-routing'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msexch-routing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msexch-routing'}{'port'}{'udp'} = '691'	; 
#	$srvcobjects_ref->{'msexch-routing'}{'ports'}{'udp'}{'691'}++	; 
#	$ports_ref->{'udp'}{'691'}{'name'} = 'msexch-routing'		; 
#	$srvcobjects_ref->{'msexch-routing'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msexch-routing'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msexch-routing'}{'port'}{'tcp'} = '691'	; 
#	$srvcobjects_ref->{'msexch-routing'}{'ports'}{'tcp'}{'691'}++	; 
#	$ports_ref->{'tcp'}{'691'}{'name'} = 'msexch-routing'		; 
#	$srvcobjects_ref->{'griffin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'griffin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'griffin'}{'port'}{'udp'} = '2458'	; 
#	$srvcobjects_ref->{'griffin'}{'ports'}{'udp'}{'2458'}++	; 
#	$ports_ref->{'udp'}{'2458'}{'name'} = 'griffin'		; 
#	$srvcobjects_ref->{'griffin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'griffin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'griffin'}{'port'}{'tcp'} = '2458'	; 
#	$srvcobjects_ref->{'griffin'}{'ports'}{'tcp'}{'2458'}++	; 
#	$ports_ref->{'tcp'}{'2458'}{'name'} = 'griffin'		; 
#	$srvcobjects_ref->{'op-probe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'op-probe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'op-probe'}{'port'}{'udp'} = '7030'	; 
#	$srvcobjects_ref->{'op-probe'}{'ports'}{'udp'}{'7030'}++	; 
#	$ports_ref->{'udp'}{'7030'}{'name'} = 'op-probe'		; 
#	$srvcobjects_ref->{'op-probe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'op-probe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'op-probe'}{'port'}{'tcp'} = '7030'	; 
#	$srvcobjects_ref->{'op-probe'}{'ports'}{'tcp'}{'7030'}++	; 
#	$ports_ref->{'tcp'}{'7030'}{'name'} = 'op-probe'		; 
#	$srvcobjects_ref->{'ssql'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssql'}{'port'}{'udp'} = '3352'	; 
#	$srvcobjects_ref->{'ssql'}{'ports'}{'udp'}{'3352'}++	; 
#	$ports_ref->{'udp'}{'3352'}{'name'} = 'ssql'		; 
#	$srvcobjects_ref->{'ssql'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssql'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssql'}{'port'}{'tcp'} = '3352'	; 
#	$srvcobjects_ref->{'ssql'}{'ports'}{'tcp'}{'3352'}++	; 
#	$ports_ref->{'tcp'}{'3352'}{'name'} = 'ssql'		; 
#	$srvcobjects_ref->{'driveappserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'driveappserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'driveappserver'}{'port'}{'udp'} = '1930'	; 
#	$srvcobjects_ref->{'driveappserver'}{'ports'}{'udp'}{'1930'}++	; 
#	$ports_ref->{'udp'}{'1930'}{'name'} = 'driveappserver'		; 
#	$srvcobjects_ref->{'driveappserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'driveappserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'driveappserver'}{'port'}{'tcp'} = '1930'	; 
#	$srvcobjects_ref->{'driveappserver'}{'ports'}{'tcp'}{'1930'}++	; 
#	$ports_ref->{'tcp'}{'1930'}{'name'} = 'driveappserver'		; 
#	$srvcobjects_ref->{'msi-selectplay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msi-selectplay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msi-selectplay'}{'port'}{'udp'} = '2871'	; 
#	$srvcobjects_ref->{'msi-selectplay'}{'ports'}{'udp'}{'2871'}++	; 
#	$ports_ref->{'udp'}{'2871'}{'name'} = 'msi-selectplay'		; 
#	$srvcobjects_ref->{'msi-selectplay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msi-selectplay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msi-selectplay'}{'port'}{'tcp'} = '2871'	; 
#	$srvcobjects_ref->{'msi-selectplay'}{'ports'}{'tcp'}{'2871'}++	; 
#	$ports_ref->{'tcp'}{'2871'}{'name'} = 'msi-selectplay'		; 
#	$srvcobjects_ref->{'matip-type-b'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'matip-type-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'matip-type-b'}{'port'}{'udp'} = '351'	; 
#	$srvcobjects_ref->{'matip-type-b'}{'ports'}{'udp'}{'351'}++	; 
#	$ports_ref->{'udp'}{'351'}{'name'} = 'matip-type-b'		; 
#	$srvcobjects_ref->{'matip-type-b'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'matip-type-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'matip-type-b'}{'port'}{'tcp'} = '351'	; 
#	$srvcobjects_ref->{'matip-type-b'}{'ports'}{'tcp'}{'351'}++	; 
#	$ports_ref->{'tcp'}{'351'}{'name'} = 'matip-type-b'		; 
#	$srvcobjects_ref->{'optiwave-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'optiwave-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optiwave-lm'}{'port'}{'udp'} = '2524'	; 
#	$srvcobjects_ref->{'optiwave-lm'}{'ports'}{'udp'}{'2524'}++	; 
#	$ports_ref->{'udp'}{'2524'}{'name'} = 'optiwave-lm'		; 
#	$srvcobjects_ref->{'optiwave-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'optiwave-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optiwave-lm'}{'port'}{'tcp'} = '2524'	; 
#	$srvcobjects_ref->{'optiwave-lm'}{'ports'}{'tcp'}{'2524'}++	; 
#	$ports_ref->{'tcp'}{'2524'}{'name'} = 'optiwave-lm'		; 
#	$srvcobjects_ref->{'dict'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dict'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dict'}{'port'}{'udp'} = '2628'	; 
#	$srvcobjects_ref->{'dict'}{'ports'}{'udp'}{'2628'}++	; 
#	$ports_ref->{'udp'}{'2628'}{'name'} = 'dict'		; 
#	$srvcobjects_ref->{'dict'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dict'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dict'}{'port'}{'tcp'} = '2628'	; 
#	$srvcobjects_ref->{'dict'}{'ports'}{'tcp'}{'2628'}++	; 
#	$ports_ref->{'tcp'}{'2628'}{'name'} = 'dict'		; 
#	$srvcobjects_ref->{'pktcable-cops'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pktcable-cops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pktcable-cops'}{'port'}{'udp'} = '2126'	; 
#	$srvcobjects_ref->{'pktcable-cops'}{'ports'}{'udp'}{'2126'}++	; 
#	$ports_ref->{'udp'}{'2126'}{'name'} = 'pktcable-cops'		; 
#	$srvcobjects_ref->{'pktcable-cops'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pktcable-cops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pktcable-cops'}{'port'}{'tcp'} = '2126'	; 
#	$srvcobjects_ref->{'pktcable-cops'}{'ports'}{'tcp'}{'2126'}++	; 
#	$ports_ref->{'tcp'}{'2126'}{'name'} = 'pktcable-cops'		; 
#	$srvcobjects_ref->{'gc-config'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gc-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gc-config'}{'port'}{'udp'} = '3436'	; 
#	$srvcobjects_ref->{'gc-config'}{'ports'}{'udp'}{'3436'}++	; 
#	$ports_ref->{'udp'}{'3436'}{'name'} = 'gc-config'		; 
#	$srvcobjects_ref->{'gc-config'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gc-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gc-config'}{'port'}{'tcp'} = '3436'	; 
#	$srvcobjects_ref->{'gc-config'}{'ports'}{'tcp'}{'3436'}++	; 
#	$ports_ref->{'tcp'}{'3436'}{'name'} = 'gc-config'		; 
#	$srvcobjects_ref->{'su-mit-tg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'su-mit-tg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'su-mit-tg'}{'port'}{'udp'} = '89'	; 
#	$srvcobjects_ref->{'su-mit-tg'}{'ports'}{'udp'}{'89'}++	; 
#	$ports_ref->{'udp'}{'89'}{'name'} = 'su-mit-tg'		; 
#	$srvcobjects_ref->{'su-mit-tg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'su-mit-tg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'su-mit-tg'}{'port'}{'tcp'} = '89'	; 
#	$srvcobjects_ref->{'su-mit-tg'}{'ports'}{'tcp'}{'89'}++	; 
#	$ports_ref->{'tcp'}{'89'}{'name'} = 'su-mit-tg'		; 
#	$srvcobjects_ref->{'oracle-vp2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oracle-vp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-vp2'}{'port'}{'udp'} = '1808'	; 
#	$srvcobjects_ref->{'oracle-vp2'}{'ports'}{'udp'}{'1808'}++	; 
#	$ports_ref->{'udp'}{'1808'}{'name'} = 'oracle-vp2'		; 
#	$srvcobjects_ref->{'oracle-vp2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oracle-vp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-vp2'}{'port'}{'tcp'} = '1808'	; 
#	$srvcobjects_ref->{'oracle-vp2'}{'ports'}{'tcp'}{'1808'}++	; 
#	$ports_ref->{'tcp'}{'1808'}{'name'} = 'oracle-vp2'		; 
#	$srvcobjects_ref->{'ipsendmsg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipsendmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipsendmsg'}{'port'}{'udp'} = '1992'	; 
#	$srvcobjects_ref->{'ipsendmsg'}{'ports'}{'udp'}{'1992'}++	; 
#	$ports_ref->{'udp'}{'1992'}{'name'} = 'ipsendmsg'		; 
#	$srvcobjects_ref->{'ipsendmsg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipsendmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipsendmsg'}{'port'}{'tcp'} = '1992'	; 
#	$srvcobjects_ref->{'ipsendmsg'}{'ports'}{'tcp'}{'1992'}++	; 
#	$ports_ref->{'tcp'}{'1992'}{'name'} = 'ipsendmsg'		; 
#	$srvcobjects_ref->{'ansatrader'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ansatrader'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansatrader'}{'port'}{'udp'} = '124'	; 
#	$srvcobjects_ref->{'ansatrader'}{'ports'}{'udp'}{'124'}++	; 
#	$ports_ref->{'udp'}{'124'}{'name'} = 'ansatrader'		; 
#	$srvcobjects_ref->{'ansatrader'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ansatrader'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ansatrader'}{'port'}{'tcp'} = '124'	; 
#	$srvcobjects_ref->{'ansatrader'}{'ports'}{'tcp'}{'124'}++	; 
#	$ports_ref->{'tcp'}{'124'}{'name'} = 'ansatrader'		; 
#	$srvcobjects_ref->{'optocontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'optocontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optocontrol'}{'port'}{'udp'} = '22001'	; 
#	$srvcobjects_ref->{'optocontrol'}{'ports'}{'udp'}{'22001'}++	; 
#	$ports_ref->{'udp'}{'22001'}{'name'} = 'optocontrol'		; 
#	$srvcobjects_ref->{'optocontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'optocontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optocontrol'}{'port'}{'tcp'} = '22001'	; 
#	$srvcobjects_ref->{'optocontrol'}{'ports'}{'tcp'}{'22001'}++	; 
#	$ports_ref->{'tcp'}{'22001'}{'name'} = 'optocontrol'		; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'port'}{'udp'} = '2934'	; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'ports'}{'udp'}{'2934'}++	; 
#	$ports_ref->{'udp'}{'2934'}{'name'} = '4-tieropmcli'		; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'port'}{'tcp'} = '2934'	; 
#	$srvcobjects_ref->{'4-tieropmcli'}{'ports'}{'tcp'}{'2934'}++	; 
#	$ports_ref->{'tcp'}{'2934'}{'name'} = '4-tieropmcli'		; 
#	$srvcobjects_ref->{'tacnews'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tacnews'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacnews'}{'port'}{'udp'} = '98'	; 
#	$srvcobjects_ref->{'tacnews'}{'ports'}{'udp'}{'98'}++	; 
#	$ports_ref->{'udp'}{'98'}{'name'} = 'tacnews'		; 
#	$srvcobjects_ref->{'tacnews'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tacnews'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tacnews'}{'port'}{'tcp'} = '98'	; 
#	$srvcobjects_ref->{'tacnews'}{'ports'}{'tcp'}{'98'}++	; 
#	$ports_ref->{'tcp'}{'98'}{'name'} = 'tacnews'		; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'port'}{'udp'} = '3472'	; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'ports'}{'udp'}{'3472'}++	; 
#	$ports_ref->{'udp'}{'3472'}{'name'} = 'jaugsremotec-1'		; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'port'}{'tcp'} = '3472'	; 
#	$srvcobjects_ref->{'jaugsremotec-1'}{'ports'}{'tcp'}{'3472'}++	; 
#	$ports_ref->{'tcp'}{'3472'}{'name'} = 'jaugsremotec-1'		; 
#	$srvcobjects_ref->{'dabew'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dabew'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dabew'}{'port'}{'udp'} = '1271'	; 
#	$srvcobjects_ref->{'dabew'}{'ports'}{'udp'}{'1271'}++	; 
#	$ports_ref->{'udp'}{'1271'}{'name'} = 'dabew'		; 
#	$srvcobjects_ref->{'dabew'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dabew'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dabew'}{'port'}{'tcp'} = '1271'	; 
#	$srvcobjects_ref->{'dabew'}{'ports'}{'tcp'}{'1271'}++	; 
#	$ports_ref->{'tcp'}{'1271'}{'name'} = 'dabew'		; 
#	$srvcobjects_ref->{'fjcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjcp'}{'port'}{'udp'} = '3648'	; 
#	$srvcobjects_ref->{'fjcp'}{'ports'}{'udp'}{'3648'}++	; 
#	$ports_ref->{'udp'}{'3648'}{'name'} = 'fjcp'		; 
#	$srvcobjects_ref->{'fjcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjcp'}{'port'}{'tcp'} = '3648'	; 
#	$srvcobjects_ref->{'fjcp'}{'ports'}{'tcp'}{'3648'}++	; 
#	$ports_ref->{'tcp'}{'3648'}{'name'} = 'fjcp'		; 
#	$srvcobjects_ref->{'mc2studios'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mc2studios'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc2studios'}{'port'}{'udp'} = '1899'	; 
#	$srvcobjects_ref->{'mc2studios'}{'ports'}{'udp'}{'1899'}++	; 
#	$ports_ref->{'udp'}{'1899'}{'name'} = 'mc2studios'		; 
#	$srvcobjects_ref->{'mc2studios'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mc2studios'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc2studios'}{'port'}{'tcp'} = '1899'	; 
#	$srvcobjects_ref->{'mc2studios'}{'ports'}{'tcp'}{'1899'}++	; 
#	$ports_ref->{'tcp'}{'1899'}{'name'} = 'mc2studios'		; 
#	$srvcobjects_ref->{'facilityview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'facilityview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facilityview'}{'port'}{'udp'} = '1561'	; 
#	$srvcobjects_ref->{'facilityview'}{'ports'}{'udp'}{'1561'}++	; 
#	$ports_ref->{'udp'}{'1561'}{'name'} = 'facilityview'		; 
#	$srvcobjects_ref->{'facilityview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'facilityview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facilityview'}{'port'}{'tcp'} = '1561'	; 
#	$srvcobjects_ref->{'facilityview'}{'ports'}{'tcp'}{'1561'}++	; 
#	$ports_ref->{'tcp'}{'1561'}{'name'} = 'facilityview'		; 
#	$srvcobjects_ref->{'asam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asam'}{'port'}{'udp'} = '3451'	; 
#	$srvcobjects_ref->{'asam'}{'ports'}{'udp'}{'3451'}++	; 
#	$ports_ref->{'udp'}{'3451'}{'name'} = 'asam'		; 
#	$srvcobjects_ref->{'asam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asam'}{'port'}{'tcp'} = '3451'	; 
#	$srvcobjects_ref->{'asam'}{'ports'}{'tcp'}{'3451'}++	; 
#	$ports_ref->{'tcp'}{'3451'}{'name'} = 'asam'		; 
#	$srvcobjects_ref->{'intecom-ps2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intecom-ps2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intecom-ps2'}{'port'}{'udp'} = '5057'	; 
#	$srvcobjects_ref->{'intecom-ps2'}{'ports'}{'udp'}{'5057'}++	; 
#	$ports_ref->{'udp'}{'5057'}{'name'} = 'intecom-ps2'		; 
#	$srvcobjects_ref->{'intecom-ps2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intecom-ps2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intecom-ps2'}{'port'}{'tcp'} = '5057'	; 
#	$srvcobjects_ref->{'intecom-ps2'}{'ports'}{'tcp'}{'5057'}++	; 
#	$ports_ref->{'tcp'}{'5057'}{'name'} = 'intecom-ps2'		; 
#	$srvcobjects_ref->{'srmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'srmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srmp'}{'port'}{'udp'} = '193'	; 
#	$srvcobjects_ref->{'srmp'}{'ports'}{'udp'}{'193'}++	; 
#	$ports_ref->{'udp'}{'193'}{'name'} = 'srmp'		; 
#	$srvcobjects_ref->{'srmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'srmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'srmp'}{'port'}{'tcp'} = '193'	; 
#	$srvcobjects_ref->{'srmp'}{'ports'}{'tcp'}{'193'}++	; 
#	$ports_ref->{'tcp'}{'193'}{'name'} = 'srmp'		; 
#	$srvcobjects_ref->{'texar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'texar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'texar'}{'port'}{'udp'} = '333'	; 
#	$srvcobjects_ref->{'texar'}{'ports'}{'udp'}{'333'}++	; 
#	$ports_ref->{'udp'}{'333'}{'name'} = 'texar'		; 
#	$srvcobjects_ref->{'texar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'texar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'texar'}{'port'}{'tcp'} = '333'	; 
#	$srvcobjects_ref->{'texar'}{'ports'}{'tcp'}{'333'}++	; 
#	$ports_ref->{'tcp'}{'333'}{'name'} = 'texar'		; 
#	$srvcobjects_ref->{'dic-aida'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dic-aida'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dic-aida'}{'port'}{'udp'} = '1941'	; 
#	$srvcobjects_ref->{'dic-aida'}{'ports'}{'udp'}{'1941'}++	; 
#	$ports_ref->{'udp'}{'1941'}{'name'} = 'dic-aida'		; 
#	$srvcobjects_ref->{'dic-aida'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dic-aida'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dic-aida'}{'port'}{'tcp'} = '1941'	; 
#	$srvcobjects_ref->{'dic-aida'}{'ports'}{'tcp'}{'1941'}++	; 
#	$ports_ref->{'tcp'}{'1941'}{'name'} = 'dic-aida'		; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'port'}{'udp'} = '9207'	; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'ports'}{'udp'}{'9207'}++	; 
#	$ports_ref->{'udp'}{'9207'}{'name'} = 'wap-vcal-s'		; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'port'}{'tcp'} = '9207'	; 
#	$srvcobjects_ref->{'wap-vcal-s'}{'ports'}{'tcp'}{'9207'}++	; 
#	$ports_ref->{'tcp'}{'9207'}{'name'} = 'wap-vcal-s'		; 
#	$srvcobjects_ref->{'sm-pas-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sm-pas-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-3'}{'port'}{'udp'} = '2940'	; 
#	$srvcobjects_ref->{'sm-pas-3'}{'ports'}{'udp'}{'2940'}++	; 
#	$ports_ref->{'udp'}{'2940'}{'name'} = 'sm-pas-3'		; 
#	$srvcobjects_ref->{'sm-pas-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sm-pas-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-3'}{'port'}{'tcp'} = '2940'	; 
#	$srvcobjects_ref->{'sm-pas-3'}{'ports'}{'tcp'}{'2940'}++	; 
#	$ports_ref->{'tcp'}{'2940'}{'name'} = 'sm-pas-3'		; 
#	$srvcobjects_ref->{'aol-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aol-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol-1'}{'port'}{'udp'} = '5191'	; 
#	$srvcobjects_ref->{'aol-1'}{'ports'}{'udp'}{'5191'}++	; 
#	$ports_ref->{'udp'}{'5191'}{'name'} = 'aol-1'		; 
#	$srvcobjects_ref->{'aol-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aol-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol-1'}{'port'}{'tcp'} = '5191'	; 
#	$srvcobjects_ref->{'aol-1'}{'ports'}{'tcp'}{'5191'}++	; 
#	$ports_ref->{'tcp'}{'5191'}{'name'} = 'aol-1'		; 
#	$srvcobjects_ref->{'powwow-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'powwow-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powwow-server'}{'port'}{'udp'} = '13224'	; 
#	$srvcobjects_ref->{'powwow-server'}{'ports'}{'udp'}{'13224'}++	; 
#	$ports_ref->{'udp'}{'13224'}{'name'} = 'powwow-server'		; 
#	$srvcobjects_ref->{'powwow-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'powwow-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powwow-server'}{'port'}{'tcp'} = '13224'	; 
#	$srvcobjects_ref->{'powwow-server'}{'ports'}{'tcp'}{'13224'}++	; 
#	$ports_ref->{'tcp'}{'13224'}{'name'} = 'powwow-server'		; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'port'}{'udp'} = '1513'	; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'ports'}{'udp'}{'1513'}++	; 
#	$ports_ref->{'udp'}{'1513'}{'name'} = 'fujitsu-dtc'		; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'port'}{'tcp'} = '1513'	; 
#	$srvcobjects_ref->{'fujitsu-dtc'}{'ports'}{'tcp'}{'1513'}++	; 
#	$ports_ref->{'tcp'}{'1513'}{'name'} = 'fujitsu-dtc'		; 
#	$srvcobjects_ref->{'x-bone-api'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'x-bone-api'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x-bone-api'}{'port'}{'udp'} = '2165'	; 
#	$srvcobjects_ref->{'x-bone-api'}{'ports'}{'udp'}{'2165'}++	; 
#	$ports_ref->{'udp'}{'2165'}{'name'} = 'x-bone-api'		; 
#	$srvcobjects_ref->{'x-bone-api'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'x-bone-api'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'x-bone-api'}{'port'}{'tcp'} = '2165'	; 
#	$srvcobjects_ref->{'x-bone-api'}{'ports'}{'tcp'}{'2165'}++	; 
#	$ports_ref->{'tcp'}{'2165'}{'name'} = 'x-bone-api'		; 
#	$srvcobjects_ref->{'psmond'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'psmond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psmond'}{'port'}{'udp'} = '1788'	; 
#	$srvcobjects_ref->{'psmond'}{'ports'}{'udp'}{'1788'}++	; 
#	$ports_ref->{'udp'}{'1788'}{'name'} = 'psmond'		; 
#	$srvcobjects_ref->{'psmond'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'psmond'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'psmond'}{'port'}{'tcp'} = '1788'	; 
#	$srvcobjects_ref->{'psmond'}{'ports'}{'tcp'}{'1788'}++	; 
#	$ports_ref->{'tcp'}{'1788'}{'name'} = 'psmond'		; 
#	$srvcobjects_ref->{'bnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bnet'}{'port'}{'udp'} = '415'	; 
#	$srvcobjects_ref->{'bnet'}{'ports'}{'udp'}{'415'}++	; 
#	$ports_ref->{'udp'}{'415'}{'name'} = 'bnet'		; 
#	$srvcobjects_ref->{'bnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bnet'}{'port'}{'tcp'} = '415'	; 
#	$srvcobjects_ref->{'bnet'}{'ports'}{'tcp'}{'415'}++	; 
#	$ports_ref->{'tcp'}{'415'}{'name'} = 'bnet'		; 
#	$srvcobjects_ref->{'msgsys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msgsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msgsys'}{'port'}{'udp'} = '9594'	; 
#	$srvcobjects_ref->{'msgsys'}{'ports'}{'udp'}{'9594'}++	; 
#	$ports_ref->{'udp'}{'9594'}{'name'} = 'msgsys'		; 
#	$srvcobjects_ref->{'msgsys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msgsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msgsys'}{'port'}{'tcp'} = '9594'	; 
#	$srvcobjects_ref->{'msgsys'}{'ports'}{'tcp'}{'9594'}++	; 
#	$ports_ref->{'tcp'}{'9594'}{'name'} = 'msgsys'		; 
#	$srvcobjects_ref->{'blwnkl-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'blwnkl-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blwnkl-port'}{'port'}{'udp'} = '2625'	; 
#	$srvcobjects_ref->{'blwnkl-port'}{'ports'}{'udp'}{'2625'}++	; 
#	$ports_ref->{'udp'}{'2625'}{'name'} = 'blwnkl-port'		; 
#	$srvcobjects_ref->{'blwnkl-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'blwnkl-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blwnkl-port'}{'port'}{'tcp'} = '2625'	; 
#	$srvcobjects_ref->{'blwnkl-port'}{'ports'}{'tcp'}{'2625'}++	; 
#	$ports_ref->{'tcp'}{'2625'}{'name'} = 'blwnkl-port'		; 
#	$srvcobjects_ref->{'mumps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mumps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mumps'}{'port'}{'udp'} = '188'	; 
#	$srvcobjects_ref->{'mumps'}{'ports'}{'udp'}{'188'}++	; 
#	$ports_ref->{'udp'}{'188'}{'name'} = 'mumps'		; 
#	$srvcobjects_ref->{'mumps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mumps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mumps'}{'port'}{'tcp'} = '188'	; 
#	$srvcobjects_ref->{'mumps'}{'ports'}{'tcp'}{'188'}++	; 
#	$ports_ref->{'tcp'}{'188'}{'name'} = 'mumps'		; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'port'}{'udp'} = '1231'	; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'ports'}{'udp'}{'1231'}++	; 
#	$ports_ref->{'udp'}{'1231'}{'name'} = 'menandmice-lpm'		; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'port'}{'tcp'} = '1231'	; 
#	$srvcobjects_ref->{'menandmice-lpm'}{'ports'}{'tcp'}{'1231'}++	; 
#	$ports_ref->{'tcp'}{'1231'}{'name'} = 'menandmice-lpm'		; 
#	$srvcobjects_ref->{'qrepos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qrepos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qrepos'}{'port'}{'udp'} = '3166'	; 
#	$srvcobjects_ref->{'qrepos'}{'ports'}{'udp'}{'3166'}++	; 
#	$ports_ref->{'udp'}{'3166'}{'name'} = 'qrepos'		; 
#	$srvcobjects_ref->{'qrepos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qrepos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qrepos'}{'port'}{'tcp'} = '3166'	; 
#	$srvcobjects_ref->{'qrepos'}{'ports'}{'tcp'}{'3166'}++	; 
#	$ports_ref->{'tcp'}{'3166'}{'name'} = 'qrepos'		; 
#	$srvcobjects_ref->{'ibm3494'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm3494'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm3494'}{'port'}{'udp'} = '3494'	; 
#	$srvcobjects_ref->{'ibm3494'}{'ports'}{'udp'}{'3494'}++	; 
#	$ports_ref->{'udp'}{'3494'}{'name'} = 'ibm3494'		; 
#	$srvcobjects_ref->{'ibm3494'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm3494'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm3494'}{'port'}{'tcp'} = '3494'	; 
#	$srvcobjects_ref->{'ibm3494'}{'ports'}{'tcp'}{'3494'}++	; 
#	$ports_ref->{'tcp'}{'3494'}{'name'} = 'ibm3494'		; 
#	$srvcobjects_ref->{'rap-listen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rap-listen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap-listen'}{'port'}{'udp'} = '1531'	; 
#	$srvcobjects_ref->{'rap-listen'}{'ports'}{'udp'}{'1531'}++	; 
#	$ports_ref->{'udp'}{'1531'}{'name'} = 'rap-listen'		; 
#	$srvcobjects_ref->{'rap-listen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rap-listen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rap-listen'}{'port'}{'tcp'} = '1531'	; 
#	$srvcobjects_ref->{'rap-listen'}{'ports'}{'tcp'}{'1531'}++	; 
#	$ports_ref->{'tcp'}{'1531'}{'name'} = 'rap-listen'		; 
#	$srvcobjects_ref->{'virtual-places'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'virtual-places'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtual-places'}{'port'}{'udp'} = '1533'	; 
#	$srvcobjects_ref->{'virtual-places'}{'ports'}{'udp'}{'1533'}++	; 
#	$ports_ref->{'udp'}{'1533'}{'name'} = 'virtual-places'		; 
#	$srvcobjects_ref->{'virtual-places'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'virtual-places'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'virtual-places'}{'port'}{'tcp'} = '1533'	; 
#	$srvcobjects_ref->{'virtual-places'}{'ports'}{'tcp'}{'1533'}++	; 
#	$ports_ref->{'tcp'}{'1533'}{'name'} = 'virtual-places'		; 
#	$srvcobjects_ref->{'hp-3000-telnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-3000-telnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-3000-telnet'}{'port'}{'tcp'} = '2564'	; 
#	$srvcobjects_ref->{'hp-3000-telnet'}{'ports'}{'tcp'}{'2564'}++	; 
#	$ports_ref->{'tcp'}{'2564'}{'name'} = 'hp-3000-telnet'		; 
#	$srvcobjects_ref->{'fryeserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fryeserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fryeserv'}{'port'}{'udp'} = '2788'	; 
#	$srvcobjects_ref->{'fryeserv'}{'ports'}{'udp'}{'2788'}++	; 
#	$ports_ref->{'udp'}{'2788'}{'name'} = 'fryeserv'		; 
#	$srvcobjects_ref->{'fryeserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fryeserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fryeserv'}{'port'}{'tcp'} = '2788'	; 
#	$srvcobjects_ref->{'fryeserv'}{'ports'}{'tcp'}{'2788'}++	; 
#	$ports_ref->{'tcp'}{'2788'}{'name'} = 'fryeserv'		; 
#	$srvcobjects_ref->{'prRegister'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prRegister'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prRegister'}{'port'}{'udp'} = '4457'	; 
#	$srvcobjects_ref->{'prRegister'}{'ports'}{'udp'}{'4457'}++	; 
#	$ports_ref->{'udp'}{'4457'}{'name'} = 'prRegister'		; 
#	$srvcobjects_ref->{'prRegister'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prRegister'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prRegister'}{'port'}{'tcp'} = '4457'	; 
#	$srvcobjects_ref->{'prRegister'}{'ports'}{'tcp'}{'4457'}++	; 
#	$ports_ref->{'tcp'}{'4457'}{'name'} = 'prRegister'		; 
#	$srvcobjects_ref->{'oveadmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oveadmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oveadmgr'}{'port'}{'udp'} = '7427'	; 
#	$srvcobjects_ref->{'oveadmgr'}{'ports'}{'udp'}{'7427'}++	; 
#	$ports_ref->{'udp'}{'7427'}{'name'} = 'oveadmgr'		; 
#	$srvcobjects_ref->{'oveadmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oveadmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oveadmgr'}{'port'}{'tcp'} = '7427'	; 
#	$srvcobjects_ref->{'oveadmgr'}{'ports'}{'tcp'}{'7427'}++	; 
#	$ports_ref->{'tcp'}{'7427'}{'name'} = 'oveadmgr'		; 
#	$srvcobjects_ref->{'sns-query'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-query'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-query'}{'port'}{'udp'} = '2659'	; 
#	$srvcobjects_ref->{'sns-query'}{'ports'}{'udp'}{'2659'}++	; 
#	$ports_ref->{'udp'}{'2659'}{'name'} = 'sns-query'		; 
#	$srvcobjects_ref->{'sns-query'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-query'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-query'}{'port'}{'tcp'} = '2659'	; 
#	$srvcobjects_ref->{'sns-query'}{'ports'}{'tcp'}{'2659'}++	; 
#	$ports_ref->{'tcp'}{'2659'}{'name'} = 'sns-query'		; 
#	$srvcobjects_ref->{'bpcp-poll'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bpcp-poll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpcp-poll'}{'port'}{'udp'} = '2844'	; 
#	$srvcobjects_ref->{'bpcp-poll'}{'ports'}{'udp'}{'2844'}++	; 
#	$ports_ref->{'udp'}{'2844'}{'name'} = 'bpcp-poll'		; 
#	$srvcobjects_ref->{'bpcp-poll'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bpcp-poll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpcp-poll'}{'port'}{'tcp'} = '2844'	; 
#	$srvcobjects_ref->{'bpcp-poll'}{'ports'}{'tcp'}{'2844'}++	; 
#	$ports_ref->{'tcp'}{'2844'}{'name'} = 'bpcp-poll'		; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'port'}{'udp'} = '5021'	; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'ports'}{'udp'}{'5021'}++	; 
#	$ports_ref->{'udp'}{'5021'}{'name'} = 'zenginkyo-2'		; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'port'}{'tcp'} = '5021'	; 
#	$srvcobjects_ref->{'zenginkyo-2'}{'ports'}{'tcp'}{'5021'}++	; 
#	$ports_ref->{'tcp'}{'5021'}{'name'} = 'zenginkyo-2'		; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'port'}{'udp'} = '2956'	; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'ports'}{'udp'}{'2956'}++	; 
#	$ports_ref->{'udp'}{'2956'}{'name'} = 'ovrimosdbman'		; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'port'}{'tcp'} = '2956'	; 
#	$srvcobjects_ref->{'ovrimosdbman'}{'ports'}{'tcp'}{'2956'}++	; 
#	$ports_ref->{'tcp'}{'2956'}{'name'} = 'ovrimosdbman'		; 
#	$srvcobjects_ref->{'precise-sft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'precise-sft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'precise-sft'}{'port'}{'udp'} = '2315'	; 
#	$srvcobjects_ref->{'precise-sft'}{'ports'}{'udp'}{'2315'}++	; 
#	$ports_ref->{'udp'}{'2315'}{'name'} = 'precise-sft'		; 
#	$srvcobjects_ref->{'precise-sft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'precise-sft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'precise-sft'}{'port'}{'tcp'} = '2315'	; 
#	$srvcobjects_ref->{'precise-sft'}{'ports'}{'tcp'}{'2315'}++	; 
#	$ports_ref->{'tcp'}{'2315'}{'name'} = 'precise-sft'		; 
#	$srvcobjects_ref->{'rightbrain'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rightbrain'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rightbrain'}{'port'}{'udp'} = '1354'	; 
#	$srvcobjects_ref->{'rightbrain'}{'ports'}{'udp'}{'1354'}++	; 
#	$ports_ref->{'udp'}{'1354'}{'name'} = 'rightbrain'		; 
#	$srvcobjects_ref->{'rightbrain'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rightbrain'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rightbrain'}{'port'}{'tcp'} = '1354'	; 
#	$srvcobjects_ref->{'rightbrain'}{'ports'}{'tcp'}{'1354'}++	; 
#	$ports_ref->{'tcp'}{'1354'}{'name'} = 'rightbrain'		; 
#	$srvcobjects_ref->{'netview-aix-12'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-12'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-12'}{'port'}{'udp'} = '1672'	; 
#	$srvcobjects_ref->{'netview-aix-12'}{'ports'}{'udp'}{'1672'}++	; 
#	$ports_ref->{'udp'}{'1672'}{'name'} = 'netview-aix-12'		; 
#	$srvcobjects_ref->{'netview-aix-12'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-12'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-12'}{'port'}{'tcp'} = '1672'	; 
#	$srvcobjects_ref->{'netview-aix-12'}{'ports'}{'tcp'}{'1672'}++	; 
#	$ports_ref->{'tcp'}{'1672'}{'name'} = 'netview-aix-12'		; 
#	$srvcobjects_ref->{'ms-rome'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-rome'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-rome'}{'port'}{'udp'} = '569'	; 
#	$srvcobjects_ref->{'ms-rome'}{'ports'}{'udp'}{'569'}++	; 
#	$ports_ref->{'udp'}{'569'}{'name'} = 'ms-rome'		; 
#	$srvcobjects_ref->{'ms-rome'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-rome'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-rome'}{'port'}{'tcp'} = '569'	; 
#	$srvcobjects_ref->{'ms-rome'}{'ports'}{'tcp'}{'569'}++	; 
#	$ports_ref->{'tcp'}{'569'}{'name'} = 'ms-rome'		; 
#	$srvcobjects_ref->{'taiclock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'taiclock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taiclock'}{'port'}{'udp'} = '4014'	; 
#	$srvcobjects_ref->{'taiclock'}{'ports'}{'udp'}{'4014'}++	; 
#	$ports_ref->{'udp'}{'4014'}{'name'} = 'taiclock'		; 
#	$srvcobjects_ref->{'taiclock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'taiclock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taiclock'}{'port'}{'tcp'} = '4014'	; 
#	$srvcobjects_ref->{'taiclock'}{'ports'}{'tcp'}{'4014'}++	; 
#	$ports_ref->{'tcp'}{'4014'}{'name'} = 'taiclock'		; 
#	$srvcobjects_ref->{'comsat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'comsat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'comsat'}{'port'}{'udp'} = '512'	; 
#	$srvcobjects_ref->{'comsat'}{'ports'}{'udp'}{'512'}++	; 
#	$ports_ref->{'udp'}{'512'}{'name'} = 'comsat'		; 
#	$srvcobjects_ref->{'nim'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nim'}{'port'}{'udp'} = '1058'	; 
#	$srvcobjects_ref->{'nim'}{'ports'}{'udp'}{'1058'}++	; 
#	$ports_ref->{'udp'}{'1058'}{'name'} = 'nim'		; 
#	$srvcobjects_ref->{'nim'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nim'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nim'}{'port'}{'tcp'} = '1058'	; 
#	$srvcobjects_ref->{'nim'}{'ports'}{'tcp'}{'1058'}++	; 
#	$ports_ref->{'tcp'}{'1058'}{'name'} = 'nim'		; 
#	$srvcobjects_ref->{'ua-secureagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ua-secureagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ua-secureagent'}{'port'}{'udp'} = '19194'	; 
#	$srvcobjects_ref->{'ua-secureagent'}{'ports'}{'udp'}{'19194'}++	; 
#	$ports_ref->{'udp'}{'19194'}{'name'} = 'ua-secureagent'		; 
#	$srvcobjects_ref->{'ua-secureagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ua-secureagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ua-secureagent'}{'port'}{'tcp'} = '19194'	; 
#	$srvcobjects_ref->{'ua-secureagent'}{'ports'}{'tcp'}{'19194'}++	; 
#	$ports_ref->{'tcp'}{'19194'}{'name'} = 'ua-secureagent'		; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'port'}{'udp'} = '2119'	; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'ports'}{'udp'}{'2119'}++	; 
#	$ports_ref->{'udp'}{'2119'}{'name'} = 'gsigatekeeper'		; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'port'}{'tcp'} = '2119'	; 
#	$srvcobjects_ref->{'gsigatekeeper'}{'ports'}{'tcp'}{'2119'}++	; 
#	$ports_ref->{'tcp'}{'2119'}{'name'} = 'gsigatekeeper'		; 
#	$srvcobjects_ref->{'mecomm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mecomm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mecomm'}{'port'}{'udp'} = '668'	; 
#	$srvcobjects_ref->{'mecomm'}{'ports'}{'udp'}{'668'}++	; 
#	$ports_ref->{'udp'}{'668'}{'name'} = 'mecomm'		; 
#	$srvcobjects_ref->{'mecomm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mecomm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mecomm'}{'port'}{'tcp'} = '668'	; 
#	$srvcobjects_ref->{'mecomm'}{'ports'}{'tcp'}{'668'}++	; 
#	$ports_ref->{'tcp'}{'668'}{'name'} = 'mecomm'		; 
#	$srvcobjects_ref->{'brcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'brcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brcd'}{'port'}{'udp'} = '1323'	; 
#	$srvcobjects_ref->{'brcd'}{'ports'}{'udp'}{'1323'}++	; 
#	$ports_ref->{'udp'}{'1323'}{'name'} = 'brcd'		; 
#	$srvcobjects_ref->{'brcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'brcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'brcd'}{'port'}{'tcp'} = '1323'	; 
#	$srvcobjects_ref->{'brcd'}{'ports'}{'tcp'}{'1323'}++	; 
#	$ports_ref->{'tcp'}{'1323'}{'name'} = 'brcd'		; 
#	$srvcobjects_ref->{'daytime'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'daytime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'daytime'}{'port'}{'udp'} = '13'	; 
#	$srvcobjects_ref->{'daytime'}{'ports'}{'udp'}{'13'}++	; 
#	$ports_ref->{'udp'}{'13'}{'name'} = 'daytime'		; 
#	$srvcobjects_ref->{'daytime'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'daytime'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'daytime'}{'port'}{'tcp'} = '13'	; 
#	$srvcobjects_ref->{'daytime'}{'ports'}{'tcp'}{'13'}++	; 
#	$ports_ref->{'tcp'}{'13'}{'name'} = 'daytime'		; 
#	$srvcobjects_ref->{'roboer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'roboer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roboer'}{'port'}{'udp'} = '2919'	; 
#	$srvcobjects_ref->{'roboer'}{'ports'}{'udp'}{'2919'}++	; 
#	$ports_ref->{'udp'}{'2919'}{'name'} = 'roboer'		; 
#	$srvcobjects_ref->{'roboer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'roboer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roboer'}{'port'}{'tcp'} = '2919'	; 
#	$srvcobjects_ref->{'roboer'}{'ports'}{'tcp'}{'2919'}++	; 
#	$ports_ref->{'tcp'}{'2919'}{'name'} = 'roboer'		; 
#	$srvcobjects_ref->{'scx-proxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scx-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scx-proxy'}{'port'}{'udp'} = '470'	; 
#	$srvcobjects_ref->{'scx-proxy'}{'ports'}{'udp'}{'470'}++	; 
#	$ports_ref->{'udp'}{'470'}{'name'} = 'scx-proxy'		; 
#	$srvcobjects_ref->{'scx-proxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scx-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scx-proxy'}{'port'}{'tcp'} = '470'	; 
#	$srvcobjects_ref->{'scx-proxy'}{'ports'}{'tcp'}{'470'}++	; 
#	$ports_ref->{'tcp'}{'470'}{'name'} = 'scx-proxy'		; 
#	$srvcobjects_ref->{'tomato-springs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tomato-springs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tomato-springs'}{'port'}{'udp'} = '3040'	; 
#	$srvcobjects_ref->{'tomato-springs'}{'ports'}{'udp'}{'3040'}++	; 
#	$ports_ref->{'udp'}{'3040'}{'name'} = 'tomato-springs'		; 
#	$srvcobjects_ref->{'tomato-springs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tomato-springs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tomato-springs'}{'port'}{'tcp'} = '3040'	; 
#	$srvcobjects_ref->{'tomato-springs'}{'ports'}{'tcp'}{'3040'}++	; 
#	$ports_ref->{'tcp'}{'3040'}{'name'} = 'tomato-springs'		; 
#	$srvcobjects_ref->{'excerpts'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'excerpts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'excerpts'}{'port'}{'udp'} = '5401'	; 
#	$srvcobjects_ref->{'excerpts'}{'ports'}{'udp'}{'5401'}++	; 
#	$ports_ref->{'udp'}{'5401'}{'name'} = 'excerpts'		; 
#	$srvcobjects_ref->{'excerpts'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'excerpts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'excerpts'}{'port'}{'tcp'} = '5401'	; 
#	$srvcobjects_ref->{'excerpts'}{'ports'}{'tcp'}{'5401'}++	; 
#	$ports_ref->{'tcp'}{'5401'}{'name'} = 'excerpts'		; 
#	$srvcobjects_ref->{'evtp-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'evtp-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'evtp-data'}{'port'}{'udp'} = '2835'	; 
#	$srvcobjects_ref->{'evtp-data'}{'ports'}{'udp'}{'2835'}++	; 
#	$ports_ref->{'udp'}{'2835'}{'name'} = 'evtp-data'		; 
#	$srvcobjects_ref->{'evtp-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'evtp-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'evtp-data'}{'port'}{'tcp'} = '2835'	; 
#	$srvcobjects_ref->{'evtp-data'}{'ports'}{'tcp'}{'2835'}++	; 
#	$ports_ref->{'tcp'}{'2835'}{'name'} = 'evtp-data'		; 
#	$srvcobjects_ref->{'autocuelog'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'autocuelog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autocuelog'}{'port'}{'tcp'} = '3104'	; 
#	$srvcobjects_ref->{'autocuelog'}{'ports'}{'tcp'}{'3104'}++	; 
#	$ports_ref->{'tcp'}{'3104'}{'name'} = 'autocuelog'		; 
#	$srvcobjects_ref->{'tnmpv2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tnmpv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tnmpv2'}{'port'}{'udp'} = '3686'	; 
#	$srvcobjects_ref->{'tnmpv2'}{'ports'}{'udp'}{'3686'}++	; 
#	$ports_ref->{'udp'}{'3686'}{'name'} = 'tnmpv2'		; 
#	$srvcobjects_ref->{'tnmpv2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tnmpv2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tnmpv2'}{'port'}{'tcp'} = '3686'	; 
#	$srvcobjects_ref->{'tnmpv2'}{'ports'}{'tcp'}{'3686'}++	; 
#	$ports_ref->{'tcp'}{'3686'}{'name'} = 'tnmpv2'		; 
#	$srvcobjects_ref->{'fxaengine-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fxaengine-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fxaengine-net'}{'port'}{'udp'} = '3402'	; 
#	$srvcobjects_ref->{'fxaengine-net'}{'ports'}{'udp'}{'3402'}++	; 
#	$ports_ref->{'udp'}{'3402'}{'name'} = 'fxaengine-net'		; 
#	$srvcobjects_ref->{'fxaengine-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fxaengine-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fxaengine-net'}{'port'}{'tcp'} = '3402'	; 
#	$srvcobjects_ref->{'fxaengine-net'}{'ports'}{'tcp'}{'3402'}++	; 
#	$ports_ref->{'tcp'}{'3402'}{'name'} = 'fxaengine-net'		; 
#	$srvcobjects_ref->{'cops'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cops'}{'port'}{'udp'} = '3288'	; 
#	$srvcobjects_ref->{'cops'}{'ports'}{'udp'}{'3288'}++	; 
#	$ports_ref->{'udp'}{'3288'}{'name'} = 'cops'		; 
#	$srvcobjects_ref->{'cops'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cops'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cops'}{'port'}{'tcp'} = '3288'	; 
#	$srvcobjects_ref->{'cops'}{'ports'}{'tcp'}{'3288'}++	; 
#	$ports_ref->{'tcp'}{'3288'}{'name'} = 'cops'		; 
#	$srvcobjects_ref->{'astromed-main'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'astromed-main'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'astromed-main'}{'port'}{'udp'} = '2864'	; 
#	$srvcobjects_ref->{'astromed-main'}{'ports'}{'udp'}{'2864'}++	; 
#	$ports_ref->{'udp'}{'2864'}{'name'} = 'astromed-main'		; 
#	$srvcobjects_ref->{'astromed-main'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'astromed-main'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'astromed-main'}{'port'}{'tcp'} = '2864'	; 
#	$srvcobjects_ref->{'astromed-main'}{'ports'}{'tcp'}{'2864'}++	; 
#	$ports_ref->{'tcp'}{'2864'}{'name'} = 'astromed-main'		; 
#	$srvcobjects_ref->{'mimer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mimer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mimer'}{'port'}{'udp'} = '1360'	; 
#	$srvcobjects_ref->{'mimer'}{'ports'}{'udp'}{'1360'}++	; 
#	$ports_ref->{'udp'}{'1360'}{'name'} = 'mimer'		; 
#	$srvcobjects_ref->{'mimer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mimer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mimer'}{'port'}{'tcp'} = '1360'	; 
#	$srvcobjects_ref->{'mimer'}{'ports'}{'tcp'}{'1360'}++	; 
#	$ports_ref->{'tcp'}{'1360'}{'name'} = 'mimer'		; 
#	$srvcobjects_ref->{'idfp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idfp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idfp'}{'port'}{'udp'} = '549'	; 
#	$srvcobjects_ref->{'idfp'}{'ports'}{'udp'}{'549'}++	; 
#	$ports_ref->{'udp'}{'549'}{'name'} = 'idfp'		; 
#	$srvcobjects_ref->{'idfp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idfp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idfp'}{'port'}{'tcp'} = '549'	; 
#	$srvcobjects_ref->{'idfp'}{'ports'}{'tcp'}{'549'}++	; 
#	$ports_ref->{'tcp'}{'549'}{'name'} = 'idfp'		; 
#	$srvcobjects_ref->{'weblogin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'weblogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'weblogin'}{'port'}{'udp'} = '2054'	; 
#	$srvcobjects_ref->{'weblogin'}{'ports'}{'udp'}{'2054'}++	; 
#	$ports_ref->{'udp'}{'2054'}{'name'} = 'weblogin'		; 
#	$srvcobjects_ref->{'weblogin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'weblogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'weblogin'}{'port'}{'tcp'} = '2054'	; 
#	$srvcobjects_ref->{'weblogin'}{'ports'}{'tcp'}{'2054'}++	; 
#	$ports_ref->{'tcp'}{'2054'}{'name'} = 'weblogin'		; 
#	$srvcobjects_ref->{'plato'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'plato'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plato'}{'port'}{'udp'} = '3285'	; 
#	$srvcobjects_ref->{'plato'}{'ports'}{'udp'}{'3285'}++	; 
#	$ports_ref->{'udp'}{'3285'}{'name'} = 'plato'		; 
#	$srvcobjects_ref->{'plato'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'plato'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'plato'}{'port'}{'tcp'} = '3285'	; 
#	$srvcobjects_ref->{'plato'}{'ports'}{'tcp'}{'3285'}++	; 
#	$ports_ref->{'tcp'}{'3285'}{'name'} = 'plato'		; 
#	$srvcobjects_ref->{'mach'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mach'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mach'}{'port'}{'udp'} = '6631'	; 
#	$srvcobjects_ref->{'mach'}{'ports'}{'udp'}{'6631'}++	; 
#	$ports_ref->{'udp'}{'6631'}{'name'} = 'mach'		; 
#	$srvcobjects_ref->{'mach'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mach'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mach'}{'port'}{'tcp'} = '6631'	; 
#	$srvcobjects_ref->{'mach'}{'ports'}{'tcp'}{'6631'}++	; 
#	$ports_ref->{'tcp'}{'6631'}{'name'} = 'mach'		; 
#	$srvcobjects_ref->{'socorfs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'socorfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'socorfs'}{'port'}{'udp'} = '3379'	; 
#	$srvcobjects_ref->{'socorfs'}{'ports'}{'udp'}{'3379'}++	; 
#	$ports_ref->{'udp'}{'3379'}{'name'} = 'socorfs'		; 
#	$srvcobjects_ref->{'socorfs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'socorfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'socorfs'}{'port'}{'tcp'} = '3379'	; 
#	$srvcobjects_ref->{'socorfs'}{'ports'}{'tcp'}{'3379'}++	; 
#	$ports_ref->{'tcp'}{'3379'}{'name'} = 'socorfs'		; 
#	$srvcobjects_ref->{'fjhpjp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjhpjp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjhpjp'}{'port'}{'udp'} = '3067'	; 
#	$srvcobjects_ref->{'fjhpjp'}{'ports'}{'udp'}{'3067'}++	; 
#	$ports_ref->{'udp'}{'3067'}{'name'} = 'fjhpjp'		; 
#	$srvcobjects_ref->{'fjhpjp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjhpjp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjhpjp'}{'port'}{'tcp'} = '3067'	; 
#	$srvcobjects_ref->{'fjhpjp'}{'ports'}{'tcp'}{'3067'}++	; 
#	$ports_ref->{'tcp'}{'3067'}{'name'} = 'fjhpjp'		; 
#	$srvcobjects_ref->{'cas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cas'}{'port'}{'udp'} = '2418'	; 
#	$srvcobjects_ref->{'cas'}{'ports'}{'udp'}{'2418'}++	; 
#	$ports_ref->{'udp'}{'2418'}{'name'} = 'cas'		; 
#	$srvcobjects_ref->{'cas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cas'}{'port'}{'tcp'} = '2418'	; 
#	$srvcobjects_ref->{'cas'}{'ports'}{'tcp'}{'2418'}++	; 
#	$ports_ref->{'tcp'}{'2418'}{'name'} = 'cas'		; 
#	$srvcobjects_ref->{'umsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'umsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'umsp'}{'port'}{'udp'} = '2110'	; 
#	$srvcobjects_ref->{'umsp'}{'ports'}{'udp'}{'2110'}++	; 
#	$ports_ref->{'udp'}{'2110'}{'name'} = 'umsp'		; 
#	$srvcobjects_ref->{'umsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'umsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'umsp'}{'port'}{'tcp'} = '2110'	; 
#	$srvcobjects_ref->{'umsp'}{'ports'}{'tcp'}{'2110'}++	; 
#	$ports_ref->{'tcp'}{'2110'}{'name'} = 'umsp'		; 
#	$srvcobjects_ref->{'csms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csms'}{'port'}{'udp'} = '3399'	; 
#	$srvcobjects_ref->{'csms'}{'ports'}{'udp'}{'3399'}++	; 
#	$ports_ref->{'udp'}{'3399'}{'name'} = 'csms'		; 
#	$srvcobjects_ref->{'csms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csms'}{'port'}{'tcp'} = '3399'	; 
#	$srvcobjects_ref->{'csms'}{'ports'}{'tcp'}{'3399'}++	; 
#	$ports_ref->{'tcp'}{'3399'}{'name'} = 'csms'		; 
#	$srvcobjects_ref->{'netview-aix-9'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-9'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-9'}{'port'}{'udp'} = '1669'	; 
#	$srvcobjects_ref->{'netview-aix-9'}{'ports'}{'udp'}{'1669'}++	; 
#	$ports_ref->{'udp'}{'1669'}{'name'} = 'netview-aix-9'		; 
#	$srvcobjects_ref->{'netview-aix-9'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-9'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-9'}{'port'}{'tcp'} = '1669'	; 
#	$srvcobjects_ref->{'netview-aix-9'}{'ports'}{'tcp'}{'1669'}++	; 
#	$ports_ref->{'tcp'}{'1669'}{'name'} = 'netview-aix-9'		; 
#	$srvcobjects_ref->{'msdp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msdp'}{'port'}{'udp'} = '639'	; 
#	$srvcobjects_ref->{'msdp'}{'ports'}{'udp'}{'639'}++	; 
#	$ports_ref->{'udp'}{'639'}{'name'} = 'msdp'		; 
#	$srvcobjects_ref->{'msdp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msdp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msdp'}{'port'}{'tcp'} = '639'	; 
#	$srvcobjects_ref->{'msdp'}{'ports'}{'tcp'}{'639'}++	; 
#	$ports_ref->{'tcp'}{'639'}{'name'} = 'msdp'		; 
#	$srvcobjects_ref->{'hp-hcip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-hcip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-hcip'}{'port'}{'udp'} = '1782'	; 
#	$srvcobjects_ref->{'hp-hcip'}{'ports'}{'udp'}{'1782'}++	; 
#	$ports_ref->{'udp'}{'1782'}{'name'} = 'hp-hcip'		; 
#	$srvcobjects_ref->{'hp-hcip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-hcip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-hcip'}{'port'}{'tcp'} = '1782'	; 
#	$srvcobjects_ref->{'hp-hcip'}{'ports'}{'tcp'}{'1782'}++	; 
#	$ports_ref->{'tcp'}{'1782'}{'name'} = 'hp-hcip'		; 
#	$srvcobjects_ref->{'pmcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pmcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmcd'}{'port'}{'udp'} = '44321'	; 
#	$srvcobjects_ref->{'pmcd'}{'ports'}{'udp'}{'44321'}++	; 
#	$ports_ref->{'udp'}{'44321'}{'name'} = 'pmcd'		; 
#	$srvcobjects_ref->{'pmcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pmcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmcd'}{'port'}{'tcp'} = '44321'	; 
#	$srvcobjects_ref->{'pmcd'}{'ports'}{'tcp'}{'44321'}++	; 
#	$ports_ref->{'tcp'}{'44321'}{'name'} = 'pmcd'		; 
#	$srvcobjects_ref->{'opsession-srvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsession-srvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsession-srvr'}{'port'}{'udp'} = '3304'	; 
#	$srvcobjects_ref->{'opsession-srvr'}{'ports'}{'udp'}{'3304'}++	; 
#	$ports_ref->{'udp'}{'3304'}{'name'} = 'opsession-srvr'		; 
#	$srvcobjects_ref->{'opsession-srvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsession-srvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsession-srvr'}{'port'}{'tcp'} = '3304'	; 
#	$srvcobjects_ref->{'opsession-srvr'}{'ports'}{'tcp'}{'3304'}++	; 
#	$ports_ref->{'tcp'}{'3304'}{'name'} = 'opsession-srvr'		; 
#	$srvcobjects_ref->{'lofr-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lofr-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lofr-lm'}{'port'}{'udp'} = '1752'	; 
#	$srvcobjects_ref->{'lofr-lm'}{'ports'}{'udp'}{'1752'}++	; 
#	$ports_ref->{'udp'}{'1752'}{'name'} = 'lofr-lm'		; 
#	$srvcobjects_ref->{'lofr-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lofr-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lofr-lm'}{'port'}{'tcp'} = '1752'	; 
#	$srvcobjects_ref->{'lofr-lm'}{'ports'}{'tcp'}{'1752'}++	; 
#	$ports_ref->{'tcp'}{'1752'}{'name'} = 'lofr-lm'		; 
#	$srvcobjects_ref->{'arkivio'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arkivio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arkivio'}{'port'}{'udp'} = '3426'	; 
#	$srvcobjects_ref->{'arkivio'}{'ports'}{'udp'}{'3426'}++	; 
#	$ports_ref->{'udp'}{'3426'}{'name'} = 'arkivio'		; 
#	$srvcobjects_ref->{'arkivio'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arkivio'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arkivio'}{'port'}{'tcp'} = '3426'	; 
#	$srvcobjects_ref->{'arkivio'}{'ports'}{'tcp'}{'3426'}++	; 
#	$ports_ref->{'tcp'}{'3426'}{'name'} = 'arkivio'		; 
#	$srvcobjects_ref->{'optilogic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'optilogic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optilogic'}{'port'}{'udp'} = '2435'	; 
#	$srvcobjects_ref->{'optilogic'}{'ports'}{'udp'}{'2435'}++	; 
#	$ports_ref->{'udp'}{'2435'}{'name'} = 'optilogic'		; 
#	$srvcobjects_ref->{'optilogic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'optilogic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'optilogic'}{'port'}{'tcp'} = '2435'	; 
#	$srvcobjects_ref->{'optilogic'}{'ports'}{'tcp'}{'2435'}++	; 
#	$ports_ref->{'tcp'}{'2435'}{'name'} = 'optilogic'		; 
#	$srvcobjects_ref->{'cimplex'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cimplex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cimplex'}{'port'}{'udp'} = '673'	; 
#	$srvcobjects_ref->{'cimplex'}{'ports'}{'udp'}{'673'}++	; 
#	$ports_ref->{'udp'}{'673'}{'name'} = 'cimplex'		; 
#	$srvcobjects_ref->{'cimplex'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cimplex'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cimplex'}{'port'}{'tcp'} = '673'	; 
#	$srvcobjects_ref->{'cimplex'}{'ports'}{'tcp'}{'673'}++	; 
#	$ports_ref->{'tcp'}{'673'}{'name'} = 'cimplex'		; 
#	$srvcobjects_ref->{'samd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'samd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'samd'}{'port'}{'udp'} = '3275'	; 
#	$srvcobjects_ref->{'samd'}{'ports'}{'udp'}{'3275'}++	; 
#	$ports_ref->{'udp'}{'3275'}{'name'} = 'samd'		; 
#	$srvcobjects_ref->{'samd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'samd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'samd'}{'port'}{'tcp'} = '3275'	; 
#	$srvcobjects_ref->{'samd'}{'ports'}{'tcp'}{'3275'}++	; 
#	$ports_ref->{'tcp'}{'3275'}{'name'} = 'samd'		; 
#	$srvcobjects_ref->{'ldp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ldp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldp'}{'port'}{'udp'} = '646'	; 
#	$srvcobjects_ref->{'ldp'}{'ports'}{'udp'}{'646'}++	; 
#	$ports_ref->{'udp'}{'646'}{'name'} = 'ldp'		; 
#	$srvcobjects_ref->{'ldp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ldp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldp'}{'port'}{'tcp'} = '646'	; 
#	$srvcobjects_ref->{'ldp'}{'ports'}{'tcp'}{'646'}++	; 
#	$ports_ref->{'tcp'}{'646'}{'name'} = 'ldp'		; 
#	$srvcobjects_ref->{'ms-sql-m'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-sql-m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sql-m'}{'port'}{'udp'} = '1434'	; 
#	$srvcobjects_ref->{'ms-sql-m'}{'ports'}{'udp'}{'1434'}++	; 
#	$ports_ref->{'udp'}{'1434'}{'name'} = 'ms-sql-m'		; 
#	$srvcobjects_ref->{'ms-sql-m'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-sql-m'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-sql-m'}{'port'}{'tcp'} = '1434'	; 
#	$srvcobjects_ref->{'ms-sql-m'}{'ports'}{'tcp'}{'1434'}++	; 
#	$ports_ref->{'tcp'}{'1434'}{'name'} = 'ms-sql-m'		; 
#	$srvcobjects_ref->{'nssagentmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nssagentmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nssagentmgr'}{'port'}{'udp'} = '4454'	; 
#	$srvcobjects_ref->{'nssagentmgr'}{'ports'}{'udp'}{'4454'}++	; 
#	$ports_ref->{'udp'}{'4454'}{'name'} = 'nssagentmgr'		; 
#	$srvcobjects_ref->{'nssagentmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nssagentmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nssagentmgr'}{'port'}{'tcp'} = '4454'	; 
#	$srvcobjects_ref->{'nssagentmgr'}{'ports'}{'tcp'}{'4454'}++	; 
#	$ports_ref->{'tcp'}{'4454'}{'name'} = 'nssagentmgr'		; 
#	$srvcobjects_ref->{'sm-pas-5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sm-pas-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-5'}{'port'}{'udp'} = '2942'	; 
#	$srvcobjects_ref->{'sm-pas-5'}{'ports'}{'udp'}{'2942'}++	; 
#	$ports_ref->{'udp'}{'2942'}{'name'} = 'sm-pas-5'		; 
#	$srvcobjects_ref->{'sm-pas-5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sm-pas-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sm-pas-5'}{'port'}{'tcp'} = '2942'	; 
#	$srvcobjects_ref->{'sm-pas-5'}{'ports'}{'tcp'}{'2942'}++	; 
#	$ports_ref->{'tcp'}{'2942'}{'name'} = 'sm-pas-5'		; 
#	$srvcobjects_ref->{'scp-config'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scp-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scp-config'}{'port'}{'udp'} = '10001'	; 
#	$srvcobjects_ref->{'scp-config'}{'ports'}{'udp'}{'10001'}++	; 
#	$ports_ref->{'udp'}{'10001'}{'name'} = 'scp-config'		; 
#	$srvcobjects_ref->{'scp-config'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scp-config'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scp-config'}{'port'}{'tcp'} = '10001'	; 
#	$srvcobjects_ref->{'scp-config'}{'ports'}{'tcp'}{'10001'}++	; 
#	$ports_ref->{'tcp'}{'10001'}{'name'} = 'scp-config'		; 
#	$srvcobjects_ref->{'raven-rmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raven-rmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven-rmp'}{'port'}{'udp'} = '3532'	; 
#	$srvcobjects_ref->{'raven-rmp'}{'ports'}{'udp'}{'3532'}++	; 
#	$ports_ref->{'udp'}{'3532'}{'name'} = 'raven-rmp'		; 
#	$srvcobjects_ref->{'raven-rmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raven-rmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven-rmp'}{'port'}{'tcp'} = '3532'	; 
#	$srvcobjects_ref->{'raven-rmp'}{'ports'}{'tcp'}{'3532'}++	; 
#	$ports_ref->{'tcp'}{'3532'}{'name'} = 'raven-rmp'		; 
#	$srvcobjects_ref->{'cera-bcm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cera-bcm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cera-bcm'}{'port'}{'udp'} = '1794'	; 
#	$srvcobjects_ref->{'cera-bcm'}{'ports'}{'udp'}{'1794'}++	; 
#	$ports_ref->{'udp'}{'1794'}{'name'} = 'cera-bcm'		; 
#	$srvcobjects_ref->{'cera-bcm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cera-bcm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cera-bcm'}{'port'}{'tcp'} = '1794'	; 
#	$srvcobjects_ref->{'cera-bcm'}{'ports'}{'tcp'}{'1794'}++	; 
#	$ports_ref->{'tcp'}{'1794'}{'name'} = 'cera-bcm'		; 
#	$srvcobjects_ref->{'norton-lambert'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'norton-lambert'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'norton-lambert'}{'port'}{'udp'} = '2338'	; 
#	$srvcobjects_ref->{'norton-lambert'}{'ports'}{'udp'}{'2338'}++	; 
#	$ports_ref->{'udp'}{'2338'}{'name'} = 'norton-lambert'		; 
#	$srvcobjects_ref->{'norton-lambert'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'norton-lambert'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'norton-lambert'}{'port'}{'tcp'} = '2338'	; 
#	$srvcobjects_ref->{'norton-lambert'}{'ports'}{'tcp'}{'2338'}++	; 
#	$ports_ref->{'tcp'}{'2338'}{'name'} = 'norton-lambert'		; 
#	$srvcobjects_ref->{'macon-tcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'macon-tcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'macon-tcp'}{'port'}{'tcp'} = '456'	; 
#	$srvcobjects_ref->{'macon-tcp'}{'ports'}{'tcp'}{'456'}++	; 
#	$ports_ref->{'tcp'}{'456'}{'name'} = 'macon-tcp'		; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'port'}{'udp'} = '9211'	; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'ports'}{'udp'}{'9211'}++	; 
#	$ports_ref->{'udp'}{'9211'}{'name'} = 'lif-mlp-s'		; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'port'}{'tcp'} = '9211'	; 
#	$srvcobjects_ref->{'lif-mlp-s'}{'ports'}{'tcp'}{'9211'}++	; 
#	$ports_ref->{'tcp'}{'9211'}{'name'} = 'lif-mlp-s'		; 
#	$srvcobjects_ref->{'vocaltec-phone'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vocaltec-phone'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vocaltec-phone'}{'port'}{'udp'} = '22555'	; 
#	$srvcobjects_ref->{'vocaltec-phone'}{'ports'}{'udp'}{'22555'}++	; 
#	$ports_ref->{'udp'}{'22555'}{'name'} = 'vocaltec-phone'		; 
#	$srvcobjects_ref->{'hermes'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hermes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hermes'}{'port'}{'udp'} = '1248'	; 
#	$srvcobjects_ref->{'hermes'}{'ports'}{'udp'}{'1248'}++	; 
#	$ports_ref->{'udp'}{'1248'}{'name'} = 'hermes'		; 
#	$srvcobjects_ref->{'hermes'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hermes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hermes'}{'port'}{'tcp'} = '1248'	; 
#	$srvcobjects_ref->{'hermes'}{'ports'}{'tcp'}{'1248'}++	; 
#	$ports_ref->{'tcp'}{'1248'}{'name'} = 'hermes'		; 
#	$srvcobjects_ref->{'fksp-audit'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fksp-audit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fksp-audit'}{'port'}{'udp'} = '3729'	; 
#	$srvcobjects_ref->{'fksp-audit'}{'ports'}{'udp'}{'3729'}++	; 
#	$ports_ref->{'udp'}{'3729'}{'name'} = 'fksp-audit'		; 
#	$srvcobjects_ref->{'fksp-audit'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fksp-audit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fksp-audit'}{'port'}{'tcp'} = '3729'	; 
#	$srvcobjects_ref->{'fksp-audit'}{'ports'}{'tcp'}{'3729'}++	; 
#	$ports_ref->{'tcp'}{'3729'}{'name'} = 'fksp-audit'		; 
#	$srvcobjects_ref->{'acmaint_transd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acmaint_transd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acmaint_transd'}{'port'}{'udp'} = '775'	; 
#	$srvcobjects_ref->{'acmaint_transd'}{'ports'}{'udp'}{'775'}++	; 
#	$ports_ref->{'udp'}{'775'}{'name'} = 'acmaint_transd'		; 
#	$srvcobjects_ref->{'mftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mftp'}{'port'}{'udp'} = '349'	; 
#	$srvcobjects_ref->{'mftp'}{'ports'}{'udp'}{'349'}++	; 
#	$ports_ref->{'udp'}{'349'}{'name'} = 'mftp'		; 
#	$srvcobjects_ref->{'mftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mftp'}{'port'}{'udp'} = '5402'	; 
#	$srvcobjects_ref->{'mftp'}{'ports'}{'udp'}{'5402'}++	; 
#	$ports_ref->{'udp'}{'5402'}{'name'} = 'mftp'		; 
#	$srvcobjects_ref->{'mftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mftp'}{'port'}{'tcp'} = '349'	; 
#	$srvcobjects_ref->{'mftp'}{'ports'}{'tcp'}{'349'}++	; 
#	$ports_ref->{'tcp'}{'349'}{'name'} = 'mftp'		; 
#	$srvcobjects_ref->{'mftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mftp'}{'port'}{'tcp'} = '5402'	; 
#	$srvcobjects_ref->{'mftp'}{'ports'}{'tcp'}{'5402'}++	; 
#	$ports_ref->{'tcp'}{'5402'}{'name'} = 'mftp'		; 
#	$srvcobjects_ref->{'ept-machine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ept-machine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ept-machine'}{'port'}{'udp'} = '3628'	; 
#	$srvcobjects_ref->{'ept-machine'}{'ports'}{'udp'}{'3628'}++	; 
#	$ports_ref->{'udp'}{'3628'}{'name'} = 'ept-machine'		; 
#	$srvcobjects_ref->{'ept-machine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ept-machine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ept-machine'}{'port'}{'tcp'} = '3628'	; 
#	$srvcobjects_ref->{'ept-machine'}{'ports'}{'tcp'}{'3628'}++	; 
#	$ports_ref->{'tcp'}{'3628'}{'name'} = 'ept-machine'		; 
#	$srvcobjects_ref->{'lv-ffx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lv-ffx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-ffx'}{'port'}{'udp'} = '2144'	; 
#	$srvcobjects_ref->{'lv-ffx'}{'ports'}{'udp'}{'2144'}++	; 
#	$ports_ref->{'udp'}{'2144'}{'name'} = 'lv-ffx'		; 
#	$srvcobjects_ref->{'lv-ffx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lv-ffx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lv-ffx'}{'port'}{'tcp'} = '2144'	; 
#	$srvcobjects_ref->{'lv-ffx'}{'ports'}{'tcp'}{'2144'}++	; 
#	$ports_ref->{'tcp'}{'2144'}{'name'} = 'lv-ffx'		; 
#	$srvcobjects_ref->{'ddm-rdb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddm-rdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddm-rdb'}{'port'}{'udp'} = '446'	; 
#	$srvcobjects_ref->{'ddm-rdb'}{'ports'}{'udp'}{'446'}++	; 
#	$ports_ref->{'udp'}{'446'}{'name'} = 'ddm-rdb'		; 
#	$srvcobjects_ref->{'ddm-rdb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddm-rdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddm-rdb'}{'port'}{'tcp'} = '446'	; 
#	$srvcobjects_ref->{'ddm-rdb'}{'ports'}{'tcp'}{'446'}++	; 
#	$ports_ref->{'tcp'}{'446'}{'name'} = 'ddm-rdb'		; 
#	$srvcobjects_ref->{'ni-ftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ni-ftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ni-ftp'}{'port'}{'udp'} = '47'	; 
#	$srvcobjects_ref->{'ni-ftp'}{'ports'}{'udp'}{'47'}++	; 
#	$ports_ref->{'udp'}{'47'}{'name'} = 'ni-ftp'		; 
#	$srvcobjects_ref->{'ni-ftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ni-ftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ni-ftp'}{'port'}{'tcp'} = '47'	; 
#	$srvcobjects_ref->{'ni-ftp'}{'ports'}{'tcp'}{'47'}++	; 
#	$ports_ref->{'tcp'}{'47'}{'name'} = 'ni-ftp'		; 
#	$srvcobjects_ref->{'net8-cman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'net8-cman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net8-cman'}{'port'}{'udp'} = '1830'	; 
#	$srvcobjects_ref->{'net8-cman'}{'ports'}{'udp'}{'1830'}++	; 
#	$ports_ref->{'udp'}{'1830'}{'name'} = 'net8-cman'		; 
#	$srvcobjects_ref->{'net8-cman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'net8-cman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net8-cman'}{'port'}{'tcp'} = '1830'	; 
#	$srvcobjects_ref->{'net8-cman'}{'ports'}{'tcp'}{'1830'}++	; 
#	$ports_ref->{'tcp'}{'1830'}{'name'} = 'net8-cman'		; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'port'}{'udp'} = '2680'	; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'ports'}{'udp'}{'2680'}++	; 
#	$ports_ref->{'udp'}{'2680'}{'name'} = 'pxc-sapxom'		; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'port'}{'tcp'} = '2680'	; 
#	$srvcobjects_ref->{'pxc-sapxom'}{'ports'}{'tcp'}{'2680'}++	; 
#	$ports_ref->{'tcp'}{'2680'}{'name'} = 'pxc-sapxom'		; 
#	$srvcobjects_ref->{'berknet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'berknet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'berknet'}{'port'}{'tcp'} = '2005'	; 
#	$srvcobjects_ref->{'berknet'}{'ports'}{'tcp'}{'2005'}++	; 
#	$ports_ref->{'tcp'}{'2005'}{'name'} = 'berknet'		; 
#	$srvcobjects_ref->{'fhc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fhc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fhc'}{'port'}{'udp'} = '1499'	; 
#	$srvcobjects_ref->{'fhc'}{'ports'}{'udp'}{'1499'}++	; 
#	$ports_ref->{'udp'}{'1499'}{'name'} = 'fhc'		; 
#	$srvcobjects_ref->{'fhc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fhc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fhc'}{'port'}{'tcp'} = '1499'	; 
#	$srvcobjects_ref->{'fhc'}{'ports'}{'tcp'}{'1499'}++	; 
#	$ports_ref->{'tcp'}{'1499'}{'name'} = 'fhc'		; 
#	$srvcobjects_ref->{'telnetcpcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telnetcpcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telnetcpcd'}{'port'}{'udp'} = '3696'	; 
#	$srvcobjects_ref->{'telnetcpcd'}{'ports'}{'udp'}{'3696'}++	; 
#	$ports_ref->{'udp'}{'3696'}{'name'} = 'telnetcpcd'		; 
#	$srvcobjects_ref->{'telnetcpcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telnetcpcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telnetcpcd'}{'port'}{'tcp'} = '3696'	; 
#	$srvcobjects_ref->{'telnetcpcd'}{'ports'}{'tcp'}{'3696'}++	; 
#	$ports_ref->{'tcp'}{'3696'}{'name'} = 'telnetcpcd'		; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'port'}{'udp'} = '1674'	; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'ports'}{'udp'}{'1674'}++	; 
#	$ports_ref->{'udp'}{'1674'}{'name'} = 'proshare-mc-2'		; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'port'}{'tcp'} = '1674'	; 
#	$srvcobjects_ref->{'proshare-mc-2'}{'ports'}{'tcp'}{'1674'}++	; 
#	$ports_ref->{'tcp'}{'1674'}{'name'} = 'proshare-mc-2'		; 
#	$srvcobjects_ref->{'zymed-zpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zymed-zpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zymed-zpp'}{'port'}{'udp'} = '2133'	; 
#	$srvcobjects_ref->{'zymed-zpp'}{'ports'}{'udp'}{'2133'}++	; 
#	$ports_ref->{'udp'}{'2133'}{'name'} = 'zymed-zpp'		; 
#	$srvcobjects_ref->{'zymed-zpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zymed-zpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zymed-zpp'}{'port'}{'tcp'} = '2133'	; 
#	$srvcobjects_ref->{'zymed-zpp'}{'ports'}{'tcp'}{'2133'}++	; 
#	$ports_ref->{'tcp'}{'2133'}{'name'} = 'zymed-zpp'		; 
#	$srvcobjects_ref->{'femis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'femis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'femis'}{'port'}{'udp'} = '1776'	; 
#	$srvcobjects_ref->{'femis'}{'ports'}{'udp'}{'1776'}++	; 
#	$ports_ref->{'udp'}{'1776'}{'name'} = 'femis'		; 
#	$srvcobjects_ref->{'femis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'femis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'femis'}{'port'}{'tcp'} = '1776'	; 
#	$srvcobjects_ref->{'femis'}{'ports'}{'tcp'}{'1776'}++	; 
#	$ports_ref->{'tcp'}{'1776'}{'name'} = 'femis'		; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'port'}{'udp'} = '1769'	; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'ports'}{'udp'}{'1769'}++	; 
#	$ports_ref->{'udp'}{'1769'}{'name'} = 'bmc-net-adm'		; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'port'}{'tcp'} = '1769'	; 
#	$srvcobjects_ref->{'bmc-net-adm'}{'ports'}{'tcp'}{'1769'}++	; 
#	$ports_ref->{'tcp'}{'1769'}{'name'} = 'bmc-net-adm'		; 
#	$srvcobjects_ref->{'med-ovw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'med-ovw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-ovw'}{'port'}{'udp'} = '24004'	; 
#	$srvcobjects_ref->{'med-ovw'}{'ports'}{'udp'}{'24004'}++	; 
#	$ports_ref->{'udp'}{'24004'}{'name'} = 'med-ovw'		; 
#	$srvcobjects_ref->{'med-ovw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'med-ovw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-ovw'}{'port'}{'tcp'} = '24004'	; 
#	$srvcobjects_ref->{'med-ovw'}{'ports'}{'tcp'}{'24004'}++	; 
#	$ports_ref->{'tcp'}{'24004'}{'name'} = 'med-ovw'		; 
#	$srvcobjects_ref->{'sso-service'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sso-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sso-service'}{'port'}{'udp'} = '2710'	; 
#	$srvcobjects_ref->{'sso-service'}{'ports'}{'udp'}{'2710'}++	; 
#	$ports_ref->{'udp'}{'2710'}{'name'} = 'sso-service'		; 
#	$srvcobjects_ref->{'sso-service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sso-service'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sso-service'}{'port'}{'tcp'} = '2710'	; 
#	$srvcobjects_ref->{'sso-service'}{'ports'}{'tcp'}{'2710'}++	; 
#	$ports_ref->{'tcp'}{'2710'}{'name'} = 'sso-service'		; 
#	$srvcobjects_ref->{'daishi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'daishi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'daishi'}{'port'}{'udp'} = '2870'	; 
#	$srvcobjects_ref->{'daishi'}{'ports'}{'udp'}{'2870'}++	; 
#	$ports_ref->{'udp'}{'2870'}{'name'} = 'daishi'		; 
#	$srvcobjects_ref->{'daishi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'daishi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'daishi'}{'port'}{'tcp'} = '2870'	; 
#	$srvcobjects_ref->{'daishi'}{'ports'}{'tcp'}{'2870'}++	; 
#	$ports_ref->{'tcp'}{'2870'}{'name'} = 'daishi'		; 
#	$srvcobjects_ref->{'npep-messaging'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'npep-messaging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npep-messaging'}{'port'}{'udp'} = '2868'	; 
#	$srvcobjects_ref->{'npep-messaging'}{'ports'}{'udp'}{'2868'}++	; 
#	$ports_ref->{'udp'}{'2868'}{'name'} = 'npep-messaging'		; 
#	$srvcobjects_ref->{'npep-messaging'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'npep-messaging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npep-messaging'}{'port'}{'tcp'} = '2868'	; 
#	$srvcobjects_ref->{'npep-messaging'}{'ports'}{'tcp'}{'2868'}++	; 
#	$ports_ref->{'tcp'}{'2868'}{'name'} = 'npep-messaging'		; 
#	$srvcobjects_ref->{'press'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'press'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'press'}{'port'}{'udp'} = '3582'	; 
#	$srvcobjects_ref->{'press'}{'ports'}{'udp'}{'3582'}++	; 
#	$ports_ref->{'udp'}{'3582'}{'name'} = 'press'		; 
#	$srvcobjects_ref->{'press'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'press'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'press'}{'port'}{'tcp'} = '3582'	; 
#	$srvcobjects_ref->{'press'}{'ports'}{'tcp'}{'3582'}++	; 
#	$ports_ref->{'tcp'}{'3582'}{'name'} = 'press'		; 
#	$srvcobjects_ref->{'funkproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'funkproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'funkproxy'}{'port'}{'udp'} = '1505'	; 
#	$srvcobjects_ref->{'funkproxy'}{'ports'}{'udp'}{'1505'}++	; 
#	$ports_ref->{'udp'}{'1505'}{'name'} = 'funkproxy'		; 
#	$srvcobjects_ref->{'funkproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'funkproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'funkproxy'}{'port'}{'tcp'} = '1505'	; 
#	$srvcobjects_ref->{'funkproxy'}{'ports'}{'tcp'}{'1505'}++	; 
#	$ports_ref->{'tcp'}{'1505'}{'name'} = 'funkproxy'		; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'port'}{'udp'} = '8208'	; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'ports'}{'udp'}{'8208'}++	; 
#	$ports_ref->{'udp'}{'8208'}{'name'} = 'lm-webwatcher'		; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'port'}{'tcp'} = '8208'	; 
#	$srvcobjects_ref->{'lm-webwatcher'}{'ports'}{'tcp'}{'8208'}++	; 
#	$ports_ref->{'tcp'}{'8208'}{'name'} = 'lm-webwatcher'		; 
#	$srvcobjects_ref->{'ftp-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftp-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftp-data'}{'port'}{'udp'} = '20'	; 
#	$srvcobjects_ref->{'ftp-data'}{'ports'}{'udp'}{'20'}++	; 
#	$ports_ref->{'udp'}{'20'}{'name'} = 'ftp-data'		; 
#	$srvcobjects_ref->{'ftp-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftp-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftp-data'}{'port'}{'tcp'} = '20'	; 
#	$srvcobjects_ref->{'ftp-data'}{'ports'}{'tcp'}{'20'}++	; 
#	$ports_ref->{'tcp'}{'20'}{'name'} = 'ftp-data'		; 
#	$srvcobjects_ref->{'pharmasoft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pharmasoft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pharmasoft'}{'port'}{'udp'} = '1779'	; 
#	$srvcobjects_ref->{'pharmasoft'}{'ports'}{'udp'}{'1779'}++	; 
#	$ports_ref->{'udp'}{'1779'}{'name'} = 'pharmasoft'		; 
#	$srvcobjects_ref->{'pharmasoft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pharmasoft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pharmasoft'}{'port'}{'tcp'} = '1779'	; 
#	$srvcobjects_ref->{'pharmasoft'}{'ports'}{'tcp'}{'1779'}++	; 
#	$ports_ref->{'tcp'}{'1779'}{'name'} = 'pharmasoft'		; 
#	$srvcobjects_ref->{'prosharedata'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prosharedata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharedata'}{'port'}{'udp'} = '5715'	; 
#	$srvcobjects_ref->{'prosharedata'}{'ports'}{'udp'}{'5715'}++	; 
#	$ports_ref->{'udp'}{'5715'}{'name'} = 'prosharedata'		; 
#	$srvcobjects_ref->{'prosharedata'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prosharedata'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prosharedata'}{'port'}{'tcp'} = '5715'	; 
#	$srvcobjects_ref->{'prosharedata'}{'ports'}{'tcp'}{'5715'}++	; 
#	$ports_ref->{'tcp'}{'5715'}{'name'} = 'prosharedata'		; 
#	$srvcobjects_ref->{'dwmsgserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dwmsgserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwmsgserver'}{'port'}{'udp'} = '3228'	; 
#	$srvcobjects_ref->{'dwmsgserver'}{'ports'}{'udp'}{'3228'}++	; 
#	$ports_ref->{'udp'}{'3228'}{'name'} = 'dwmsgserver'		; 
#	$srvcobjects_ref->{'dwmsgserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dwmsgserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwmsgserver'}{'port'}{'tcp'} = '3228'	; 
#	$srvcobjects_ref->{'dwmsgserver'}{'ports'}{'tcp'}{'3228'}++	; 
#	$ports_ref->{'tcp'}{'3228'}{'name'} = 'dwmsgserver'		; 
#	$srvcobjects_ref->{'ieee-mms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ieee-mms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ieee-mms'}{'port'}{'udp'} = '651'	; 
#	$srvcobjects_ref->{'ieee-mms'}{'ports'}{'udp'}{'651'}++	; 
#	$ports_ref->{'udp'}{'651'}{'name'} = 'ieee-mms'		; 
#	$srvcobjects_ref->{'ieee-mms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ieee-mms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ieee-mms'}{'port'}{'tcp'} = '651'	; 
#	$srvcobjects_ref->{'ieee-mms'}{'ports'}{'tcp'}{'651'}++	; 
#	$ports_ref->{'tcp'}{'651'}{'name'} = 'ieee-mms'		; 
#	$srvcobjects_ref->{'drmsmc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'drmsmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'drmsmc'}{'port'}{'udp'} = '1878'	; 
#	$srvcobjects_ref->{'drmsmc'}{'ports'}{'udp'}{'1878'}++	; 
#	$ports_ref->{'udp'}{'1878'}{'name'} = 'drmsmc'		; 
#	$srvcobjects_ref->{'drmsmc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'drmsmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'drmsmc'}{'port'}{'tcp'} = '1878'	; 
#	$srvcobjects_ref->{'drmsmc'}{'ports'}{'tcp'}{'1878'}++	; 
#	$ports_ref->{'tcp'}{'1878'}{'name'} = 'drmsmc'		; 
#	$srvcobjects_ref->{'cab-protocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cab-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cab-protocol'}{'port'}{'udp'} = '595'	; 
#	$srvcobjects_ref->{'cab-protocol'}{'ports'}{'udp'}{'595'}++	; 
#	$ports_ref->{'udp'}{'595'}{'name'} = 'cab-protocol'		; 
#	$srvcobjects_ref->{'cab-protocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cab-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cab-protocol'}{'port'}{'tcp'} = '595'	; 
#	$srvcobjects_ref->{'cab-protocol'}{'ports'}{'tcp'}{'595'}++	; 
#	$ports_ref->{'tcp'}{'595'}{'name'} = 'cab-protocol'		; 
#	$srvcobjects_ref->{'wilkenlistener'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wilkenlistener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wilkenlistener'}{'port'}{'udp'} = '1890'	; 
#	$srvcobjects_ref->{'wilkenlistener'}{'ports'}{'udp'}{'1890'}++	; 
#	$ports_ref->{'udp'}{'1890'}{'name'} = 'wilkenlistener'		; 
#	$srvcobjects_ref->{'wilkenlistener'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wilkenlistener'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wilkenlistener'}{'port'}{'tcp'} = '1890'	; 
#	$srvcobjects_ref->{'wilkenlistener'}{'ports'}{'tcp'}{'1890'}++	; 
#	$ports_ref->{'tcp'}{'1890'}{'name'} = 'wilkenlistener'		; 
#	$srvcobjects_ref->{'at-rtmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-rtmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-rtmp'}{'port'}{'udp'} = '201'	; 
#	$srvcobjects_ref->{'at-rtmp'}{'ports'}{'udp'}{'201'}++	; 
#	$ports_ref->{'udp'}{'201'}{'name'} = 'at-rtmp'		; 
#	$srvcobjects_ref->{'at-rtmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-rtmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-rtmp'}{'port'}{'tcp'} = '201'	; 
#	$srvcobjects_ref->{'at-rtmp'}{'ports'}{'tcp'}{'201'}++	; 
#	$ports_ref->{'tcp'}{'201'}{'name'} = 'at-rtmp'		; 
#	$srvcobjects_ref->{'netsupport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netsupport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsupport'}{'port'}{'udp'} = '5405'	; 
#	$srvcobjects_ref->{'netsupport'}{'ports'}{'udp'}{'5405'}++	; 
#	$ports_ref->{'udp'}{'5405'}{'name'} = 'netsupport'		; 
#	$srvcobjects_ref->{'netsupport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netsupport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netsupport'}{'port'}{'tcp'} = '5405'	; 
#	$srvcobjects_ref->{'netsupport'}{'ports'}{'tcp'}{'5405'}++	; 
#	$ports_ref->{'tcp'}{'5405'}{'name'} = 'netsupport'		; 
#	$srvcobjects_ref->{'ssm-cssps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssm-cssps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssm-cssps'}{'port'}{'udp'} = '2478'	; 
#	$srvcobjects_ref->{'ssm-cssps'}{'ports'}{'udp'}{'2478'}++	; 
#	$ports_ref->{'udp'}{'2478'}{'name'} = 'ssm-cssps'		; 
#	$srvcobjects_ref->{'ssm-cssps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssm-cssps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssm-cssps'}{'port'}{'tcp'} = '2478'	; 
#	$srvcobjects_ref->{'ssm-cssps'}{'ports'}{'tcp'}{'2478'}++	; 
#	$ports_ref->{'tcp'}{'2478'}{'name'} = 'ssm-cssps'		; 
#	$srvcobjects_ref->{'icl-twobase3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase3'}{'port'}{'udp'} = '25002'	; 
#	$srvcobjects_ref->{'icl-twobase3'}{'ports'}{'udp'}{'25002'}++	; 
#	$ports_ref->{'udp'}{'25002'}{'name'} = 'icl-twobase3'		; 
#	$srvcobjects_ref->{'icl-twobase3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase3'}{'port'}{'tcp'} = '25002'	; 
#	$srvcobjects_ref->{'icl-twobase3'}{'ports'}{'tcp'}{'25002'}++	; 
#	$ports_ref->{'tcp'}{'25002'}{'name'} = 'icl-twobase3'		; 
#	$srvcobjects_ref->{'hp-sca'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-sca'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sca'}{'port'}{'udp'} = '19411'	; 
#	$srvcobjects_ref->{'hp-sca'}{'ports'}{'udp'}{'19411'}++	; 
#	$ports_ref->{'udp'}{'19411'}{'name'} = 'hp-sca'		; 
#	$srvcobjects_ref->{'hp-sca'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-sca'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sca'}{'port'}{'tcp'} = '19411'	; 
#	$srvcobjects_ref->{'hp-sca'}{'ports'}{'tcp'}{'19411'}++	; 
#	$ports_ref->{'tcp'}{'19411'}{'name'} = 'hp-sca'		; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'port'}{'udp'} = '2749'	; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'ports'}{'udp'}{'2749'}++	; 
#	$ports_ref->{'udp'}{'2749'}{'name'} = 'fjippol-cnsl'		; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'port'}{'tcp'} = '2749'	; 
#	$srvcobjects_ref->{'fjippol-cnsl'}{'ports'}{'tcp'}{'2749'}++	; 
#	$ports_ref->{'tcp'}{'2749'}{'name'} = 'fjippol-cnsl'		; 
#	$srvcobjects_ref->{'dei-icda'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dei-icda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dei-icda'}{'port'}{'udp'} = '618'	; 
#	$srvcobjects_ref->{'dei-icda'}{'ports'}{'udp'}{'618'}++	; 
#	$ports_ref->{'udp'}{'618'}{'name'} = 'dei-icda'		; 
#	$srvcobjects_ref->{'dei-icda'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dei-icda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dei-icda'}{'port'}{'tcp'} = '618'	; 
#	$srvcobjects_ref->{'dei-icda'}{'ports'}{'tcp'}{'618'}++	; 
#	$ports_ref->{'tcp'}{'618'}{'name'} = 'dei-icda'		; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'port'}{'udp'} = '747'	; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'ports'}{'udp'}{'747'}++	; 
#	$ports_ref->{'udp'}{'747'}{'name'} = 'fujitsu-dev'		; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'port'}{'tcp'} = '747'	; 
#	$srvcobjects_ref->{'fujitsu-dev'}{'ports'}{'tcp'}{'747'}++	; 
#	$ports_ref->{'tcp'}{'747'}{'name'} = 'fujitsu-dev'		; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'port'}{'udp'} = '5404'	; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'ports'}{'udp'}{'5404'}++	; 
#	$ports_ref->{'udp'}{'5404'}{'name'} = 'hpoms-dps-lstn'		; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'port'}{'tcp'} = '5404'	; 
#	$srvcobjects_ref->{'hpoms-dps-lstn'}{'ports'}{'tcp'}{'5404'}++	; 
#	$ports_ref->{'tcp'}{'5404'}{'name'} = 'hpoms-dps-lstn'		; 
#	$srvcobjects_ref->{'dccm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dccm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dccm'}{'port'}{'udp'} = '5679'	; 
#	$srvcobjects_ref->{'dccm'}{'ports'}{'udp'}{'5679'}++	; 
#	$ports_ref->{'udp'}{'5679'}{'name'} = 'dccm'		; 
#	$srvcobjects_ref->{'dccm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dccm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dccm'}{'port'}{'tcp'} = '5679'	; 
#	$srvcobjects_ref->{'dccm'}{'ports'}{'tcp'}{'5679'}++	; 
#	$ports_ref->{'tcp'}{'5679'}{'name'} = 'dccm'		; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'port'}{'udp'} = '1630'	; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'ports'}{'udp'}{'1630'}++	; 
#	$ports_ref->{'udp'}{'1630'}{'name'} = 'oraclenet8cman'		; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'port'}{'tcp'} = '1630'	; 
#	$srvcobjects_ref->{'oraclenet8cman'}{'ports'}{'tcp'}{'1630'}++	; 
#	$ports_ref->{'tcp'}{'1630'}{'name'} = 'oraclenet8cman'		; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'port'}{'udp'} = '2068'	; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'ports'}{'udp'}{'2068'}++	; 
#	$ports_ref->{'udp'}{'2068'}{'name'} = 'avauthsrvprtcl'		; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'port'}{'tcp'} = '2068'	; 
#	$srvcobjects_ref->{'avauthsrvprtcl'}{'ports'}{'tcp'}{'2068'}++	; 
#	$ports_ref->{'tcp'}{'2068'}{'name'} = 'avauthsrvprtcl'		; 
#	$srvcobjects_ref->{'netbookmark'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netbookmark'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbookmark'}{'port'}{'udp'} = '3131'	; 
#	$srvcobjects_ref->{'netbookmark'}{'ports'}{'udp'}{'3131'}++	; 
#	$ports_ref->{'udp'}{'3131'}{'name'} = 'netbookmark'		; 
#	$srvcobjects_ref->{'netbookmark'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netbookmark'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netbookmark'}{'port'}{'tcp'} = '3131'	; 
#	$srvcobjects_ref->{'netbookmark'}{'ports'}{'tcp'}{'3131'}++	; 
#	$ports_ref->{'tcp'}{'3131'}{'name'} = 'netbookmark'		; 
#	$srvcobjects_ref->{'http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http'}{'port'}{'udp'} = '80'	; 
#	$srvcobjects_ref->{'http'}{'ports'}{'udp'}{'80'}++	; 
#	$ports_ref->{'udp'}{'80'}{'name'} = 'http'		; 
#	$srvcobjects_ref->{'http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http'}{'port'}{'tcp'} = '80'	; 
#	$srvcobjects_ref->{'http'}{'ports'}{'tcp'}{'80'}++	; 
#	$ports_ref->{'tcp'}{'80'}{'name'} = 'http'		; 
#	$srvcobjects_ref->{'ftps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftps'}{'port'}{'udp'} = '990'	; 
#	$srvcobjects_ref->{'ftps'}{'ports'}{'udp'}{'990'}++	; 
#	$ports_ref->{'udp'}{'990'}{'name'} = 'ftps'		; 
#	$srvcobjects_ref->{'ftps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftps'}{'port'}{'tcp'} = '990'	; 
#	$srvcobjects_ref->{'ftps'}{'ports'}{'tcp'}{'990'}++	; 
#	$ports_ref->{'tcp'}{'990'}{'name'} = 'ftps'		; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'port'}{'udp'} = '1770'	; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'ports'}{'udp'}{'1770'}++	; 
#	$ports_ref->{'udp'}{'1770'}{'name'} = 'bmc-net-svc'		; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'port'}{'tcp'} = '1770'	; 
#	$srvcobjects_ref->{'bmc-net-svc'}{'ports'}{'tcp'}{'1770'}++	; 
#	$ports_ref->{'tcp'}{'1770'}{'name'} = 'bmc-net-svc'		; 
#	$srvcobjects_ref->{'hp-sessmon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-sessmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sessmon'}{'port'}{'udp'} = '19412'	; 
#	$srvcobjects_ref->{'hp-sessmon'}{'ports'}{'udp'}{'19412'}++	; 
#	$ports_ref->{'udp'}{'19412'}{'name'} = 'hp-sessmon'		; 
#	$srvcobjects_ref->{'hp-sessmon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-sessmon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sessmon'}{'port'}{'tcp'} = '19412'	; 
#	$srvcobjects_ref->{'hp-sessmon'}{'ports'}{'tcp'}{'19412'}++	; 
#	$ports_ref->{'tcp'}{'19412'}{'name'} = 'hp-sessmon'		; 
#	$srvcobjects_ref->{'pro-ed'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pro-ed'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pro-ed'}{'port'}{'udp'} = '8032'	; 
#	$srvcobjects_ref->{'pro-ed'}{'ports'}{'udp'}{'8032'}++	; 
#	$ports_ref->{'udp'}{'8032'}{'name'} = 'pro-ed'		; 
#	$srvcobjects_ref->{'pro-ed'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pro-ed'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pro-ed'}{'port'}{'tcp'} = '8032'	; 
#	$srvcobjects_ref->{'pro-ed'}{'ports'}{'tcp'}{'8032'}++	; 
#	$ports_ref->{'tcp'}{'8032'}{'name'} = 'pro-ed'		; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'port'}{'udp'} = '1584'	; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'ports'}{'udp'}{'1584'}++	; 
#	$ports_ref->{'udp'}{'1584'}{'name'} = 'tn-tl-fd2'		; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'port'}{'tcp'} = '1584'	; 
#	$srvcobjects_ref->{'tn-tl-fd2'}{'ports'}{'tcp'}{'1584'}++	; 
#	$ports_ref->{'tcp'}{'1584'}{'name'} = 'tn-tl-fd2'		; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'port'}{'udp'} = '2490'	; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'ports'}{'udp'}{'2490'}++	; 
#	$ports_ref->{'udp'}{'2490'}{'name'} = 'qip-qdhcp'		; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'port'}{'tcp'} = '2490'	; 
#	$srvcobjects_ref->{'qip-qdhcp'}{'ports'}{'tcp'}{'2490'}++	; 
#	$ports_ref->{'tcp'}{'2490'}{'name'} = 'qip-qdhcp'		; 
#	$srvcobjects_ref->{'netuitive'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netuitive'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netuitive'}{'port'}{'udp'} = '1286'	; 
#	$srvcobjects_ref->{'netuitive'}{'ports'}{'udp'}{'1286'}++	; 
#	$ports_ref->{'udp'}{'1286'}{'name'} = 'netuitive'		; 
#	$srvcobjects_ref->{'netuitive'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netuitive'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netuitive'}{'port'}{'tcp'} = '1286'	; 
#	$srvcobjects_ref->{'netuitive'}{'ports'}{'tcp'}{'1286'}++	; 
#	$ports_ref->{'tcp'}{'1286'}{'name'} = 'netuitive'		; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'port'}{'udp'} = '1657'	; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'ports'}{'udp'}{'1657'}++	; 
#	$ports_ref->{'udp'}{'1657'}{'name'} = 'fujitsu-mmpdc'		; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'port'}{'tcp'} = '1657'	; 
#	$srvcobjects_ref->{'fujitsu-mmpdc'}{'ports'}{'tcp'}{'1657'}++	; 
#	$ports_ref->{'tcp'}{'1657'}{'name'} = 'fujitsu-mmpdc'		; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'port'}{'udp'} = '828'	; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'ports'}{'udp'}{'828'}++	; 
#	$ports_ref->{'udp'}{'828'}{'name'} = 'itm-mcell-s'		; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'port'}{'tcp'} = '828'	; 
#	$srvcobjects_ref->{'itm-mcell-s'}{'ports'}{'tcp'}{'828'}++	; 
#	$ports_ref->{'tcp'}{'828'}{'name'} = 'itm-mcell-s'		; 
#	$srvcobjects_ref->{'anet-l'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anet-l'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-l'}{'port'}{'udp'} = '3339'	; 
#	$srvcobjects_ref->{'anet-l'}{'ports'}{'udp'}{'3339'}++	; 
#	$ports_ref->{'udp'}{'3339'}{'name'} = 'anet-l'		; 
#	$srvcobjects_ref->{'anet-l'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anet-l'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-l'}{'port'}{'tcp'} = '3339'	; 
#	$srvcobjects_ref->{'anet-l'}{'ports'}{'tcp'}{'3339'}++	; 
#	$ports_ref->{'tcp'}{'3339'}{'name'} = 'anet-l'		; 
#	$srvcobjects_ref->{'acc-raid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acc-raid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acc-raid'}{'port'}{'udp'} = '2800'	; 
#	$srvcobjects_ref->{'acc-raid'}{'ports'}{'udp'}{'2800'}++	; 
#	$ports_ref->{'udp'}{'2800'}{'name'} = 'acc-raid'		; 
#	$srvcobjects_ref->{'acc-raid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acc-raid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acc-raid'}{'port'}{'tcp'} = '2800'	; 
#	$srvcobjects_ref->{'acc-raid'}{'ports'}{'tcp'}{'2800'}++	; 
#	$ports_ref->{'tcp'}{'2800'}{'name'} = 'acc-raid'		; 
#	$srvcobjects_ref->{'avt-profile-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avt-profile-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avt-profile-1'}{'port'}{'udp'} = '5004'	; 
#	$srvcobjects_ref->{'avt-profile-1'}{'ports'}{'udp'}{'5004'}++	; 
#	$ports_ref->{'udp'}{'5004'}{'name'} = 'avt-profile-1'		; 
#	$srvcobjects_ref->{'avt-profile-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avt-profile-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avt-profile-1'}{'port'}{'tcp'} = '5004'	; 
#	$srvcobjects_ref->{'avt-profile-1'}{'ports'}{'tcp'}{'5004'}++	; 
#	$ports_ref->{'tcp'}{'5004'}{'name'} = 'avt-profile-1'		; 
#	$srvcobjects_ref->{'cmadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cmadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmadmin'}{'port'}{'udp'} = '2617'	; 
#	$srvcobjects_ref->{'cmadmin'}{'ports'}{'udp'}{'2617'}++	; 
#	$ports_ref->{'udp'}{'2617'}{'name'} = 'cmadmin'		; 
#	$srvcobjects_ref->{'cmadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cmadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmadmin'}{'port'}{'tcp'} = '2617'	; 
#	$srvcobjects_ref->{'cmadmin'}{'ports'}{'tcp'}{'2617'}++	; 
#	$ports_ref->{'tcp'}{'2617'}{'name'} = 'cmadmin'		; 
#	$srvcobjects_ref->{'sugp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sugp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sugp'}{'port'}{'udp'} = '1905'	; 
#	$srvcobjects_ref->{'sugp'}{'ports'}{'udp'}{'1905'}++	; 
#	$ports_ref->{'udp'}{'1905'}{'name'} = 'sugp'		; 
#	$srvcobjects_ref->{'sugp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sugp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sugp'}{'port'}{'tcp'} = '1905'	; 
#	$srvcobjects_ref->{'sugp'}{'ports'}{'tcp'}{'1905'}++	; 
#	$ports_ref->{'tcp'}{'1905'}{'name'} = 'sugp'		; 
#	$srvcobjects_ref->{'fsportmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fsportmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fsportmap'}{'port'}{'udp'} = '4349'	; 
#	$srvcobjects_ref->{'fsportmap'}{'ports'}{'udp'}{'4349'}++	; 
#	$ports_ref->{'udp'}{'4349'}{'name'} = 'fsportmap'		; 
#	$srvcobjects_ref->{'fsportmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fsportmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fsportmap'}{'port'}{'tcp'} = '4349'	; 
#	$srvcobjects_ref->{'fsportmap'}{'ports'}{'tcp'}{'4349'}++	; 
#	$ports_ref->{'tcp'}{'4349'}{'name'} = 'fsportmap'		; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'port'}{'udp'} = '2664'	; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'ports'}{'udp'}{'2664'}++	; 
#	$ports_ref->{'udp'}{'2664'}{'name'} = 'patrol-mq-gm'		; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'port'}{'tcp'} = '2664'	; 
#	$srvcobjects_ref->{'patrol-mq-gm'}{'ports'}{'tcp'}{'2664'}++	; 
#	$ports_ref->{'tcp'}{'2664'}{'name'} = 'patrol-mq-gm'		; 
#	$srvcobjects_ref->{'net-steward'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'net-steward'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net-steward'}{'port'}{'udp'} = '2128'	; 
#	$srvcobjects_ref->{'net-steward'}{'ports'}{'udp'}{'2128'}++	; 
#	$ports_ref->{'udp'}{'2128'}{'name'} = 'net-steward'		; 
#	$srvcobjects_ref->{'net-steward'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'net-steward'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'net-steward'}{'port'}{'tcp'} = '2128'	; 
#	$srvcobjects_ref->{'net-steward'}{'ports'}{'tcp'}{'2128'}++	; 
#	$ports_ref->{'tcp'}{'2128'}{'name'} = 'net-steward'		; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'port'}{'udp'} = '2861'	; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'ports'}{'udp'}{'2861'}++	; 
#	$ports_ref->{'udp'}{'2861'}{'name'} = 'dialpad-voice2'		; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'port'}{'tcp'} = '2861'	; 
#	$srvcobjects_ref->{'dialpad-voice2'}{'ports'}{'tcp'}{'2861'}++	; 
#	$ports_ref->{'tcp'}{'2861'}{'name'} = 'dialpad-voice2'		; 
#	$srvcobjects_ref->{'zion-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zion-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zion-lm'}{'port'}{'udp'} = '1425'	; 
#	$srvcobjects_ref->{'zion-lm'}{'ports'}{'udp'}{'1425'}++	; 
#	$ports_ref->{'udp'}{'1425'}{'name'} = 'zion-lm'		; 
#	$srvcobjects_ref->{'zion-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zion-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zion-lm'}{'port'}{'tcp'} = '1425'	; 
#	$srvcobjects_ref->{'zion-lm'}{'ports'}{'tcp'}{'1425'}++	; 
#	$ports_ref->{'tcp'}{'1425'}{'name'} = 'zion-lm'		; 
#	$srvcobjects_ref->{'ms-theater'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-theater'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-theater'}{'port'}{'udp'} = '2460'	; 
#	$srvcobjects_ref->{'ms-theater'}{'ports'}{'udp'}{'2460'}++	; 
#	$ports_ref->{'udp'}{'2460'}{'name'} = 'ms-theater'		; 
#	$srvcobjects_ref->{'ms-theater'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-theater'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-theater'}{'port'}{'tcp'} = '2460'	; 
#	$srvcobjects_ref->{'ms-theater'}{'ports'}{'tcp'}{'2460'}++	; 
#	$ports_ref->{'tcp'}{'2460'}{'name'} = 'ms-theater'		; 
#	$srvcobjects_ref->{'unisys-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unisys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unisys-lm'}{'port'}{'udp'} = '1823'	; 
#	$srvcobjects_ref->{'unisys-lm'}{'ports'}{'udp'}{'1823'}++	; 
#	$ports_ref->{'udp'}{'1823'}{'name'} = 'unisys-lm'		; 
#	$srvcobjects_ref->{'unisys-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unisys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unisys-lm'}{'port'}{'tcp'} = '1823'	; 
#	$srvcobjects_ref->{'unisys-lm'}{'ports'}{'tcp'}{'1823'}++	; 
#	$ports_ref->{'tcp'}{'1823'}{'name'} = 'unisys-lm'		; 
#	$srvcobjects_ref->{'fxp-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fxp-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fxp-1'}{'port'}{'udp'} = '286'	; 
#	$srvcobjects_ref->{'fxp-1'}{'ports'}{'udp'}{'286'}++	; 
#	$ports_ref->{'udp'}{'286'}{'name'} = 'fxp-1'		; 
#	$srvcobjects_ref->{'fxp-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fxp-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fxp-1'}{'port'}{'tcp'} = '286'	; 
#	$srvcobjects_ref->{'fxp-1'}{'ports'}{'tcp'}{'286'}++	; 
#	$ports_ref->{'tcp'}{'286'}{'name'} = 'fxp-1'		; 
#	$srvcobjects_ref->{'cbserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cbserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cbserver'}{'port'}{'udp'} = '3388'	; 
#	$srvcobjects_ref->{'cbserver'}{'ports'}{'udp'}{'3388'}++	; 
#	$ports_ref->{'udp'}{'3388'}{'name'} = 'cbserver'		; 
#	$srvcobjects_ref->{'cbserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cbserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cbserver'}{'port'}{'tcp'} = '3388'	; 
#	$srvcobjects_ref->{'cbserver'}{'ports'}{'tcp'}{'3388'}++	; 
#	$ports_ref->{'tcp'}{'3388'}{'name'} = 'cbserver'		; 
#	$srvcobjects_ref->{'netinfo-local'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netinfo-local'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netinfo-local'}{'port'}{'udp'} = '1033'	; 
#	$srvcobjects_ref->{'netinfo-local'}{'ports'}{'udp'}{'1033'}++	; 
#	$ports_ref->{'udp'}{'1033'}{'name'} = 'netinfo-local'		; 
#	$srvcobjects_ref->{'netinfo-local'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netinfo-local'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netinfo-local'}{'port'}{'tcp'} = '1033'	; 
#	$srvcobjects_ref->{'netinfo-local'}{'ports'}{'tcp'}{'1033'}++	; 
#	$ports_ref->{'tcp'}{'1033'}{'name'} = 'netinfo-local'		; 
#	$srvcobjects_ref->{'novell-zen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'novell-zen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-zen'}{'port'}{'udp'} = '2544'	; 
#	$srvcobjects_ref->{'novell-zen'}{'ports'}{'udp'}{'2544'}++	; 
#	$ports_ref->{'udp'}{'2544'}{'name'} = 'novell-zen'		; 
#	$srvcobjects_ref->{'novell-zen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'novell-zen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-zen'}{'port'}{'tcp'} = '2544'	; 
#	$srvcobjects_ref->{'novell-zen'}{'ports'}{'tcp'}{'2544'}++	; 
#	$ports_ref->{'tcp'}{'2544'}{'name'} = 'novell-zen'		; 
#	$srvcobjects_ref->{'enl-name'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'enl-name'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enl-name'}{'port'}{'udp'} = '1805'	; 
#	$srvcobjects_ref->{'enl-name'}{'ports'}{'udp'}{'1805'}++	; 
#	$ports_ref->{'udp'}{'1805'}{'name'} = 'enl-name'		; 
#	$srvcobjects_ref->{'enl-name'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'enl-name'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enl-name'}{'port'}{'tcp'} = '1805'	; 
#	$srvcobjects_ref->{'enl-name'}{'ports'}{'tcp'}{'1805'}++	; 
#	$ports_ref->{'tcp'}{'1805'}{'name'} = 'enl-name'		; 
#	$srvcobjects_ref->{'dtserver-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dtserver-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtserver-port'}{'port'}{'udp'} = '4028'	; 
#	$srvcobjects_ref->{'dtserver-port'}{'ports'}{'udp'}{'4028'}++	; 
#	$ports_ref->{'udp'}{'4028'}{'name'} = 'dtserver-port'		; 
#	$srvcobjects_ref->{'dtserver-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dtserver-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dtserver-port'}{'port'}{'tcp'} = '4028'	; 
#	$srvcobjects_ref->{'dtserver-port'}{'ports'}{'tcp'}{'4028'}++	; 
#	$ports_ref->{'tcp'}{'4028'}{'name'} = 'dtserver-port'		; 
#	$srvcobjects_ref->{'cyaserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cyaserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cyaserv'}{'port'}{'udp'} = '2584'	; 
#	$srvcobjects_ref->{'cyaserv'}{'ports'}{'udp'}{'2584'}++	; 
#	$ports_ref->{'udp'}{'2584'}{'name'} = 'cyaserv'		; 
#	$srvcobjects_ref->{'cyaserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cyaserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cyaserv'}{'port'}{'tcp'} = '2584'	; 
#	$srvcobjects_ref->{'cyaserv'}{'ports'}{'tcp'}{'2584'}++	; 
#	$ports_ref->{'tcp'}{'2584'}{'name'} = 'cyaserv'		; 
#	$srvcobjects_ref->{'facsys-router'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'facsys-router'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facsys-router'}{'port'}{'udp'} = '2515'	; 
#	$srvcobjects_ref->{'facsys-router'}{'ports'}{'udp'}{'2515'}++	; 
#	$ports_ref->{'udp'}{'2515'}{'name'} = 'facsys-router'		; 
#	$srvcobjects_ref->{'facsys-router'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'facsys-router'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facsys-router'}{'port'}{'tcp'} = '2515'	; 
#	$srvcobjects_ref->{'facsys-router'}{'ports'}{'tcp'}{'2515'}++	; 
#	$ports_ref->{'tcp'}{'2515'}{'name'} = 'facsys-router'		; 
#	$srvcobjects_ref->{'wysdma'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wysdma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wysdma'}{'port'}{'udp'} = '3741'	; 
#	$srvcobjects_ref->{'wysdma'}{'ports'}{'udp'}{'3741'}++	; 
#	$ports_ref->{'udp'}{'3741'}{'name'} = 'wysdma'		; 
#	$srvcobjects_ref->{'wysdma'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wysdma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wysdma'}{'port'}{'tcp'} = '3741'	; 
#	$srvcobjects_ref->{'wysdma'}{'ports'}{'tcp'}{'3741'}++	; 
#	$ports_ref->{'tcp'}{'3741'}{'name'} = 'wysdma'		; 
#	$srvcobjects_ref->{'kermit'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kermit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kermit'}{'port'}{'udp'} = '1649'	; 
#	$srvcobjects_ref->{'kermit'}{'ports'}{'udp'}{'1649'}++	; 
#	$ports_ref->{'udp'}{'1649'}{'name'} = 'kermit'		; 
#	$srvcobjects_ref->{'kermit'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kermit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kermit'}{'port'}{'tcp'} = '1649'	; 
#	$srvcobjects_ref->{'kermit'}{'ports'}{'tcp'}{'1649'}++	; 
#	$ports_ref->{'tcp'}{'1649'}{'name'} = 'kermit'		; 
#	$srvcobjects_ref->{'vmnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vmnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vmnet'}{'port'}{'udp'} = '175'	; 
#	$srvcobjects_ref->{'vmnet'}{'ports'}{'udp'}{'175'}++	; 
#	$ports_ref->{'udp'}{'175'}{'name'} = 'vmnet'		; 
#	$srvcobjects_ref->{'vmnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vmnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vmnet'}{'port'}{'tcp'} = '175'	; 
#	$srvcobjects_ref->{'vmnet'}{'ports'}{'tcp'}{'175'}++	; 
#	$ports_ref->{'tcp'}{'175'}{'name'} = 'vmnet'		; 
#	$srvcobjects_ref->{'bftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bftp'}{'port'}{'udp'} = '152'	; 
#	$srvcobjects_ref->{'bftp'}{'ports'}{'udp'}{'152'}++	; 
#	$ports_ref->{'udp'}{'152'}{'name'} = 'bftp'		; 
#	$srvcobjects_ref->{'bftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bftp'}{'port'}{'tcp'} = '152'	; 
#	$srvcobjects_ref->{'bftp'}{'ports'}{'tcp'}{'152'}++	; 
#	$ports_ref->{'tcp'}{'152'}{'name'} = 'bftp'		; 
#	$srvcobjects_ref->{'smaclmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smaclmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smaclmgr'}{'port'}{'udp'} = '4660'	; 
#	$srvcobjects_ref->{'smaclmgr'}{'ports'}{'udp'}{'4660'}++	; 
#	$ports_ref->{'udp'}{'4660'}{'name'} = 'smaclmgr'		; 
#	$srvcobjects_ref->{'smaclmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smaclmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smaclmgr'}{'port'}{'tcp'} = '4660'	; 
#	$srvcobjects_ref->{'smaclmgr'}{'ports'}{'tcp'}{'4660'}++	; 
#	$ports_ref->{'tcp'}{'4660'}{'name'} = 'smaclmgr'		; 
#	$srvcobjects_ref->{'minivend'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'minivend'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'minivend'}{'port'}{'udp'} = '7786'	; 
#	$srvcobjects_ref->{'minivend'}{'ports'}{'udp'}{'7786'}++	; 
#	$ports_ref->{'udp'}{'7786'}{'name'} = 'minivend'		; 
#	$srvcobjects_ref->{'minivend'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'minivend'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'minivend'}{'port'}{'tcp'} = '7786'	; 
#	$srvcobjects_ref->{'minivend'}{'ports'}{'tcp'}{'7786'}++	; 
#	$ports_ref->{'tcp'}{'7786'}{'name'} = 'minivend'		; 
#	$srvcobjects_ref->{'CAIlic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'CAIlic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'CAIlic'}{'port'}{'udp'} = '216'	; 
#	$srvcobjects_ref->{'CAIlic'}{'ports'}{'udp'}{'216'}++	; 
#	$ports_ref->{'udp'}{'216'}{'name'} = 'CAIlic'		; 
#	$srvcobjects_ref->{'CAIlic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'CAIlic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'CAIlic'}{'port'}{'tcp'} = '216'	; 
#	$srvcobjects_ref->{'CAIlic'}{'ports'}{'tcp'}{'216'}++	; 
#	$ports_ref->{'tcp'}{'216'}{'name'} = 'CAIlic'		; 
#	$srvcobjects_ref->{'cl/1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cl/1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cl/1'}{'port'}{'udp'} = '172'	; 
#	$srvcobjects_ref->{'cl/1'}{'ports'}{'udp'}{'172'}++	; 
#	$ports_ref->{'udp'}{'172'}{'name'} = 'cl/1'		; 
#	$srvcobjects_ref->{'cl/1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cl/1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cl/1'}{'port'}{'tcp'} = '172'	; 
#	$srvcobjects_ref->{'cl/1'}{'ports'}{'tcp'}{'172'}++	; 
#	$ports_ref->{'tcp'}{'172'}{'name'} = 'cl/1'		; 
#	$srvcobjects_ref->{'netview-aix-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-2'}{'port'}{'udp'} = '1662'	; 
#	$srvcobjects_ref->{'netview-aix-2'}{'ports'}{'udp'}{'1662'}++	; 
#	$ports_ref->{'udp'}{'1662'}{'name'} = 'netview-aix-2'		; 
#	$srvcobjects_ref->{'netview-aix-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-2'}{'port'}{'tcp'} = '1662'	; 
#	$srvcobjects_ref->{'netview-aix-2'}{'ports'}{'tcp'}{'1662'}++	; 
#	$ports_ref->{'tcp'}{'1662'}{'name'} = 'netview-aix-2'		; 
#	$srvcobjects_ref->{'awg-proxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'awg-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'awg-proxy'}{'port'}{'udp'} = '3277'	; 
#	$srvcobjects_ref->{'awg-proxy'}{'ports'}{'udp'}{'3277'}++	; 
#	$ports_ref->{'udp'}{'3277'}{'name'} = 'awg-proxy'		; 
#	$srvcobjects_ref->{'awg-proxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'awg-proxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'awg-proxy'}{'port'}{'tcp'} = '3277'	; 
#	$srvcobjects_ref->{'awg-proxy'}{'ports'}{'tcp'}{'3277'}++	; 
#	$ports_ref->{'tcp'}{'3277'}{'name'} = 'awg-proxy'		; 
#	$srvcobjects_ref->{'de-cache-query'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'de-cache-query'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-cache-query'}{'port'}{'udp'} = '1255'	; 
#	$srvcobjects_ref->{'de-cache-query'}{'ports'}{'udp'}{'1255'}++	; 
#	$ports_ref->{'udp'}{'1255'}{'name'} = 'de-cache-query'		; 
#	$srvcobjects_ref->{'de-cache-query'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'de-cache-query'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-cache-query'}{'port'}{'tcp'} = '1255'	; 
#	$srvcobjects_ref->{'de-cache-query'}{'ports'}{'tcp'}{'1255'}++	; 
#	$ports_ref->{'tcp'}{'1255'}{'name'} = 'de-cache-query'		; 
#	$srvcobjects_ref->{'ginad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ginad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ginad'}{'port'}{'udp'} = '634'	; 
#	$srvcobjects_ref->{'ginad'}{'ports'}{'udp'}{'634'}++	; 
#	$ports_ref->{'udp'}{'634'}{'name'} = 'ginad'		; 
#	$srvcobjects_ref->{'ginad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ginad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ginad'}{'port'}{'tcp'} = '634'	; 
#	$srvcobjects_ref->{'ginad'}{'ports'}{'tcp'}{'634'}++	; 
#	$ports_ref->{'tcp'}{'634'}{'name'} = 'ginad'		; 
#	$srvcobjects_ref->{'smart-diagnose'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smart-diagnose'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smart-diagnose'}{'port'}{'udp'} = '2721'	; 
#	$srvcobjects_ref->{'smart-diagnose'}{'ports'}{'udp'}{'2721'}++	; 
#	$ports_ref->{'udp'}{'2721'}{'name'} = 'smart-diagnose'		; 
#	$srvcobjects_ref->{'smart-diagnose'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smart-diagnose'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smart-diagnose'}{'port'}{'tcp'} = '2721'	; 
#	$srvcobjects_ref->{'smart-diagnose'}{'ports'}{'tcp'}{'2721'}++	; 
#	$ports_ref->{'tcp'}{'2721'}{'name'} = 'smart-diagnose'		; 
#	$srvcobjects_ref->{'vpjp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpjp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpjp'}{'port'}{'udp'} = '1345'	; 
#	$srvcobjects_ref->{'vpjp'}{'ports'}{'udp'}{'1345'}++	; 
#	$ports_ref->{'udp'}{'1345'}{'name'} = 'vpjp'		; 
#	$srvcobjects_ref->{'vpjp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpjp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpjp'}{'port'}{'tcp'} = '1345'	; 
#	$srvcobjects_ref->{'vpjp'}{'ports'}{'tcp'}{'1345'}++	; 
#	$ports_ref->{'tcp'}{'1345'}{'name'} = 'vpjp'		; 
#	$srvcobjects_ref->{'faxstfx-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'faxstfx-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'faxstfx-port'}{'port'}{'udp'} = '3684'	; 
#	$srvcobjects_ref->{'faxstfx-port'}{'ports'}{'udp'}{'3684'}++	; 
#	$ports_ref->{'udp'}{'3684'}{'name'} = 'faxstfx-port'		; 
#	$srvcobjects_ref->{'faxstfx-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'faxstfx-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'faxstfx-port'}{'port'}{'tcp'} = '3684'	; 
#	$srvcobjects_ref->{'faxstfx-port'}{'ports'}{'tcp'}{'3684'}++	; 
#	$ports_ref->{'tcp'}{'3684'}{'name'} = 'faxstfx-port'		; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'port'}{'udp'} = '459'	; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'ports'}{'udp'}{'459'}++	; 
#	$ports_ref->{'udp'}{'459'}{'name'} = 'ampr-rcmd'		; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'port'}{'tcp'} = '459'	; 
#	$srvcobjects_ref->{'ampr-rcmd'}{'ports'}{'tcp'}{'459'}++	; 
#	$ports_ref->{'tcp'}{'459'}{'name'} = 'ampr-rcmd'		; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'port'}{'udp'} = '847'	; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'ports'}{'udp'}{'847'}++	; 
#	$ports_ref->{'udp'}{'847'}{'name'} = 'dhcp-failover2'		; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'port'}{'tcp'} = '847'	; 
#	$srvcobjects_ref->{'dhcp-failover2'}{'ports'}{'tcp'}{'847'}++	; 
#	$ports_ref->{'tcp'}{'847'}{'name'} = 'dhcp-failover2'		; 
#	$srvcobjects_ref->{'md-cg-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'md-cg-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'md-cg-http'}{'port'}{'udp'} = '2688'	; 
#	$srvcobjects_ref->{'md-cg-http'}{'ports'}{'udp'}{'2688'}++	; 
#	$ports_ref->{'udp'}{'2688'}{'name'} = 'md-cg-http'		; 
#	$srvcobjects_ref->{'md-cg-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'md-cg-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'md-cg-http'}{'port'}{'tcp'} = '2688'	; 
#	$srvcobjects_ref->{'md-cg-http'}{'ports'}{'tcp'}{'2688'}++	; 
#	$ports_ref->{'tcp'}{'2688'}{'name'} = 'md-cg-http'		; 
#	$srvcobjects_ref->{'hacl-qs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hacl-qs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-qs'}{'port'}{'udp'} = '1238'	; 
#	$srvcobjects_ref->{'hacl-qs'}{'ports'}{'udp'}{'1238'}++	; 
#	$ports_ref->{'udp'}{'1238'}{'name'} = 'hacl-qs'		; 
#	$srvcobjects_ref->{'hacl-qs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hacl-qs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hacl-qs'}{'port'}{'tcp'} = '1238'	; 
#	$srvcobjects_ref->{'hacl-qs'}{'ports'}{'tcp'}{'1238'}++	; 
#	$ports_ref->{'tcp'}{'1238'}{'name'} = 'hacl-qs'		; 
#	$srvcobjects_ref->{'blocks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'blocks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blocks'}{'port'}{'udp'} = '10288'	; 
#	$srvcobjects_ref->{'blocks'}{'ports'}{'udp'}{'10288'}++	; 
#	$ports_ref->{'udp'}{'10288'}{'name'} = 'blocks'		; 
#	$srvcobjects_ref->{'blocks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'blocks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'blocks'}{'port'}{'tcp'} = '10288'	; 
#	$srvcobjects_ref->{'blocks'}{'ports'}{'tcp'}{'10288'}++	; 
#	$ports_ref->{'tcp'}{'10288'}{'name'} = 'blocks'		; 
#	$srvcobjects_ref->{'sentinel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sentinel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentinel'}{'port'}{'udp'} = '3588'	; 
#	$srvcobjects_ref->{'sentinel'}{'ports'}{'udp'}{'3588'}++	; 
#	$ports_ref->{'udp'}{'3588'}{'name'} = 'sentinel'		; 
#	$srvcobjects_ref->{'sentinel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sentinel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sentinel'}{'port'}{'tcp'} = '3588'	; 
#	$srvcobjects_ref->{'sentinel'}{'ports'}{'tcp'}{'3588'}++	; 
#	$ports_ref->{'tcp'}{'3588'}{'name'} = 'sentinel'		; 
#	$srvcobjects_ref->{'masc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'masc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'masc'}{'port'}{'udp'} = '2587'	; 
#	$srvcobjects_ref->{'masc'}{'ports'}{'udp'}{'2587'}++	; 
#	$ports_ref->{'udp'}{'2587'}{'name'} = 'masc'		; 
#	$srvcobjects_ref->{'masc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'masc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'masc'}{'port'}{'tcp'} = '2587'	; 
#	$srvcobjects_ref->{'masc'}{'ports'}{'tcp'}{'2587'}++	; 
#	$ports_ref->{'tcp'}{'2587'}{'name'} = 'masc'		; 
#	$srvcobjects_ref->{'accord-mgc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'accord-mgc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accord-mgc'}{'port'}{'udp'} = '1205'	; 
#	$srvcobjects_ref->{'accord-mgc'}{'ports'}{'udp'}{'1205'}++	; 
#	$ports_ref->{'udp'}{'1205'}{'name'} = 'accord-mgc'		; 
#	$srvcobjects_ref->{'accord-mgc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'accord-mgc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accord-mgc'}{'port'}{'tcp'} = '1205'	; 
#	$srvcobjects_ref->{'accord-mgc'}{'ports'}{'tcp'}{'1205'}++	; 
#	$ports_ref->{'tcp'}{'1205'}{'name'} = 'accord-mgc'		; 
#	$srvcobjects_ref->{'f5-iquery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'f5-iquery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'f5-iquery'}{'port'}{'udp'} = '4353'	; 
#	$srvcobjects_ref->{'f5-iquery'}{'ports'}{'udp'}{'4353'}++	; 
#	$ports_ref->{'udp'}{'4353'}{'name'} = 'f5-iquery'		; 
#	$srvcobjects_ref->{'f5-iquery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'f5-iquery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'f5-iquery'}{'port'}{'tcp'} = '4353'	; 
#	$srvcobjects_ref->{'f5-iquery'}{'ports'}{'tcp'}{'4353'}++	; 
#	$ports_ref->{'tcp'}{'4353'}{'name'} = 'f5-iquery'		; 
#	$srvcobjects_ref->{'metasys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metasys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metasys'}{'port'}{'udp'} = '11001'	; 
#	$srvcobjects_ref->{'metasys'}{'ports'}{'udp'}{'11001'}++	; 
#	$ports_ref->{'udp'}{'11001'}{'name'} = 'metasys'		; 
#	$srvcobjects_ref->{'metasys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metasys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metasys'}{'port'}{'tcp'} = '11001'	; 
#	$srvcobjects_ref->{'metasys'}{'ports'}{'tcp'}{'11001'}++	; 
#	$ports_ref->{'tcp'}{'11001'}{'name'} = 'metasys'		; 
#	$srvcobjects_ref->{'fjmpcm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjmpcm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjmpcm'}{'port'}{'udp'} = '2975'	; 
#	$srvcobjects_ref->{'fjmpcm'}{'ports'}{'udp'}{'2975'}++	; 
#	$ports_ref->{'udp'}{'2975'}{'name'} = 'fjmpcm'		; 
#	$srvcobjects_ref->{'fjmpcm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjmpcm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjmpcm'}{'port'}{'tcp'} = '2975'	; 
#	$srvcobjects_ref->{'fjmpcm'}{'ports'}{'tcp'}{'2975'}++	; 
#	$ports_ref->{'tcp'}{'2975'}{'name'} = 'fjmpcm'		; 
#	$srvcobjects_ref->{'proofd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proofd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proofd'}{'port'}{'udp'} = '1093'	; 
#	$srvcobjects_ref->{'proofd'}{'ports'}{'udp'}{'1093'}++	; 
#	$ports_ref->{'udp'}{'1093'}{'name'} = 'proofd'		; 
#	$srvcobjects_ref->{'proofd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proofd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proofd'}{'port'}{'tcp'} = '1093'	; 
#	$srvcobjects_ref->{'proofd'}{'ports'}{'tcp'}{'1093'}++	; 
#	$ports_ref->{'tcp'}{'1093'}{'name'} = 'proofd'		; 
#	$srvcobjects_ref->{'solid-e-engine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'solid-e-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'solid-e-engine'}{'port'}{'udp'} = '1964'	; 
#	$srvcobjects_ref->{'solid-e-engine'}{'ports'}{'udp'}{'1964'}++	; 
#	$ports_ref->{'udp'}{'1964'}{'name'} = 'solid-e-engine'		; 
#	$srvcobjects_ref->{'solid-e-engine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'solid-e-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'solid-e-engine'}{'port'}{'tcp'} = '1964'	; 
#	$srvcobjects_ref->{'solid-e-engine'}{'ports'}{'tcp'}{'1964'}++	; 
#	$ports_ref->{'tcp'}{'1964'}{'name'} = 'solid-e-engine'		; 
#	$srvcobjects_ref->{'vpsipport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpsipport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpsipport'}{'port'}{'udp'} = '2649'	; 
#	$srvcobjects_ref->{'vpsipport'}{'ports'}{'udp'}{'2649'}++	; 
#	$ports_ref->{'udp'}{'2649'}{'name'} = 'vpsipport'		; 
#	$srvcobjects_ref->{'vpsipport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpsipport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpsipport'}{'port'}{'tcp'} = '2649'	; 
#	$srvcobjects_ref->{'vpsipport'}{'ports'}{'tcp'}{'2649'}++	; 
#	$ports_ref->{'tcp'}{'2649'}{'name'} = 'vpsipport'		; 
#	$srvcobjects_ref->{'ctdhercules'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ctdhercules'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctdhercules'}{'port'}{'udp'} = '3773'	; 
#	$srvcobjects_ref->{'ctdhercules'}{'ports'}{'udp'}{'3773'}++	; 
#	$ports_ref->{'udp'}{'3773'}{'name'} = 'ctdhercules'		; 
#	$srvcobjects_ref->{'ctdhercules'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ctdhercules'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ctdhercules'}{'port'}{'tcp'} = '3773'	; 
#	$srvcobjects_ref->{'ctdhercules'}{'ports'}{'tcp'}{'3773'}++	; 
#	$ports_ref->{'tcp'}{'3773'}{'name'} = 'ctdhercules'		; 
#	$srvcobjects_ref->{'tag-ups-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tag-ups-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tag-ups-1'}{'port'}{'udp'} = '3573'	; 
#	$srvcobjects_ref->{'tag-ups-1'}{'ports'}{'udp'}{'3573'}++	; 
#	$ports_ref->{'udp'}{'3573'}{'name'} = 'tag-ups-1'		; 
#	$srvcobjects_ref->{'tag-ups-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tag-ups-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tag-ups-1'}{'port'}{'tcp'} = '3573'	; 
#	$srvcobjects_ref->{'tag-ups-1'}{'ports'}{'tcp'}{'3573'}++	; 
#	$ports_ref->{'tcp'}{'3573'}{'name'} = 'tag-ups-1'		; 
#	$srvcobjects_ref->{'sonus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sonus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonus'}{'port'}{'udp'} = '2653'	; 
#	$srvcobjects_ref->{'sonus'}{'ports'}{'udp'}{'2653'}++	; 
#	$ports_ref->{'udp'}{'2653'}{'name'} = 'sonus'		; 
#	$srvcobjects_ref->{'sonus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sonus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonus'}{'port'}{'tcp'} = '2653'	; 
#	$srvcobjects_ref->{'sonus'}{'ports'}{'tcp'}{'2653'}++	; 
#	$ports_ref->{'tcp'}{'2653'}{'name'} = 'sonus'		; 
#	$srvcobjects_ref->{'facsys-ntp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'facsys-ntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facsys-ntp'}{'port'}{'udp'} = '2514'	; 
#	$srvcobjects_ref->{'facsys-ntp'}{'ports'}{'udp'}{'2514'}++	; 
#	$ports_ref->{'udp'}{'2514'}{'name'} = 'facsys-ntp'		; 
#	$srvcobjects_ref->{'facsys-ntp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'facsys-ntp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'facsys-ntp'}{'port'}{'tcp'} = '2514'	; 
#	$srvcobjects_ref->{'facsys-ntp'}{'ports'}{'tcp'}{'2514'}++	; 
#	$ports_ref->{'tcp'}{'2514'}{'name'} = 'facsys-ntp'		; 
#	$srvcobjects_ref->{'base'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'base'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'base'}{'port'}{'udp'} = '5429'	; 
#	$srvcobjects_ref->{'base'}{'ports'}{'udp'}{'5429'}++	; 
#	$ports_ref->{'udp'}{'5429'}{'name'} = 'base'		; 
#	$srvcobjects_ref->{'base'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'base'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'base'}{'port'}{'tcp'} = '5429'	; 
#	$srvcobjects_ref->{'base'}{'ports'}{'tcp'}{'5429'}++	; 
#	$ports_ref->{'tcp'}{'5429'}{'name'} = 'base'		; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'port'}{'udp'} = '6550'	; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'ports'}{'udp'}{'6550'}++	; 
#	$ports_ref->{'udp'}{'6550'}{'name'} = 'fg-sysupdate'		; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'port'}{'tcp'} = '6550'	; 
#	$srvcobjects_ref->{'fg-sysupdate'}{'ports'}{'tcp'}{'6550'}++	; 
#	$ports_ref->{'tcp'}{'6550'}{'name'} = 'fg-sysupdate'		; 
#	$srvcobjects_ref->{'nati-svrloc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nati-svrloc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-svrloc'}{'port'}{'udp'} = '3580'	; 
#	$srvcobjects_ref->{'nati-svrloc'}{'ports'}{'udp'}{'3580'}++	; 
#	$ports_ref->{'udp'}{'3580'}{'name'} = 'nati-svrloc'		; 
#	$srvcobjects_ref->{'nati-svrloc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nati-svrloc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-svrloc'}{'port'}{'tcp'} = '3580'	; 
#	$srvcobjects_ref->{'nati-svrloc'}{'ports'}{'tcp'}{'3580'}++	; 
#	$ports_ref->{'tcp'}{'3580'}{'name'} = 'nati-svrloc'		; 
#	$srvcobjects_ref->{'worldfusion2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'worldfusion2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldfusion2'}{'port'}{'udp'} = '2596'	; 
#	$srvcobjects_ref->{'worldfusion2'}{'ports'}{'udp'}{'2596'}++	; 
#	$ports_ref->{'udp'}{'2596'}{'name'} = 'worldfusion2'		; 
#	$srvcobjects_ref->{'worldfusion2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'worldfusion2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldfusion2'}{'port'}{'tcp'} = '2596'	; 
#	$srvcobjects_ref->{'worldfusion2'}{'ports'}{'tcp'}{'2596'}++	; 
#	$ports_ref->{'tcp'}{'2596'}{'name'} = 'worldfusion2'		; 
#	$srvcobjects_ref->{'ibm-abtact'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-abtact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-abtact'}{'port'}{'udp'} = '1586'	; 
#	$srvcobjects_ref->{'ibm-abtact'}{'ports'}{'udp'}{'1586'}++	; 
#	$ports_ref->{'udp'}{'1586'}{'name'} = 'ibm-abtact'		; 
#	$srvcobjects_ref->{'ibm-abtact'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-abtact'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-abtact'}{'port'}{'tcp'} = '1586'	; 
#	$srvcobjects_ref->{'ibm-abtact'}{'ports'}{'tcp'}{'1586'}++	; 
#	$ports_ref->{'tcp'}{'1586'}{'name'} = 'ibm-abtact'		; 
#	$srvcobjects_ref->{'a14'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'a14'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a14'}{'port'}{'udp'} = '3597'	; 
#	$srvcobjects_ref->{'a14'}{'ports'}{'udp'}{'3597'}++	; 
#	$ports_ref->{'udp'}{'3597'}{'name'} = 'a14'		; 
#	$srvcobjects_ref->{'a14'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'a14'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a14'}{'port'}{'tcp'} = '3597'	; 
#	$srvcobjects_ref->{'a14'}{'ports'}{'tcp'}{'3597'}++	; 
#	$ports_ref->{'tcp'}{'3597'}{'name'} = 'a14'		; 
#	$srvcobjects_ref->{'sso-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sso-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sso-control'}{'port'}{'udp'} = '2711'	; 
#	$srvcobjects_ref->{'sso-control'}{'ports'}{'udp'}{'2711'}++	; 
#	$ports_ref->{'udp'}{'2711'}{'name'} = 'sso-control'		; 
#	$srvcobjects_ref->{'sso-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sso-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sso-control'}{'port'}{'tcp'} = '2711'	; 
#	$srvcobjects_ref->{'sso-control'}{'ports'}{'tcp'}{'2711'}++	; 
#	$ports_ref->{'tcp'}{'2711'}{'name'} = 'sso-control'		; 
#	$srvcobjects_ref->{'netiq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netiq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq'}{'port'}{'udp'} = '2220'	; 
#	$srvcobjects_ref->{'netiq'}{'ports'}{'udp'}{'2220'}++	; 
#	$ports_ref->{'udp'}{'2220'}{'name'} = 'netiq'		; 
#	$srvcobjects_ref->{'netiq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netiq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq'}{'port'}{'tcp'} = '2220'	; 
#	$srvcobjects_ref->{'netiq'}{'ports'}{'tcp'}{'2220'}++	; 
#	$ports_ref->{'tcp'}{'2220'}{'name'} = 'netiq'		; 
#	$srvcobjects_ref->{'apc-5454'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-5454'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-5454'}{'port'}{'udp'} = '5454'	; 
#	$srvcobjects_ref->{'apc-5454'}{'ports'}{'udp'}{'5454'}++	; 
#	$ports_ref->{'udp'}{'5454'}{'name'} = 'apc-5454'		; 
#	$srvcobjects_ref->{'apc-5454'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-5454'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-5454'}{'port'}{'tcp'} = '5454'	; 
#	$srvcobjects_ref->{'apc-5454'}{'ports'}{'tcp'}{'5454'}++	; 
#	$ports_ref->{'tcp'}{'5454'}{'name'} = 'apc-5454'		; 
#	$srvcobjects_ref->{'dts'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dts'}{'port'}{'udp'} = '2594'	; 
#	$srvcobjects_ref->{'dts'}{'ports'}{'udp'}{'2594'}++	; 
#	$ports_ref->{'udp'}{'2594'}{'name'} = 'dts'		; 
#	$srvcobjects_ref->{'dts'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dts'}{'port'}{'tcp'} = '2594'	; 
#	$srvcobjects_ref->{'dts'}{'ports'}{'tcp'}{'2594'}++	; 
#	$ports_ref->{'tcp'}{'2594'}{'name'} = 'dts'		; 
#	$srvcobjects_ref->{'user-manager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'user-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'user-manager'}{'port'}{'udp'} = '3272'	; 
#	$srvcobjects_ref->{'user-manager'}{'ports'}{'udp'}{'3272'}++	; 
#	$ports_ref->{'udp'}{'3272'}{'name'} = 'user-manager'		; 
#	$srvcobjects_ref->{'user-manager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'user-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'user-manager'}{'port'}{'tcp'} = '3272'	; 
#	$srvcobjects_ref->{'user-manager'}{'ports'}{'tcp'}{'3272'}++	; 
#	$ports_ref->{'tcp'}{'3272'}{'name'} = 'user-manager'		; 
#	$srvcobjects_ref->{'mmcc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mmcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mmcc'}{'port'}{'udp'} = '5050'	; 
#	$srvcobjects_ref->{'mmcc'}{'ports'}{'udp'}{'5050'}++	; 
#	$ports_ref->{'udp'}{'5050'}{'name'} = 'mmcc'		; 
#	$srvcobjects_ref->{'mmcc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mmcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mmcc'}{'port'}{'tcp'} = '5050'	; 
#	$srvcobjects_ref->{'mmcc'}{'ports'}{'tcp'}{'5050'}++	; 
#	$ports_ref->{'tcp'}{'5050'}{'name'} = 'mmcc'		; 
#	$srvcobjects_ref->{'gsi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsi'}{'port'}{'udp'} = '1850'	; 
#	$srvcobjects_ref->{'gsi'}{'ports'}{'udp'}{'1850'}++	; 
#	$ports_ref->{'udp'}{'1850'}{'name'} = 'gsi'		; 
#	$srvcobjects_ref->{'gsi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gsi'}{'port'}{'tcp'} = '1850'	; 
#	$srvcobjects_ref->{'gsi'}{'ports'}{'tcp'}{'1850'}++	; 
#	$ports_ref->{'tcp'}{'1850'}{'name'} = 'gsi'		; 
#	$srvcobjects_ref->{'intelsync'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intelsync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intelsync'}{'port'}{'udp'} = '3692'	; 
#	$srvcobjects_ref->{'intelsync'}{'ports'}{'udp'}{'3692'}++	; 
#	$ports_ref->{'udp'}{'3692'}{'name'} = 'intelsync'		; 
#	$srvcobjects_ref->{'intelsync'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intelsync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intelsync'}{'port'}{'tcp'} = '3692'	; 
#	$srvcobjects_ref->{'intelsync'}{'ports'}{'tcp'}{'3692'}++	; 
#	$ports_ref->{'tcp'}{'3692'}{'name'} = 'intelsync'		; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'port'}{'udp'} = '2654'	; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'ports'}{'udp'}{'2654'}++	; 
#	$ports_ref->{'udp'}{'2654'}{'name'} = 'corel_vncadmin'		; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'port'}{'tcp'} = '2654'	; 
#	$srvcobjects_ref->{'corel_vncadmin'}{'ports'}{'tcp'}{'2654'}++	; 
#	$ports_ref->{'tcp'}{'2654'}{'name'} = 'corel_vncadmin'		; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'port'}{'udp'} = '2389'	; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'ports'}{'udp'}{'2389'}++	; 
#	$ports_ref->{'udp'}{'2389'}{'name'} = 'ovsessionmgr'		; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'port'}{'tcp'} = '2389'	; 
#	$srvcobjects_ref->{'ovsessionmgr'}{'ports'}{'tcp'}{'2389'}++	; 
#	$ports_ref->{'tcp'}{'2389'}{'name'} = 'ovsessionmgr'		; 
#	$srvcobjects_ref->{'filex-lport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filex-lport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filex-lport'}{'port'}{'udp'} = '1887'	; 
#	$srvcobjects_ref->{'filex-lport'}{'ports'}{'udp'}{'1887'}++	; 
#	$ports_ref->{'udp'}{'1887'}{'name'} = 'filex-lport'		; 
#	$srvcobjects_ref->{'filex-lport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filex-lport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filex-lport'}{'port'}{'tcp'} = '1887'	; 
#	$srvcobjects_ref->{'filex-lport'}{'ports'}{'tcp'}{'1887'}++	; 
#	$ports_ref->{'tcp'}{'1887'}{'name'} = 'filex-lport'		; 
#	$srvcobjects_ref->{'sitaraserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sitaraserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sitaraserver'}{'port'}{'udp'} = '2629'	; 
#	$srvcobjects_ref->{'sitaraserver'}{'ports'}{'udp'}{'2629'}++	; 
#	$ports_ref->{'udp'}{'2629'}{'name'} = 'sitaraserver'		; 
#	$srvcobjects_ref->{'sitaraserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sitaraserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sitaraserver'}{'port'}{'tcp'} = '2629'	; 
#	$srvcobjects_ref->{'sitaraserver'}{'ports'}{'tcp'}{'2629'}++	; 
#	$ports_ref->{'tcp'}{'2629'}{'name'} = 'sitaraserver'		; 
#	$srvcobjects_ref->{'synel-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'synel-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synel-data'}{'port'}{'udp'} = '3734'	; 
#	$srvcobjects_ref->{'synel-data'}{'ports'}{'udp'}{'3734'}++	; 
#	$ports_ref->{'udp'}{'3734'}{'name'} = 'synel-data'		; 
#	$srvcobjects_ref->{'synel-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'synel-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'synel-data'}{'port'}{'tcp'} = '3734'	; 
#	$srvcobjects_ref->{'synel-data'}{'ports'}{'tcp'}{'3734'}++	; 
#	$ports_ref->{'tcp'}{'3734'}{'name'} = 'synel-data'		; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'port'}{'udp'} = '7979'	; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'ports'}{'udp'}{'7979'}++	; 
#	$ports_ref->{'udp'}{'7979'}{'name'} = 'micromuse-ncps'		; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'port'}{'tcp'} = '7979'	; 
#	$srvcobjects_ref->{'micromuse-ncps'}{'ports'}{'tcp'}{'7979'}++	; 
#	$ports_ref->{'tcp'}{'7979'}{'name'} = 'micromuse-ncps'		; 
#	$srvcobjects_ref->{'emcsymapiport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emcsymapiport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emcsymapiport'}{'port'}{'udp'} = '2707'	; 
#	$srvcobjects_ref->{'emcsymapiport'}{'ports'}{'udp'}{'2707'}++	; 
#	$ports_ref->{'udp'}{'2707'}{'name'} = 'emcsymapiport'		; 
#	$srvcobjects_ref->{'emcsymapiport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emcsymapiport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emcsymapiport'}{'port'}{'tcp'} = '2707'	; 
#	$srvcobjects_ref->{'emcsymapiport'}{'ports'}{'tcp'}{'2707'}++	; 
#	$ports_ref->{'tcp'}{'2707'}{'name'} = 'emcsymapiport'		; 
#	$srvcobjects_ref->{'watilapp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'watilapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watilapp'}{'port'}{'udp'} = '1269'	; 
#	$srvcobjects_ref->{'watilapp'}{'ports'}{'udp'}{'1269'}++	; 
#	$ports_ref->{'udp'}{'1269'}{'name'} = 'watilapp'		; 
#	$srvcobjects_ref->{'watilapp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'watilapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watilapp'}{'port'}{'tcp'} = '1269'	; 
#	$srvcobjects_ref->{'watilapp'}{'ports'}{'tcp'}{'1269'}++	; 
#	$ports_ref->{'tcp'}{'1269'}{'name'} = 'watilapp'		; 
#	$srvcobjects_ref->{'sesi-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sesi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sesi-lm'}{'port'}{'udp'} = '1714'	; 
#	$srvcobjects_ref->{'sesi-lm'}{'ports'}{'udp'}{'1714'}++	; 
#	$ports_ref->{'udp'}{'1714'}{'name'} = 'sesi-lm'		; 
#	$srvcobjects_ref->{'sesi-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sesi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sesi-lm'}{'port'}{'tcp'} = '1714'	; 
#	$srvcobjects_ref->{'sesi-lm'}{'ports'}{'tcp'}{'1714'}++	; 
#	$ports_ref->{'tcp'}{'1714'}{'name'} = 'sesi-lm'		; 
#	$srvcobjects_ref->{'biap-mp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'biap-mp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'biap-mp'}{'port'}{'udp'} = '1962'	; 
#	$srvcobjects_ref->{'biap-mp'}{'ports'}{'udp'}{'1962'}++	; 
#	$ports_ref->{'udp'}{'1962'}{'name'} = 'biap-mp'		; 
#	$srvcobjects_ref->{'biap-mp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'biap-mp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'biap-mp'}{'port'}{'tcp'} = '1962'	; 
#	$srvcobjects_ref->{'biap-mp'}{'ports'}{'tcp'}{'1962'}++	; 
#	$ports_ref->{'tcp'}{'1962'}{'name'} = 'biap-mp'		; 
#	$srvcobjects_ref->{'eforward'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eforward'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eforward'}{'port'}{'udp'} = '2181'	; 
#	$srvcobjects_ref->{'eforward'}{'ports'}{'udp'}{'2181'}++	; 
#	$ports_ref->{'udp'}{'2181'}{'name'} = 'eforward'		; 
#	$srvcobjects_ref->{'eforward'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eforward'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eforward'}{'port'}{'tcp'} = '2181'	; 
#	$srvcobjects_ref->{'eforward'}{'ports'}{'tcp'}{'2181'}++	; 
#	$ports_ref->{'tcp'}{'2181'}{'name'} = 'eforward'		; 
#	$srvcobjects_ref->{'sql-net'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sql-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sql-net'}{'port'}{'udp'} = '150'	; 
#	$srvcobjects_ref->{'sql-net'}{'ports'}{'udp'}{'150'}++	; 
#	$ports_ref->{'udp'}{'150'}{'name'} = 'sql-net'		; 
#	$srvcobjects_ref->{'sql-net'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sql-net'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sql-net'}{'port'}{'tcp'} = '150'	; 
#	$srvcobjects_ref->{'sql-net'}{'ports'}{'tcp'}{'150'}++	; 
#	$ports_ref->{'tcp'}{'150'}{'name'} = 'sql-net'		; 
#	$srvcobjects_ref->{'dicom-iscl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dicom-iscl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dicom-iscl'}{'port'}{'udp'} = '2761'	; 
#	$srvcobjects_ref->{'dicom-iscl'}{'ports'}{'udp'}{'2761'}++	; 
#	$ports_ref->{'udp'}{'2761'}{'name'} = 'dicom-iscl'		; 
#	$srvcobjects_ref->{'dicom-iscl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dicom-iscl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dicom-iscl'}{'port'}{'tcp'} = '2761'	; 
#	$srvcobjects_ref->{'dicom-iscl'}{'ports'}{'tcp'}{'2761'}++	; 
#	$ports_ref->{'tcp'}{'2761'}{'name'} = 'dicom-iscl'		; 
#	$srvcobjects_ref->{'dlsrap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dlsrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlsrap'}{'port'}{'udp'} = '1973'	; 
#	$srvcobjects_ref->{'dlsrap'}{'ports'}{'udp'}{'1973'}++	; 
#	$ports_ref->{'udp'}{'1973'}{'name'} = 'dlsrap'		; 
#	$srvcobjects_ref->{'dlsrap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dlsrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlsrap'}{'port'}{'tcp'} = '1973'	; 
#	$srvcobjects_ref->{'dlsrap'}{'ports'}{'tcp'}{'1973'}++	; 
#	$ports_ref->{'tcp'}{'1973'}{'name'} = 'dlsrap'		; 
#	$srvcobjects_ref->{'ent-engine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ent-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ent-engine'}{'port'}{'udp'} = '3665'	; 
#	$srvcobjects_ref->{'ent-engine'}{'ports'}{'udp'}{'3665'}++	; 
#	$ports_ref->{'udp'}{'3665'}{'name'} = 'ent-engine'		; 
#	$srvcobjects_ref->{'ent-engine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ent-engine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ent-engine'}{'port'}{'tcp'} = '3665'	; 
#	$srvcobjects_ref->{'ent-engine'}{'ports'}{'tcp'}{'3665'}++	; 
#	$ports_ref->{'tcp'}{'3665'}{'name'} = 'ent-engine'		; 
#	$srvcobjects_ref->{'galileo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'galileo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'galileo'}{'port'}{'udp'} = '3519'	; 
#	$srvcobjects_ref->{'galileo'}{'ports'}{'udp'}{'3519'}++	; 
#	$ports_ref->{'udp'}{'3519'}{'name'} = 'galileo'		; 
#	$srvcobjects_ref->{'pammrpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pammrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pammrpc'}{'port'}{'udp'} = '1633'	; 
#	$srvcobjects_ref->{'pammrpc'}{'ports'}{'udp'}{'1633'}++	; 
#	$ports_ref->{'udp'}{'1633'}{'name'} = 'pammrpc'		; 
#	$srvcobjects_ref->{'pammrpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pammrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pammrpc'}{'port'}{'tcp'} = '1633'	; 
#	$srvcobjects_ref->{'pammrpc'}{'ports'}{'tcp'}{'1633'}++	; 
#	$ports_ref->{'tcp'}{'1633'}{'name'} = 'pammrpc'		; 
#	$srvcobjects_ref->{'csi-lfap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csi-lfap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csi-lfap'}{'port'}{'udp'} = '3145'	; 
#	$srvcobjects_ref->{'csi-lfap'}{'ports'}{'udp'}{'3145'}++	; 
#	$ports_ref->{'udp'}{'3145'}{'name'} = 'csi-lfap'		; 
#	$srvcobjects_ref->{'csi-lfap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csi-lfap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csi-lfap'}{'port'}{'tcp'} = '3145'	; 
#	$srvcobjects_ref->{'csi-lfap'}{'ports'}{'tcp'}{'3145'}++	; 
#	$ports_ref->{'tcp'}{'3145'}{'name'} = 'csi-lfap'		; 
#	$srvcobjects_ref->{'cimtrak'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cimtrak'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cimtrak'}{'port'}{'udp'} = '3749'	; 
#	$srvcobjects_ref->{'cimtrak'}{'ports'}{'udp'}{'3749'}++	; 
#	$ports_ref->{'udp'}{'3749'}{'name'} = 'cimtrak'		; 
#	$srvcobjects_ref->{'cimtrak'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cimtrak'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cimtrak'}{'port'}{'tcp'} = '3749'	; 
#	$srvcobjects_ref->{'cimtrak'}{'ports'}{'tcp'}{'3749'}++	; 
#	$ports_ref->{'tcp'}{'3749'}{'name'} = 'cimtrak'		; 
#	$srvcobjects_ref->{'cesdinv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cesdinv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cesdinv'}{'port'}{'udp'} = '2856'	; 
#	$srvcobjects_ref->{'cesdinv'}{'ports'}{'udp'}{'2856'}++	; 
#	$ports_ref->{'udp'}{'2856'}{'name'} = 'cesdinv'		; 
#	$srvcobjects_ref->{'cesdinv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cesdinv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cesdinv'}{'port'}{'tcp'} = '2856'	; 
#	$srvcobjects_ref->{'cesdinv'}{'ports'}{'tcp'}{'2856'}++	; 
#	$ports_ref->{'tcp'}{'2856'}{'name'} = 'cesdinv'		; 
#	$srvcobjects_ref->{'sunclustermgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sunclustermgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunclustermgr'}{'port'}{'udp'} = '1097'	; 
#	$srvcobjects_ref->{'sunclustermgr'}{'ports'}{'udp'}{'1097'}++	; 
#	$ports_ref->{'udp'}{'1097'}{'name'} = 'sunclustermgr'		; 
#	$srvcobjects_ref->{'sunclustermgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sunclustermgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sunclustermgr'}{'port'}{'tcp'} = '1097'	; 
#	$srvcobjects_ref->{'sunclustermgr'}{'ports'}{'tcp'}{'1097'}++	; 
#	$ports_ref->{'tcp'}{'1097'}{'name'} = 'sunclustermgr'		; 
#	$srvcobjects_ref->{'twsdss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'twsdss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'twsdss'}{'port'}{'udp'} = '3012'	; 
#	$srvcobjects_ref->{'twsdss'}{'ports'}{'udp'}{'3012'}++	; 
#	$ports_ref->{'udp'}{'3012'}{'name'} = 'twsdss'		; 
#	$srvcobjects_ref->{'twsdss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'twsdss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'twsdss'}{'port'}{'tcp'} = '3012'	; 
#	$srvcobjects_ref->{'twsdss'}{'ports'}{'tcp'}{'3012'}++	; 
#	$ports_ref->{'tcp'}{'3012'}{'name'} = 'twsdss'		; 
#	$srvcobjects_ref->{'raven2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'raven2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven2'}{'port'}{'udp'} = '2714'	; 
#	$srvcobjects_ref->{'raven2'}{'ports'}{'udp'}{'2714'}++	; 
#	$ports_ref->{'udp'}{'2714'}{'name'} = 'raven2'		; 
#	$srvcobjects_ref->{'raven2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'raven2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'raven2'}{'port'}{'tcp'} = '2714'	; 
#	$srvcobjects_ref->{'raven2'}{'ports'}{'tcp'}{'2714'}++	; 
#	$ports_ref->{'tcp'}{'2714'}{'name'} = 'raven2'		; 
#	$srvcobjects_ref->{'tn-tl-w2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tn-tl-w2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-w2'}{'port'}{'udp'} = '474'	; 
#	$srvcobjects_ref->{'tn-tl-w2'}{'ports'}{'udp'}{'474'}++	; 
#	$ports_ref->{'udp'}{'474'}{'name'} = 'tn-tl-w2'		; 
#	$srvcobjects_ref->{'3Com-nsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3Com-nsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3Com-nsd'}{'port'}{'udp'} = '1742'	; 
#	$srvcobjects_ref->{'3Com-nsd'}{'ports'}{'udp'}{'1742'}++	; 
#	$ports_ref->{'udp'}{'1742'}{'name'} = '3Com-nsd'		; 
#	$srvcobjects_ref->{'3Com-nsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3Com-nsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3Com-nsd'}{'port'}{'tcp'} = '1742'	; 
#	$srvcobjects_ref->{'3Com-nsd'}{'ports'}{'tcp'}{'1742'}++	; 
#	$ports_ref->{'tcp'}{'1742'}{'name'} = '3Com-nsd'		; 
#	$srvcobjects_ref->{'influence'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'influence'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'influence'}{'port'}{'udp'} = '3345'	; 
#	$srvcobjects_ref->{'influence'}{'ports'}{'udp'}{'3345'}++	; 
#	$ports_ref->{'udp'}{'3345'}{'name'} = 'influence'		; 
#	$srvcobjects_ref->{'influence'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'influence'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'influence'}{'port'}{'tcp'} = '3345'	; 
#	$srvcobjects_ref->{'influence'}{'ports'}{'tcp'}{'3345'}++	; 
#	$ports_ref->{'tcp'}{'3345'}{'name'} = 'influence'		; 
#	$srvcobjects_ref->{'nmmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmmp'}{'port'}{'udp'} = '3649'	; 
#	$srvcobjects_ref->{'nmmp'}{'ports'}{'udp'}{'3649'}++	; 
#	$ports_ref->{'udp'}{'3649'}{'name'} = 'nmmp'		; 
#	$srvcobjects_ref->{'nmmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmmp'}{'port'}{'tcp'} = '3649'	; 
#	$srvcobjects_ref->{'nmmp'}{'ports'}{'tcp'}{'3649'}++	; 
#	$ports_ref->{'tcp'}{'3649'}{'name'} = 'nmmp'		; 
#	$srvcobjects_ref->{'dca'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dca'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dca'}{'port'}{'udp'} = '1456'	; 
#	$srvcobjects_ref->{'dca'}{'ports'}{'udp'}{'1456'}++	; 
#	$ports_ref->{'udp'}{'1456'}{'name'} = 'dca'		; 
#	$srvcobjects_ref->{'dca'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dca'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dca'}{'port'}{'tcp'} = '1456'	; 
#	$srvcobjects_ref->{'dca'}{'ports'}{'tcp'}{'1456'}++	; 
#	$ports_ref->{'tcp'}{'1456'}{'name'} = 'dca'		; 
#	$srvcobjects_ref->{'sysopt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sysopt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysopt'}{'port'}{'udp'} = '3281'	; 
#	$srvcobjects_ref->{'sysopt'}{'ports'}{'udp'}{'3281'}++	; 
#	$ports_ref->{'udp'}{'3281'}{'name'} = 'sysopt'		; 
#	$srvcobjects_ref->{'sysopt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sysopt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sysopt'}{'port'}{'tcp'} = '3281'	; 
#	$srvcobjects_ref->{'sysopt'}{'ports'}{'tcp'}{'3281'}++	; 
#	$ports_ref->{'tcp'}{'3281'}{'name'} = 'sysopt'		; 
#	$srvcobjects_ref->{'ipcserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipcserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcserver'}{'port'}{'udp'} = '600'	; 
#	$srvcobjects_ref->{'ipcserver'}{'ports'}{'udp'}{'600'}++	; 
#	$ports_ref->{'udp'}{'600'}{'name'} = 'ipcserver'		; 
#	$srvcobjects_ref->{'ipcserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipcserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipcserver'}{'port'}{'tcp'} = '600'	; 
#	$srvcobjects_ref->{'ipcserver'}{'ports'}{'tcp'}{'600'}++	; 
#	$ports_ref->{'tcp'}{'600'}{'name'} = 'ipcserver'		; 
#	$srvcobjects_ref->{'tivoconnect'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tivoconnect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tivoconnect'}{'port'}{'udp'} = '2190'	; 
#	$srvcobjects_ref->{'tivoconnect'}{'ports'}{'udp'}{'2190'}++	; 
#	$ports_ref->{'udp'}{'2190'}{'name'} = 'tivoconnect'		; 
#	$srvcobjects_ref->{'tivoconnect'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tivoconnect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tivoconnect'}{'port'}{'tcp'} = '2190'	; 
#	$srvcobjects_ref->{'tivoconnect'}{'ports'}{'tcp'}{'2190'}++	; 
#	$ports_ref->{'tcp'}{'2190'}{'name'} = 'tivoconnect'		; 
#	$srvcobjects_ref->{'precise-vip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'precise-vip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'precise-vip'}{'port'}{'udp'} = '2924'	; 
#	$srvcobjects_ref->{'precise-vip'}{'ports'}{'udp'}{'2924'}++	; 
#	$ports_ref->{'udp'}{'2924'}{'name'} = 'precise-vip'		; 
#	$srvcobjects_ref->{'precise-vip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'precise-vip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'precise-vip'}{'port'}{'tcp'} = '2924'	; 
#	$srvcobjects_ref->{'precise-vip'}{'ports'}{'tcp'}{'2924'}++	; 
#	$ports_ref->{'tcp'}{'2924'}{'name'} = 'precise-vip'		; 
#	$srvcobjects_ref->{'hp-status'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-status'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-status'}{'port'}{'udp'} = '5226'	; 
#	$srvcobjects_ref->{'hp-status'}{'ports'}{'udp'}{'5226'}++	; 
#	$ports_ref->{'udp'}{'5226'}{'name'} = 'hp-status'		; 
#	$srvcobjects_ref->{'hp-status'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-status'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-status'}{'port'}{'tcp'} = '5226'	; 
#	$srvcobjects_ref->{'hp-status'}{'ports'}{'tcp'}{'5226'}++	; 
#	$ports_ref->{'tcp'}{'5226'}{'name'} = 'hp-status'		; 
#	$srvcobjects_ref->{'dwr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dwr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwr'}{'port'}{'udp'} = '644'	; 
#	$srvcobjects_ref->{'dwr'}{'ports'}{'udp'}{'644'}++	; 
#	$ports_ref->{'udp'}{'644'}{'name'} = 'dwr'		; 
#	$srvcobjects_ref->{'dwr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dwr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwr'}{'port'}{'tcp'} = '644'	; 
#	$srvcobjects_ref->{'dwr'}{'ports'}{'tcp'}{'644'}++	; 
#	$ports_ref->{'tcp'}{'644'}{'name'} = 'dwr'		; 
#	$srvcobjects_ref->{'jmb-cds2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmb-cds2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmb-cds2'}{'port'}{'udp'} = '8901'	; 
#	$srvcobjects_ref->{'jmb-cds2'}{'ports'}{'udp'}{'8901'}++	; 
#	$ports_ref->{'udp'}{'8901'}{'name'} = 'jmb-cds2'		; 
#	$srvcobjects_ref->{'jmb-cds2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmb-cds2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmb-cds2'}{'port'}{'tcp'} = '8901'	; 
#	$srvcobjects_ref->{'jmb-cds2'}{'ports'}{'tcp'}{'8901'}++	; 
#	$ports_ref->{'tcp'}{'8901'}{'name'} = 'jmb-cds2'		; 
#	$srvcobjects_ref->{'afs3-prserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-prserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-prserver'}{'port'}{'udp'} = '7002'	; 
#	$srvcobjects_ref->{'afs3-prserver'}{'ports'}{'udp'}{'7002'}++	; 
#	$ports_ref->{'udp'}{'7002'}{'name'} = 'afs3-prserver'		; 
#	$srvcobjects_ref->{'afs3-prserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-prserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-prserver'}{'port'}{'tcp'} = '7002'	; 
#	$srvcobjects_ref->{'afs3-prserver'}{'ports'}{'tcp'}{'7002'}++	; 
#	$ports_ref->{'tcp'}{'7002'}{'name'} = 'afs3-prserver'		; 
#	$srvcobjects_ref->{'cuillamartin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cuillamartin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cuillamartin'}{'port'}{'udp'} = '1356'	; 
#	$srvcobjects_ref->{'cuillamartin'}{'ports'}{'udp'}{'1356'}++	; 
#	$ports_ref->{'udp'}{'1356'}{'name'} = 'cuillamartin'		; 
#	$srvcobjects_ref->{'cuillamartin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cuillamartin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cuillamartin'}{'port'}{'tcp'} = '1356'	; 
#	$srvcobjects_ref->{'cuillamartin'}{'ports'}{'tcp'}{'1356'}++	; 
#	$ports_ref->{'tcp'}{'1356'}{'name'} = 'cuillamartin'		; 
#	$srvcobjects_ref->{'slingshot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slingshot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slingshot'}{'port'}{'udp'} = '1705'	; 
#	$srvcobjects_ref->{'slingshot'}{'ports'}{'udp'}{'1705'}++	; 
#	$ports_ref->{'udp'}{'1705'}{'name'} = 'slingshot'		; 
#	$srvcobjects_ref->{'slingshot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slingshot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slingshot'}{'port'}{'tcp'} = '1705'	; 
#	$srvcobjects_ref->{'slingshot'}{'ports'}{'tcp'}{'1705'}++	; 
#	$ports_ref->{'tcp'}{'1705'}{'name'} = 'slingshot'		; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'port'}{'udp'} = '1213'	; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'ports'}{'udp'}{'1213'}++	; 
#	$ports_ref->{'udp'}{'1213'}{'name'} = 'mpc-lifenet'		; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'port'}{'tcp'} = '1213'	; 
#	$srvcobjects_ref->{'mpc-lifenet'}{'ports'}{'tcp'}{'1213'}++	; 
#	$ports_ref->{'tcp'}{'1213'}{'name'} = 'mpc-lifenet'		; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'port'}{'udp'} = '2246'	; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'ports'}{'udp'}{'2246'}++	; 
#	$ports_ref->{'udp'}{'2246'}{'name'} = 'pc-mta-addrmap'		; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'port'}{'tcp'} = '2246'	; 
#	$srvcobjects_ref->{'pc-mta-addrmap'}{'ports'}{'tcp'}{'2246'}++	; 
#	$ports_ref->{'tcp'}{'2246'}{'name'} = 'pc-mta-addrmap'		; 
#	$srvcobjects_ref->{'cisco-sys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cisco-sys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-sys'}{'port'}{'udp'} = '132'	; 
#	$srvcobjects_ref->{'cisco-sys'}{'ports'}{'udp'}{'132'}++	; 
#	$ports_ref->{'udp'}{'132'}{'name'} = 'cisco-sys'		; 
#	$srvcobjects_ref->{'cisco-sys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cisco-sys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cisco-sys'}{'port'}{'tcp'} = '132'	; 
#	$srvcobjects_ref->{'cisco-sys'}{'ports'}{'tcp'}{'132'}++	; 
#	$ports_ref->{'tcp'}{'132'}{'name'} = 'cisco-sys'		; 
#	$srvcobjects_ref->{'etftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'etftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etftp'}{'port'}{'udp'} = '1818'	; 
#	$srvcobjects_ref->{'etftp'}{'ports'}{'udp'}{'1818'}++	; 
#	$ports_ref->{'udp'}{'1818'}{'name'} = 'etftp'		; 
#	$srvcobjects_ref->{'etftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'etftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etftp'}{'port'}{'tcp'} = '1818'	; 
#	$srvcobjects_ref->{'etftp'}{'ports'}{'tcp'}{'1818'}++	; 
#	$ports_ref->{'tcp'}{'1818'}{'name'} = 'etftp'		; 
#	$srvcobjects_ref->{'pago-services1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pago-services1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pago-services1'}{'port'}{'udp'} = '30001'	; 
#	$srvcobjects_ref->{'pago-services1'}{'ports'}{'udp'}{'30001'}++	; 
#	$ports_ref->{'udp'}{'30001'}{'name'} = 'pago-services1'		; 
#	$srvcobjects_ref->{'pago-services1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pago-services1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pago-services1'}{'port'}{'tcp'} = '30001'	; 
#	$srvcobjects_ref->{'pago-services1'}{'ports'}{'tcp'}{'30001'}++	; 
#	$ports_ref->{'tcp'}{'30001'}{'name'} = 'pago-services1'		; 
#	$srvcobjects_ref->{'monkeycom'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'monkeycom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'monkeycom'}{'port'}{'udp'} = '9898'	; 
#	$srvcobjects_ref->{'monkeycom'}{'ports'}{'udp'}{'9898'}++	; 
#	$ports_ref->{'udp'}{'9898'}{'name'} = 'monkeycom'		; 
#	$srvcobjects_ref->{'monkeycom'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'monkeycom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'monkeycom'}{'port'}{'tcp'} = '9898'	; 
#	$srvcobjects_ref->{'monkeycom'}{'ports'}{'tcp'}{'9898'}++	; 
#	$ports_ref->{'tcp'}{'9898'}{'name'} = 'monkeycom'		; 
#	$srvcobjects_ref->{'privoxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'privoxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privoxy'}{'port'}{'udp'} = '8118'	; 
#	$srvcobjects_ref->{'privoxy'}{'ports'}{'udp'}{'8118'}++	; 
#	$ports_ref->{'udp'}{'8118'}{'name'} = 'privoxy'		; 
#	$srvcobjects_ref->{'privoxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'privoxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privoxy'}{'port'}{'tcp'} = '8118'	; 
#	$srvcobjects_ref->{'privoxy'}{'ports'}{'tcp'}{'8118'}++	; 
#	$ports_ref->{'tcp'}{'8118'}{'name'} = 'privoxy'		; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'port'}{'udp'} = '1579'	; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'ports'}{'udp'}{'1579'}++	; 
#	$ports_ref->{'udp'}{'1579'}{'name'} = 'ioc-sea-lm'		; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'port'}{'tcp'} = '1579'	; 
#	$srvcobjects_ref->{'ioc-sea-lm'}{'ports'}{'tcp'}{'1579'}++	; 
#	$ports_ref->{'tcp'}{'1579'}{'name'} = 'ioc-sea-lm'		; 
#	$srvcobjects_ref->{'connect-client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'connect-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connect-client'}{'port'}{'udp'} = '3441'	; 
#	$srvcobjects_ref->{'connect-client'}{'ports'}{'udp'}{'3441'}++	; 
#	$ports_ref->{'udp'}{'3441'}{'name'} = 'connect-client'		; 
#	$srvcobjects_ref->{'connect-client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'connect-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connect-client'}{'port'}{'tcp'} = '3441'	; 
#	$srvcobjects_ref->{'connect-client'}{'ports'}{'tcp'}{'3441'}++	; 
#	$ports_ref->{'tcp'}{'3441'}{'name'} = 'connect-client'		; 
#	$srvcobjects_ref->{'opus-services'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opus-services'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opus-services'}{'port'}{'udp'} = '3718'	; 
#	$srvcobjects_ref->{'opus-services'}{'ports'}{'udp'}{'3718'}++	; 
#	$ports_ref->{'udp'}{'3718'}{'name'} = 'opus-services'		; 
#	$srvcobjects_ref->{'opus-services'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opus-services'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opus-services'}{'port'}{'tcp'} = '3718'	; 
#	$srvcobjects_ref->{'opus-services'}{'ports'}{'tcp'}{'3718'}++	; 
#	$ports_ref->{'tcp'}{'3718'}{'name'} = 'opus-services'		; 
#	$srvcobjects_ref->{'groove-dpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'groove-dpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'groove-dpp'}{'port'}{'udp'} = '1211'	; 
#	$srvcobjects_ref->{'groove-dpp'}{'ports'}{'udp'}{'1211'}++	; 
#	$ports_ref->{'udp'}{'1211'}{'name'} = 'groove-dpp'		; 
#	$srvcobjects_ref->{'groove-dpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'groove-dpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'groove-dpp'}{'port'}{'tcp'} = '1211'	; 
#	$srvcobjects_ref->{'groove-dpp'}{'ports'}{'tcp'}{'1211'}++	; 
#	$ports_ref->{'tcp'}{'1211'}{'name'} = 'groove-dpp'		; 
#	$srvcobjects_ref->{'rdlap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rdlap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdlap'}{'port'}{'udp'} = '2321'	; 
#	$srvcobjects_ref->{'rdlap'}{'ports'}{'udp'}{'2321'}++	; 
#	$ports_ref->{'udp'}{'2321'}{'name'} = 'rdlap'		; 
#	$srvcobjects_ref->{'rdlap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rdlap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdlap'}{'port'}{'tcp'} = '2321'	; 
#	$srvcobjects_ref->{'rdlap'}{'ports'}{'tcp'}{'2321'}++	; 
#	$ports_ref->{'tcp'}{'2321'}{'name'} = 'rdlap'		; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'port'}{'udp'} = '2548'	; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'ports'}{'udp'}{'2548'}++	; 
#	$ports_ref->{'udp'}{'2548'}{'name'} = 'vytalvaultpipe'		; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'port'}{'tcp'} = '2548'	; 
#	$srvcobjects_ref->{'vytalvaultpipe'}{'ports'}{'tcp'}{'2548'}++	; 
#	$ports_ref->{'tcp'}{'2548'}{'name'} = 'vytalvaultpipe'		; 
#	$srvcobjects_ref->{'startron'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'startron'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'startron'}{'port'}{'udp'} = '1057'	; 
#	$srvcobjects_ref->{'startron'}{'ports'}{'udp'}{'1057'}++	; 
#	$ports_ref->{'udp'}{'1057'}{'name'} = 'startron'		; 
#	$srvcobjects_ref->{'startron'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'startron'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'startron'}{'port'}{'tcp'} = '1057'	; 
#	$srvcobjects_ref->{'startron'}{'ports'}{'tcp'}{'1057'}++	; 
#	$ports_ref->{'tcp'}{'1057'}{'name'} = 'startron'		; 
#	$srvcobjects_ref->{'vrtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtp'}{'port'}{'udp'} = '2255'	; 
#	$srvcobjects_ref->{'vrtp'}{'ports'}{'udp'}{'2255'}++	; 
#	$ports_ref->{'udp'}{'2255'}{'name'} = 'vrtp'		; 
#	$srvcobjects_ref->{'vrtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtp'}{'port'}{'tcp'} = '2255'	; 
#	$srvcobjects_ref->{'vrtp'}{'ports'}{'tcp'}{'2255'}++	; 
#	$ports_ref->{'tcp'}{'2255'}{'name'} = 'vrtp'		; 
#	$srvcobjects_ref->{'nucleus-sand'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nucleus-sand'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nucleus-sand'}{'port'}{'udp'} = '1201'	; 
#	$srvcobjects_ref->{'nucleus-sand'}{'ports'}{'udp'}{'1201'}++	; 
#	$ports_ref->{'udp'}{'1201'}{'name'} = 'nucleus-sand'		; 
#	$srvcobjects_ref->{'nucleus-sand'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nucleus-sand'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nucleus-sand'}{'port'}{'tcp'} = '1201'	; 
#	$srvcobjects_ref->{'nucleus-sand'}{'ports'}{'tcp'}{'1201'}++	; 
#	$ports_ref->{'tcp'}{'1201'}{'name'} = 'nucleus-sand'		; 
#	$srvcobjects_ref->{'donnyworld'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'donnyworld'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'donnyworld'}{'port'}{'udp'} = '1821'	; 
#	$srvcobjects_ref->{'donnyworld'}{'ports'}{'udp'}{'1821'}++	; 
#	$ports_ref->{'udp'}{'1821'}{'name'} = 'donnyworld'		; 
#	$srvcobjects_ref->{'donnyworld'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'donnyworld'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'donnyworld'}{'port'}{'tcp'} = '1821'	; 
#	$srvcobjects_ref->{'donnyworld'}{'ports'}{'tcp'}{'1821'}++	; 
#	$ports_ref->{'tcp'}{'1821'}{'name'} = 'donnyworld'		; 
#	$srvcobjects_ref->{'pipe_server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pipe_server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pipe_server'}{'port'}{'udp'} = '2010'	; 
#	$srvcobjects_ref->{'pipe_server'}{'ports'}{'udp'}{'2010'}++	; 
#	$ports_ref->{'udp'}{'2010'}{'name'} = 'pipe_server'		; 
#	$srvcobjects_ref->{'dirgis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dirgis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dirgis'}{'port'}{'udp'} = '2496'	; 
#	$srvcobjects_ref->{'dirgis'}{'ports'}{'udp'}{'2496'}++	; 
#	$ports_ref->{'udp'}{'2496'}{'name'} = 'dirgis'		; 
#	$srvcobjects_ref->{'dirgis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dirgis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dirgis'}{'port'}{'tcp'} = '2496'	; 
#	$srvcobjects_ref->{'dirgis'}{'ports'}{'tcp'}{'2496'}++	; 
#	$ports_ref->{'tcp'}{'2496'}{'name'} = 'dirgis'		; 
#	$srvcobjects_ref->{'eppc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eppc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eppc'}{'port'}{'udp'} = '3031'	; 
#	$srvcobjects_ref->{'eppc'}{'ports'}{'udp'}{'3031'}++	; 
#	$ports_ref->{'udp'}{'3031'}{'name'} = 'eppc'		; 
#	$srvcobjects_ref->{'eppc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eppc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eppc'}{'port'}{'tcp'} = '3031'	; 
#	$srvcobjects_ref->{'eppc'}{'ports'}{'tcp'}{'3031'}++	; 
#	$ports_ref->{'tcp'}{'3031'}{'name'} = 'eppc'		; 
#	$srvcobjects_ref->{'cqg-netlan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cqg-netlan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cqg-netlan'}{'port'}{'udp'} = '2823'	; 
#	$srvcobjects_ref->{'cqg-netlan'}{'ports'}{'udp'}{'2823'}++	; 
#	$ports_ref->{'udp'}{'2823'}{'name'} = 'cqg-netlan'		; 
#	$srvcobjects_ref->{'cqg-netlan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cqg-netlan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cqg-netlan'}{'port'}{'tcp'} = '2823'	; 
#	$srvcobjects_ref->{'cqg-netlan'}{'ports'}{'tcp'}{'2823'}++	; 
#	$ports_ref->{'tcp'}{'2823'}{'name'} = 'cqg-netlan'		; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'port'}{'udp'} = '1885'	; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'ports'}{'udp'}{'1885'}++	; 
#	$ports_ref->{'udp'}{'1885'}{'name'} = 'vrtstrapserver'		; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'port'}{'tcp'} = '1885'	; 
#	$srvcobjects_ref->{'vrtstrapserver'}{'ports'}{'tcp'}{'1885'}++	; 
#	$ports_ref->{'tcp'}{'1885'}{'name'} = 'vrtstrapserver'		; 
#	$srvcobjects_ref->{'aairnet-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aairnet-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aairnet-1'}{'port'}{'udp'} = '3618'	; 
#	$srvcobjects_ref->{'aairnet-1'}{'ports'}{'udp'}{'3618'}++	; 
#	$ports_ref->{'udp'}{'3618'}{'name'} = 'aairnet-1'		; 
#	$srvcobjects_ref->{'aairnet-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aairnet-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aairnet-1'}{'port'}{'tcp'} = '3618'	; 
#	$srvcobjects_ref->{'aairnet-1'}{'ports'}{'tcp'}{'3618'}++	; 
#	$ports_ref->{'tcp'}{'3618'}{'name'} = 'aairnet-1'		; 
#	$srvcobjects_ref->{'santak-ups'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'santak-ups'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'santak-ups'}{'port'}{'udp'} = '3038'	; 
#	$srvcobjects_ref->{'santak-ups'}{'ports'}{'udp'}{'3038'}++	; 
#	$ports_ref->{'udp'}{'3038'}{'name'} = 'santak-ups'		; 
#	$srvcobjects_ref->{'santak-ups'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'santak-ups'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'santak-ups'}{'port'}{'tcp'} = '3038'	; 
#	$srvcobjects_ref->{'santak-ups'}{'ports'}{'tcp'}{'3038'}++	; 
#	$ports_ref->{'tcp'}{'3038'}{'name'} = 'santak-ups'		; 
#	$srvcobjects_ref->{'ezmeeting'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ezmeeting'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezmeeting'}{'port'}{'udp'} = '26261'	; 
#	$srvcobjects_ref->{'ezmeeting'}{'ports'}{'udp'}{'26261'}++	; 
#	$ports_ref->{'udp'}{'26261'}{'name'} = 'ezmeeting'		; 
#	$srvcobjects_ref->{'ezmeeting'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ezmeeting'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ezmeeting'}{'port'}{'tcp'} = '26261'	; 
#	$srvcobjects_ref->{'ezmeeting'}{'ports'}{'tcp'}{'26261'}++	; 
#	$ports_ref->{'tcp'}{'26261'}{'name'} = 'ezmeeting'		; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'port'}{'udp'} = '2391'	; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'ports'}{'udp'}{'2391'}++	; 
#	$ports_ref->{'udp'}{'2391'}{'name'} = '3com-net-mgmt'		; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'port'}{'tcp'} = '2391'	; 
#	$srvcobjects_ref->{'3com-net-mgmt'}{'ports'}{'tcp'}{'2391'}++	; 
#	$ports_ref->{'tcp'}{'2391'}{'name'} = '3com-net-mgmt'		; 
#	$srvcobjects_ref->{'vopied'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vopied'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vopied'}{'port'}{'udp'} = '13783'	; 
#	$srvcobjects_ref->{'vopied'}{'ports'}{'udp'}{'13783'}++	; 
#	$ports_ref->{'udp'}{'13783'}{'name'} = 'vopied'		; 
#	$srvcobjects_ref->{'vopied'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vopied'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vopied'}{'port'}{'tcp'} = '13783'	; 
#	$srvcobjects_ref->{'vopied'}{'ports'}{'tcp'}{'13783'}++	; 
#	$ports_ref->{'tcp'}{'13783'}{'name'} = 'vopied'		; 
#	$srvcobjects_ref->{'tdp-suite'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tdp-suite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tdp-suite'}{'port'}{'udp'} = '1814'	; 
#	$srvcobjects_ref->{'tdp-suite'}{'ports'}{'udp'}{'1814'}++	; 
#	$ports_ref->{'udp'}{'1814'}{'name'} = 'tdp-suite'		; 
#	$srvcobjects_ref->{'tdp-suite'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tdp-suite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tdp-suite'}{'port'}{'tcp'} = '1814'	; 
#	$srvcobjects_ref->{'tdp-suite'}{'ports'}{'tcp'}{'1814'}++	; 
#	$ports_ref->{'tcp'}{'1814'}{'name'} = 'tdp-suite'		; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'port'}{'udp'} = '2891'	; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'ports'}{'udp'}{'2891'}++	; 
#	$ports_ref->{'udp'}{'2891'}{'name'} = 'cinegrfx-elmd'		; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'port'}{'tcp'} = '2891'	; 
#	$srvcobjects_ref->{'cinegrfx-elmd'}{'ports'}{'tcp'}{'2891'}++	; 
#	$ports_ref->{'tcp'}{'2891'}{'name'} = 'cinegrfx-elmd'		; 
#	$srvcobjects_ref->{'rmlnk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmlnk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmlnk'}{'port'}{'udp'} = '2818'	; 
#	$srvcobjects_ref->{'rmlnk'}{'ports'}{'udp'}{'2818'}++	; 
#	$ports_ref->{'udp'}{'2818'}{'name'} = 'rmlnk'		; 
#	$srvcobjects_ref->{'rmlnk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmlnk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmlnk'}{'port'}{'tcp'} = '2818'	; 
#	$srvcobjects_ref->{'rmlnk'}{'ports'}{'tcp'}{'2818'}++	; 
#	$ports_ref->{'tcp'}{'2818'}{'name'} = 'rmlnk'		; 
#	$srvcobjects_ref->{'florence'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'florence'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'florence'}{'port'}{'udp'} = '1228'	; 
#	$srvcobjects_ref->{'florence'}{'ports'}{'udp'}{'1228'}++	; 
#	$ports_ref->{'udp'}{'1228'}{'name'} = 'florence'		; 
#	$srvcobjects_ref->{'florence'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'florence'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'florence'}{'port'}{'tcp'} = '1228'	; 
#	$srvcobjects_ref->{'florence'}{'ports'}{'tcp'}{'1228'}++	; 
#	$ports_ref->{'tcp'}{'1228'}{'name'} = 'florence'		; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'port'}{'udp'} = '829'	; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'ports'}{'udp'}{'829'}++	; 
#	$ports_ref->{'udp'}{'829'}{'name'} = 'pkix-3-ca-ra'		; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'port'}{'tcp'} = '829'	; 
#	$srvcobjects_ref->{'pkix-3-ca-ra'}{'ports'}{'tcp'}{'829'}++	; 
#	$ports_ref->{'tcp'}{'829'}{'name'} = 'pkix-3-ca-ra'		; 
#	$srvcobjects_ref->{'intel_rci'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intel_rci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intel_rci'}{'port'}{'udp'} = '24386'	; 
#	$srvcobjects_ref->{'intel_rci'}{'ports'}{'udp'}{'24386'}++	; 
#	$ports_ref->{'udp'}{'24386'}{'name'} = 'intel_rci'		; 
#	$srvcobjects_ref->{'intel_rci'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intel_rci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intel_rci'}{'port'}{'tcp'} = '24386'	; 
#	$srvcobjects_ref->{'intel_rci'}{'ports'}{'tcp'}{'24386'}++	; 
#	$ports_ref->{'tcp'}{'24386'}{'name'} = 'intel_rci'		; 
#	$srvcobjects_ref->{'genisar-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'genisar-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genisar-port'}{'port'}{'udp'} = '3475'	; 
#	$srvcobjects_ref->{'genisar-port'}{'ports'}{'udp'}{'3475'}++	; 
#	$ports_ref->{'udp'}{'3475'}{'name'} = 'genisar-port'		; 
#	$srvcobjects_ref->{'genisar-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'genisar-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genisar-port'}{'port'}{'tcp'} = '3475'	; 
#	$srvcobjects_ref->{'genisar-port'}{'ports'}{'tcp'}{'3475'}++	; 
#	$ports_ref->{'tcp'}{'3475'}{'name'} = 'genisar-port'		; 
#	$srvcobjects_ref->{'anynetgateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anynetgateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anynetgateway'}{'port'}{'udp'} = '1491'	; 
#	$srvcobjects_ref->{'anynetgateway'}{'ports'}{'udp'}{'1491'}++	; 
#	$ports_ref->{'udp'}{'1491'}{'name'} = 'anynetgateway'		; 
#	$srvcobjects_ref->{'anynetgateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anynetgateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anynetgateway'}{'port'}{'tcp'} = '1491'	; 
#	$srvcobjects_ref->{'anynetgateway'}{'ports'}{'tcp'}{'1491'}++	; 
#	$ports_ref->{'tcp'}{'1491'}{'name'} = 'anynetgateway'		; 
#	$srvcobjects_ref->{'poweronnud'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'poweronnud'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'poweronnud'}{'port'}{'udp'} = '3168'	; 
#	$srvcobjects_ref->{'poweronnud'}{'ports'}{'udp'}{'3168'}++	; 
#	$ports_ref->{'udp'}{'3168'}{'name'} = 'poweronnud'		; 
#	$srvcobjects_ref->{'poweronnud'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'poweronnud'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'poweronnud'}{'port'}{'tcp'} = '3168'	; 
#	$srvcobjects_ref->{'poweronnud'}{'ports'}{'tcp'}{'3168'}++	; 
#	$ports_ref->{'tcp'}{'3168'}{'name'} = 'poweronnud'		; 
#	$srvcobjects_ref->{'dbreporter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbreporter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbreporter'}{'port'}{'udp'} = '1379'	; 
#	$srvcobjects_ref->{'dbreporter'}{'ports'}{'udp'}{'1379'}++	; 
#	$ports_ref->{'udp'}{'1379'}{'name'} = 'dbreporter'		; 
#	$srvcobjects_ref->{'dbreporter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbreporter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbreporter'}{'port'}{'tcp'} = '1379'	; 
#	$srvcobjects_ref->{'dbreporter'}{'ports'}{'tcp'}{'1379'}++	; 
#	$ports_ref->{'tcp'}{'1379'}{'name'} = 'dbreporter'		; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'port'}{'udp'} = '1861'	; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'ports'}{'udp'}{'1861'}++	; 
#	$ports_ref->{'udp'}{'1861'}{'name'} = 'lecroy-vicp'		; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'port'}{'tcp'} = '1861'	; 
#	$srvcobjects_ref->{'lecroy-vicp'}{'ports'}{'tcp'}{'1861'}++	; 
#	$ports_ref->{'tcp'}{'1861'}{'name'} = 'lecroy-vicp'		; 
#	$srvcobjects_ref->{'moshebeeri'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'moshebeeri'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'moshebeeri'}{'port'}{'udp'} = '2627'	; 
#	$srvcobjects_ref->{'moshebeeri'}{'ports'}{'udp'}{'2627'}++	; 
#	$ports_ref->{'udp'}{'2627'}{'name'} = 'moshebeeri'		; 
#	$srvcobjects_ref->{'moshebeeri'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'moshebeeri'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'moshebeeri'}{'port'}{'tcp'} = '2627'	; 
#	$srvcobjects_ref->{'moshebeeri'}{'ports'}{'tcp'}{'2627'}++	; 
#	$ports_ref->{'tcp'}{'2627'}{'name'} = 'moshebeeri'		; 
#	$srvcobjects_ref->{'dsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsp'}{'port'}{'udp'} = '33'	; 
#	$srvcobjects_ref->{'dsp'}{'ports'}{'udp'}{'33'}++	; 
#	$ports_ref->{'udp'}{'33'}{'name'} = 'dsp'		; 
#	$srvcobjects_ref->{'dsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsp'}{'port'}{'tcp'} = '33'	; 
#	$srvcobjects_ref->{'dsp'}{'ports'}{'tcp'}{'33'}++	; 
#	$ports_ref->{'tcp'}{'33'}{'name'} = 'dsp'		; 
#	$srvcobjects_ref->{'mctet-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mctet-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctet-gateway'}{'port'}{'udp'} = '3116'	; 
#	$srvcobjects_ref->{'mctet-gateway'}{'ports'}{'udp'}{'3116'}++	; 
#	$ports_ref->{'udp'}{'3116'}{'name'} = 'mctet-gateway'		; 
#	$srvcobjects_ref->{'mctet-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mctet-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctet-gateway'}{'port'}{'tcp'} = '3116'	; 
#	$srvcobjects_ref->{'mctet-gateway'}{'ports'}{'tcp'}{'3116'}++	; 
#	$ports_ref->{'tcp'}{'3116'}{'name'} = 'mctet-gateway'		; 
#	$srvcobjects_ref->{'pirp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pirp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pirp'}{'port'}{'udp'} = '553'	; 
#	$srvcobjects_ref->{'pirp'}{'ports'}{'udp'}{'553'}++	; 
#	$ports_ref->{'udp'}{'553'}{'name'} = 'pirp'		; 
#	$srvcobjects_ref->{'pirp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pirp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pirp'}{'port'}{'tcp'} = '553'	; 
#	$srvcobjects_ref->{'pirp'}{'ports'}{'tcp'}{'553'}++	; 
#	$ports_ref->{'tcp'}{'553'}{'name'} = 'pirp'		; 
#	$srvcobjects_ref->{'asipregistry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asipregistry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asipregistry'}{'port'}{'udp'} = '687'	; 
#	$srvcobjects_ref->{'asipregistry'}{'ports'}{'udp'}{'687'}++	; 
#	$ports_ref->{'udp'}{'687'}{'name'} = 'asipregistry'		; 
#	$srvcobjects_ref->{'asipregistry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asipregistry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asipregistry'}{'port'}{'tcp'} = '687'	; 
#	$srvcobjects_ref->{'asipregistry'}{'ports'}{'tcp'}{'687'}++	; 
#	$ports_ref->{'tcp'}{'687'}{'name'} = 'asipregistry'		; 
#	$srvcobjects_ref->{'exosee'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'exosee'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exosee'}{'port'}{'udp'} = '1027'	; 
#	$srvcobjects_ref->{'exosee'}{'ports'}{'udp'}{'1027'}++	; 
#	$ports_ref->{'udp'}{'1027'}{'name'} = 'exosee'		; 
#	$srvcobjects_ref->{'exosee'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'exosee'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'exosee'}{'port'}{'tcp'} = '1027'	; 
#	$srvcobjects_ref->{'exosee'}{'ports'}{'tcp'}{'1027'}++	; 
#	$ports_ref->{'tcp'}{'1027'}{'name'} = 'exosee'		; 
#	$srvcobjects_ref->{'adobeserver-3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adobeserver-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-3'}{'port'}{'udp'} = '3703'	; 
#	$srvcobjects_ref->{'adobeserver-3'}{'ports'}{'udp'}{'3703'}++	; 
#	$ports_ref->{'udp'}{'3703'}{'name'} = 'adobeserver-3'		; 
#	$srvcobjects_ref->{'adobeserver-3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adobeserver-3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-3'}{'port'}{'tcp'} = '3703'	; 
#	$srvcobjects_ref->{'adobeserver-3'}{'ports'}{'tcp'}{'3703'}++	; 
#	$ports_ref->{'tcp'}{'3703'}{'name'} = 'adobeserver-3'		; 
#	$srvcobjects_ref->{'lotusnote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lotusnote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lotusnote'}{'port'}{'udp'} = '1352'	; 
#	$srvcobjects_ref->{'lotusnote'}{'ports'}{'udp'}{'1352'}++	; 
#	$ports_ref->{'udp'}{'1352'}{'name'} = 'lotusnote'		; 
#	$srvcobjects_ref->{'lotusnote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lotusnote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lotusnote'}{'port'}{'tcp'} = '1352'	; 
#	$srvcobjects_ref->{'lotusnote'}{'ports'}{'tcp'}{'1352'}++	; 
#	$ports_ref->{'tcp'}{'1352'}{'name'} = 'lotusnote'		; 
#	$srvcobjects_ref->{'megardsvr-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'megardsvr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'megardsvr-port'}{'port'}{'udp'} = '3571'	; 
#	$srvcobjects_ref->{'megardsvr-port'}{'ports'}{'udp'}{'3571'}++	; 
#	$ports_ref->{'udp'}{'3571'}{'name'} = 'megardsvr-port'		; 
#	$srvcobjects_ref->{'megardsvr-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'megardsvr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'megardsvr-port'}{'port'}{'tcp'} = '3571'	; 
#	$srvcobjects_ref->{'megardsvr-port'}{'ports'}{'tcp'}{'3571'}++	; 
#	$ports_ref->{'tcp'}{'3571'}{'name'} = 'megardsvr-port'		; 
#	$srvcobjects_ref->{'nimcontroller'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nimcontroller'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimcontroller'}{'port'}{'udp'} = '48000'	; 
#	$srvcobjects_ref->{'nimcontroller'}{'ports'}{'udp'}{'48000'}++	; 
#	$ports_ref->{'udp'}{'48000'}{'name'} = 'nimcontroller'		; 
#	$srvcobjects_ref->{'nimcontroller'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nimcontroller'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nimcontroller'}{'port'}{'tcp'} = '48000'	; 
#	$srvcobjects_ref->{'nimcontroller'}{'ports'}{'tcp'}{'48000'}++	; 
#	$ports_ref->{'tcp'}{'48000'}{'name'} = 'nimcontroller'		; 
#	$srvcobjects_ref->{'kopek-httphead'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kopek-httphead'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kopek-httphead'}{'port'}{'udp'} = '27504'	; 
#	$srvcobjects_ref->{'kopek-httphead'}{'ports'}{'udp'}{'27504'}++	; 
#	$ports_ref->{'udp'}{'27504'}{'name'} = 'kopek-httphead'		; 
#	$srvcobjects_ref->{'kopek-httphead'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kopek-httphead'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kopek-httphead'}{'port'}{'tcp'} = '27504'	; 
#	$srvcobjects_ref->{'kopek-httphead'}{'ports'}{'tcp'}{'27504'}++	; 
#	$ports_ref->{'tcp'}{'27504'}{'name'} = 'kopek-httphead'		; 
#	$srvcobjects_ref->{'s8-client-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'s8-client-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'s8-client-port'}{'port'}{'udp'} = '3153'	; 
#	$srvcobjects_ref->{'s8-client-port'}{'ports'}{'udp'}{'3153'}++	; 
#	$ports_ref->{'udp'}{'3153'}{'name'} = 's8-client-port'		; 
#	$srvcobjects_ref->{'s8-client-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'s8-client-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'s8-client-port'}{'port'}{'tcp'} = '3153'	; 
#	$srvcobjects_ref->{'s8-client-port'}{'ports'}{'tcp'}{'3153'}++	; 
#	$ports_ref->{'tcp'}{'3153'}{'name'} = 's8-client-port'		; 
#	$srvcobjects_ref->{'sgcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sgcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgcp'}{'port'}{'udp'} = '440'	; 
#	$srvcobjects_ref->{'sgcp'}{'ports'}{'udp'}{'440'}++	; 
#	$ports_ref->{'udp'}{'440'}{'name'} = 'sgcp'		; 
#	$srvcobjects_ref->{'sgcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sgcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sgcp'}{'port'}{'tcp'} = '440'	; 
#	$srvcobjects_ref->{'sgcp'}{'ports'}{'tcp'}{'440'}++	; 
#	$ports_ref->{'tcp'}{'440'}{'name'} = 'sgcp'		; 
#	$srvcobjects_ref->{'paragent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'paragent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paragent'}{'port'}{'udp'} = '9022'	; 
#	$srvcobjects_ref->{'paragent'}{'ports'}{'udp'}{'9022'}++	; 
#	$ports_ref->{'udp'}{'9022'}{'name'} = 'paragent'		; 
#	$srvcobjects_ref->{'paragent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'paragent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'paragent'}{'port'}{'tcp'} = '9022'	; 
#	$srvcobjects_ref->{'paragent'}{'ports'}{'tcp'}{'9022'}++	; 
#	$ports_ref->{'tcp'}{'9022'}{'name'} = 'paragent'		; 
#	$srvcobjects_ref->{'radius'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radius'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radius'}{'port'}{'udp'} = '1812'	; 
#	$srvcobjects_ref->{'radius'}{'ports'}{'udp'}{'1812'}++	; 
#	$ports_ref->{'udp'}{'1812'}{'name'} = 'radius'		; 
#	$srvcobjects_ref->{'radius'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radius'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radius'}{'port'}{'tcp'} = '1812'	; 
#	$srvcobjects_ref->{'radius'}{'ports'}{'tcp'}{'1812'}++	; 
#	$ports_ref->{'tcp'}{'1812'}{'name'} = 'radius'		; 
#	$srvcobjects_ref->{'clvm-cfg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'clvm-cfg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clvm-cfg'}{'port'}{'udp'} = '1476'	; 
#	$srvcobjects_ref->{'clvm-cfg'}{'ports'}{'udp'}{'1476'}++	; 
#	$ports_ref->{'udp'}{'1476'}{'name'} = 'clvm-cfg'		; 
#	$srvcobjects_ref->{'clvm-cfg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'clvm-cfg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clvm-cfg'}{'port'}{'tcp'} = '1476'	; 
#	$srvcobjects_ref->{'clvm-cfg'}{'ports'}{'tcp'}{'1476'}++	; 
#	$ports_ref->{'tcp'}{'1476'}{'name'} = 'clvm-cfg'		; 
#	$srvcobjects_ref->{'vvr-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vvr-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vvr-data'}{'port'}{'udp'} = '8199'	; 
#	$srvcobjects_ref->{'vvr-data'}{'ports'}{'udp'}{'8199'}++	; 
#	$ports_ref->{'udp'}{'8199'}{'name'} = 'vvr-data'		; 
#	$srvcobjects_ref->{'vvr-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vvr-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vvr-data'}{'port'}{'tcp'} = '8199'	; 
#	$srvcobjects_ref->{'vvr-data'}{'ports'}{'tcp'}{'8199'}++	; 
#	$ports_ref->{'tcp'}{'8199'}{'name'} = 'vvr-data'		; 
#	$srvcobjects_ref->{'imgames'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imgames'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imgames'}{'port'}{'udp'} = '1077'	; 
#	$srvcobjects_ref->{'imgames'}{'ports'}{'udp'}{'1077'}++	; 
#	$ports_ref->{'udp'}{'1077'}{'name'} = 'imgames'		; 
#	$srvcobjects_ref->{'imgames'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imgames'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imgames'}{'port'}{'tcp'} = '1077'	; 
#	$srvcobjects_ref->{'imgames'}{'ports'}{'tcp'}{'1077'}++	; 
#	$ports_ref->{'tcp'}{'1077'}{'name'} = 'imgames'		; 
#	$srvcobjects_ref->{'firemonrcc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'firemonrcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firemonrcc'}{'port'}{'udp'} = '3192'	; 
#	$srvcobjects_ref->{'firemonrcc'}{'ports'}{'udp'}{'3192'}++	; 
#	$ports_ref->{'udp'}{'3192'}{'name'} = 'firemonrcc'		; 
#	$srvcobjects_ref->{'firemonrcc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'firemonrcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'firemonrcc'}{'port'}{'tcp'} = '3192'	; 
#	$srvcobjects_ref->{'firemonrcc'}{'ports'}{'tcp'}{'3192'}++	; 
#	$ports_ref->{'tcp'}{'3192'}{'name'} = 'firemonrcc'		; 
#	$srvcobjects_ref->{'swldy-sias'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swldy-sias'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swldy-sias'}{'port'}{'udp'} = '1250'	; 
#	$srvcobjects_ref->{'swldy-sias'}{'ports'}{'udp'}{'1250'}++	; 
#	$ports_ref->{'udp'}{'1250'}{'name'} = 'swldy-sias'		; 
#	$srvcobjects_ref->{'swldy-sias'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swldy-sias'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swldy-sias'}{'port'}{'tcp'} = '1250'	; 
#	$srvcobjects_ref->{'swldy-sias'}{'ports'}{'tcp'}{'1250'}++	; 
#	$ports_ref->{'tcp'}{'1250'}{'name'} = 'swldy-sias'		; 
#	$srvcobjects_ref->{'launchbird-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'launchbird-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'launchbird-lm'}{'port'}{'udp'} = '3739'	; 
#	$srvcobjects_ref->{'launchbird-lm'}{'ports'}{'udp'}{'3739'}++	; 
#	$ports_ref->{'udp'}{'3739'}{'name'} = 'launchbird-lm'		; 
#	$srvcobjects_ref->{'launchbird-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'launchbird-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'launchbird-lm'}{'port'}{'tcp'} = '3739'	; 
#	$srvcobjects_ref->{'launchbird-lm'}{'ports'}{'tcp'}{'3739'}++	; 
#	$ports_ref->{'tcp'}{'3739'}{'name'} = 'launchbird-lm'		; 
#	$srvcobjects_ref->{'evb-elm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'evb-elm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'evb-elm'}{'port'}{'udp'} = '1504'	; 
#	$srvcobjects_ref->{'evb-elm'}{'ports'}{'udp'}{'1504'}++	; 
#	$ports_ref->{'udp'}{'1504'}{'name'} = 'evb-elm'		; 
#	$srvcobjects_ref->{'evb-elm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'evb-elm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'evb-elm'}{'port'}{'tcp'} = '1504'	; 
#	$srvcobjects_ref->{'evb-elm'}{'ports'}{'tcp'}{'1504'}++	; 
#	$ports_ref->{'tcp'}{'1504'}{'name'} = 'evb-elm'		; 
#	$srvcobjects_ref->{'imqtunnels'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imqtunnels'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imqtunnels'}{'port'}{'udp'} = '7674'	; 
#	$srvcobjects_ref->{'imqtunnels'}{'ports'}{'udp'}{'7674'}++	; 
#	$ports_ref->{'udp'}{'7674'}{'name'} = 'imqtunnels'		; 
#	$srvcobjects_ref->{'imqtunnels'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imqtunnels'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imqtunnels'}{'port'}{'tcp'} = '7674'	; 
#	$srvcobjects_ref->{'imqtunnels'}{'ports'}{'tcp'}{'7674'}++	; 
#	$ports_ref->{'tcp'}{'7674'}{'name'} = 'imqtunnels'		; 
#	$srvcobjects_ref->{'netport-id'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netport-id'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netport-id'}{'port'}{'udp'} = '3129'	; 
#	$srvcobjects_ref->{'netport-id'}{'ports'}{'udp'}{'3129'}++	; 
#	$ports_ref->{'udp'}{'3129'}{'name'} = 'netport-id'		; 
#	$srvcobjects_ref->{'netport-id'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netport-id'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netport-id'}{'port'}{'tcp'} = '3129'	; 
#	$srvcobjects_ref->{'netport-id'}{'ports'}{'tcp'}{'3129'}++	; 
#	$ports_ref->{'tcp'}{'3129'}{'name'} = 'netport-id'		; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'port'}{'udp'} = '7000'	; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'ports'}{'udp'}{'7000'}++	; 
#	$ports_ref->{'udp'}{'7000'}{'name'} = 'afs3-fileserver'		; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'port'}{'tcp'} = '7000'	; 
#	$srvcobjects_ref->{'afs3-fileserver'}{'ports'}{'tcp'}{'7000'}++	; 
#	$ports_ref->{'tcp'}{'7000'}{'name'} = 'afs3-fileserver'		; 
#	$srvcobjects_ref->{'qip-login'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qip-login'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-login'}{'port'}{'udp'} = '2366'	; 
#	$srvcobjects_ref->{'qip-login'}{'ports'}{'udp'}{'2366'}++	; 
#	$ports_ref->{'udp'}{'2366'}{'name'} = 'qip-login'		; 
#	$srvcobjects_ref->{'qip-login'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qip-login'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-login'}{'port'}{'tcp'} = '2366'	; 
#	$srvcobjects_ref->{'qip-login'}{'ports'}{'tcp'}{'2366'}++	; 
#	$ports_ref->{'tcp'}{'2366'}{'name'} = 'qip-login'		; 
#	$srvcobjects_ref->{'bdir_priv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bdir_priv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bdir_priv'}{'port'}{'udp'} = '6507'	; 
#	$srvcobjects_ref->{'bdir_priv'}{'ports'}{'udp'}{'6507'}++	; 
#	$ports_ref->{'udp'}{'6507'}{'name'} = 'bdir_priv'		; 
#	$srvcobjects_ref->{'bdir_priv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bdir_priv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bdir_priv'}{'port'}{'tcp'} = '6507'	; 
#	$srvcobjects_ref->{'bdir_priv'}{'ports'}{'tcp'}{'6507'}++	; 
#	$ports_ref->{'tcp'}{'6507'}{'name'} = 'bdir_priv'		; 
#	$srvcobjects_ref->{'codasrv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'codasrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codasrv'}{'port'}{'udp'} = '2432'	; 
#	$srvcobjects_ref->{'codasrv'}{'ports'}{'udp'}{'2432'}++	; 
#	$ports_ref->{'udp'}{'2432'}{'name'} = 'codasrv'		; 
#	$srvcobjects_ref->{'codasrv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'codasrv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codasrv'}{'port'}{'tcp'} = '2432'	; 
#	$srvcobjects_ref->{'codasrv'}{'ports'}{'tcp'}{'2432'}++	; 
#	$ports_ref->{'tcp'}{'2432'}{'name'} = 'codasrv'		; 
#	$srvcobjects_ref->{'winddx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'winddx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winddx'}{'port'}{'udp'} = '1727'	; 
#	$srvcobjects_ref->{'winddx'}{'ports'}{'udp'}{'1727'}++	; 
#	$ports_ref->{'udp'}{'1727'}{'name'} = 'winddx'		; 
#	$srvcobjects_ref->{'winddx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'winddx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winddx'}{'port'}{'tcp'} = '1727'	; 
#	$srvcobjects_ref->{'winddx'}{'ports'}{'tcp'}{'1727'}++	; 
#	$ports_ref->{'tcp'}{'1727'}{'name'} = 'winddx'		; 
#	$srvcobjects_ref->{'tributary'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tributary'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tributary'}{'port'}{'udp'} = '2580'	; 
#	$srvcobjects_ref->{'tributary'}{'ports'}{'udp'}{'2580'}++	; 
#	$ports_ref->{'udp'}{'2580'}{'name'} = 'tributary'		; 
#	$srvcobjects_ref->{'tributary'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tributary'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tributary'}{'port'}{'tcp'} = '2580'	; 
#	$srvcobjects_ref->{'tributary'}{'ports'}{'tcp'}{'2580'}++	; 
#	$ports_ref->{'tcp'}{'2580'}{'name'} = 'tributary'		; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'port'}{'udp'} = '1651'	; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'ports'}{'udp'}{'1651'}++	; 
#	$ports_ref->{'udp'}{'1651'}{'name'} = 'shiva_confsrvr'		; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'port'}{'tcp'} = '1651'	; 
#	$srvcobjects_ref->{'shiva_confsrvr'}{'ports'}{'tcp'}{'1651'}++	; 
#	$ports_ref->{'tcp'}{'1651'}{'name'} = 'shiva_confsrvr'		; 
#	$srvcobjects_ref->{'giop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'giop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'giop'}{'port'}{'udp'} = '2481'	; 
#	$srvcobjects_ref->{'giop'}{'ports'}{'udp'}{'2481'}++	; 
#	$ports_ref->{'udp'}{'2481'}{'name'} = 'giop'		; 
#	$srvcobjects_ref->{'giop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'giop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'giop'}{'port'}{'tcp'} = '2481'	; 
#	$srvcobjects_ref->{'giop'}{'ports'}{'tcp'}{'2481'}++	; 
#	$ports_ref->{'tcp'}{'2481'}{'name'} = 'giop'		; 
#	$srvcobjects_ref->{'trap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trap'}{'port'}{'udp'} = '4020'	; 
#	$srvcobjects_ref->{'trap'}{'ports'}{'udp'}{'4020'}++	; 
#	$ports_ref->{'udp'}{'4020'}{'name'} = 'trap'		; 
#	$srvcobjects_ref->{'trap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trap'}{'port'}{'tcp'} = '4020'	; 
#	$srvcobjects_ref->{'trap'}{'ports'}{'tcp'}{'4020'}++	; 
#	$ports_ref->{'tcp'}{'4020'}{'name'} = 'trap'		; 
#	$srvcobjects_ref->{'peerbook-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'peerbook-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'peerbook-port'}{'port'}{'udp'} = '3135'	; 
#	$srvcobjects_ref->{'peerbook-port'}{'ports'}{'udp'}{'3135'}++	; 
#	$ports_ref->{'udp'}{'3135'}{'name'} = 'peerbook-port'		; 
#	$srvcobjects_ref->{'peerbook-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'peerbook-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'peerbook-port'}{'port'}{'tcp'} = '3135'	; 
#	$srvcobjects_ref->{'peerbook-port'}{'ports'}{'tcp'}{'3135'}++	; 
#	$ports_ref->{'tcp'}{'3135'}{'name'} = 'peerbook-port'		; 
#	$srvcobjects_ref->{'belarc-http'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'belarc-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'belarc-http'}{'port'}{'udp'} = '2693'	; 
#	$srvcobjects_ref->{'belarc-http'}{'ports'}{'udp'}{'2693'}++	; 
#	$ports_ref->{'udp'}{'2693'}{'name'} = 'belarc-http'		; 
#	$srvcobjects_ref->{'belarc-http'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'belarc-http'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'belarc-http'}{'port'}{'tcp'} = '2693'	; 
#	$srvcobjects_ref->{'belarc-http'}{'ports'}{'tcp'}{'2693'}++	; 
#	$ports_ref->{'tcp'}{'2693'}{'name'} = 'belarc-http'		; 
#	$srvcobjects_ref->{'odsi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'odsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odsi'}{'port'}{'udp'} = '1308'	; 
#	$srvcobjects_ref->{'odsi'}{'ports'}{'udp'}{'1308'}++	; 
#	$ports_ref->{'udp'}{'1308'}{'name'} = 'odsi'		; 
#	$srvcobjects_ref->{'odsi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'odsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odsi'}{'port'}{'tcp'} = '1308'	; 
#	$srvcobjects_ref->{'odsi'}{'ports'}{'tcp'}{'1308'}++	; 
#	$ports_ref->{'tcp'}{'1308'}{'name'} = 'odsi'		; 
#	$srvcobjects_ref->{'wap-push'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-push'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-push'}{'port'}{'udp'} = '2948'	; 
#	$srvcobjects_ref->{'wap-push'}{'ports'}{'udp'}{'2948'}++	; 
#	$ports_ref->{'udp'}{'2948'}{'name'} = 'wap-push'		; 
#	$srvcobjects_ref->{'wap-push'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-push'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-push'}{'port'}{'tcp'} = '2948'	; 
#	$srvcobjects_ref->{'wap-push'}{'ports'}{'tcp'}{'2948'}++	; 
#	$ports_ref->{'tcp'}{'2948'}{'name'} = 'wap-push'		; 
#	$srvcobjects_ref->{'arcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arcp'}{'port'}{'udp'} = '7070'	; 
#	$srvcobjects_ref->{'arcp'}{'ports'}{'udp'}{'7070'}++	; 
#	$ports_ref->{'udp'}{'7070'}{'name'} = 'arcp'		; 
#	$srvcobjects_ref->{'arcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arcp'}{'port'}{'tcp'} = '7070'	; 
#	$srvcobjects_ref->{'arcp'}{'ports'}{'tcp'}{'7070'}++	; 
#	$ports_ref->{'tcp'}{'7070'}{'name'} = 'arcp'		; 
#	$srvcobjects_ref->{'array-manager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'array-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'array-manager'}{'port'}{'udp'} = '3726'	; 
#	$srvcobjects_ref->{'array-manager'}{'ports'}{'udp'}{'3726'}++	; 
#	$ports_ref->{'udp'}{'3726'}{'name'} = 'array-manager'		; 
#	$srvcobjects_ref->{'array-manager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'array-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'array-manager'}{'port'}{'tcp'} = '3726'	; 
#	$srvcobjects_ref->{'array-manager'}{'ports'}{'tcp'}{'3726'}++	; 
#	$ports_ref->{'tcp'}{'3726'}{'name'} = 'array-manager'		; 
#	$srvcobjects_ref->{'icon-discover'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icon-discover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icon-discover'}{'port'}{'udp'} = '2799'	; 
#	$srvcobjects_ref->{'icon-discover'}{'ports'}{'udp'}{'2799'}++	; 
#	$ports_ref->{'udp'}{'2799'}{'name'} = 'icon-discover'		; 
#	$srvcobjects_ref->{'icon-discover'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icon-discover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icon-discover'}{'port'}{'tcp'} = '2799'	; 
#	$srvcobjects_ref->{'icon-discover'}{'ports'}{'tcp'}{'2799'}++	; 
#	$ports_ref->{'tcp'}{'2799'}{'name'} = 'icon-discover'		; 
#	$srvcobjects_ref->{'h323gatedisc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h323gatedisc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323gatedisc'}{'port'}{'udp'} = '1718'	; 
#	$srvcobjects_ref->{'h323gatedisc'}{'ports'}{'udp'}{'1718'}++	; 
#	$ports_ref->{'udp'}{'1718'}{'name'} = 'h323gatedisc'		; 
#	$srvcobjects_ref->{'h323gatedisc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h323gatedisc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323gatedisc'}{'port'}{'tcp'} = '1718'	; 
#	$srvcobjects_ref->{'h323gatedisc'}{'ports'}{'tcp'}{'1718'}++	; 
#	$ports_ref->{'tcp'}{'1718'}{'name'} = 'h323gatedisc'		; 
#	$srvcobjects_ref->{'mpm-flags'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpm-flags'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpm-flags'}{'port'}{'udp'} = '44'	; 
#	$srvcobjects_ref->{'mpm-flags'}{'ports'}{'udp'}{'44'}++	; 
#	$ports_ref->{'udp'}{'44'}{'name'} = 'mpm-flags'		; 
#	$srvcobjects_ref->{'mpm-flags'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpm-flags'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpm-flags'}{'port'}{'tcp'} = '44'	; 
#	$srvcobjects_ref->{'mpm-flags'}{'ports'}{'tcp'}{'44'}++	; 
#	$ports_ref->{'tcp'}{'44'}{'name'} = 'mpm-flags'		; 
#	$srvcobjects_ref->{'cytel-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cytel-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cytel-lm'}{'port'}{'udp'} = '3297'	; 
#	$srvcobjects_ref->{'cytel-lm'}{'ports'}{'udp'}{'3297'}++	; 
#	$ports_ref->{'udp'}{'3297'}{'name'} = 'cytel-lm'		; 
#	$srvcobjects_ref->{'cytel-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cytel-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cytel-lm'}{'port'}{'tcp'} = '3297'	; 
#	$srvcobjects_ref->{'cytel-lm'}{'ports'}{'tcp'}{'3297'}++	; 
#	$ports_ref->{'tcp'}{'3297'}{'name'} = 'cytel-lm'		; 
#	$srvcobjects_ref->{'simba-cs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simba-cs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simba-cs'}{'port'}{'udp'} = '1543'	; 
#	$srvcobjects_ref->{'simba-cs'}{'ports'}{'udp'}{'1543'}++	; 
#	$ports_ref->{'udp'}{'1543'}{'name'} = 'simba-cs'		; 
#	$srvcobjects_ref->{'simba-cs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simba-cs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simba-cs'}{'port'}{'tcp'} = '1543'	; 
#	$srvcobjects_ref->{'simba-cs'}{'ports'}{'tcp'}{'1543'}++	; 
#	$ports_ref->{'tcp'}{'1543'}{'name'} = 'simba-cs'		; 
#	$srvcobjects_ref->{'winshadow'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'winshadow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winshadow'}{'port'}{'udp'} = '3261'	; 
#	$srvcobjects_ref->{'winshadow'}{'ports'}{'udp'}{'3261'}++	; 
#	$ports_ref->{'udp'}{'3261'}{'name'} = 'winshadow'		; 
#	$srvcobjects_ref->{'winshadow'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'winshadow'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winshadow'}{'port'}{'tcp'} = '3261'	; 
#	$srvcobjects_ref->{'winshadow'}{'ports'}{'tcp'}{'3261'}++	; 
#	$ports_ref->{'tcp'}{'3261'}{'name'} = 'winshadow'		; 
#	$srvcobjects_ref->{'esps-portal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esps-portal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esps-portal'}{'port'}{'udp'} = '2867'	; 
#	$srvcobjects_ref->{'esps-portal'}{'ports'}{'udp'}{'2867'}++	; 
#	$ports_ref->{'udp'}{'2867'}{'name'} = 'esps-portal'		; 
#	$srvcobjects_ref->{'esps-portal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esps-portal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esps-portal'}{'port'}{'tcp'} = '2867'	; 
#	$srvcobjects_ref->{'esps-portal'}{'ports'}{'tcp'}{'2867'}++	; 
#	$ports_ref->{'tcp'}{'2867'}{'name'} = 'esps-portal'		; 
#	$srvcobjects_ref->{'fg-fps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fg-fps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fg-fps'}{'port'}{'udp'} = '3293'	; 
#	$srvcobjects_ref->{'fg-fps'}{'ports'}{'udp'}{'3293'}++	; 
#	$ports_ref->{'udp'}{'3293'}{'name'} = 'fg-fps'		; 
#	$srvcobjects_ref->{'fg-fps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fg-fps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fg-fps'}{'port'}{'tcp'} = '3293'	; 
#	$srvcobjects_ref->{'fg-fps'}{'ports'}{'tcp'}{'3293'}++	; 
#	$ports_ref->{'tcp'}{'3293'}{'name'} = 'fg-fps'		; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'port'}{'udp'} = '502'	; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'ports'}{'udp'}{'502'}++	; 
#	$ports_ref->{'udp'}{'502'}{'name'} = 'asa-appl-proto'		; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'port'}{'tcp'} = '502'	; 
#	$srvcobjects_ref->{'asa-appl-proto'}{'ports'}{'tcp'}{'502'}++	; 
#	$ports_ref->{'tcp'}{'502'}{'name'} = 'asa-appl-proto'		; 
#	$srvcobjects_ref->{'epp-temp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'epp-temp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epp-temp'}{'port'}{'udp'} = '3121'	; 
#	$srvcobjects_ref->{'epp-temp'}{'ports'}{'udp'}{'3121'}++	; 
#	$ports_ref->{'udp'}{'3121'}{'name'} = 'epp-temp'		; 
#	$srvcobjects_ref->{'epp-temp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'epp-temp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epp-temp'}{'port'}{'tcp'} = '3121'	; 
#	$srvcobjects_ref->{'epp-temp'}{'ports'}{'tcp'}{'3121'}++	; 
#	$ports_ref->{'tcp'}{'3121'}{'name'} = 'epp-temp'		; 
#	$srvcobjects_ref->{'audionews'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'audionews'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audionews'}{'port'}{'udp'} = '114'	; 
#	$srvcobjects_ref->{'audionews'}{'ports'}{'udp'}{'114'}++	; 
#	$ports_ref->{'udp'}{'114'}{'name'} = 'audionews'		; 
#	$srvcobjects_ref->{'audionews'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'audionews'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audionews'}{'port'}{'tcp'} = '114'	; 
#	$srvcobjects_ref->{'audionews'}{'ports'}{'tcp'}{'114'}++	; 
#	$ports_ref->{'tcp'}{'114'}{'name'} = 'audionews'		; 
#	$srvcobjects_ref->{'va-pacbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'va-pacbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'va-pacbase'}{'port'}{'udp'} = '3676'	; 
#	$srvcobjects_ref->{'va-pacbase'}{'ports'}{'udp'}{'3676'}++	; 
#	$ports_ref->{'udp'}{'3676'}{'name'} = 'va-pacbase'		; 
#	$srvcobjects_ref->{'va-pacbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'va-pacbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'va-pacbase'}{'port'}{'tcp'} = '3676'	; 
#	$srvcobjects_ref->{'va-pacbase'}{'ports'}{'tcp'}{'3676'}++	; 
#	$ports_ref->{'tcp'}{'3676'}{'name'} = 'va-pacbase'		; 
#	$srvcobjects_ref->{'mciautoreg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mciautoreg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mciautoreg'}{'port'}{'udp'} = '1528'	; 
#	$srvcobjects_ref->{'mciautoreg'}{'ports'}{'udp'}{'1528'}++	; 
#	$ports_ref->{'udp'}{'1528'}{'name'} = 'mciautoreg'		; 
#	$srvcobjects_ref->{'mciautoreg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mciautoreg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mciautoreg'}{'port'}{'tcp'} = '1528'	; 
#	$srvcobjects_ref->{'mciautoreg'}{'ports'}{'tcp'}{'1528'}++	; 
#	$ports_ref->{'tcp'}{'1528'}{'name'} = 'mciautoreg'		; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'port'}{'udp'} = '1989'	; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'ports'}{'udp'}{'1989'}++	; 
#	$ports_ref->{'udp'}{'1989'}{'name'} = 'tr-rsrb-p3'		; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'port'}{'tcp'} = '1989'	; 
#	$srvcobjects_ref->{'tr-rsrb-p3'}{'ports'}{'tcp'}{'1989'}++	; 
#	$ports_ref->{'tcp'}{'1989'}{'name'} = 'tr-rsrb-p3'		; 
#	$srvcobjects_ref->{'sms-remctrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sms-remctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-remctrl'}{'port'}{'udp'} = '2704'	; 
#	$srvcobjects_ref->{'sms-remctrl'}{'ports'}{'udp'}{'2704'}++	; 
#	$ports_ref->{'udp'}{'2704'}{'name'} = 'sms-remctrl'		; 
#	$srvcobjects_ref->{'sms-remctrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sms-remctrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-remctrl'}{'port'}{'tcp'} = '2704'	; 
#	$srvcobjects_ref->{'sms-remctrl'}{'ports'}{'tcp'}{'2704'}++	; 
#	$ports_ref->{'tcp'}{'2704'}{'name'} = 'sms-remctrl'		; 
#	$srvcobjects_ref->{'mpidcagt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpidcagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpidcagt'}{'port'}{'udp'} = '9397'	; 
#	$srvcobjects_ref->{'mpidcagt'}{'ports'}{'udp'}{'9397'}++	; 
#	$ports_ref->{'udp'}{'9397'}{'name'} = 'mpidcagt'		; 
#	$srvcobjects_ref->{'mpidcagt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpidcagt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpidcagt'}{'port'}{'tcp'} = '9397'	; 
#	$srvcobjects_ref->{'mpidcagt'}{'ports'}{'tcp'}{'9397'}++	; 
#	$ports_ref->{'tcp'}{'9397'}{'name'} = 'mpidcagt'		; 
#	$srvcobjects_ref->{'sa-msg-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sa-msg-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sa-msg-port'}{'port'}{'udp'} = '1646'	; 
#	$srvcobjects_ref->{'sa-msg-port'}{'ports'}{'udp'}{'1646'}++	; 
#	$ports_ref->{'udp'}{'1646'}{'name'} = 'sa-msg-port'		; 
#	$srvcobjects_ref->{'sa-msg-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sa-msg-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sa-msg-port'}{'port'}{'tcp'} = '1646'	; 
#	$srvcobjects_ref->{'sa-msg-port'}{'ports'}{'tcp'}{'1646'}++	; 
#	$ports_ref->{'tcp'}{'1646'}{'name'} = 'sa-msg-port'		; 
#	$srvcobjects_ref->{'rebol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rebol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rebol'}{'port'}{'udp'} = '2997'	; 
#	$srvcobjects_ref->{'rebol'}{'ports'}{'udp'}{'2997'}++	; 
#	$ports_ref->{'udp'}{'2997'}{'name'} = 'rebol'		; 
#	$srvcobjects_ref->{'rebol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rebol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rebol'}{'port'}{'tcp'} = '2997'	; 
#	$srvcobjects_ref->{'rebol'}{'ports'}{'tcp'}{'2997'}++	; 
#	$ports_ref->{'tcp'}{'2997'}{'name'} = 'rebol'		; 
#	$srvcobjects_ref->{'simslink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simslink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simslink'}{'port'}{'udp'} = '2676'	; 
#	$srvcobjects_ref->{'simslink'}{'ports'}{'udp'}{'2676'}++	; 
#	$ports_ref->{'udp'}{'2676'}{'name'} = 'simslink'		; 
#	$srvcobjects_ref->{'simslink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simslink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simslink'}{'port'}{'tcp'} = '2676'	; 
#	$srvcobjects_ref->{'simslink'}{'ports'}{'tcp'}{'2676'}++	; 
#	$ports_ref->{'tcp'}{'2676'}{'name'} = 'simslink'		; 
#	$srvcobjects_ref->{'nmsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsp'}{'port'}{'udp'} = '1790'	; 
#	$srvcobjects_ref->{'nmsp'}{'ports'}{'udp'}{'1790'}++	; 
#	$ports_ref->{'udp'}{'1790'}{'name'} = 'nmsp'		; 
#	$srvcobjects_ref->{'nmsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nmsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsp'}{'port'}{'udp'} = '537'	; 
#	$srvcobjects_ref->{'nmsp'}{'ports'}{'udp'}{'537'}++	; 
#	$ports_ref->{'udp'}{'537'}{'name'} = 'nmsp'		; 
#	$srvcobjects_ref->{'nmsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsp'}{'port'}{'tcp'} = '1790'	; 
#	$srvcobjects_ref->{'nmsp'}{'ports'}{'tcp'}{'1790'}++	; 
#	$ports_ref->{'tcp'}{'1790'}{'name'} = 'nmsp'		; 
#	$srvcobjects_ref->{'nmsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nmsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nmsp'}{'port'}{'tcp'} = '537'	; 
#	$srvcobjects_ref->{'nmsp'}{'ports'}{'tcp'}{'537'}++	; 
#	$ports_ref->{'tcp'}{'537'}{'name'} = 'nmsp'		; 
#	$srvcobjects_ref->{'ste-smsc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ste-smsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ste-smsc'}{'port'}{'udp'} = '1836'	; 
#	$srvcobjects_ref->{'ste-smsc'}{'ports'}{'udp'}{'1836'}++	; 
#	$ports_ref->{'udp'}{'1836'}{'name'} = 'ste-smsc'		; 
#	$srvcobjects_ref->{'ste-smsc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ste-smsc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ste-smsc'}{'port'}{'tcp'} = '1836'	; 
#	$srvcobjects_ref->{'ste-smsc'}{'ports'}{'tcp'}{'1836'}++	; 
#	$ports_ref->{'tcp'}{'1836'}{'name'} = 'ste-smsc'		; 
#	$srvcobjects_ref->{'udp-sr-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'udp-sr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udp-sr-port'}{'port'}{'udp'} = '1624'	; 
#	$srvcobjects_ref->{'udp-sr-port'}{'ports'}{'udp'}{'1624'}++	; 
#	$ports_ref->{'udp'}{'1624'}{'name'} = 'udp-sr-port'		; 
#	$srvcobjects_ref->{'udp-sr-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'udp-sr-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'udp-sr-port'}{'port'}{'tcp'} = '1624'	; 
#	$srvcobjects_ref->{'udp-sr-port'}{'ports'}{'tcp'}{'1624'}++	; 
#	$ports_ref->{'tcp'}{'1624'}{'name'} = 'udp-sr-port'		; 
#	$srvcobjects_ref->{'vpad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpad'}{'port'}{'udp'} = '1516'	; 
#	$srvcobjects_ref->{'vpad'}{'ports'}{'udp'}{'1516'}++	; 
#	$ports_ref->{'udp'}{'1516'}{'name'} = 'vpad'		; 
#	$srvcobjects_ref->{'vpad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpad'}{'port'}{'tcp'} = '1516'	; 
#	$srvcobjects_ref->{'vpad'}{'ports'}{'tcp'}{'1516'}++	; 
#	$ports_ref->{'tcp'}{'1516'}{'name'} = 'vpad'		; 
#	$srvcobjects_ref->{'pipes'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pipes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pipes'}{'port'}{'udp'} = '1465'	; 
#	$srvcobjects_ref->{'pipes'}{'ports'}{'udp'}{'1465'}++	; 
#	$ports_ref->{'udp'}{'1465'}{'name'} = 'pipes'		; 
#	$srvcobjects_ref->{'pipes'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pipes'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pipes'}{'port'}{'tcp'} = '1465'	; 
#	$srvcobjects_ref->{'pipes'}{'ports'}{'tcp'}{'1465'}++	; 
#	$ports_ref->{'tcp'}{'1465'}{'name'} = 'pipes'		; 
#	$srvcobjects_ref->{'bmc-ar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-ar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-ar'}{'port'}{'udp'} = '2494'	; 
#	$srvcobjects_ref->{'bmc-ar'}{'ports'}{'udp'}{'2494'}++	; 
#	$ports_ref->{'udp'}{'2494'}{'name'} = 'bmc-ar'		; 
#	$srvcobjects_ref->{'bmc-ar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-ar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-ar'}{'port'}{'tcp'} = '2494'	; 
#	$srvcobjects_ref->{'bmc-ar'}{'ports'}{'tcp'}{'2494'}++	; 
#	$ports_ref->{'tcp'}{'2494'}{'name'} = 'bmc-ar'		; 
#	$srvcobjects_ref->{'pop3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pop3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pop3'}{'port'}{'udp'} = '110'	; 
#	$srvcobjects_ref->{'pop3'}{'ports'}{'udp'}{'110'}++	; 
#	$ports_ref->{'udp'}{'110'}{'name'} = 'pop3'		; 
#	$srvcobjects_ref->{'pop3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pop3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pop3'}{'port'}{'tcp'} = '110'	; 
#	$srvcobjects_ref->{'pop3'}{'ports'}{'tcp'}{'110'}++	; 
#	$ports_ref->{'tcp'}{'110'}{'name'} = 'pop3'		; 
#	$srvcobjects_ref->{'fpitp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fpitp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fpitp'}{'port'}{'udp'} = '1045'	; 
#	$srvcobjects_ref->{'fpitp'}{'ports'}{'udp'}{'1045'}++	; 
#	$ports_ref->{'udp'}{'1045'}{'name'} = 'fpitp'		; 
#	$srvcobjects_ref->{'fpitp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fpitp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fpitp'}{'port'}{'tcp'} = '1045'	; 
#	$srvcobjects_ref->{'fpitp'}{'ports'}{'tcp'}{'1045'}++	; 
#	$ports_ref->{'tcp'}{'1045'}{'name'} = 'fpitp'		; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'port'}{'udp'} = '3985'	; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'ports'}{'udp'}{'3985'}++	; 
#	$ports_ref->{'udp'}{'3985'}{'name'} = 'mapper-mapethd'		; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'port'}{'tcp'} = '3985'	; 
#	$srvcobjects_ref->{'mapper-mapethd'}{'ports'}{'tcp'}{'3985'}++	; 
#	$ports_ref->{'tcp'}{'3985'}{'name'} = 'mapper-mapethd'		; 
#	$srvcobjects_ref->{'tekpls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tekpls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tekpls'}{'port'}{'udp'} = '1946'	; 
#	$srvcobjects_ref->{'tekpls'}{'ports'}{'udp'}{'1946'}++	; 
#	$ports_ref->{'udp'}{'1946'}{'name'} = 'tekpls'		; 
#	$srvcobjects_ref->{'tekpls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tekpls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tekpls'}{'port'}{'tcp'} = '1946'	; 
#	$srvcobjects_ref->{'tekpls'}{'ports'}{'tcp'}{'1946'}++	; 
#	$ports_ref->{'tcp'}{'1946'}{'name'} = 'tekpls'		; 
#	$srvcobjects_ref->{'odeumservlink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'odeumservlink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odeumservlink'}{'port'}{'udp'} = '3523'	; 
#	$srvcobjects_ref->{'odeumservlink'}{'ports'}{'udp'}{'3523'}++	; 
#	$ports_ref->{'udp'}{'3523'}{'name'} = 'odeumservlink'		; 
#	$srvcobjects_ref->{'odeumservlink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'odeumservlink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'odeumservlink'}{'port'}{'tcp'} = '3523'	; 
#	$srvcobjects_ref->{'odeumservlink'}{'ports'}{'tcp'}{'3523'}++	; 
#	$ports_ref->{'tcp'}{'3523'}{'name'} = 'odeumservlink'		; 
#	$srvcobjects_ref->{'aol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol'}{'port'}{'udp'} = '5190'	; 
#	$srvcobjects_ref->{'aol'}{'ports'}{'udp'}{'5190'}++	; 
#	$ports_ref->{'udp'}{'5190'}{'name'} = 'aol'		; 
#	$srvcobjects_ref->{'aol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol'}{'port'}{'tcp'} = '5190'	; 
#	$srvcobjects_ref->{'aol'}{'ports'}{'tcp'}{'5190'}++	; 
#	$ports_ref->{'tcp'}{'5190'}{'name'} = 'aol'		; 
#	$srvcobjects_ref->{'vsamredirector'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsamredirector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsamredirector'}{'port'}{'udp'} = '2387'	; 
#	$srvcobjects_ref->{'vsamredirector'}{'ports'}{'udp'}{'2387'}++	; 
#	$ports_ref->{'udp'}{'2387'}{'name'} = 'vsamredirector'		; 
#	$srvcobjects_ref->{'vsamredirector'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsamredirector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsamredirector'}{'port'}{'tcp'} = '2387'	; 
#	$srvcobjects_ref->{'vsamredirector'}{'ports'}{'tcp'}{'2387'}++	; 
#	$ports_ref->{'tcp'}{'2387'}{'name'} = 'vsamredirector'		; 
#	$srvcobjects_ref->{'cft-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-1'}{'port'}{'udp'} = '1762'	; 
#	$srvcobjects_ref->{'cft-1'}{'ports'}{'udp'}{'1762'}++	; 
#	$ports_ref->{'udp'}{'1762'}{'name'} = 'cft-1'		; 
#	$srvcobjects_ref->{'cft-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-1'}{'port'}{'tcp'} = '1762'	; 
#	$srvcobjects_ref->{'cft-1'}{'ports'}{'tcp'}{'1762'}++	; 
#	$ports_ref->{'tcp'}{'1762'}{'name'} = 'cft-1'		; 
#	$srvcobjects_ref->{'njenet-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'njenet-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'njenet-ssl'}{'port'}{'udp'} = '2252'	; 
#	$srvcobjects_ref->{'njenet-ssl'}{'ports'}{'udp'}{'2252'}++	; 
#	$ports_ref->{'udp'}{'2252'}{'name'} = 'njenet-ssl'		; 
#	$srvcobjects_ref->{'njenet-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'njenet-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'njenet-ssl'}{'port'}{'tcp'} = '2252'	; 
#	$srvcobjects_ref->{'njenet-ssl'}{'ports'}{'tcp'}{'2252'}++	; 
#	$ports_ref->{'tcp'}{'2252'}{'name'} = 'njenet-ssl'		; 
#	$srvcobjects_ref->{'npds-tracker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'npds-tracker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npds-tracker'}{'port'}{'udp'} = '3680'	; 
#	$srvcobjects_ref->{'npds-tracker'}{'ports'}{'udp'}{'3680'}++	; 
#	$ports_ref->{'udp'}{'3680'}{'name'} = 'npds-tracker'		; 
#	$srvcobjects_ref->{'npds-tracker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'npds-tracker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'npds-tracker'}{'port'}{'tcp'} = '3680'	; 
#	$srvcobjects_ref->{'npds-tracker'}{'ports'}{'tcp'}{'3680'}++	; 
#	$ports_ref->{'tcp'}{'3680'}{'name'} = 'npds-tracker'		; 
#	$srvcobjects_ref->{'netadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netadmin'}{'port'}{'udp'} = '2450'	; 
#	$srvcobjects_ref->{'netadmin'}{'ports'}{'udp'}{'2450'}++	; 
#	$ports_ref->{'udp'}{'2450'}{'name'} = 'netadmin'		; 
#	$srvcobjects_ref->{'netadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netadmin'}{'port'}{'tcp'} = '2450'	; 
#	$srvcobjects_ref->{'netadmin'}{'ports'}{'tcp'}{'2450'}++	; 
#	$ports_ref->{'tcp'}{'2450'}{'name'} = 'netadmin'		; 
#	$srvcobjects_ref->{'ddi-tcp-7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddi-tcp-7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-tcp-7'}{'port'}{'tcp'} = '8894'	; 
#	$srvcobjects_ref->{'ddi-tcp-7'}{'ports'}{'tcp'}{'8894'}++	; 
#	$ports_ref->{'tcp'}{'8894'}{'name'} = 'ddi-tcp-7'		; 
#	$srvcobjects_ref->{'bre'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bre'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bre'}{'port'}{'udp'} = '4096'	; 
#	$srvcobjects_ref->{'bre'}{'ports'}{'udp'}{'4096'}++	; 
#	$ports_ref->{'udp'}{'4096'}{'name'} = 'bre'		; 
#	$srvcobjects_ref->{'bre'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bre'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bre'}{'port'}{'tcp'} = '4096'	; 
#	$srvcobjects_ref->{'bre'}{'ports'}{'tcp'}{'4096'}++	; 
#	$ports_ref->{'tcp'}{'4096'}{'name'} = 'bre'		; 
#	$srvcobjects_ref->{'arena-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arena-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arena-server'}{'port'}{'udp'} = '11321'	; 
#	$srvcobjects_ref->{'arena-server'}{'ports'}{'udp'}{'11321'}++	; 
#	$ports_ref->{'udp'}{'11321'}{'name'} = 'arena-server'		; 
#	$srvcobjects_ref->{'arena-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arena-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arena-server'}{'port'}{'tcp'} = '11321'	; 
#	$srvcobjects_ref->{'arena-server'}{'ports'}{'tcp'}{'11321'}++	; 
#	$ports_ref->{'tcp'}{'11321'}{'name'} = 'arena-server'		; 
#	$srvcobjects_ref->{'vaprtm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vaprtm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vaprtm'}{'port'}{'udp'} = '3654'	; 
#	$srvcobjects_ref->{'vaprtm'}{'ports'}{'udp'}{'3654'}++	; 
#	$ports_ref->{'udp'}{'3654'}{'name'} = 'vaprtm'		; 
#	$srvcobjects_ref->{'vaprtm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vaprtm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vaprtm'}{'port'}{'tcp'} = '3654'	; 
#	$srvcobjects_ref->{'vaprtm'}{'ports'}{'tcp'}{'3654'}++	; 
#	$ports_ref->{'tcp'}{'3654'}{'name'} = 'vaprtm'		; 
#	$srvcobjects_ref->{'mvs-capacity'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mvs-capacity'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mvs-capacity'}{'port'}{'udp'} = '10007'	; 
#	$srvcobjects_ref->{'mvs-capacity'}{'ports'}{'udp'}{'10007'}++	; 
#	$ports_ref->{'udp'}{'10007'}{'name'} = 'mvs-capacity'		; 
#	$srvcobjects_ref->{'mvs-capacity'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mvs-capacity'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mvs-capacity'}{'port'}{'tcp'} = '10007'	; 
#	$srvcobjects_ref->{'mvs-capacity'}{'ports'}{'tcp'}{'10007'}++	; 
#	$ports_ref->{'tcp'}{'10007'}{'name'} = 'mvs-capacity'		; 
#	$srvcobjects_ref->{'lionhead'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lionhead'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lionhead'}{'port'}{'udp'} = '2611'	; 
#	$srvcobjects_ref->{'lionhead'}{'ports'}{'udp'}{'2611'}++	; 
#	$ports_ref->{'udp'}{'2611'}{'name'} = 'lionhead'		; 
#	$srvcobjects_ref->{'lionhead'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lionhead'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lionhead'}{'port'}{'tcp'} = '2611'	; 
#	$srvcobjects_ref->{'lionhead'}{'ports'}{'tcp'}{'2611'}++	; 
#	$ports_ref->{'tcp'}{'2611'}{'name'} = 'lionhead'		; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'port'}{'udp'} = '8131'	; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'ports'}{'udp'}{'8131'}++	; 
#	$ports_ref->{'udp'}{'8131'}{'name'} = 'indigo-vbcp'		; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'port'}{'tcp'} = '8131'	; 
#	$srvcobjects_ref->{'indigo-vbcp'}{'ports'}{'tcp'}{'8131'}++	; 
#	$ports_ref->{'tcp'}{'8131'}{'name'} = 'indigo-vbcp'		; 
#	$srvcobjects_ref->{'teredo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'teredo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teredo'}{'port'}{'udp'} = '3544'	; 
#	$srvcobjects_ref->{'teredo'}{'ports'}{'udp'}{'3544'}++	; 
#	$ports_ref->{'udp'}{'3544'}{'name'} = 'teredo'		; 
#	$srvcobjects_ref->{'teredo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'teredo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teredo'}{'port'}{'tcp'} = '3544'	; 
#	$srvcobjects_ref->{'teredo'}{'ports'}{'tcp'}{'3544'}++	; 
#	$ports_ref->{'tcp'}{'3544'}{'name'} = 'teredo'		; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'port'}{'udp'} = '3175'	; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'ports'}{'udp'}{'3175'}++	; 
#	$ports_ref->{'udp'}{'3175'}{'name'} = 't1-e1-over-ip'		; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'port'}{'tcp'} = '3175'	; 
#	$srvcobjects_ref->{'t1-e1-over-ip'}{'ports'}{'tcp'}{'3175'}++	; 
#	$ports_ref->{'tcp'}{'3175'}{'name'} = 't1-e1-over-ip'		; 
#	$srvcobjects_ref->{'sim-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sim-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sim-control'}{'port'}{'udp'} = '3110'	; 
#	$srvcobjects_ref->{'sim-control'}{'ports'}{'udp'}{'3110'}++	; 
#	$ports_ref->{'udp'}{'3110'}{'name'} = 'sim-control'		; 
#	$srvcobjects_ref->{'sim-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sim-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sim-control'}{'port'}{'tcp'} = '3110'	; 
#	$srvcobjects_ref->{'sim-control'}{'ports'}{'tcp'}{'3110'}++	; 
#	$ports_ref->{'tcp'}{'3110'}{'name'} = 'sim-control'		; 
#	$srvcobjects_ref->{'ncpm-pm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncpm-pm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncpm-pm'}{'port'}{'udp'} = '1591'	; 
#	$srvcobjects_ref->{'ncpm-pm'}{'ports'}{'udp'}{'1591'}++	; 
#	$ports_ref->{'udp'}{'1591'}{'name'} = 'ncpm-pm'		; 
#	$srvcobjects_ref->{'ncpm-pm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncpm-pm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncpm-pm'}{'port'}{'tcp'} = '1591'	; 
#	$srvcobjects_ref->{'ncpm-pm'}{'ports'}{'tcp'}{'1591'}++	; 
#	$ports_ref->{'tcp'}{'1591'}{'name'} = 'ncpm-pm'		; 
#	$srvcobjects_ref->{'remote-winsock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remote-winsock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-winsock'}{'port'}{'udp'} = '1745'	; 
#	$srvcobjects_ref->{'remote-winsock'}{'ports'}{'udp'}{'1745'}++	; 
#	$ports_ref->{'udp'}{'1745'}{'name'} = 'remote-winsock'		; 
#	$srvcobjects_ref->{'remote-winsock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remote-winsock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remote-winsock'}{'port'}{'tcp'} = '1745'	; 
#	$srvcobjects_ref->{'remote-winsock'}{'ports'}{'tcp'}{'1745'}++	; 
#	$ports_ref->{'tcp'}{'1745'}{'name'} = 'remote-winsock'		; 
#	$srvcobjects_ref->{'caci-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'caci-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caci-lm'}{'port'}{'udp'} = '1554'	; 
#	$srvcobjects_ref->{'caci-lm'}{'ports'}{'udp'}{'1554'}++	; 
#	$ports_ref->{'udp'}{'1554'}{'name'} = 'caci-lm'		; 
#	$srvcobjects_ref->{'caci-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'caci-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caci-lm'}{'port'}{'tcp'} = '1554'	; 
#	$srvcobjects_ref->{'caci-lm'}{'ports'}{'tcp'}{'1554'}++	; 
#	$ports_ref->{'tcp'}{'1554'}{'name'} = 'caci-lm'		; 
#	$srvcobjects_ref->{'go-login'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'go-login'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'go-login'}{'port'}{'udp'} = '491'	; 
#	$srvcobjects_ref->{'go-login'}{'ports'}{'udp'}{'491'}++	; 
#	$ports_ref->{'udp'}{'491'}{'name'} = 'go-login'		; 
#	$srvcobjects_ref->{'go-login'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'go-login'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'go-login'}{'port'}{'tcp'} = '491'	; 
#	$srvcobjects_ref->{'go-login'}{'ports'}{'tcp'}{'491'}++	; 
#	$ports_ref->{'tcp'}{'491'}{'name'} = 'go-login'		; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'port'}{'udp'} = '1593'	; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'ports'}{'udp'}{'1593'}++	; 
#	$ports_ref->{'udp'}{'1593'}{'name'} = 'mainsoft-lm'		; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'port'}{'tcp'} = '1593'	; 
#	$srvcobjects_ref->{'mainsoft-lm'}{'ports'}{'tcp'}{'1593'}++	; 
#	$ports_ref->{'tcp'}{'1593'}{'name'} = 'mainsoft-lm'		; 
#	$srvcobjects_ref->{'serverview-gf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'serverview-gf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-gf'}{'port'}{'udp'} = '3171'	; 
#	$srvcobjects_ref->{'serverview-gf'}{'ports'}{'udp'}{'3171'}++	; 
#	$ports_ref->{'udp'}{'3171'}{'name'} = 'serverview-gf'		; 
#	$srvcobjects_ref->{'serverview-gf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'serverview-gf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-gf'}{'port'}{'tcp'} = '3171'	; 
#	$srvcobjects_ref->{'serverview-gf'}{'ports'}{'tcp'}{'3171'}++	; 
#	$ports_ref->{'tcp'}{'3171'}{'name'} = 'serverview-gf'		; 
#	$srvcobjects_ref->{'qtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qtp'}{'port'}{'udp'} = '2935'	; 
#	$srvcobjects_ref->{'qtp'}{'ports'}{'udp'}{'2935'}++	; 
#	$ports_ref->{'udp'}{'2935'}{'name'} = 'qtp'		; 
#	$srvcobjects_ref->{'qtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qtp'}{'port'}{'tcp'} = '2935'	; 
#	$srvcobjects_ref->{'qtp'}{'ports'}{'tcp'}{'2935'}++	; 
#	$ports_ref->{'tcp'}{'2935'}{'name'} = 'qtp'		; 
#	$srvcobjects_ref->{'zserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zserv'}{'port'}{'udp'} = '346'	; 
#	$srvcobjects_ref->{'zserv'}{'ports'}{'udp'}{'346'}++	; 
#	$ports_ref->{'udp'}{'346'}{'name'} = 'zserv'		; 
#	$srvcobjects_ref->{'zserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zserv'}{'port'}{'tcp'} = '346'	; 
#	$srvcobjects_ref->{'zserv'}{'ports'}{'tcp'}{'346'}++	; 
#	$ports_ref->{'tcp'}{'346'}{'name'} = 'zserv'		; 
#	$srvcobjects_ref->{'mzap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mzap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mzap'}{'port'}{'udp'} = '2106'	; 
#	$srvcobjects_ref->{'mzap'}{'ports'}{'udp'}{'2106'}++	; 
#	$ports_ref->{'udp'}{'2106'}{'name'} = 'mzap'		; 
#	$srvcobjects_ref->{'mzap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mzap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mzap'}{'port'}{'tcp'} = '2106'	; 
#	$srvcobjects_ref->{'mzap'}{'ports'}{'tcp'}{'2106'}++	; 
#	$ports_ref->{'tcp'}{'2106'}{'name'} = 'mzap'		; 
#	$srvcobjects_ref->{'camp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'camp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'camp'}{'port'}{'udp'} = '4450'	; 
#	$srvcobjects_ref->{'camp'}{'ports'}{'udp'}{'4450'}++	; 
#	$ports_ref->{'udp'}{'4450'}{'name'} = 'camp'		; 
#	$srvcobjects_ref->{'camp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'camp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'camp'}{'port'}{'tcp'} = '4450'	; 
#	$srvcobjects_ref->{'camp'}{'ports'}{'tcp'}{'4450'}++	; 
#	$ports_ref->{'tcp'}{'4450'}{'name'} = 'camp'		; 
#	$srvcobjects_ref->{'sccip-media'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sccip-media'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sccip-media'}{'port'}{'udp'} = '3499'	; 
#	$srvcobjects_ref->{'sccip-media'}{'ports'}{'udp'}{'3499'}++	; 
#	$ports_ref->{'udp'}{'3499'}{'name'} = 'sccip-media'		; 
#	$srvcobjects_ref->{'sccip-media'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sccip-media'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sccip-media'}{'port'}{'tcp'} = '3499'	; 
#	$srvcobjects_ref->{'sccip-media'}{'ports'}{'tcp'}{'3499'}++	; 
#	$ports_ref->{'tcp'}{'3499'}{'name'} = 'sccip-media'		; 
#	$srvcobjects_ref->{'cautcpd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cautcpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cautcpd'}{'port'}{'udp'} = '3061'	; 
#	$srvcobjects_ref->{'cautcpd'}{'ports'}{'udp'}{'3061'}++	; 
#	$ports_ref->{'udp'}{'3061'}{'name'} = 'cautcpd'		; 
#	$srvcobjects_ref->{'cautcpd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cautcpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cautcpd'}{'port'}{'tcp'} = '3061'	; 
#	$srvcobjects_ref->{'cautcpd'}{'ports'}{'tcp'}{'3061'}++	; 
#	$ports_ref->{'tcp'}{'3061'}{'name'} = 'cautcpd'		; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'port'}{'udp'} = '1086'	; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'ports'}{'udp'}{'1086'}++	; 
#	$ports_ref->{'udp'}{'1086'}{'name'} = 'cplscrambler-lg'		; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'port'}{'tcp'} = '1086'	; 
#	$srvcobjects_ref->{'cplscrambler-lg'}{'ports'}{'tcp'}{'1086'}++	; 
#	$ports_ref->{'tcp'}{'1086'}{'name'} = 'cplscrambler-lg'		; 
#	$srvcobjects_ref->{'aol-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aol-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol-2'}{'port'}{'udp'} = '5192'	; 
#	$srvcobjects_ref->{'aol-2'}{'ports'}{'udp'}{'5192'}++	; 
#	$ports_ref->{'udp'}{'5192'}{'name'} = 'aol-2'		; 
#	$srvcobjects_ref->{'aol-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aol-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aol-2'}{'port'}{'tcp'} = '5192'	; 
#	$srvcobjects_ref->{'aol-2'}{'ports'}{'tcp'}{'5192'}++	; 
#	$ports_ref->{'tcp'}{'5192'}{'name'} = 'aol-2'		; 
#	$srvcobjects_ref->{'igo-incognito'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'igo-incognito'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igo-incognito'}{'port'}{'udp'} = '4100'	; 
#	$srvcobjects_ref->{'igo-incognito'}{'ports'}{'udp'}{'4100'}++	; 
#	$ports_ref->{'udp'}{'4100'}{'name'} = 'igo-incognito'		; 
#	$srvcobjects_ref->{'igo-incognito'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'igo-incognito'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igo-incognito'}{'port'}{'tcp'} = '4100'	; 
#	$srvcobjects_ref->{'igo-incognito'}{'ports'}{'tcp'}{'4100'}++	; 
#	$ports_ref->{'tcp'}{'4100'}{'name'} = 'igo-incognito'		; 
#	$srvcobjects_ref->{'netserialext4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netserialext4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext4'}{'port'}{'udp'} = '16368'	; 
#	$srvcobjects_ref->{'netserialext4'}{'ports'}{'udp'}{'16368'}++	; 
#	$ports_ref->{'udp'}{'16368'}{'name'} = 'netserialext4'		; 
#	$srvcobjects_ref->{'netserialext4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netserialext4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netserialext4'}{'port'}{'tcp'} = '16368'	; 
#	$srvcobjects_ref->{'netserialext4'}{'ports'}{'tcp'}{'16368'}++	; 
#	$ports_ref->{'tcp'}{'16368'}{'name'} = 'netserialext4'		; 
#	$srvcobjects_ref->{'att-intercom'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'att-intercom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'att-intercom'}{'port'}{'udp'} = '4983'	; 
#	$srvcobjects_ref->{'att-intercom'}{'ports'}{'udp'}{'4983'}++	; 
#	$ports_ref->{'udp'}{'4983'}{'name'} = 'att-intercom'		; 
#	$srvcobjects_ref->{'att-intercom'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'att-intercom'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'att-intercom'}{'port'}{'tcp'} = '4983'	; 
#	$srvcobjects_ref->{'att-intercom'}{'ports'}{'tcp'}{'4983'}++	; 
#	$ports_ref->{'tcp'}{'4983'}{'name'} = 'att-intercom'		; 
#	$srvcobjects_ref->{'hp-device-disc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-device-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-device-disc'}{'port'}{'udp'} = '3329'	; 
#	$srvcobjects_ref->{'hp-device-disc'}{'ports'}{'udp'}{'3329'}++	; 
#	$ports_ref->{'udp'}{'3329'}{'name'} = 'hp-device-disc'		; 
#	$srvcobjects_ref->{'hp-device-disc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-device-disc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-device-disc'}{'port'}{'tcp'} = '3329'	; 
#	$srvcobjects_ref->{'hp-device-disc'}{'ports'}{'tcp'}{'3329'}++	; 
#	$ports_ref->{'tcp'}{'3329'}{'name'} = 'hp-device-disc'		; 
#	$srvcobjects_ref->{'netiq-voipa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netiq-voipa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-voipa'}{'port'}{'udp'} = '10116'	; 
#	$srvcobjects_ref->{'netiq-voipa'}{'ports'}{'udp'}{'10116'}++	; 
#	$ports_ref->{'udp'}{'10116'}{'name'} = 'netiq-voipa'		; 
#	$srvcobjects_ref->{'netiq-voipa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netiq-voipa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-voipa'}{'port'}{'tcp'} = '10116'	; 
#	$srvcobjects_ref->{'netiq-voipa'}{'ports'}{'tcp'}{'10116'}++	; 
#	$ports_ref->{'tcp'}{'10116'}{'name'} = 'netiq-voipa'		; 
#	$srvcobjects_ref->{'radix'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'radix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radix'}{'port'}{'udp'} = '2872'	; 
#	$srvcobjects_ref->{'radix'}{'ports'}{'udp'}{'2872'}++	; 
#	$ports_ref->{'udp'}{'2872'}{'name'} = 'radix'		; 
#	$srvcobjects_ref->{'radix'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radix'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radix'}{'port'}{'tcp'} = '2872'	; 
#	$srvcobjects_ref->{'radix'}{'ports'}{'tcp'}{'2872'}++	; 
#	$ports_ref->{'tcp'}{'2872'}{'name'} = 'radix'		; 
#	$srvcobjects_ref->{'palace-5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'palace-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-5'}{'port'}{'udp'} = '9996'	; 
#	$srvcobjects_ref->{'palace-5'}{'ports'}{'udp'}{'9996'}++	; 
#	$ports_ref->{'udp'}{'9996'}{'name'} = 'palace-5'		; 
#	$srvcobjects_ref->{'palace-5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'palace-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-5'}{'port'}{'tcp'} = '9996'	; 
#	$srvcobjects_ref->{'palace-5'}{'ports'}{'tcp'}{'9996'}++	; 
#	$ports_ref->{'tcp'}{'9996'}{'name'} = 'palace-5'		; 
#	$srvcobjects_ref->{'pit-vpn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pit-vpn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pit-vpn'}{'port'}{'udp'} = '2865'	; 
#	$srvcobjects_ref->{'pit-vpn'}{'ports'}{'udp'}{'2865'}++	; 
#	$ports_ref->{'udp'}{'2865'}{'name'} = 'pit-vpn'		; 
#	$srvcobjects_ref->{'pit-vpn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pit-vpn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pit-vpn'}{'port'}{'tcp'} = '2865'	; 
#	$srvcobjects_ref->{'pit-vpn'}{'ports'}{'tcp'}{'2865'}++	; 
#	$ports_ref->{'tcp'}{'2865'}{'name'} = 'pit-vpn'		; 
#	$srvcobjects_ref->{'seagull-ais'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'seagull-ais'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seagull-ais'}{'port'}{'udp'} = '1208'	; 
#	$srvcobjects_ref->{'seagull-ais'}{'ports'}{'udp'}{'1208'}++	; 
#	$ports_ref->{'udp'}{'1208'}{'name'} = 'seagull-ais'		; 
#	$srvcobjects_ref->{'seagull-ais'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'seagull-ais'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seagull-ais'}{'port'}{'tcp'} = '1208'	; 
#	$srvcobjects_ref->{'seagull-ais'}{'ports'}{'tcp'}{'1208'}++	; 
#	$ports_ref->{'tcp'}{'1208'}{'name'} = 'seagull-ais'		; 
#	$srvcobjects_ref->{'prolink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prolink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prolink'}{'port'}{'udp'} = '1678'	; 
#	$srvcobjects_ref->{'prolink'}{'ports'}{'udp'}{'1678'}++	; 
#	$ports_ref->{'udp'}{'1678'}{'name'} = 'prolink'		; 
#	$srvcobjects_ref->{'prolink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prolink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prolink'}{'port'}{'tcp'} = '1678'	; 
#	$srvcobjects_ref->{'prolink'}{'ports'}{'tcp'}{'1678'}++	; 
#	$ports_ref->{'tcp'}{'1678'}{'name'} = 'prolink'		; 
#	$srvcobjects_ref->{'flashmsg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'flashmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flashmsg'}{'port'}{'udp'} = '2884'	; 
#	$srvcobjects_ref->{'flashmsg'}{'ports'}{'udp'}{'2884'}++	; 
#	$ports_ref->{'udp'}{'2884'}{'name'} = 'flashmsg'		; 
#	$srvcobjects_ref->{'flashmsg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'flashmsg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flashmsg'}{'port'}{'tcp'} = '2884'	; 
#	$srvcobjects_ref->{'flashmsg'}{'ports'}{'tcp'}{'2884'}++	; 
#	$ports_ref->{'tcp'}{'2884'}{'name'} = 'flashmsg'		; 
#	$srvcobjects_ref->{'philips-vc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'philips-vc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'philips-vc'}{'port'}{'udp'} = '583'	; 
#	$srvcobjects_ref->{'philips-vc'}{'ports'}{'udp'}{'583'}++	; 
#	$ports_ref->{'udp'}{'583'}{'name'} = 'philips-vc'		; 
#	$srvcobjects_ref->{'philips-vc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'philips-vc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'philips-vc'}{'port'}{'tcp'} = '583'	; 
#	$srvcobjects_ref->{'philips-vc'}{'ports'}{'tcp'}{'583'}++	; 
#	$ports_ref->{'tcp'}{'583'}{'name'} = 'philips-vc'		; 
#	$srvcobjects_ref->{'ariel1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ariel1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariel1'}{'port'}{'udp'} = '419'	; 
#	$srvcobjects_ref->{'ariel1'}{'ports'}{'udp'}{'419'}++	; 
#	$ports_ref->{'udp'}{'419'}{'name'} = 'ariel1'		; 
#	$srvcobjects_ref->{'ariel1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ariel1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ariel1'}{'port'}{'tcp'} = '419'	; 
#	$srvcobjects_ref->{'ariel1'}{'ports'}{'tcp'}{'419'}++	; 
#	$ports_ref->{'tcp'}{'419'}{'name'} = 'ariel1'		; 
#	$srvcobjects_ref->{'s-openmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'s-openmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'s-openmail'}{'port'}{'udp'} = '5767'	; 
#	$srvcobjects_ref->{'s-openmail'}{'ports'}{'udp'}{'5767'}++	; 
#	$ports_ref->{'udp'}{'5767'}{'name'} = 's-openmail'		; 
#	$srvcobjects_ref->{'s-openmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'s-openmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'s-openmail'}{'port'}{'tcp'} = '5767'	; 
#	$srvcobjects_ref->{'s-openmail'}{'ports'}{'tcp'}{'5767'}++	; 
#	$ports_ref->{'tcp'}{'5767'}{'name'} = 's-openmail'		; 
#	$srvcobjects_ref->{'caps-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'caps-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caps-lm'}{'port'}{'udp'} = '3290'	; 
#	$srvcobjects_ref->{'caps-lm'}{'ports'}{'udp'}{'3290'}++	; 
#	$ports_ref->{'udp'}{'3290'}{'name'} = 'caps-lm'		; 
#	$srvcobjects_ref->{'caps-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'caps-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'caps-lm'}{'port'}{'tcp'} = '3290'	; 
#	$srvcobjects_ref->{'caps-lm'}{'ports'}{'tcp'}{'3290'}++	; 
#	$ports_ref->{'tcp'}{'3290'}{'name'} = 'caps-lm'		; 
#	$srvcobjects_ref->{'nettgain-nms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nettgain-nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nettgain-nms'}{'port'}{'udp'} = '1879'	; 
#	$srvcobjects_ref->{'nettgain-nms'}{'ports'}{'udp'}{'1879'}++	; 
#	$ports_ref->{'udp'}{'1879'}{'name'} = 'nettgain-nms'		; 
#	$srvcobjects_ref->{'nettgain-nms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nettgain-nms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nettgain-nms'}{'port'}{'tcp'} = '1879'	; 
#	$srvcobjects_ref->{'nettgain-nms'}{'ports'}{'tcp'}{'1879'}++	; 
#	$ports_ref->{'tcp'}{'1879'}{'name'} = 'nettgain-nms'		; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'port'}{'udp'} = '45966'	; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'ports'}{'udp'}{'45966'}++	; 
#	$ports_ref->{'udp'}{'45966'}{'name'} = 'ssr-servermgr'		; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'port'}{'tcp'} = '45966'	; 
#	$srvcobjects_ref->{'ssr-servermgr'}{'ports'}{'tcp'}{'45966'}++	; 
#	$ports_ref->{'tcp'}{'45966'}{'name'} = 'ssr-servermgr'		; 
#	$srvcobjects_ref->{'palace-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'palace-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-2'}{'port'}{'udp'} = '9993'	; 
#	$srvcobjects_ref->{'palace-2'}{'ports'}{'udp'}{'9993'}++	; 
#	$ports_ref->{'udp'}{'9993'}{'name'} = 'palace-2'		; 
#	$srvcobjects_ref->{'palace-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'palace-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-2'}{'port'}{'tcp'} = '9993'	; 
#	$srvcobjects_ref->{'palace-2'}{'ports'}{'tcp'}{'9993'}++	; 
#	$ports_ref->{'tcp'}{'9993'}{'name'} = 'palace-2'		; 
#	$srvcobjects_ref->{'nest-protocol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nest-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nest-protocol'}{'port'}{'udp'} = '489'	; 
#	$srvcobjects_ref->{'nest-protocol'}{'ports'}{'udp'}{'489'}++	; 
#	$ports_ref->{'udp'}{'489'}{'name'} = 'nest-protocol'		; 
#	$srvcobjects_ref->{'nest-protocol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nest-protocol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nest-protocol'}{'port'}{'tcp'} = '489'	; 
#	$srvcobjects_ref->{'nest-protocol'}{'ports'}{'tcp'}{'489'}++	; 
#	$ports_ref->{'tcp'}{'489'}{'name'} = 'nest-protocol'		; 
#	$srvcobjects_ref->{'distcc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'distcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'distcc'}{'port'}{'udp'} = '3632'	; 
#	$srvcobjects_ref->{'distcc'}{'ports'}{'udp'}{'3632'}++	; 
#	$ports_ref->{'udp'}{'3632'}{'name'} = 'distcc'		; 
#	$srvcobjects_ref->{'distcc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'distcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'distcc'}{'port'}{'tcp'} = '3632'	; 
#	$srvcobjects_ref->{'distcc'}{'ports'}{'tcp'}{'3632'}++	; 
#	$ports_ref->{'tcp'}{'3632'}{'name'} = 'distcc'		; 
#	$srvcobjects_ref->{'windlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'windlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'windlm'}{'port'}{'udp'} = '1785'	; 
#	$srvcobjects_ref->{'windlm'}{'ports'}{'udp'}{'1785'}++	; 
#	$ports_ref->{'udp'}{'1785'}{'name'} = 'windlm'		; 
#	$srvcobjects_ref->{'windlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'windlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'windlm'}{'port'}{'tcp'} = '1785'	; 
#	$srvcobjects_ref->{'windlm'}{'ports'}{'tcp'}{'1785'}++	; 
#	$ports_ref->{'tcp'}{'1785'}{'name'} = 'windlm'		; 
#	$srvcobjects_ref->{'tivoli-npm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tivoli-npm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tivoli-npm'}{'port'}{'udp'} = '1965'	; 
#	$srvcobjects_ref->{'tivoli-npm'}{'ports'}{'udp'}{'1965'}++	; 
#	$ports_ref->{'udp'}{'1965'}{'name'} = 'tivoli-npm'		; 
#	$srvcobjects_ref->{'tivoli-npm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tivoli-npm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tivoli-npm'}{'port'}{'tcp'} = '1965'	; 
#	$srvcobjects_ref->{'tivoli-npm'}{'ports'}{'tcp'}{'1965'}++	; 
#	$ports_ref->{'tcp'}{'1965'}{'name'} = 'tivoli-npm'		; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'port'}{'udp'} = '9206'	; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'ports'}{'udp'}{'9206'}++	; 
#	$ports_ref->{'udp'}{'9206'}{'name'} = 'wap-vcard-s'		; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'port'}{'tcp'} = '9206'	; 
#	$srvcobjects_ref->{'wap-vcard-s'}{'ports'}{'tcp'}{'9206'}++	; 
#	$ports_ref->{'tcp'}{'9206'}{'name'} = 'wap-vcard-s'		; 
#	$srvcobjects_ref->{'oa-system'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oa-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oa-system'}{'port'}{'udp'} = '8022'	; 
#	$srvcobjects_ref->{'oa-system'}{'ports'}{'udp'}{'8022'}++	; 
#	$ports_ref->{'udp'}{'8022'}{'name'} = 'oa-system'		; 
#	$srvcobjects_ref->{'oa-system'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oa-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oa-system'}{'port'}{'tcp'} = '8022'	; 
#	$srvcobjects_ref->{'oa-system'}{'ports'}{'tcp'}{'8022'}++	; 
#	$ports_ref->{'tcp'}{'8022'}{'name'} = 'oa-system'		; 
#	$srvcobjects_ref->{'powergemplus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'powergemplus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powergemplus'}{'port'}{'udp'} = '2899'	; 
#	$srvcobjects_ref->{'powergemplus'}{'ports'}{'udp'}{'2899'}++	; 
#	$ports_ref->{'udp'}{'2899'}{'name'} = 'powergemplus'		; 
#	$srvcobjects_ref->{'powergemplus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'powergemplus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powergemplus'}{'port'}{'tcp'} = '2899'	; 
#	$srvcobjects_ref->{'powergemplus'}{'ports'}{'tcp'}{'2899'}++	; 
#	$ports_ref->{'tcp'}{'2899'}{'name'} = 'powergemplus'		; 
#	$srvcobjects_ref->{'xrpc-registry'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xrpc-registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xrpc-registry'}{'port'}{'udp'} = '3651'	; 
#	$srvcobjects_ref->{'xrpc-registry'}{'ports'}{'udp'}{'3651'}++	; 
#	$ports_ref->{'udp'}{'3651'}{'name'} = 'xrpc-registry'		; 
#	$srvcobjects_ref->{'xrpc-registry'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xrpc-registry'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xrpc-registry'}{'port'}{'tcp'} = '3651'	; 
#	$srvcobjects_ref->{'xrpc-registry'}{'ports'}{'tcp'}{'3651'}++	; 
#	$ports_ref->{'tcp'}{'3651'}{'name'} = 'xrpc-registry'		; 
#	$srvcobjects_ref->{'vrts-at-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrts-at-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-at-port'}{'port'}{'udp'} = '2821'	; 
#	$srvcobjects_ref->{'vrts-at-port'}{'ports'}{'udp'}{'2821'}++	; 
#	$ports_ref->{'udp'}{'2821'}{'name'} = 'vrts-at-port'		; 
#	$srvcobjects_ref->{'vrts-at-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrts-at-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrts-at-port'}{'port'}{'tcp'} = '2821'	; 
#	$srvcobjects_ref->{'vrts-at-port'}{'ports'}{'tcp'}{'2821'}++	; 
#	$ports_ref->{'tcp'}{'2821'}{'name'} = 'vrts-at-port'		; 
#	$srvcobjects_ref->{'cadis-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadis-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadis-2'}{'port'}{'udp'} = '1442'	; 
#	$srvcobjects_ref->{'cadis-2'}{'ports'}{'udp'}{'1442'}++	; 
#	$ports_ref->{'udp'}{'1442'}{'name'} = 'cadis-2'		; 
#	$srvcobjects_ref->{'cadis-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadis-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadis-2'}{'port'}{'tcp'} = '1442'	; 
#	$srvcobjects_ref->{'cadis-2'}{'ports'}{'tcp'}{'1442'}++	; 
#	$ports_ref->{'tcp'}{'1442'}{'name'} = 'cadis-2'		; 
#	$srvcobjects_ref->{'apc-3506'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-3506'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-3506'}{'port'}{'udp'} = '3506'	; 
#	$srvcobjects_ref->{'apc-3506'}{'ports'}{'udp'}{'3506'}++	; 
#	$ports_ref->{'udp'}{'3506'}{'name'} = 'apc-3506'		; 
#	$srvcobjects_ref->{'apc-3506'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-3506'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-3506'}{'port'}{'tcp'} = '3506'	; 
#	$srvcobjects_ref->{'apc-3506'}{'ports'}{'tcp'}{'3506'}++	; 
#	$ports_ref->{'tcp'}{'3506'}{'name'} = 'apc-3506'		; 
#	$srvcobjects_ref->{'gpsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gpsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gpsd'}{'port'}{'udp'} = '2947'	; 
#	$srvcobjects_ref->{'gpsd'}{'ports'}{'udp'}{'2947'}++	; 
#	$ports_ref->{'udp'}{'2947'}{'name'} = 'gpsd'		; 
#	$srvcobjects_ref->{'gpsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gpsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gpsd'}{'port'}{'tcp'} = '2947'	; 
#	$srvcobjects_ref->{'gpsd'}{'ports'}{'tcp'}{'2947'}++	; 
#	$ports_ref->{'tcp'}{'2947'}{'name'} = 'gpsd'		; 
#	$srvcobjects_ref->{'pcg-radar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcg-radar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcg-radar'}{'port'}{'udp'} = '1036'	; 
#	$srvcobjects_ref->{'pcg-radar'}{'ports'}{'udp'}{'1036'}++	; 
#	$ports_ref->{'udp'}{'1036'}{'name'} = 'pcg-radar'		; 
#	$srvcobjects_ref->{'pcg-radar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcg-radar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcg-radar'}{'port'}{'tcp'} = '1036'	; 
#	$srvcobjects_ref->{'pcg-radar'}{'ports'}{'tcp'}{'1036'}++	; 
#	$ports_ref->{'tcp'}{'1036'}{'name'} = 'pcg-radar'		; 
#	$srvcobjects_ref->{'rib-slm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rib-slm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rib-slm'}{'port'}{'udp'} = '3296'	; 
#	$srvcobjects_ref->{'rib-slm'}{'ports'}{'udp'}{'3296'}++	; 
#	$ports_ref->{'udp'}{'3296'}{'name'} = 'rib-slm'		; 
#	$srvcobjects_ref->{'rib-slm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rib-slm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rib-slm'}{'port'}{'tcp'} = '3296'	; 
#	$srvcobjects_ref->{'rib-slm'}{'ports'}{'tcp'}{'3296'}++	; 
#	$ports_ref->{'tcp'}{'3296'}{'name'} = 'rib-slm'		; 
#	$srvcobjects_ref->{'piranha1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'piranha1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'piranha1'}{'port'}{'udp'} = '4600'	; 
#	$srvcobjects_ref->{'piranha1'}{'ports'}{'udp'}{'4600'}++	; 
#	$ports_ref->{'udp'}{'4600'}{'name'} = 'piranha1'		; 
#	$srvcobjects_ref->{'piranha1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'piranha1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'piranha1'}{'port'}{'tcp'} = '4600'	; 
#	$srvcobjects_ref->{'piranha1'}{'ports'}{'tcp'}{'4600'}++	; 
#	$ports_ref->{'tcp'}{'4600'}{'name'} = 'piranha1'		; 
#	$srvcobjects_ref->{'itm-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itm-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-lm'}{'port'}{'udp'} = '2828'	; 
#	$srvcobjects_ref->{'itm-lm'}{'ports'}{'udp'}{'2828'}++	; 
#	$ports_ref->{'udp'}{'2828'}{'name'} = 'itm-lm'		; 
#	$srvcobjects_ref->{'itm-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itm-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itm-lm'}{'port'}{'tcp'} = '2828'	; 
#	$srvcobjects_ref->{'itm-lm'}{'ports'}{'tcp'}{'2828'}++	; 
#	$ports_ref->{'tcp'}{'2828'}{'name'} = 'itm-lm'		; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'port'}{'udp'} = '2715'	; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'ports'}{'udp'}{'2715'}++	; 
#	$ports_ref->{'udp'}{'2715'}{'name'} = 'hpstgmgr2'		; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'port'}{'tcp'} = '2715'	; 
#	$srvcobjects_ref->{'hpstgmgr2'}{'ports'}{'tcp'}{'2715'}++	; 
#	$ports_ref->{'tcp'}{'2715'}{'name'} = 'hpstgmgr2'		; 
#	$srvcobjects_ref->{'bcs-broker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bcs-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bcs-broker'}{'port'}{'udp'} = '1704'	; 
#	$srvcobjects_ref->{'bcs-broker'}{'ports'}{'udp'}{'1704'}++	; 
#	$ports_ref->{'udp'}{'1704'}{'name'} = 'bcs-broker'		; 
#	$srvcobjects_ref->{'bcs-broker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bcs-broker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bcs-broker'}{'port'}{'tcp'} = '1704'	; 
#	$srvcobjects_ref->{'bcs-broker'}{'ports'}{'tcp'}{'1704'}++	; 
#	$ports_ref->{'tcp'}{'1704'}{'name'} = 'bcs-broker'		; 
#	$srvcobjects_ref->{'bacula-dir'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bacula-dir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacula-dir'}{'port'}{'udp'} = '9101'	; 
#	$srvcobjects_ref->{'bacula-dir'}{'ports'}{'udp'}{'9101'}++	; 
#	$ports_ref->{'udp'}{'9101'}{'name'} = 'bacula-dir'		; 
#	$srvcobjects_ref->{'bacula-dir'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bacula-dir'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacula-dir'}{'port'}{'tcp'} = '9101'	; 
#	$srvcobjects_ref->{'bacula-dir'}{'ports'}{'tcp'}{'9101'}++	; 
#	$ports_ref->{'tcp'}{'9101'}{'name'} = 'bacula-dir'		; 
#	$srvcobjects_ref->{'winpharaoh'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'winpharaoh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winpharaoh'}{'port'}{'udp'} = '6065'	; 
#	$srvcobjects_ref->{'winpharaoh'}{'ports'}{'udp'}{'6065'}++	; 
#	$ports_ref->{'udp'}{'6065'}{'name'} = 'winpharaoh'		; 
#	$srvcobjects_ref->{'winpharaoh'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'winpharaoh'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'winpharaoh'}{'port'}{'tcp'} = '6065'	; 
#	$srvcobjects_ref->{'winpharaoh'}{'ports'}{'tcp'}{'6065'}++	; 
#	$ports_ref->{'tcp'}{'6065'}{'name'} = 'winpharaoh'		; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'port'}{'udp'} = '616'	; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'ports'}{'udp'}{'616'}++	; 
#	$ports_ref->{'udp'}{'616'}{'name'} = 'sco-sysmgr'		; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'port'}{'tcp'} = '616'	; 
#	$srvcobjects_ref->{'sco-sysmgr'}{'ports'}{'tcp'}{'616'}++	; 
#	$ports_ref->{'tcp'}{'616'}{'name'} = 'sco-sysmgr'		; 
#	$srvcobjects_ref->{'netclip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netclip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netclip'}{'port'}{'udp'} = '2971'	; 
#	$srvcobjects_ref->{'netclip'}{'ports'}{'udp'}{'2971'}++	; 
#	$ports_ref->{'udp'}{'2971'}{'name'} = 'netclip'		; 
#	$srvcobjects_ref->{'netclip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netclip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netclip'}{'port'}{'tcp'} = '2971'	; 
#	$srvcobjects_ref->{'netclip'}{'ports'}{'tcp'}{'2971'}++	; 
#	$ports_ref->{'tcp'}{'2971'}{'name'} = 'netclip'		; 
#	$srvcobjects_ref->{'nucleus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nucleus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nucleus'}{'port'}{'udp'} = '1463'	; 
#	$srvcobjects_ref->{'nucleus'}{'ports'}{'udp'}{'1463'}++	; 
#	$ports_ref->{'udp'}{'1463'}{'name'} = 'nucleus'		; 
#	$srvcobjects_ref->{'nucleus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nucleus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nucleus'}{'port'}{'tcp'} = '1463'	; 
#	$srvcobjects_ref->{'nucleus'}{'ports'}{'tcp'}{'1463'}++	; 
#	$ports_ref->{'tcp'}{'1463'}{'name'} = 'nucleus'		; 
#	$srvcobjects_ref->{'xo-wave'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xo-wave'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xo-wave'}{'port'}{'udp'} = '3763'	; 
#	$srvcobjects_ref->{'xo-wave'}{'ports'}{'udp'}{'3763'}++	; 
#	$ports_ref->{'udp'}{'3763'}{'name'} = 'xo-wave'		; 
#	$srvcobjects_ref->{'xo-wave'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xo-wave'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xo-wave'}{'port'}{'tcp'} = '3763'	; 
#	$srvcobjects_ref->{'xo-wave'}{'ports'}{'tcp'}{'3763'}++	; 
#	$ports_ref->{'tcp'}{'3763'}{'name'} = 'xo-wave'		; 
#	$srvcobjects_ref->{'remoteware-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'remoteware-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remoteware-srv'}{'port'}{'udp'} = '3002'	; 
#	$srvcobjects_ref->{'remoteware-srv'}{'ports'}{'udp'}{'3002'}++	; 
#	$ports_ref->{'udp'}{'3002'}{'name'} = 'remoteware-srv'		; 
#	$srvcobjects_ref->{'remoteware-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'remoteware-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'remoteware-srv'}{'port'}{'tcp'} = '3002'	; 
#	$srvcobjects_ref->{'remoteware-srv'}{'ports'}{'tcp'}{'3002'}++	; 
#	$ports_ref->{'tcp'}{'3002'}{'name'} = 'remoteware-srv'		; 
#	$srvcobjects_ref->{'photuris'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'photuris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'photuris'}{'port'}{'udp'} = '468'	; 
#	$srvcobjects_ref->{'photuris'}{'ports'}{'udp'}{'468'}++	; 
#	$ports_ref->{'udp'}{'468'}{'name'} = 'photuris'		; 
#	$srvcobjects_ref->{'photuris'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'photuris'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'photuris'}{'port'}{'tcp'} = '468'	; 
#	$srvcobjects_ref->{'photuris'}{'ports'}{'tcp'}{'468'}++	; 
#	$ports_ref->{'tcp'}{'468'}{'name'} = 'photuris'		; 
#	$srvcobjects_ref->{'snifferserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snifferserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snifferserver'}{'port'}{'udp'} = '2533'	; 
#	$srvcobjects_ref->{'snifferserver'}{'ports'}{'udp'}{'2533'}++	; 
#	$ports_ref->{'udp'}{'2533'}{'name'} = 'snifferserver'		; 
#	$srvcobjects_ref->{'snifferserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snifferserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snifferserver'}{'port'}{'tcp'} = '2533'	; 
#	$srvcobjects_ref->{'snifferserver'}{'ports'}{'tcp'}{'2533'}++	; 
#	$ports_ref->{'tcp'}{'2533'}{'name'} = 'snifferserver'		; 
#	$srvcobjects_ref->{'gcsp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gcsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gcsp'}{'port'}{'udp'} = '3429'	; 
#	$srvcobjects_ref->{'gcsp'}{'ports'}{'udp'}{'3429'}++	; 
#	$ports_ref->{'udp'}{'3429'}{'name'} = 'gcsp'		; 
#	$srvcobjects_ref->{'gcsp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gcsp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gcsp'}{'port'}{'tcp'} = '3429'	; 
#	$srvcobjects_ref->{'gcsp'}{'ports'}{'tcp'}{'3429'}++	; 
#	$ports_ref->{'tcp'}{'3429'}{'name'} = 'gcsp'		; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'port'}{'udp'} = '3077'	; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'ports'}{'udp'}{'3077'}++	; 
#	$ports_ref->{'udp'}{'3077'}{'name'} = 'orbix-loc-ssl'		; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'port'}{'tcp'} = '3077'	; 
#	$srvcobjects_ref->{'orbix-loc-ssl'}{'ports'}{'tcp'}{'3077'}++	; 
#	$ports_ref->{'tcp'}{'3077'}{'name'} = 'orbix-loc-ssl'		; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'port'}{'udp'} = '4017'	; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'ports'}{'udp'}{'4017'}++	; 
#	$ports_ref->{'udp'}{'4017'}{'name'} = 'talarian-mcast3'		; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'port'}{'tcp'} = '4017'	; 
#	$srvcobjects_ref->{'talarian-mcast3'}{'ports'}{'tcp'}{'4017'}++	; 
#	$ports_ref->{'tcp'}{'4017'}{'name'} = 'talarian-mcast3'		; 
#	$srvcobjects_ref->{'netware-csp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netware-csp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netware-csp'}{'port'}{'udp'} = '1366'	; 
#	$srvcobjects_ref->{'netware-csp'}{'ports'}{'udp'}{'1366'}++	; 
#	$ports_ref->{'udp'}{'1366'}{'name'} = 'netware-csp'		; 
#	$srvcobjects_ref->{'netware-csp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netware-csp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netware-csp'}{'port'}{'tcp'} = '1366'	; 
#	$srvcobjects_ref->{'netware-csp'}{'ports'}{'tcp'}{'1366'}++	; 
#	$ports_ref->{'tcp'}{'1366'}{'name'} = 'netware-csp'		; 
#	$srvcobjects_ref->{'seagulllms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'seagulllms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seagulllms'}{'port'}{'udp'} = '1291'	; 
#	$srvcobjects_ref->{'seagulllms'}{'ports'}{'udp'}{'1291'}++	; 
#	$ports_ref->{'udp'}{'1291'}{'name'} = 'seagulllms'		; 
#	$srvcobjects_ref->{'seagulllms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'seagulllms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seagulllms'}{'port'}{'tcp'} = '1291'	; 
#	$srvcobjects_ref->{'seagulllms'}{'ports'}{'tcp'}{'1291'}++	; 
#	$ports_ref->{'tcp'}{'1291'}{'name'} = 'seagulllms'		; 
#	$srvcobjects_ref->{'ticf-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ticf-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ticf-1'}{'port'}{'udp'} = '492'	; 
#	$srvcobjects_ref->{'ticf-1'}{'ports'}{'udp'}{'492'}++	; 
#	$ports_ref->{'udp'}{'492'}{'name'} = 'ticf-1'		; 
#	$srvcobjects_ref->{'ticf-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ticf-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ticf-1'}{'port'}{'tcp'} = '492'	; 
#	$srvcobjects_ref->{'ticf-1'}{'ports'}{'tcp'}{'492'}++	; 
#	$ports_ref->{'tcp'}{'492'}{'name'} = 'ticf-1'		; 
#	$srvcobjects_ref->{'redstorm_info'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'redstorm_info'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_info'}{'port'}{'udp'} = '2348'	; 
#	$srvcobjects_ref->{'redstorm_info'}{'ports'}{'udp'}{'2348'}++	; 
#	$ports_ref->{'udp'}{'2348'}{'name'} = 'redstorm_info'		; 
#	$srvcobjects_ref->{'redstorm_info'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'redstorm_info'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_info'}{'port'}{'tcp'} = '2348'	; 
#	$srvcobjects_ref->{'redstorm_info'}{'ports'}{'tcp'}{'2348'}++	; 
#	$ports_ref->{'tcp'}{'2348'}{'name'} = 'redstorm_info'		; 
#	$srvcobjects_ref->{'proactivesrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proactivesrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proactivesrvr'}{'port'}{'udp'} = '2722'	; 
#	$srvcobjects_ref->{'proactivesrvr'}{'ports'}{'udp'}{'2722'}++	; 
#	$ports_ref->{'udp'}{'2722'}{'name'} = 'proactivesrvr'		; 
#	$srvcobjects_ref->{'proactivesrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proactivesrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proactivesrvr'}{'port'}{'tcp'} = '2722'	; 
#	$srvcobjects_ref->{'proactivesrvr'}{'ports'}{'tcp'}{'2722'}++	; 
#	$ports_ref->{'tcp'}{'2722'}{'name'} = 'proactivesrvr'		; 
#	$srvcobjects_ref->{'qftest-lookup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qftest-lookup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qftest-lookup'}{'port'}{'udp'} = '3543'	; 
#	$srvcobjects_ref->{'qftest-lookup'}{'ports'}{'udp'}{'3543'}++	; 
#	$ports_ref->{'udp'}{'3543'}{'name'} = 'qftest-lookup'		; 
#	$srvcobjects_ref->{'qftest-lookup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qftest-lookup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qftest-lookup'}{'port'}{'tcp'} = '3543'	; 
#	$srvcobjects_ref->{'qftest-lookup'}{'ports'}{'tcp'}{'3543'}++	; 
#	$ports_ref->{'tcp'}{'3543'}{'name'} = 'qftest-lookup'		; 
#	$srvcobjects_ref->{'callwaveiam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'callwaveiam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'callwaveiam'}{'port'}{'udp'} = '9283'	; 
#	$srvcobjects_ref->{'callwaveiam'}{'ports'}{'udp'}{'9283'}++	; 
#	$ports_ref->{'udp'}{'9283'}{'name'} = 'callwaveiam'		; 
#	$srvcobjects_ref->{'callwaveiam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'callwaveiam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'callwaveiam'}{'port'}{'tcp'} = '9283'	; 
#	$srvcobjects_ref->{'callwaveiam'}{'ports'}{'tcp'}{'9283'}++	; 
#	$ports_ref->{'tcp'}{'9283'}{'name'} = 'callwaveiam'		; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'port'}{'udp'} = '3602'	; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'ports'}{'udp'}{'3602'}++	; 
#	$ports_ref->{'udp'}{'3602'}{'name'} = 'infiniswitchcl'		; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'port'}{'tcp'} = '3602'	; 
#	$srvcobjects_ref->{'infiniswitchcl'}{'ports'}{'tcp'}{'3602'}++	; 
#	$ports_ref->{'tcp'}{'3602'}{'name'} = 'infiniswitchcl'		; 
#	$srvcobjects_ref->{'aicc-cmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aicc-cmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aicc-cmi'}{'port'}{'udp'} = '3316'	; 
#	$srvcobjects_ref->{'aicc-cmi'}{'ports'}{'udp'}{'3316'}++	; 
#	$ports_ref->{'udp'}{'3316'}{'name'} = 'aicc-cmi'		; 
#	$srvcobjects_ref->{'aicc-cmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aicc-cmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aicc-cmi'}{'port'}{'tcp'} = '3316'	; 
#	$srvcobjects_ref->{'aicc-cmi'}{'ports'}{'tcp'}{'3316'}++	; 
#	$ports_ref->{'tcp'}{'3316'}{'name'} = 'aicc-cmi'		; 
#	$srvcobjects_ref->{'opennl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opennl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opennl'}{'port'}{'udp'} = '1258'	; 
#	$srvcobjects_ref->{'opennl'}{'ports'}{'udp'}{'1258'}++	; 
#	$ports_ref->{'udp'}{'1258'}{'name'} = 'opennl'		; 
#	$srvcobjects_ref->{'opennl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opennl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opennl'}{'port'}{'tcp'} = '1258'	; 
#	$srvcobjects_ref->{'opennl'}{'ports'}{'tcp'}{'1258'}++	; 
#	$ports_ref->{'tcp'}{'1258'}{'name'} = 'opennl'		; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'port'}{'udp'} = '2305'	; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'ports'}{'udp'}{'2305'}++	; 
#	$ports_ref->{'udp'}{'2305'}{'name'} = 'mt-scaleserver'		; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'port'}{'tcp'} = '2305'	; 
#	$srvcobjects_ref->{'mt-scaleserver'}{'ports'}{'tcp'}{'2305'}++	; 
#	$ports_ref->{'tcp'}{'2305'}{'name'} = 'mt-scaleserver'		; 
#	$srvcobjects_ref->{'abarsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abarsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abarsd'}{'port'}{'udp'} = '8402'	; 
#	$srvcobjects_ref->{'abarsd'}{'ports'}{'udp'}{'8402'}++	; 
#	$ports_ref->{'udp'}{'8402'}{'name'} = 'abarsd'		; 
#	$srvcobjects_ref->{'abarsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abarsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abarsd'}{'port'}{'tcp'} = '8402'	; 
#	$srvcobjects_ref->{'abarsd'}{'ports'}{'tcp'}{'8402'}++	; 
#	$ports_ref->{'tcp'}{'8402'}{'name'} = 'abarsd'		; 
#	$srvcobjects_ref->{'vlsi-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vlsi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vlsi-lm'}{'port'}{'udp'} = '1500'	; 
#	$srvcobjects_ref->{'vlsi-lm'}{'ports'}{'udp'}{'1500'}++	; 
#	$ports_ref->{'udp'}{'1500'}{'name'} = 'vlsi-lm'		; 
#	$srvcobjects_ref->{'vlsi-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vlsi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vlsi-lm'}{'port'}{'tcp'} = '1500'	; 
#	$srvcobjects_ref->{'vlsi-lm'}{'ports'}{'tcp'}{'1500'}++	; 
#	$ports_ref->{'tcp'}{'1500'}{'name'} = 'vlsi-lm'		; 
#	$srvcobjects_ref->{'ehtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ehtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ehtp'}{'port'}{'udp'} = '1295'	; 
#	$srvcobjects_ref->{'ehtp'}{'ports'}{'udp'}{'1295'}++	; 
#	$ports_ref->{'udp'}{'1295'}{'name'} = 'ehtp'		; 
#	$srvcobjects_ref->{'ehtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ehtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ehtp'}{'port'}{'tcp'} = '1295'	; 
#	$srvcobjects_ref->{'ehtp'}{'ports'}{'tcp'}{'1295'}++	; 
#	$ports_ref->{'tcp'}{'1295'}{'name'} = 'ehtp'		; 
#	$srvcobjects_ref->{'tn-tl-r2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tn-tl-r2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tn-tl-r2'}{'port'}{'udp'} = '1580'	; 
#	$srvcobjects_ref->{'tn-tl-r2'}{'ports'}{'udp'}{'1580'}++	; 
#	$ports_ref->{'udp'}{'1580'}{'name'} = 'tn-tl-r2'		; 
#	$srvcobjects_ref->{'bl-idm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bl-idm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bl-idm'}{'port'}{'udp'} = '142'	; 
#	$srvcobjects_ref->{'bl-idm'}{'ports'}{'udp'}{'142'}++	; 
#	$ports_ref->{'udp'}{'142'}{'name'} = 'bl-idm'		; 
#	$srvcobjects_ref->{'bl-idm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bl-idm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bl-idm'}{'port'}{'tcp'} = '142'	; 
#	$srvcobjects_ref->{'bl-idm'}{'ports'}{'tcp'}{'142'}++	; 
#	$ports_ref->{'tcp'}{'142'}{'name'} = 'bl-idm'		; 
#	$srvcobjects_ref->{'ica'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ica'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ica'}{'port'}{'udp'} = '1494'	; 
#	$srvcobjects_ref->{'ica'}{'ports'}{'udp'}{'1494'}++	; 
#	$ports_ref->{'udp'}{'1494'}{'name'} = 'ica'		; 
#	$srvcobjects_ref->{'ica'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ica'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ica'}{'port'}{'tcp'} = '1494'	; 
#	$srvcobjects_ref->{'ica'}{'ports'}{'tcp'}{'1494'}++	; 
#	$ports_ref->{'tcp'}{'1494'}{'name'} = 'ica'		; 
#	$srvcobjects_ref->{'octopus'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'octopus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'octopus'}{'port'}{'udp'} = '10008'	; 
#	$srvcobjects_ref->{'octopus'}{'ports'}{'udp'}{'10008'}++	; 
#	$ports_ref->{'udp'}{'10008'}{'name'} = 'octopus'		; 
#	$srvcobjects_ref->{'octopus'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'octopus'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'octopus'}{'port'}{'tcp'} = '10008'	; 
#	$srvcobjects_ref->{'octopus'}{'ports'}{'tcp'}{'10008'}++	; 
#	$ports_ref->{'tcp'}{'10008'}{'name'} = 'octopus'		; 
#	$srvcobjects_ref->{'ms-olap3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-olap3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap3'}{'port'}{'udp'} = '2382'	; 
#	$srvcobjects_ref->{'ms-olap3'}{'ports'}{'udp'}{'2382'}++	; 
#	$ports_ref->{'udp'}{'2382'}{'name'} = 'ms-olap3'		; 
#	$srvcobjects_ref->{'ms-olap3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-olap3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-olap3'}{'port'}{'tcp'} = '2382'	; 
#	$srvcobjects_ref->{'ms-olap3'}{'ports'}{'tcp'}{'2382'}++	; 
#	$ports_ref->{'tcp'}{'2382'}{'name'} = 'ms-olap3'		; 
#	$srvcobjects_ref->{'bpcd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bpcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpcd'}{'port'}{'udp'} = '13782'	; 
#	$srvcobjects_ref->{'bpcd'}{'ports'}{'udp'}{'13782'}++	; 
#	$ports_ref->{'udp'}{'13782'}{'name'} = 'bpcd'		; 
#	$srvcobjects_ref->{'bpcd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bpcd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpcd'}{'port'}{'tcp'} = '13782'	; 
#	$srvcobjects_ref->{'bpcd'}{'ports'}{'tcp'}{'13782'}++	; 
#	$ports_ref->{'tcp'}{'13782'}{'name'} = 'bpcd'		; 
#	$srvcobjects_ref->{'msims'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msims'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msims'}{'port'}{'udp'} = '1582'	; 
#	$srvcobjects_ref->{'msims'}{'ports'}{'udp'}{'1582'}++	; 
#	$ports_ref->{'udp'}{'1582'}{'name'} = 'msims'		; 
#	$srvcobjects_ref->{'msims'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msims'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msims'}{'port'}{'tcp'} = '1582'	; 
#	$srvcobjects_ref->{'msims'}{'ports'}{'tcp'}{'1582'}++	; 
#	$ports_ref->{'tcp'}{'1582'}{'name'} = 'msims'		; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'port'}{'udp'} = '695'	; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'ports'}{'udp'}{'695'}++	; 
#	$ports_ref->{'udp'}{'695'}{'name'} = 'ieee-mms-ssl'		; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'port'}{'tcp'} = '695'	; 
#	$srvcobjects_ref->{'ieee-mms-ssl'}{'ports'}{'tcp'}{'695'}++	; 
#	$ports_ref->{'tcp'}{'695'}{'name'} = 'ieee-mms-ssl'		; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'port'}{'udp'} = '2896'	; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'ports'}{'udp'}{'2896'}++	; 
#	$ports_ref->{'udp'}{'2896'}{'name'} = 'ecovisiong6-1'		; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'port'}{'tcp'} = '2896'	; 
#	$srvcobjects_ref->{'ecovisiong6-1'}{'ports'}{'tcp'}{'2896'}++	; 
#	$ports_ref->{'tcp'}{'2896'}{'name'} = 'ecovisiong6-1'		; 
#	$srvcobjects_ref->{'ddi-udp-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddi-udp-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddi-udp-2'}{'port'}{'udp'} = '8889'	; 
#	$srvcobjects_ref->{'ddi-udp-2'}{'ports'}{'udp'}{'8889'}++	; 
#	$ports_ref->{'udp'}{'8889'}{'name'} = 'ddi-udp-2'		; 
#	$srvcobjects_ref->{'cichlid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cichlid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cichlid'}{'port'}{'udp'} = '1377'	; 
#	$srvcobjects_ref->{'cichlid'}{'ports'}{'udp'}{'1377'}++	; 
#	$ports_ref->{'udp'}{'1377'}{'name'} = 'cichlid'		; 
#	$srvcobjects_ref->{'cichlid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cichlid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cichlid'}{'port'}{'tcp'} = '1377'	; 
#	$srvcobjects_ref->{'cichlid'}{'ports'}{'tcp'}{'1377'}++	; 
#	$ports_ref->{'tcp'}{'1377'}{'name'} = 'cichlid'		; 
#	$srvcobjects_ref->{'dls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls'}{'port'}{'udp'} = '197'	; 
#	$srvcobjects_ref->{'dls'}{'ports'}{'udp'}{'197'}++	; 
#	$ports_ref->{'udp'}{'197'}{'name'} = 'dls'		; 
#	$srvcobjects_ref->{'dls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls'}{'port'}{'udp'} = '2047'	; 
#	$srvcobjects_ref->{'dls'}{'ports'}{'udp'}{'2047'}++	; 
#	$ports_ref->{'udp'}{'2047'}{'name'} = 'dls'		; 
#	$srvcobjects_ref->{'dls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls'}{'port'}{'tcp'} = '197'	; 
#	$srvcobjects_ref->{'dls'}{'ports'}{'tcp'}{'197'}++	; 
#	$ports_ref->{'tcp'}{'197'}{'name'} = 'dls'		; 
#	$srvcobjects_ref->{'dls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dls'}{'port'}{'tcp'} = '2047'	; 
#	$srvcobjects_ref->{'dls'}{'ports'}{'tcp'}{'2047'}++	; 
#	$ports_ref->{'tcp'}{'2047'}{'name'} = 'dls'		; 
#	$srvcobjects_ref->{'deos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'deos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'deos'}{'port'}{'udp'} = '76'	; 
#	$srvcobjects_ref->{'deos'}{'ports'}{'udp'}{'76'}++	; 
#	$ports_ref->{'udp'}{'76'}{'name'} = 'deos'		; 
#	$srvcobjects_ref->{'deos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'deos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'deos'}{'port'}{'tcp'} = '76'	; 
#	$srvcobjects_ref->{'deos'}{'ports'}{'tcp'}{'76'}++	; 
#	$ports_ref->{'tcp'}{'76'}{'name'} = 'deos'		; 
#	$srvcobjects_ref->{'cddbp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cddbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cddbp'}{'port'}{'tcp'} = '888'	; 
#	$srvcobjects_ref->{'cddbp'}{'ports'}{'tcp'}{'888'}++	; 
#	$ports_ref->{'tcp'}{'888'}{'name'} = 'cddbp'		; 
#	$srvcobjects_ref->{'audio-activmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'audio-activmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audio-activmail'}{'port'}{'udp'} = '1397'	; 
#	$srvcobjects_ref->{'audio-activmail'}{'ports'}{'udp'}{'1397'}++	; 
#	$ports_ref->{'udp'}{'1397'}{'name'} = 'audio-activmail'		; 
#	$srvcobjects_ref->{'audio-activmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'audio-activmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audio-activmail'}{'port'}{'tcp'} = '1397'	; 
#	$srvcobjects_ref->{'audio-activmail'}{'ports'}{'tcp'}{'1397'}++	; 
#	$ports_ref->{'tcp'}{'1397'}{'name'} = 'audio-activmail'		; 
#	$srvcobjects_ref->{'powwow-client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'powwow-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powwow-client'}{'port'}{'udp'} = '13223'	; 
#	$srvcobjects_ref->{'powwow-client'}{'ports'}{'udp'}{'13223'}++	; 
#	$ports_ref->{'udp'}{'13223'}{'name'} = 'powwow-client'		; 
#	$srvcobjects_ref->{'powwow-client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'powwow-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'powwow-client'}{'port'}{'tcp'} = '13223'	; 
#	$srvcobjects_ref->{'powwow-client'}{'ports'}{'tcp'}{'13223'}++	; 
#	$ports_ref->{'tcp'}{'13223'}{'name'} = 'powwow-client'		; 
#	$srvcobjects_ref->{'directplaysrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directplaysrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directplaysrvr'}{'port'}{'udp'} = '47624'	; 
#	$srvcobjects_ref->{'directplaysrvr'}{'ports'}{'udp'}{'47624'}++	; 
#	$ports_ref->{'udp'}{'47624'}{'name'} = 'directplaysrvr'		; 
#	$srvcobjects_ref->{'directplaysrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directplaysrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directplaysrvr'}{'port'}{'tcp'} = '47624'	; 
#	$srvcobjects_ref->{'directplaysrvr'}{'ports'}{'tcp'}{'47624'}++	; 
#	$ports_ref->{'tcp'}{'47624'}{'name'} = 'directplaysrvr'		; 
#	$srvcobjects_ref->{'tempo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tempo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tempo'}{'port'}{'udp'} = '526'	; 
#	$srvcobjects_ref->{'tempo'}{'ports'}{'udp'}{'526'}++	; 
#	$ports_ref->{'udp'}{'526'}{'name'} = 'tempo'		; 
#	$srvcobjects_ref->{'tempo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tempo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tempo'}{'port'}{'tcp'} = '526'	; 
#	$srvcobjects_ref->{'tempo'}{'ports'}{'tcp'}{'526'}++	; 
#	$ports_ref->{'tcp'}{'526'}{'name'} = 'tempo'		; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'port'}{'udp'} = '1461'	; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'ports'}{'udp'}{'1461'}++	; 
#	$ports_ref->{'udp'}{'1461'}{'name'} = 'ibm_wrless_lan'		; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'port'}{'tcp'} = '1461'	; 
#	$srvcobjects_ref->{'ibm_wrless_lan'}{'ports'}{'tcp'}{'1461'}++	; 
#	$ports_ref->{'tcp'}{'1461'}{'name'} = 'ibm_wrless_lan'		; 
#	$srvcobjects_ref->{'bhoedap4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bhoedap4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhoedap4'}{'port'}{'udp'} = '352'	; 
#	$srvcobjects_ref->{'bhoedap4'}{'ports'}{'udp'}{'352'}++	; 
#	$ports_ref->{'udp'}{'352'}{'name'} = 'bhoedap4'		; 
#	$srvcobjects_ref->{'bhoedap4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bhoedap4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhoedap4'}{'port'}{'tcp'} = '352'	; 
#	$srvcobjects_ref->{'bhoedap4'}{'ports'}{'tcp'}{'352'}++	; 
#	$ports_ref->{'tcp'}{'352'}{'name'} = 'bhoedap4'		; 
#	$srvcobjects_ref->{'device'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'device'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'device'}{'port'}{'udp'} = '801'	; 
#	$srvcobjects_ref->{'device'}{'ports'}{'udp'}{'801'}++	; 
#	$ports_ref->{'udp'}{'801'}{'name'} = 'device'		; 
#	$srvcobjects_ref->{'device'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'device'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'device'}{'port'}{'tcp'} = '801'	; 
#	$srvcobjects_ref->{'device'}{'ports'}{'tcp'}{'801'}++	; 
#	$ports_ref->{'tcp'}{'801'}{'name'} = 'device'		; 
#	$srvcobjects_ref->{'pt2-discover'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pt2-discover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pt2-discover'}{'port'}{'udp'} = '1101'	; 
#	$srvcobjects_ref->{'pt2-discover'}{'ports'}{'udp'}{'1101'}++	; 
#	$ports_ref->{'udp'}{'1101'}{'name'} = 'pt2-discover'		; 
#	$srvcobjects_ref->{'pt2-discover'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pt2-discover'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pt2-discover'}{'port'}{'tcp'} = '1101'	; 
#	$srvcobjects_ref->{'pt2-discover'}{'ports'}{'tcp'}{'1101'}++	; 
#	$ports_ref->{'tcp'}{'1101'}{'name'} = 'pt2-discover'		; 
#	$srvcobjects_ref->{'media-agent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'media-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'media-agent'}{'port'}{'udp'} = '2789'	; 
#	$srvcobjects_ref->{'media-agent'}{'ports'}{'udp'}{'2789'}++	; 
#	$ports_ref->{'udp'}{'2789'}{'name'} = 'media-agent'		; 
#	$srvcobjects_ref->{'media-agent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'media-agent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'media-agent'}{'port'}{'tcp'} = '2789'	; 
#	$srvcobjects_ref->{'media-agent'}{'ports'}{'tcp'}{'2789'}++	; 
#	$ports_ref->{'tcp'}{'2789'}{'name'} = 'media-agent'		; 
#	$srvcobjects_ref->{'telops-lmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telops-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telops-lmd'}{'port'}{'udp'} = '7491'	; 
#	$srvcobjects_ref->{'telops-lmd'}{'ports'}{'udp'}{'7491'}++	; 
#	$ports_ref->{'udp'}{'7491'}{'name'} = 'telops-lmd'		; 
#	$srvcobjects_ref->{'telops-lmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telops-lmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telops-lmd'}{'port'}{'tcp'} = '7491'	; 
#	$srvcobjects_ref->{'telops-lmd'}{'ports'}{'tcp'}{'7491'}++	; 
#	$ports_ref->{'tcp'}{'7491'}{'name'} = 'telops-lmd'		; 
#	$srvcobjects_ref->{'dnp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnp'}{'port'}{'udp'} = '20000'	; 
#	$srvcobjects_ref->{'dnp'}{'ports'}{'udp'}{'20000'}++	; 
#	$ports_ref->{'udp'}{'20000'}{'name'} = 'dnp'		; 
#	$srvcobjects_ref->{'dnp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dnp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dnp'}{'port'}{'tcp'} = '20000'	; 
#	$srvcobjects_ref->{'dnp'}{'ports'}{'tcp'}{'20000'}++	; 
#	$ports_ref->{'tcp'}{'20000'}{'name'} = 'dnp'		; 
#	$srvcobjects_ref->{'nut'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nut'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nut'}{'port'}{'udp'} = '3493'	; 
#	$srvcobjects_ref->{'nut'}{'ports'}{'udp'}{'3493'}++	; 
#	$ports_ref->{'udp'}{'3493'}{'name'} = 'nut'		; 
#	$srvcobjects_ref->{'nut'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nut'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nut'}{'port'}{'tcp'} = '3493'	; 
#	$srvcobjects_ref->{'nut'}{'ports'}{'tcp'}{'3493'}++	; 
#	$ports_ref->{'tcp'}{'3493'}{'name'} = 'nut'		; 
#	$srvcobjects_ref->{'glishd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'glishd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glishd'}{'port'}{'udp'} = '2833'	; 
#	$srvcobjects_ref->{'glishd'}{'ports'}{'udp'}{'2833'}++	; 
#	$ports_ref->{'udp'}{'2833'}{'name'} = 'glishd'		; 
#	$srvcobjects_ref->{'glishd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'glishd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glishd'}{'port'}{'tcp'} = '2833'	; 
#	$srvcobjects_ref->{'glishd'}{'ports'}{'tcp'}{'2833'}++	; 
#	$ports_ref->{'tcp'}{'2833'}{'name'} = 'glishd'		; 
#	$srvcobjects_ref->{'idcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idcp'}{'port'}{'udp'} = '2326'	; 
#	$srvcobjects_ref->{'idcp'}{'ports'}{'udp'}{'2326'}++	; 
#	$ports_ref->{'udp'}{'2326'}{'name'} = 'idcp'		; 
#	$srvcobjects_ref->{'idcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idcp'}{'port'}{'tcp'} = '2326'	; 
#	$srvcobjects_ref->{'idcp'}{'ports'}{'tcp'}{'2326'}++	; 
#	$ports_ref->{'tcp'}{'2326'}{'name'} = 'idcp'		; 
#	$srvcobjects_ref->{'3m-image-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'3m-image-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3m-image-lm'}{'port'}{'udp'} = '1550'	; 
#	$srvcobjects_ref->{'3m-image-lm'}{'ports'}{'udp'}{'1550'}++	; 
#	$ports_ref->{'udp'}{'1550'}{'name'} = '3m-image-lm'		; 
#	$srvcobjects_ref->{'3m-image-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'3m-image-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'3m-image-lm'}{'port'}{'tcp'} = '1550'	; 
#	$srvcobjects_ref->{'3m-image-lm'}{'ports'}{'tcp'}{'1550'}++	; 
#	$ports_ref->{'tcp'}{'1550'}{'name'} = '3m-image-lm'		; 
#	$srvcobjects_ref->{'sane-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sane-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sane-port'}{'port'}{'udp'} = '6566'	; 
#	$srvcobjects_ref->{'sane-port'}{'ports'}{'udp'}{'6566'}++	; 
#	$ports_ref->{'udp'}{'6566'}{'name'} = 'sane-port'		; 
#	$srvcobjects_ref->{'sane-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sane-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sane-port'}{'port'}{'tcp'} = '6566'	; 
#	$srvcobjects_ref->{'sane-port'}{'ports'}{'tcp'}{'6566'}++	; 
#	$ports_ref->{'tcp'}{'6566'}{'name'} = 'sane-port'		; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'port'}{'udp'} = '318'	; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'ports'}{'udp'}{'318'}++	; 
#	$ports_ref->{'udp'}{'318'}{'name'} = 'pkix-timestamp'		; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'port'}{'tcp'} = '318'	; 
#	$srvcobjects_ref->{'pkix-timestamp'}{'ports'}{'tcp'}{'318'}++	; 
#	$ports_ref->{'tcp'}{'318'}{'name'} = 'pkix-timestamp'		; 
#	$srvcobjects_ref->{'troff'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'troff'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'troff'}{'port'}{'tcp'} = '2014'	; 
#	$srvcobjects_ref->{'troff'}{'ports'}{'tcp'}{'2014'}++	; 
#	$ports_ref->{'tcp'}{'2014'}{'name'} = 'troff'		; 
#	$srvcobjects_ref->{'urld-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'urld-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'urld-port'}{'port'}{'udp'} = '3534'	; 
#	$srvcobjects_ref->{'urld-port'}{'ports'}{'udp'}{'3534'}++	; 
#	$ports_ref->{'udp'}{'3534'}{'name'} = 'urld-port'		; 
#	$srvcobjects_ref->{'urld-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'urld-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'urld-port'}{'port'}{'tcp'} = '3534'	; 
#	$srvcobjects_ref->{'urld-port'}{'ports'}{'tcp'}{'3534'}++	; 
#	$ports_ref->{'tcp'}{'3534'}{'name'} = 'urld-port'		; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'port'}{'udp'} = '3180'	; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'ports'}{'udp'}{'3180'}++	; 
#	$ports_ref->{'udp'}{'3180'}{'name'} = 'mc-brk-srv'		; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'port'}{'tcp'} = '3180'	; 
#	$srvcobjects_ref->{'mc-brk-srv'}{'ports'}{'tcp'}{'3180'}++	; 
#	$ports_ref->{'tcp'}{'3180'}{'name'} = 'mc-brk-srv'		; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'port'}{'udp'} = '2874'	; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'ports'}{'udp'}{'2874'}++	; 
#	$ports_ref->{'udp'}{'2874'}{'name'} = 'dxmessagebase1'		; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'port'}{'tcp'} = '2874'	; 
#	$srvcobjects_ref->{'dxmessagebase1'}{'ports'}{'tcp'}{'2874'}++	; 
#	$ports_ref->{'tcp'}{'2874'}{'name'} = 'dxmessagebase1'		; 
#	$srvcobjects_ref->{'pammratc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pammratc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pammratc'}{'port'}{'udp'} = '1632'	; 
#	$srvcobjects_ref->{'pammratc'}{'ports'}{'udp'}{'1632'}++	; 
#	$ports_ref->{'udp'}{'1632'}{'name'} = 'pammratc'		; 
#	$srvcobjects_ref->{'pammratc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pammratc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pammratc'}{'port'}{'tcp'} = '1632'	; 
#	$srvcobjects_ref->{'pammratc'}{'ports'}{'tcp'}{'1632'}++	; 
#	$ports_ref->{'tcp'}{'1632'}{'name'} = 'pammratc'		; 
#	$srvcobjects_ref->{'bctp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bctp'}{'port'}{'udp'} = '8999'	; 
#	$srvcobjects_ref->{'bctp'}{'ports'}{'udp'}{'8999'}++	; 
#	$ports_ref->{'udp'}{'8999'}{'name'} = 'bctp'		; 
#	$srvcobjects_ref->{'bctp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bctp'}{'port'}{'tcp'} = '8999'	; 
#	$srvcobjects_ref->{'bctp'}{'ports'}{'tcp'}{'8999'}++	; 
#	$ports_ref->{'tcp'}{'8999'}{'name'} = 'bctp'		; 
#	$srvcobjects_ref->{'escvpnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'escvpnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'escvpnet'}{'port'}{'udp'} = '3629'	; 
#	$srvcobjects_ref->{'escvpnet'}{'ports'}{'udp'}{'3629'}++	; 
#	$ports_ref->{'udp'}{'3629'}{'name'} = 'escvpnet'		; 
#	$srvcobjects_ref->{'escvpnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'escvpnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'escvpnet'}{'port'}{'tcp'} = '3629'	; 
#	$srvcobjects_ref->{'escvpnet'}{'ports'}{'tcp'}{'3629'}++	; 
#	$ports_ref->{'tcp'}{'3629'}{'name'} = 'escvpnet'		; 
#	$srvcobjects_ref->{'vpnz'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpnz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpnz'}{'port'}{'udp'} = '1224'	; 
#	$srvcobjects_ref->{'vpnz'}{'ports'}{'udp'}{'1224'}++	; 
#	$ports_ref->{'udp'}{'1224'}{'name'} = 'vpnz'		; 
#	$srvcobjects_ref->{'vpnz'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpnz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpnz'}{'port'}{'tcp'} = '1224'	; 
#	$srvcobjects_ref->{'vpnz'}{'ports'}{'tcp'}{'1224'}++	; 
#	$ports_ref->{'tcp'}{'1224'}{'name'} = 'vpnz'		; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'port'}{'udp'} = '3626'	; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'ports'}{'udp'}{'3626'}++	; 
#	$ports_ref->{'udp'}{'3626'}{'name'} = 'bvcdaemon-port'		; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'port'}{'tcp'} = '3626'	; 
#	$srvcobjects_ref->{'bvcdaemon-port'}{'ports'}{'tcp'}{'3626'}++	; 
#	$ports_ref->{'tcp'}{'3626'}{'name'} = 'bvcdaemon-port'		; 
#	$srvcobjects_ref->{'rtmp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtmp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtmp-port'}{'port'}{'udp'} = '3500'	; 
#	$srvcobjects_ref->{'rtmp-port'}{'ports'}{'udp'}{'3500'}++	; 
#	$ports_ref->{'udp'}{'3500'}{'name'} = 'rtmp-port'		; 
#	$srvcobjects_ref->{'rtmp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtmp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtmp-port'}{'port'}{'tcp'} = '3500'	; 
#	$srvcobjects_ref->{'rtmp-port'}{'ports'}{'tcp'}{'3500'}++	; 
#	$ports_ref->{'tcp'}{'3500'}{'name'} = 'rtmp-port'		; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'port'}{'udp'} = '2678'	; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'ports'}{'udp'}{'2678'}++	; 
#	$ports_ref->{'udp'}{'2678'}{'name'} = 'gadgetgate2way'		; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'port'}{'tcp'} = '2678'	; 
#	$srvcobjects_ref->{'gadgetgate2way'}{'ports'}{'tcp'}{'2678'}++	; 
#	$ports_ref->{'tcp'}{'2678'}{'name'} = 'gadgetgate2way'		; 
#	$srvcobjects_ref->{'polestar'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'polestar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'polestar'}{'port'}{'udp'} = '1060'	; 
#	$srvcobjects_ref->{'polestar'}{'ports'}{'udp'}{'1060'}++	; 
#	$ports_ref->{'udp'}{'1060'}{'name'} = 'polestar'		; 
#	$srvcobjects_ref->{'polestar'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'polestar'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'polestar'}{'port'}{'tcp'} = '1060'	; 
#	$srvcobjects_ref->{'polestar'}{'ports'}{'tcp'}{'1060'}++	; 
#	$ports_ref->{'tcp'}{'1060'}{'name'} = 'polestar'		; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'port'}{'udp'} = '10114'	; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'ports'}{'udp'}{'10114'}++	; 
#	$ports_ref->{'udp'}{'10114'}{'name'} = 'netiq-qcheck'		; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'port'}{'tcp'} = '10114'	; 
#	$srvcobjects_ref->{'netiq-qcheck'}{'ports'}{'tcp'}{'10114'}++	; 
#	$ports_ref->{'tcp'}{'10114'}{'name'} = 'netiq-qcheck'		; 
#	$srvcobjects_ref->{'onmux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'onmux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'onmux'}{'port'}{'udp'} = '417'	; 
#	$srvcobjects_ref->{'onmux'}{'ports'}{'udp'}{'417'}++	; 
#	$ports_ref->{'udp'}{'417'}{'name'} = 'onmux'		; 
#	$srvcobjects_ref->{'onmux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'onmux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'onmux'}{'port'}{'tcp'} = '417'	; 
#	$srvcobjects_ref->{'onmux'}{'ports'}{'tcp'}{'417'}++	; 
#	$ports_ref->{'tcp'}{'417'}{'name'} = 'onmux'		; 
#	$srvcobjects_ref->{'cumulus-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cumulus-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cumulus-admin'}{'port'}{'udp'} = '8954'	; 
#	$srvcobjects_ref->{'cumulus-admin'}{'ports'}{'udp'}{'8954'}++	; 
#	$ports_ref->{'udp'}{'8954'}{'name'} = 'cumulus-admin'		; 
#	$srvcobjects_ref->{'cumulus-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cumulus-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cumulus-admin'}{'port'}{'tcp'} = '8954'	; 
#	$srvcobjects_ref->{'cumulus-admin'}{'ports'}{'tcp'}{'8954'}++	; 
#	$ports_ref->{'tcp'}{'8954'}{'name'} = 'cumulus-admin'		; 
#	$srvcobjects_ref->{'clariion-evr01'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'clariion-evr01'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clariion-evr01'}{'port'}{'udp'} = '6389'	; 
#	$srvcobjects_ref->{'clariion-evr01'}{'ports'}{'udp'}{'6389'}++	; 
#	$ports_ref->{'udp'}{'6389'}{'name'} = 'clariion-evr01'		; 
#	$srvcobjects_ref->{'clariion-evr01'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'clariion-evr01'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'clariion-evr01'}{'port'}{'tcp'} = '6389'	; 
#	$srvcobjects_ref->{'clariion-evr01'}{'ports'}{'tcp'}{'6389'}++	; 
#	$ports_ref->{'tcp'}{'6389'}{'name'} = 'clariion-evr01'		; 
#	$srvcobjects_ref->{'veritas-vis1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'veritas-vis1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-vis1'}{'port'}{'udp'} = '2993'	; 
#	$srvcobjects_ref->{'veritas-vis1'}{'ports'}{'udp'}{'2993'}++	; 
#	$ports_ref->{'udp'}{'2993'}{'name'} = 'veritas-vis1'		; 
#	$srvcobjects_ref->{'veritas-vis1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'veritas-vis1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'veritas-vis1'}{'port'}{'tcp'} = '2993'	; 
#	$srvcobjects_ref->{'veritas-vis1'}{'ports'}{'tcp'}{'2993'}++	; 
#	$ports_ref->{'tcp'}{'2993'}{'name'} = 'veritas-vis1'		; 
#	$srvcobjects_ref->{'direcpc-dll'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'direcpc-dll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direcpc-dll'}{'port'}{'udp'} = '1844'	; 
#	$srvcobjects_ref->{'direcpc-dll'}{'ports'}{'udp'}{'1844'}++	; 
#	$ports_ref->{'udp'}{'1844'}{'name'} = 'direcpc-dll'		; 
#	$srvcobjects_ref->{'direcpc-dll'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'direcpc-dll'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'direcpc-dll'}{'port'}{'tcp'} = '1844'	; 
#	$srvcobjects_ref->{'direcpc-dll'}{'ports'}{'tcp'}{'1844'}++	; 
#	$ports_ref->{'tcp'}{'1844'}{'name'} = 'direcpc-dll'		; 
#	$srvcobjects_ref->{'pdrncs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdrncs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdrncs'}{'port'}{'udp'} = '3299'	; 
#	$srvcobjects_ref->{'pdrncs'}{'ports'}{'udp'}{'3299'}++	; 
#	$ports_ref->{'udp'}{'3299'}{'name'} = 'pdrncs'		; 
#	$srvcobjects_ref->{'pdrncs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdrncs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdrncs'}{'port'}{'tcp'} = '3299'	; 
#	$srvcobjects_ref->{'pdrncs'}{'ports'}{'tcp'}{'3299'}++	; 
#	$ports_ref->{'tcp'}{'3299'}{'name'} = 'pdrncs'		; 
#	$srvcobjects_ref->{'necp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'necp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'necp'}{'port'}{'udp'} = '3262'	; 
#	$srvcobjects_ref->{'necp'}{'ports'}{'udp'}{'3262'}++	; 
#	$ports_ref->{'udp'}{'3262'}{'name'} = 'necp'		; 
#	$srvcobjects_ref->{'necp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'necp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'necp'}{'port'}{'tcp'} = '3262'	; 
#	$srvcobjects_ref->{'necp'}{'ports'}{'tcp'}{'3262'}++	; 
#	$ports_ref->{'tcp'}{'3262'}{'name'} = 'necp'		; 
#	$srvcobjects_ref->{'rpasswd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rpasswd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rpasswd'}{'port'}{'tcp'} = '774'	; 
#	$srvcobjects_ref->{'rpasswd'}{'ports'}{'tcp'}{'774'}++	; 
#	$ports_ref->{'tcp'}{'774'}{'name'} = 'rpasswd'		; 
#	$srvcobjects_ref->{'submitserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'submitserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'submitserver'}{'port'}{'udp'} = '2028'	; 
#	$srvcobjects_ref->{'submitserver'}{'ports'}{'udp'}{'2028'}++	; 
#	$ports_ref->{'udp'}{'2028'}{'name'} = 'submitserver'		; 
#	$srvcobjects_ref->{'submitserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'submitserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'submitserver'}{'port'}{'tcp'} = '2028'	; 
#	$srvcobjects_ref->{'submitserver'}{'ports'}{'tcp'}{'2028'}++	; 
#	$ports_ref->{'tcp'}{'2028'}{'name'} = 'submitserver'		; 
#	$srvcobjects_ref->{'svs-omagent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'svs-omagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svs-omagent'}{'port'}{'udp'} = '1625'	; 
#	$srvcobjects_ref->{'svs-omagent'}{'ports'}{'udp'}{'1625'}++	; 
#	$ports_ref->{'udp'}{'1625'}{'name'} = 'svs-omagent'		; 
#	$srvcobjects_ref->{'svs-omagent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'svs-omagent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'svs-omagent'}{'port'}{'tcp'} = '1625'	; 
#	$srvcobjects_ref->{'svs-omagent'}{'ports'}{'tcp'}{'1625'}++	; 
#	$ports_ref->{'tcp'}{'1625'}{'name'} = 'svs-omagent'		; 
#	$srvcobjects_ref->{'dab-sti-c'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dab-sti-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dab-sti-c'}{'port'}{'udp'} = '1076'	; 
#	$srvcobjects_ref->{'dab-sti-c'}{'ports'}{'udp'}{'1076'}++	; 
#	$ports_ref->{'udp'}{'1076'}{'name'} = 'dab-sti-c'		; 
#	$srvcobjects_ref->{'dab-sti-c'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dab-sti-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dab-sti-c'}{'port'}{'tcp'} = '1076'	; 
#	$srvcobjects_ref->{'dab-sti-c'}{'ports'}{'tcp'}{'1076'}++	; 
#	$ports_ref->{'tcp'}{'1076'}{'name'} = 'dab-sti-c'		; 
#	$srvcobjects_ref->{'unicontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unicontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unicontrol'}{'port'}{'udp'} = '2499'	; 
#	$srvcobjects_ref->{'unicontrol'}{'ports'}{'udp'}{'2499'}++	; 
#	$ports_ref->{'udp'}{'2499'}{'name'} = 'unicontrol'		; 
#	$srvcobjects_ref->{'unicontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unicontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unicontrol'}{'port'}{'udp'} = '2437'	; 
#	$srvcobjects_ref->{'unicontrol'}{'ports'}{'udp'}{'2437'}++	; 
#	$ports_ref->{'udp'}{'2437'}{'name'} = 'unicontrol'		; 
#	$srvcobjects_ref->{'unicontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unicontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unicontrol'}{'port'}{'tcp'} = '2499'	; 
#	$srvcobjects_ref->{'unicontrol'}{'ports'}{'tcp'}{'2499'}++	; 
#	$ports_ref->{'tcp'}{'2499'}{'name'} = 'unicontrol'		; 
#	$srvcobjects_ref->{'unicontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unicontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unicontrol'}{'port'}{'tcp'} = '2437'	; 
#	$srvcobjects_ref->{'unicontrol'}{'ports'}{'tcp'}{'2437'}++	; 
#	$ports_ref->{'tcp'}{'2437'}{'name'} = 'unicontrol'		; 
#	$srvcobjects_ref->{'badm_pub'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'badm_pub'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'badm_pub'}{'port'}{'udp'} = '6506'	; 
#	$srvcobjects_ref->{'badm_pub'}{'ports'}{'udp'}{'6506'}++	; 
#	$ports_ref->{'udp'}{'6506'}{'name'} = 'badm_pub'		; 
#	$srvcobjects_ref->{'badm_pub'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'badm_pub'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'badm_pub'}{'port'}{'tcp'} = '6506'	; 
#	$srvcobjects_ref->{'badm_pub'}{'ports'}{'tcp'}{'6506'}++	; 
#	$ports_ref->{'tcp'}{'6506'}{'name'} = 'badm_pub'		; 
#	$srvcobjects_ref->{'essweb-gw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'essweb-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'essweb-gw'}{'port'}{'udp'} = '1772'	; 
#	$srvcobjects_ref->{'essweb-gw'}{'ports'}{'udp'}{'1772'}++	; 
#	$ports_ref->{'udp'}{'1772'}{'name'} = 'essweb-gw'		; 
#	$srvcobjects_ref->{'essweb-gw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'essweb-gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'essweb-gw'}{'port'}{'tcp'} = '1772'	; 
#	$srvcobjects_ref->{'essweb-gw'}{'ports'}{'tcp'}{'1772'}++	; 
#	$ports_ref->{'tcp'}{'1772'}{'name'} = 'essweb-gw'		; 
#	$srvcobjects_ref->{'vision_elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vision_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vision_elmd'}{'port'}{'udp'} = '6673'	; 
#	$srvcobjects_ref->{'vision_elmd'}{'ports'}{'udp'}{'6673'}++	; 
#	$ports_ref->{'udp'}{'6673'}{'name'} = 'vision_elmd'		; 
#	$srvcobjects_ref->{'vision_elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vision_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vision_elmd'}{'port'}{'tcp'} = '6673'	; 
#	$srvcobjects_ref->{'vision_elmd'}{'ports'}{'tcp'}{'6673'}++	; 
#	$ports_ref->{'tcp'}{'6673'}{'name'} = 'vision_elmd'		; 
#	$srvcobjects_ref->{'pwdis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pwdis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwdis'}{'port'}{'udp'} = '3735'	; 
#	$srvcobjects_ref->{'pwdis'}{'ports'}{'udp'}{'3735'}++	; 
#	$ports_ref->{'udp'}{'3735'}{'name'} = 'pwdis'		; 
#	$srvcobjects_ref->{'pwdis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pwdis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwdis'}{'port'}{'tcp'} = '3735'	; 
#	$srvcobjects_ref->{'pwdis'}{'ports'}{'tcp'}{'3735'}++	; 
#	$ports_ref->{'tcp'}{'3735'}{'name'} = 'pwdis'		; 
#	$srvcobjects_ref->{'sd-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sd-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd-data'}{'port'}{'udp'} = '2385'	; 
#	$srvcobjects_ref->{'sd-data'}{'ports'}{'udp'}{'2385'}++	; 
#	$ports_ref->{'udp'}{'2385'}{'name'} = 'sd-data'		; 
#	$srvcobjects_ref->{'sd-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sd-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sd-data'}{'port'}{'tcp'} = '2385'	; 
#	$srvcobjects_ref->{'sd-data'}{'ports'}{'tcp'}{'2385'}++	; 
#	$ports_ref->{'tcp'}{'2385'}{'name'} = 'sd-data'		; 
#	$srvcobjects_ref->{'cgms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cgms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cgms'}{'port'}{'udp'} = '3003'	; 
#	$srvcobjects_ref->{'cgms'}{'ports'}{'udp'}{'3003'}++	; 
#	$ports_ref->{'udp'}{'3003'}{'name'} = 'cgms'		; 
#	$srvcobjects_ref->{'cgms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cgms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cgms'}{'port'}{'tcp'} = '3003'	; 
#	$srvcobjects_ref->{'cgms'}{'ports'}{'tcp'}{'3003'}++	; 
#	$ports_ref->{'tcp'}{'3003'}{'name'} = 'cgms'		; 
#	$srvcobjects_ref->{'csbphonemaster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csbphonemaster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csbphonemaster'}{'port'}{'udp'} = '1724'	; 
#	$srvcobjects_ref->{'csbphonemaster'}{'ports'}{'udp'}{'1724'}++	; 
#	$ports_ref->{'udp'}{'1724'}{'name'} = 'csbphonemaster'		; 
#	$srvcobjects_ref->{'csbphonemaster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csbphonemaster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csbphonemaster'}{'port'}{'tcp'} = '1724'	; 
#	$srvcobjects_ref->{'csbphonemaster'}{'ports'}{'tcp'}{'1724'}++	; 
#	$ports_ref->{'tcp'}{'1724'}{'name'} = 'csbphonemaster'		; 
#	$srvcobjects_ref->{'edm-stager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edm-stager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-stager'}{'port'}{'udp'} = '3461'	; 
#	$srvcobjects_ref->{'edm-stager'}{'ports'}{'udp'}{'3461'}++	; 
#	$ports_ref->{'udp'}{'3461'}{'name'} = 'edm-stager'		; 
#	$srvcobjects_ref->{'edm-stager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edm-stager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-stager'}{'port'}{'tcp'} = '3461'	; 
#	$srvcobjects_ref->{'edm-stager'}{'ports'}{'tcp'}{'3461'}++	; 
#	$ports_ref->{'tcp'}{'3461'}{'name'} = 'edm-stager'		; 
#	$srvcobjects_ref->{'simctlp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'simctlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simctlp'}{'port'}{'udp'} = '2857'	; 
#	$srvcobjects_ref->{'simctlp'}{'ports'}{'udp'}{'2857'}++	; 
#	$ports_ref->{'udp'}{'2857'}{'name'} = 'simctlp'		; 
#	$srvcobjects_ref->{'simctlp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'simctlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'simctlp'}{'port'}{'tcp'} = '2857'	; 
#	$srvcobjects_ref->{'simctlp'}{'ports'}{'tcp'}{'2857'}++	; 
#	$ports_ref->{'tcp'}{'2857'}{'name'} = 'simctlp'		; 
#	$srvcobjects_ref->{'citrixadmin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'citrixadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citrixadmin'}{'port'}{'udp'} = '2513'	; 
#	$srvcobjects_ref->{'citrixadmin'}{'ports'}{'udp'}{'2513'}++	; 
#	$ports_ref->{'udp'}{'2513'}{'name'} = 'citrixadmin'		; 
#	$srvcobjects_ref->{'citrixadmin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'citrixadmin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'citrixadmin'}{'port'}{'tcp'} = '2513'	; 
#	$srvcobjects_ref->{'citrixadmin'}{'ports'}{'tcp'}{'2513'}++	; 
#	$ports_ref->{'tcp'}{'2513'}{'name'} = 'citrixadmin'		; 
#	$srvcobjects_ref->{'snap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snap'}{'port'}{'udp'} = '4752'	; 
#	$srvcobjects_ref->{'snap'}{'ports'}{'udp'}{'4752'}++	; 
#	$ports_ref->{'udp'}{'4752'}{'name'} = 'snap'		; 
#	$srvcobjects_ref->{'snap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snap'}{'port'}{'tcp'} = '4752'	; 
#	$srvcobjects_ref->{'snap'}{'ports'}{'tcp'}{'4752'}++	; 
#	$ports_ref->{'tcp'}{'4752'}{'name'} = 'snap'		; 
#	$srvcobjects_ref->{'xrl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xrl'}{'port'}{'udp'} = '1104'	; 
#	$srvcobjects_ref->{'xrl'}{'ports'}{'udp'}{'1104'}++	; 
#	$ports_ref->{'udp'}{'1104'}{'name'} = 'xrl'		; 
#	$srvcobjects_ref->{'xrl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xrl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xrl'}{'port'}{'tcp'} = '1104'	; 
#	$srvcobjects_ref->{'xrl'}{'ports'}{'tcp'}{'1104'}++	; 
#	$ports_ref->{'tcp'}{'1104'}{'name'} = 'xrl'		; 
#	$srvcobjects_ref->{'sftp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftp'}{'port'}{'udp'} = '115'	; 
#	$srvcobjects_ref->{'sftp'}{'ports'}{'udp'}{'115'}++	; 
#	$ports_ref->{'udp'}{'115'}{'name'} = 'sftp'		; 
#	$srvcobjects_ref->{'sftp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sftp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sftp'}{'port'}{'tcp'} = '115'	; 
#	$srvcobjects_ref->{'sftp'}{'ports'}{'tcp'}{'115'}++	; 
#	$ports_ref->{'tcp'}{'115'}{'name'} = 'sftp'		; 
#	$srvcobjects_ref->{'apollo-gms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apollo-gms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apollo-gms'}{'port'}{'udp'} = '2759'	; 
#	$srvcobjects_ref->{'apollo-gms'}{'ports'}{'udp'}{'2759'}++	; 
#	$ports_ref->{'udp'}{'2759'}{'name'} = 'apollo-gms'		; 
#	$srvcobjects_ref->{'apollo-gms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apollo-gms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apollo-gms'}{'port'}{'tcp'} = '2759'	; 
#	$srvcobjects_ref->{'apollo-gms'}{'ports'}{'tcp'}{'2759'}++	; 
#	$ports_ref->{'tcp'}{'2759'}{'name'} = 'apollo-gms'		; 
#	$srvcobjects_ref->{'multip-msg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'multip-msg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'multip-msg'}{'port'}{'udp'} = '3733'	; 
#	$srvcobjects_ref->{'multip-msg'}{'ports'}{'udp'}{'3733'}++	; 
#	$ports_ref->{'udp'}{'3733'}{'name'} = 'multip-msg'		; 
#	$srvcobjects_ref->{'multip-msg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'multip-msg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'multip-msg'}{'port'}{'tcp'} = '3733'	; 
#	$srvcobjects_ref->{'multip-msg'}{'ports'}{'tcp'}{'3733'}++	; 
#	$ports_ref->{'tcp'}{'3733'}{'name'} = 'multip-msg'		; 
#	$srvcobjects_ref->{'lbc-sync'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lbc-sync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-sync'}{'port'}{'udp'} = '2779'	; 
#	$srvcobjects_ref->{'lbc-sync'}{'ports'}{'udp'}{'2779'}++	; 
#	$ports_ref->{'udp'}{'2779'}{'name'} = 'lbc-sync'		; 
#	$srvcobjects_ref->{'lbc-sync'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lbc-sync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lbc-sync'}{'port'}{'tcp'} = '2779'	; 
#	$srvcobjects_ref->{'lbc-sync'}{'ports'}{'tcp'}{'2779'}++	; 
#	$ports_ref->{'tcp'}{'2779'}{'name'} = 'lbc-sync'		; 
#	$srvcobjects_ref->{'bvcontrol'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bvcontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bvcontrol'}{'port'}{'udp'} = '1236'	; 
#	$srvcobjects_ref->{'bvcontrol'}{'ports'}{'udp'}{'1236'}++	; 
#	$ports_ref->{'udp'}{'1236'}{'name'} = 'bvcontrol'		; 
#	$srvcobjects_ref->{'bvcontrol'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bvcontrol'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bvcontrol'}{'port'}{'tcp'} = '1236'	; 
#	$srvcobjects_ref->{'bvcontrol'}{'ports'}{'tcp'}{'1236'}++	; 
#	$ports_ref->{'tcp'}{'1236'}{'name'} = 'bvcontrol'		; 
#	$srvcobjects_ref->{'masqdialer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'masqdialer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'masqdialer'}{'port'}{'udp'} = '224'	; 
#	$srvcobjects_ref->{'masqdialer'}{'ports'}{'udp'}{'224'}++	; 
#	$ports_ref->{'udp'}{'224'}{'name'} = 'masqdialer'		; 
#	$srvcobjects_ref->{'masqdialer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'masqdialer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'masqdialer'}{'port'}{'tcp'} = '224'	; 
#	$srvcobjects_ref->{'masqdialer'}{'ports'}{'tcp'}{'224'}++	; 
#	$ports_ref->{'tcp'}{'224'}{'name'} = 'masqdialer'		; 
#	$srvcobjects_ref->{'vce'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vce'}{'port'}{'udp'} = '11111'	; 
#	$srvcobjects_ref->{'vce'}{'ports'}{'udp'}{'11111'}++	; 
#	$ports_ref->{'udp'}{'11111'}{'name'} = 'vce'		; 
#	$srvcobjects_ref->{'vce'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vce'}{'port'}{'tcp'} = '11111'	; 
#	$srvcobjects_ref->{'vce'}{'ports'}{'tcp'}{'11111'}++	; 
#	$ports_ref->{'tcp'}{'11111'}{'name'} = 'vce'		; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'port'}{'udp'} = '1318'	; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'ports'}{'udp'}{'1318'}++	; 
#	$ports_ref->{'udp'}{'1318'}{'name'} = 'krb5gatekeeper'		; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'port'}{'tcp'} = '1318'	; 
#	$srvcobjects_ref->{'krb5gatekeeper'}{'ports'}{'tcp'}{'1318'}++	; 
#	$ports_ref->{'tcp'}{'1318'}{'name'} = 'krb5gatekeeper'		; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'port'}{'udp'} = '3358'	; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'ports'}{'udp'}{'3358'}++	; 
#	$ports_ref->{'udp'}{'3358'}{'name'} = 'mpsysrmsvr'		; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'port'}{'tcp'} = '3358'	; 
#	$srvcobjects_ref->{'mpsysrmsvr'}{'ports'}{'tcp'}{'3358'}++	; 
#	$ports_ref->{'tcp'}{'3358'}{'name'} = 'mpsysrmsvr'		; 
#	$srvcobjects_ref->{'icl-twobase9'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase9'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase9'}{'port'}{'udp'} = '25008'	; 
#	$srvcobjects_ref->{'icl-twobase9'}{'ports'}{'udp'}{'25008'}++	; 
#	$ports_ref->{'udp'}{'25008'}{'name'} = 'icl-twobase9'		; 
#	$srvcobjects_ref->{'icl-twobase9'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase9'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase9'}{'port'}{'tcp'} = '25008'	; 
#	$srvcobjects_ref->{'icl-twobase9'}{'ports'}{'tcp'}{'25008'}++	; 
#	$ports_ref->{'tcp'}{'25008'}{'name'} = 'icl-twobase9'		; 
#	$srvcobjects_ref->{'venus-se'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'venus-se'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'venus-se'}{'port'}{'udp'} = '2431'	; 
#	$srvcobjects_ref->{'venus-se'}{'ports'}{'udp'}{'2431'}++	; 
#	$ports_ref->{'udp'}{'2431'}{'name'} = 'venus-se'		; 
#	$srvcobjects_ref->{'venus-se'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'venus-se'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'venus-se'}{'port'}{'tcp'} = '2431'	; 
#	$srvcobjects_ref->{'venus-se'}{'ports'}{'tcp'}{'2431'}++	; 
#	$ports_ref->{'tcp'}{'2431'}{'name'} = 'venus-se'		; 
#	$srvcobjects_ref->{'pxc-roid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-roid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-roid'}{'port'}{'udp'} = '4004'	; 
#	$srvcobjects_ref->{'pxc-roid'}{'ports'}{'udp'}{'4004'}++	; 
#	$ports_ref->{'udp'}{'4004'}{'name'} = 'pxc-roid'		; 
#	$srvcobjects_ref->{'pxc-roid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-roid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-roid'}{'port'}{'tcp'} = '4004'	; 
#	$srvcobjects_ref->{'pxc-roid'}{'ports'}{'tcp'}{'4004'}++	; 
#	$ports_ref->{'tcp'}{'4004'}{'name'} = 'pxc-roid'		; 
#	$srvcobjects_ref->{'etebac5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'etebac5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etebac5'}{'port'}{'udp'} = '1216'	; 
#	$srvcobjects_ref->{'etebac5'}{'ports'}{'udp'}{'1216'}++	; 
#	$ports_ref->{'udp'}{'1216'}{'name'} = 'etebac5'		; 
#	$srvcobjects_ref->{'etebac5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'etebac5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'etebac5'}{'port'}{'tcp'} = '1216'	; 
#	$srvcobjects_ref->{'etebac5'}{'ports'}{'tcp'}{'1216'}++	; 
#	$ports_ref->{'tcp'}{'1216'}{'name'} = 'etebac5'		; 
#	$srvcobjects_ref->{'hems'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hems'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hems'}{'port'}{'udp'} = '151'	; 
#	$srvcobjects_ref->{'hems'}{'ports'}{'udp'}{'151'}++	; 
#	$ports_ref->{'udp'}{'151'}{'name'} = 'hems'		; 
#	$srvcobjects_ref->{'hems'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hems'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hems'}{'port'}{'tcp'} = '151'	; 
#	$srvcobjects_ref->{'hems'}{'ports'}{'tcp'}{'151'}++	; 
#	$ports_ref->{'tcp'}{'151'}{'name'} = 'hems'		; 
#	$srvcobjects_ref->{'mindprint'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mindprint'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mindprint'}{'port'}{'udp'} = '8033'	; 
#	$srvcobjects_ref->{'mindprint'}{'ports'}{'udp'}{'8033'}++	; 
#	$ports_ref->{'udp'}{'8033'}{'name'} = 'mindprint'		; 
#	$srvcobjects_ref->{'mindprint'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mindprint'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mindprint'}{'port'}{'tcp'} = '8033'	; 
#	$srvcobjects_ref->{'mindprint'}{'ports'}{'tcp'}{'8033'}++	; 
#	$ports_ref->{'tcp'}{'8033'}{'name'} = 'mindprint'		; 
#	$srvcobjects_ref->{'gw-call-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gw-call-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gw-call-port'}{'port'}{'udp'} = '3745'	; 
#	$srvcobjects_ref->{'gw-call-port'}{'ports'}{'udp'}{'3745'}++	; 
#	$ports_ref->{'udp'}{'3745'}{'name'} = 'gw-call-port'		; 
#	$srvcobjects_ref->{'gw-call-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gw-call-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gw-call-port'}{'port'}{'tcp'} = '3745'	; 
#	$srvcobjects_ref->{'gw-call-port'}{'ports'}{'tcp'}{'3745'}++	; 
#	$ports_ref->{'tcp'}{'3745'}{'name'} = 'gw-call-port'		; 
#	$srvcobjects_ref->{'dsETOS'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsETOS'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsETOS'}{'port'}{'udp'} = '378'	; 
#	$srvcobjects_ref->{'dsETOS'}{'ports'}{'udp'}{'378'}++	; 
#	$ports_ref->{'udp'}{'378'}{'name'} = 'dsETOS'		; 
#	$srvcobjects_ref->{'dsETOS'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsETOS'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsETOS'}{'port'}{'tcp'} = '378'	; 
#	$srvcobjects_ref->{'dsETOS'}{'ports'}{'tcp'}{'378'}++	; 
#	$ports_ref->{'tcp'}{'378'}{'name'} = 'dsETOS'		; 
#	$srvcobjects_ref->{'bhevent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bhevent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhevent'}{'port'}{'udp'} = '357'	; 
#	$srvcobjects_ref->{'bhevent'}{'ports'}{'udp'}{'357'}++	; 
#	$ports_ref->{'udp'}{'357'}{'name'} = 'bhevent'		; 
#	$srvcobjects_ref->{'bhevent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bhevent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhevent'}{'port'}{'tcp'} = '357'	; 
#	$srvcobjects_ref->{'bhevent'}{'ports'}{'tcp'}{'357'}++	; 
#	$ports_ref->{'tcp'}{'357'}{'name'} = 'bhevent'		; 
#	$srvcobjects_ref->{'m4-network-as'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'m4-network-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m4-network-as'}{'port'}{'udp'} = '4345'	; 
#	$srvcobjects_ref->{'m4-network-as'}{'ports'}{'udp'}{'4345'}++	; 
#	$ports_ref->{'udp'}{'4345'}{'name'} = 'm4-network-as'		; 
#	$srvcobjects_ref->{'m4-network-as'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'m4-network-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m4-network-as'}{'port'}{'tcp'} = '4345'	; 
#	$srvcobjects_ref->{'m4-network-as'}{'ports'}{'tcp'}{'4345'}++	; 
#	$ports_ref->{'tcp'}{'4345'}{'name'} = 'm4-network-as'		; 
#	$srvcobjects_ref->{'tsilb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tsilb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsilb'}{'port'}{'udp'} = '2489'	; 
#	$srvcobjects_ref->{'tsilb'}{'ports'}{'udp'}{'2489'}++	; 
#	$ports_ref->{'udp'}{'2489'}{'name'} = 'tsilb'		; 
#	$srvcobjects_ref->{'tsilb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tsilb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tsilb'}{'port'}{'tcp'} = '2489'	; 
#	$srvcobjects_ref->{'tsilb'}{'ports'}{'tcp'}{'2489'}++	; 
#	$ports_ref->{'tcp'}{'2489'}{'name'} = 'tsilb'		; 
#	$srvcobjects_ref->{'nsws'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsws'}{'port'}{'udp'} = '3049'	; 
#	$srvcobjects_ref->{'nsws'}{'ports'}{'udp'}{'3049'}++	; 
#	$ports_ref->{'udp'}{'3049'}{'name'} = 'nsws'		; 
#	$srvcobjects_ref->{'nsws'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsws'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsws'}{'port'}{'tcp'} = '3049'	; 
#	$srvcobjects_ref->{'nsws'}{'ports'}{'tcp'}{'3049'}++	; 
#	$ports_ref->{'tcp'}{'3049'}{'name'} = 'nsws'		; 
#	$srvcobjects_ref->{'dwf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dwf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwf'}{'port'}{'udp'} = '1450'	; 
#	$srvcobjects_ref->{'dwf'}{'ports'}{'udp'}{'1450'}++	; 
#	$ports_ref->{'udp'}{'1450'}{'name'} = 'dwf'		; 
#	$srvcobjects_ref->{'dwf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dwf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dwf'}{'port'}{'tcp'} = '1450'	; 
#	$srvcobjects_ref->{'dwf'}{'ports'}{'tcp'}{'1450'}++	; 
#	$ports_ref->{'tcp'}{'1450'}{'name'} = 'dwf'		; 
#	$srvcobjects_ref->{'spock'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'spock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spock'}{'port'}{'udp'} = '2507'	; 
#	$srvcobjects_ref->{'spock'}{'ports'}{'udp'}{'2507'}++	; 
#	$ports_ref->{'udp'}{'2507'}{'name'} = 'spock'		; 
#	$srvcobjects_ref->{'spock'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'spock'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'spock'}{'port'}{'tcp'} = '2507'	; 
#	$srvcobjects_ref->{'spock'}{'ports'}{'tcp'}{'2507'}++	; 
#	$ports_ref->{'tcp'}{'2507'}{'name'} = 'spock'		; 
#	$srvcobjects_ref->{'xqosd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xqosd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xqosd'}{'port'}{'udp'} = '31416'	; 
#	$srvcobjects_ref->{'xqosd'}{'ports'}{'udp'}{'31416'}++	; 
#	$ports_ref->{'udp'}{'31416'}{'name'} = 'xqosd'		; 
#	$srvcobjects_ref->{'xqosd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xqosd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xqosd'}{'port'}{'tcp'} = '31416'	; 
#	$srvcobjects_ref->{'xqosd'}{'ports'}{'tcp'}{'31416'}++	; 
#	$ports_ref->{'tcp'}{'31416'}{'name'} = 'xqosd'		; 
#	$srvcobjects_ref->{'audiojuggler'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'audiojuggler'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audiojuggler'}{'port'}{'udp'} = '3643'	; 
#	$srvcobjects_ref->{'audiojuggler'}{'ports'}{'udp'}{'3643'}++	; 
#	$ports_ref->{'udp'}{'3643'}{'name'} = 'audiojuggler'		; 
#	$srvcobjects_ref->{'audiojuggler'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'audiojuggler'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audiojuggler'}{'port'}{'tcp'} = '3643'	; 
#	$srvcobjects_ref->{'audiojuggler'}{'ports'}{'tcp'}{'3643'}++	; 
#	$ports_ref->{'tcp'}{'3643'}{'name'} = 'audiojuggler'		; 
#	$srvcobjects_ref->{'directplay8'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'directplay8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directplay8'}{'port'}{'udp'} = '6073'	; 
#	$srvcobjects_ref->{'directplay8'}{'ports'}{'udp'}{'6073'}++	; 
#	$ports_ref->{'udp'}{'6073'}{'name'} = 'directplay8'		; 
#	$srvcobjects_ref->{'directplay8'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'directplay8'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'directplay8'}{'port'}{'tcp'} = '6073'	; 
#	$srvcobjects_ref->{'directplay8'}{'ports'}{'tcp'}{'6073'}++	; 
#	$ports_ref->{'tcp'}{'6073'}{'name'} = 'directplay8'		; 
#	$srvcobjects_ref->{'essbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'essbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'essbase'}{'port'}{'udp'} = '1423'	; 
#	$srvcobjects_ref->{'essbase'}{'ports'}{'udp'}{'1423'}++	; 
#	$ports_ref->{'udp'}{'1423'}{'name'} = 'essbase'		; 
#	$srvcobjects_ref->{'essbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'essbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'essbase'}{'port'}{'tcp'} = '1423'	; 
#	$srvcobjects_ref->{'essbase'}{'ports'}{'tcp'}{'1423'}++	; 
#	$ports_ref->{'tcp'}{'1423'}{'name'} = 'essbase'		; 
#	$srvcobjects_ref->{'rsvd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvd'}{'port'}{'udp'} = '168'	; 
#	$srvcobjects_ref->{'rsvd'}{'ports'}{'udp'}{'168'}++	; 
#	$ports_ref->{'udp'}{'168'}{'name'} = 'rsvd'		; 
#	$srvcobjects_ref->{'rsvd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsvd'}{'port'}{'tcp'} = '168'	; 
#	$srvcobjects_ref->{'rsvd'}{'ports'}{'tcp'}{'168'}++	; 
#	$ports_ref->{'tcp'}{'168'}{'name'} = 'rsvd'		; 
#	$srvcobjects_ref->{'elatelink'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elatelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elatelink'}{'port'}{'udp'} = '2124'	; 
#	$srvcobjects_ref->{'elatelink'}{'ports'}{'udp'}{'2124'}++	; 
#	$ports_ref->{'udp'}{'2124'}{'name'} = 'elatelink'		; 
#	$srvcobjects_ref->{'elatelink'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elatelink'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elatelink'}{'port'}{'tcp'} = '2124'	; 
#	$srvcobjects_ref->{'elatelink'}{'ports'}{'tcp'}{'2124'}++	; 
#	$ports_ref->{'tcp'}{'2124'}{'name'} = 'elatelink'		; 
#	$srvcobjects_ref->{'ismserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ismserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ismserver'}{'port'}{'udp'} = '9500'	; 
#	$srvcobjects_ref->{'ismserver'}{'ports'}{'udp'}{'9500'}++	; 
#	$ports_ref->{'udp'}{'9500'}{'name'} = 'ismserver'		; 
#	$srvcobjects_ref->{'ismserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ismserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ismserver'}{'port'}{'tcp'} = '9500'	; 
#	$srvcobjects_ref->{'ismserver'}{'ports'}{'tcp'}{'9500'}++	; 
#	$ports_ref->{'tcp'}{'9500'}{'name'} = 'ismserver'		; 
#	$srvcobjects_ref->{'trellissvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trellissvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trellissvr'}{'port'}{'udp'} = '2078'	; 
#	$srvcobjects_ref->{'trellissvr'}{'ports'}{'udp'}{'2078'}++	; 
#	$ports_ref->{'udp'}{'2078'}{'name'} = 'trellissvr'		; 
#	$srvcobjects_ref->{'trellissvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trellissvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trellissvr'}{'port'}{'tcp'} = '2078'	; 
#	$srvcobjects_ref->{'trellissvr'}{'ports'}{'tcp'}{'2078'}++	; 
#	$ports_ref->{'tcp'}{'2078'}{'name'} = 'trellissvr'		; 
#	$srvcobjects_ref->{'oidsr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oidsr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oidsr'}{'port'}{'udp'} = '4143'	; 
#	$srvcobjects_ref->{'oidsr'}{'ports'}{'udp'}{'4143'}++	; 
#	$ports_ref->{'udp'}{'4143'}{'name'} = 'oidsr'		; 
#	$srvcobjects_ref->{'oidsr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oidsr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oidsr'}{'port'}{'tcp'} = '4143'	; 
#	$srvcobjects_ref->{'oidsr'}{'ports'}{'tcp'}{'4143'}++	; 
#	$ports_ref->{'tcp'}{'4143'}{'name'} = 'oidsr'		; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'port'}{'udp'} = '593'	; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'ports'}{'udp'}{'593'}++	; 
#	$ports_ref->{'udp'}{'593'}{'name'} = 'http-rpc-epmap'		; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'port'}{'tcp'} = '593'	; 
#	$srvcobjects_ref->{'http-rpc-epmap'}{'ports'}{'tcp'}{'593'}++	; 
#	$ports_ref->{'tcp'}{'593'}{'name'} = 'http-rpc-epmap'		; 
#	$srvcobjects_ref->{'slp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slp'}{'port'}{'udp'} = '1605'	; 
#	$srvcobjects_ref->{'slp'}{'ports'}{'udp'}{'1605'}++	; 
#	$ports_ref->{'udp'}{'1605'}{'name'} = 'slp'		; 
#	$srvcobjects_ref->{'slp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slp'}{'port'}{'tcp'} = '1605'	; 
#	$srvcobjects_ref->{'slp'}{'ports'}{'tcp'}{'1605'}++	; 
#	$ports_ref->{'tcp'}{'1605'}{'name'} = 'slp'		; 
#	$srvcobjects_ref->{'fyre-messanger'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fyre-messanger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fyre-messanger'}{'port'}{'udp'} = '2731'	; 
#	$srvcobjects_ref->{'fyre-messanger'}{'ports'}{'udp'}{'2731'}++	; 
#	$ports_ref->{'udp'}{'2731'}{'name'} = 'fyre-messanger'		; 
#	$srvcobjects_ref->{'fyre-messanger'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fyre-messanger'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fyre-messanger'}{'port'}{'tcp'} = '2731'	; 
#	$srvcobjects_ref->{'fyre-messanger'}{'ports'}{'tcp'}{'2731'}++	; 
#	$ports_ref->{'tcp'}{'2731'}{'name'} = 'fyre-messanger'		; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'port'}{'udp'} = '3612'	; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'ports'}{'udp'}{'3612'}++	; 
#	$ports_ref->{'udp'}{'3612'}{'name'} = 'hp-dataprotect'		; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'port'}{'tcp'} = '3612'	; 
#	$srvcobjects_ref->{'hp-dataprotect'}{'ports'}{'tcp'}{'3612'}++	; 
#	$ports_ref->{'tcp'}{'3612'}{'name'} = 'hp-dataprotect'		; 
#	$srvcobjects_ref->{'ssdtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssdtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssdtp'}{'port'}{'udp'} = '6071'	; 
#	$srvcobjects_ref->{'ssdtp'}{'ports'}{'udp'}{'6071'}++	; 
#	$ports_ref->{'udp'}{'6071'}{'name'} = 'ssdtp'		; 
#	$srvcobjects_ref->{'ssdtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssdtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssdtp'}{'port'}{'tcp'} = '6071'	; 
#	$srvcobjects_ref->{'ssdtp'}{'ports'}{'tcp'}{'6071'}++	; 
#	$ports_ref->{'tcp'}{'6071'}{'name'} = 'ssdtp'		; 
#	$srvcobjects_ref->{'cmip-man'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cmip-man'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmip-man'}{'port'}{'udp'} = '163'	; 
#	$srvcobjects_ref->{'cmip-man'}{'ports'}{'udp'}{'163'}++	; 
#	$ports_ref->{'udp'}{'163'}{'name'} = 'cmip-man'		; 
#	$srvcobjects_ref->{'cmip-man'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cmip-man'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cmip-man'}{'port'}{'tcp'} = '163'	; 
#	$srvcobjects_ref->{'cmip-man'}{'ports'}{'tcp'}{'163'}++	; 
#	$ports_ref->{'tcp'}{'163'}{'name'} = 'cmip-man'		; 
#	$srvcobjects_ref->{'fodms'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fodms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fodms'}{'port'}{'udp'} = '7200'	; 
#	$srvcobjects_ref->{'fodms'}{'ports'}{'udp'}{'7200'}++	; 
#	$ports_ref->{'udp'}{'7200'}{'name'} = 'fodms'		; 
#	$srvcobjects_ref->{'fodms'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fodms'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fodms'}{'port'}{'tcp'} = '7200'	; 
#	$srvcobjects_ref->{'fodms'}{'ports'}{'tcp'}{'7200'}++	; 
#	$ports_ref->{'tcp'}{'7200'}{'name'} = 'fodms'		; 
#	$srvcobjects_ref->{'sps-tunnel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sps-tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sps-tunnel'}{'port'}{'udp'} = '2876'	; 
#	$srvcobjects_ref->{'sps-tunnel'}{'ports'}{'udp'}{'2876'}++	; 
#	$ports_ref->{'udp'}{'2876'}{'name'} = 'sps-tunnel'		; 
#	$srvcobjects_ref->{'sps-tunnel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sps-tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sps-tunnel'}{'port'}{'tcp'} = '2876'	; 
#	$srvcobjects_ref->{'sps-tunnel'}{'ports'}{'tcp'}{'2876'}++	; 
#	$ports_ref->{'tcp'}{'2876'}{'name'} = 'sps-tunnel'		; 
#	$srvcobjects_ref->{'puparp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'puparp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'puparp'}{'port'}{'udp'} = '998'	; 
#	$srvcobjects_ref->{'puparp'}{'ports'}{'udp'}{'998'}++	; 
#	$ports_ref->{'udp'}{'998'}{'name'} = 'puparp'		; 
#	$srvcobjects_ref->{'t2-drm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'t2-drm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t2-drm'}{'port'}{'udp'} = '7932'	; 
#	$srvcobjects_ref->{'t2-drm'}{'ports'}{'udp'}{'7932'}++	; 
#	$ports_ref->{'udp'}{'7932'}{'name'} = 't2-drm'		; 
#	$srvcobjects_ref->{'t2-drm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'t2-drm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t2-drm'}{'port'}{'tcp'} = '7932'	; 
#	$srvcobjects_ref->{'t2-drm'}{'ports'}{'tcp'}{'7932'}++	; 
#	$ports_ref->{'tcp'}{'7932'}{'name'} = 't2-drm'		; 
#	$srvcobjects_ref->{'tenfold'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tenfold'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tenfold'}{'port'}{'udp'} = '658'	; 
#	$srvcobjects_ref->{'tenfold'}{'ports'}{'udp'}{'658'}++	; 
#	$ports_ref->{'udp'}{'658'}{'name'} = 'tenfold'		; 
#	$srvcobjects_ref->{'tenfold'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tenfold'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tenfold'}{'port'}{'tcp'} = '658'	; 
#	$srvcobjects_ref->{'tenfold'}{'ports'}{'tcp'}{'658'}++	; 
#	$ports_ref->{'tcp'}{'658'}{'name'} = 'tenfold'		; 
#	$srvcobjects_ref->{'galaxy-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'galaxy-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'galaxy-server'}{'port'}{'udp'} = '3051'	; 
#	$srvcobjects_ref->{'galaxy-server'}{'ports'}{'udp'}{'3051'}++	; 
#	$ports_ref->{'udp'}{'3051'}{'name'} = 'galaxy-server'		; 
#	$srvcobjects_ref->{'galaxy-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'galaxy-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'galaxy-server'}{'port'}{'tcp'} = '3051'	; 
#	$srvcobjects_ref->{'galaxy-server'}{'ports'}{'tcp'}{'3051'}++	; 
#	$ports_ref->{'tcp'}{'3051'}{'name'} = 'galaxy-server'		; 
#	$srvcobjects_ref->{'tve-announce'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tve-announce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tve-announce'}{'port'}{'udp'} = '2670'	; 
#	$srvcobjects_ref->{'tve-announce'}{'ports'}{'udp'}{'2670'}++	; 
#	$ports_ref->{'udp'}{'2670'}{'name'} = 'tve-announce'		; 
#	$srvcobjects_ref->{'tve-announce'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tve-announce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tve-announce'}{'port'}{'tcp'} = '2670'	; 
#	$srvcobjects_ref->{'tve-announce'}{'ports'}{'tcp'}{'2670'}++	; 
#	$ports_ref->{'tcp'}{'2670'}{'name'} = 'tve-announce'		; 
#	$srvcobjects_ref->{'mdap-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mdap-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdap-port'}{'port'}{'udp'} = '3235'	; 
#	$srvcobjects_ref->{'mdap-port'}{'ports'}{'udp'}{'3235'}++	; 
#	$ports_ref->{'udp'}{'3235'}{'name'} = 'mdap-port'		; 
#	$srvcobjects_ref->{'mdap-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mdap-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mdap-port'}{'port'}{'tcp'} = '3235'	; 
#	$srvcobjects_ref->{'mdap-port'}{'ports'}{'tcp'}{'3235'}++	; 
#	$ports_ref->{'tcp'}{'3235'}{'name'} = 'mdap-port'		; 
#	$srvcobjects_ref->{'csdm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdm'}{'port'}{'udp'} = '1472'	; 
#	$srvcobjects_ref->{'csdm'}{'ports'}{'udp'}{'1472'}++	; 
#	$ports_ref->{'udp'}{'1472'}{'name'} = 'csdm'		; 
#	$srvcobjects_ref->{'csdm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdm'}{'port'}{'udp'} = '1468'	; 
#	$srvcobjects_ref->{'csdm'}{'ports'}{'udp'}{'1468'}++	; 
#	$ports_ref->{'udp'}{'1468'}{'name'} = 'csdm'		; 
#	$srvcobjects_ref->{'csdm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdm'}{'port'}{'tcp'} = '1472'	; 
#	$srvcobjects_ref->{'csdm'}{'ports'}{'tcp'}{'1472'}++	; 
#	$ports_ref->{'tcp'}{'1472'}{'name'} = 'csdm'		; 
#	$srvcobjects_ref->{'csdm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csdm'}{'port'}{'tcp'} = '1468'	; 
#	$srvcobjects_ref->{'csdm'}{'ports'}{'tcp'}{'1468'}++	; 
#	$ports_ref->{'tcp'}{'1468'}{'name'} = 'csdm'		; 
#	$srvcobjects_ref->{'m3ua'}{'type'} = 'sctp'	; 
#	$srvcobjects_ref->{'m3ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m3ua'}{'port'}{'sctp'} = '2905'	; 
#	$srvcobjects_ref->{'m3ua'}{'ports'}{'sctp'}{'2905'}++	; 
#	$ports_ref->{'sctp'}{'2905'}{'name'} = 'm3ua'		; 
#	$srvcobjects_ref->{'m3ua'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'m3ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m3ua'}{'port'}{'udp'} = '2905'	; 
#	$srvcobjects_ref->{'m3ua'}{'ports'}{'udp'}{'2905'}++	; 
#	$ports_ref->{'udp'}{'2905'}{'name'} = 'm3ua'		; 
#	$srvcobjects_ref->{'m3ua'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'m3ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'m3ua'}{'port'}{'tcp'} = '2905'	; 
#	$srvcobjects_ref->{'m3ua'}{'ports'}{'tcp'}{'2905'}++	; 
#	$ports_ref->{'tcp'}{'2905'}{'name'} = 'm3ua'		; 
#	$srvcobjects_ref->{'iad1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iad1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iad1'}{'port'}{'udp'} = '1030'	; 
#	$srvcobjects_ref->{'iad1'}{'ports'}{'udp'}{'1030'}++	; 
#	$ports_ref->{'udp'}{'1030'}{'name'} = 'iad1'		; 
#	$srvcobjects_ref->{'iad1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iad1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iad1'}{'port'}{'tcp'} = '1030'	; 
#	$srvcobjects_ref->{'iad1'}{'ports'}{'tcp'}{'1030'}++	; 
#	$ports_ref->{'tcp'}{'1030'}{'name'} = 'iad1'		; 
#	$srvcobjects_ref->{'audit'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'audit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audit'}{'port'}{'udp'} = '182'	; 
#	$srvcobjects_ref->{'audit'}{'ports'}{'udp'}{'182'}++	; 
#	$ports_ref->{'udp'}{'182'}{'name'} = 'audit'		; 
#	$srvcobjects_ref->{'audit'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'audit'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'audit'}{'port'}{'tcp'} = '182'	; 
#	$srvcobjects_ref->{'audit'}{'ports'}{'tcp'}{'182'}++	; 
#	$ports_ref->{'tcp'}{'182'}{'name'} = 'audit'		; 
#	$srvcobjects_ref->{'mxxrlogin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mxxrlogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mxxrlogin'}{'port'}{'udp'} = '1035'	; 
#	$srvcobjects_ref->{'mxxrlogin'}{'ports'}{'udp'}{'1035'}++	; 
#	$ports_ref->{'udp'}{'1035'}{'name'} = 'mxxrlogin'		; 
#	$srvcobjects_ref->{'mxxrlogin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mxxrlogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mxxrlogin'}{'port'}{'tcp'} = '1035'	; 
#	$srvcobjects_ref->{'mxxrlogin'}{'ports'}{'tcp'}{'1035'}++	; 
#	$ports_ref->{'tcp'}{'1035'}{'name'} = 'mxxrlogin'		; 
#	$srvcobjects_ref->{'fc-ser'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fc-ser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fc-ser'}{'port'}{'udp'} = '1372'	; 
#	$srvcobjects_ref->{'fc-ser'}{'ports'}{'udp'}{'1372'}++	; 
#	$ports_ref->{'udp'}{'1372'}{'name'} = 'fc-ser'		; 
#	$srvcobjects_ref->{'fc-ser'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fc-ser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fc-ser'}{'port'}{'tcp'} = '1372'	; 
#	$srvcobjects_ref->{'fc-ser'}{'ports'}{'tcp'}{'1372'}++	; 
#	$ports_ref->{'tcp'}{'1372'}{'name'} = 'fc-ser'		; 
#	$srvcobjects_ref->{'triquest-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'triquest-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'triquest-lm'}{'port'}{'udp'} = '1588'	; 
#	$srvcobjects_ref->{'triquest-lm'}{'ports'}{'udp'}{'1588'}++	; 
#	$ports_ref->{'udp'}{'1588'}{'name'} = 'triquest-lm'		; 
#	$srvcobjects_ref->{'triquest-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'triquest-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'triquest-lm'}{'port'}{'tcp'} = '1588'	; 
#	$srvcobjects_ref->{'triquest-lm'}{'ports'}{'tcp'}{'1588'}++	; 
#	$ports_ref->{'tcp'}{'1588'}{'name'} = 'triquest-lm'		; 
#	$srvcobjects_ref->{'pserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pserver'}{'port'}{'udp'} = '3662'	; 
#	$srvcobjects_ref->{'pserver'}{'ports'}{'udp'}{'3662'}++	; 
#	$ports_ref->{'udp'}{'3662'}{'name'} = 'pserver'		; 
#	$srvcobjects_ref->{'pserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pserver'}{'port'}{'tcp'} = '3662'	; 
#	$srvcobjects_ref->{'pserver'}{'ports'}{'tcp'}{'3662'}++	; 
#	$ports_ref->{'tcp'}{'3662'}{'name'} = 'pserver'		; 
#	$srvcobjects_ref->{'agentx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'agentx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agentx'}{'port'}{'udp'} = '705'	; 
#	$srvcobjects_ref->{'agentx'}{'ports'}{'udp'}{'705'}++	; 
#	$ports_ref->{'udp'}{'705'}{'name'} = 'agentx'		; 
#	$srvcobjects_ref->{'agentx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'agentx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agentx'}{'port'}{'tcp'} = '705'	; 
#	$srvcobjects_ref->{'agentx'}{'ports'}{'tcp'}{'705'}++	; 
#	$ports_ref->{'tcp'}{'705'}{'name'} = 'agentx'		; 
#	$srvcobjects_ref->{'stun-p2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stun-p2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-p2'}{'port'}{'udp'} = '1991'	; 
#	$srvcobjects_ref->{'stun-p2'}{'ports'}{'udp'}{'1991'}++	; 
#	$ports_ref->{'udp'}{'1991'}{'name'} = 'stun-p2'		; 
#	$srvcobjects_ref->{'stun-p2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stun-p2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stun-p2'}{'port'}{'tcp'} = '1991'	; 
#	$srvcobjects_ref->{'stun-p2'}{'ports'}{'tcp'}{'1991'}++	; 
#	$ports_ref->{'tcp'}{'1991'}{'name'} = 'stun-p2'		; 
#	$srvcobjects_ref->{'xmquery'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xmquery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmquery'}{'port'}{'udp'} = '2279'	; 
#	$srvcobjects_ref->{'xmquery'}{'ports'}{'udp'}{'2279'}++	; 
#	$ports_ref->{'udp'}{'2279'}{'name'} = 'xmquery'		; 
#	$srvcobjects_ref->{'xmquery'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xmquery'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmquery'}{'port'}{'tcp'} = '2279'	; 
#	$srvcobjects_ref->{'xmquery'}{'ports'}{'tcp'}{'2279'}++	; 
#	$ports_ref->{'tcp'}{'2279'}{'name'} = 'xmquery'		; 
#	$srvcobjects_ref->{'icabrowser'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icabrowser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icabrowser'}{'port'}{'udp'} = '1604'	; 
#	$srvcobjects_ref->{'icabrowser'}{'ports'}{'udp'}{'1604'}++	; 
#	$ports_ref->{'udp'}{'1604'}{'name'} = 'icabrowser'		; 
#	$srvcobjects_ref->{'icabrowser'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icabrowser'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icabrowser'}{'port'}{'tcp'} = '1604'	; 
#	$srvcobjects_ref->{'icabrowser'}{'ports'}{'tcp'}{'1604'}++	; 
#	$ports_ref->{'tcp'}{'1604'}{'name'} = 'icabrowser'		; 
#	$srvcobjects_ref->{'sns-quote'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sns-quote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-quote'}{'port'}{'udp'} = '1967'	; 
#	$srvcobjects_ref->{'sns-quote'}{'ports'}{'udp'}{'1967'}++	; 
#	$ports_ref->{'udp'}{'1967'}{'name'} = 'sns-quote'		; 
#	$srvcobjects_ref->{'sns-quote'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sns-quote'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sns-quote'}{'port'}{'tcp'} = '1967'	; 
#	$srvcobjects_ref->{'sns-quote'}{'ports'}{'tcp'}{'1967'}++	; 
#	$ports_ref->{'tcp'}{'1967'}{'name'} = 'sns-quote'		; 
#	$srvcobjects_ref->{'fcp-udp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcp-udp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-udp'}{'port'}{'udp'} = '810'	; 
#	$srvcobjects_ref->{'fcp-udp'}{'ports'}{'udp'}{'810'}++	; 
#	$ports_ref->{'udp'}{'810'}{'name'} = 'fcp-udp'		; 
#	$srvcobjects_ref->{'fcp-udp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcp-udp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-udp'}{'port'}{'tcp'} = '810'	; 
#	$srvcobjects_ref->{'fcp-udp'}{'ports'}{'tcp'}{'810'}++	; 
#	$ports_ref->{'tcp'}{'810'}{'name'} = 'fcp-udp'		; 
#	$srvcobjects_ref->{'peport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'peport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'peport'}{'port'}{'udp'} = '1449'	; 
#	$srvcobjects_ref->{'peport'}{'ports'}{'udp'}{'1449'}++	; 
#	$ports_ref->{'udp'}{'1449'}{'name'} = 'peport'		; 
#	$srvcobjects_ref->{'peport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'peport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'peport'}{'port'}{'tcp'} = '1449'	; 
#	$srvcobjects_ref->{'peport'}{'ports'}{'tcp'}{'1449'}++	; 
#	$ports_ref->{'tcp'}{'1449'}{'name'} = 'peport'		; 
#	$srvcobjects_ref->{'anthony-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anthony-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anthony-data'}{'port'}{'udp'} = '1206'	; 
#	$srvcobjects_ref->{'anthony-data'}{'ports'}{'udp'}{'1206'}++	; 
#	$ports_ref->{'udp'}{'1206'}{'name'} = 'anthony-data'		; 
#	$srvcobjects_ref->{'anthony-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anthony-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anthony-data'}{'port'}{'tcp'} = '1206'	; 
#	$srvcobjects_ref->{'anthony-data'}{'ports'}{'tcp'}{'1206'}++	; 
#	$ports_ref->{'tcp'}{'1206'}{'name'} = 'anthony-data'		; 
#	$srvcobjects_ref->{'yestrader'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'yestrader'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'yestrader'}{'port'}{'udp'} = '1869'	; 
#	$srvcobjects_ref->{'yestrader'}{'ports'}{'udp'}{'1869'}++	; 
#	$ports_ref->{'udp'}{'1869'}{'name'} = 'yestrader'		; 
#	$srvcobjects_ref->{'yestrader'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'yestrader'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'yestrader'}{'port'}{'tcp'} = '1869'	; 
#	$srvcobjects_ref->{'yestrader'}{'ports'}{'tcp'}{'1869'}++	; 
#	$ports_ref->{'tcp'}{'1869'}{'name'} = 'yestrader'		; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'port'}{'udp'} = '5501'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'ports'}{'udp'}{'5501'}++	; 
#	$ports_ref->{'udp'}{'5501'}{'name'} = 'fcp-addr-srvr2'		; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'port'}{'tcp'} = '5501'	; 
#	$srvcobjects_ref->{'fcp-addr-srvr2'}{'ports'}{'tcp'}{'5501'}++	; 
#	$ports_ref->{'tcp'}{'5501'}{'name'} = 'fcp-addr-srvr2'		; 
#	$srvcobjects_ref->{'netwkpathengine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netwkpathengine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwkpathengine'}{'port'}{'udp'} = '3209'	; 
#	$srvcobjects_ref->{'netwkpathengine'}{'ports'}{'udp'}{'3209'}++	; 
#	$ports_ref->{'udp'}{'3209'}{'name'} = 'netwkpathengine'		; 
#	$srvcobjects_ref->{'netwkpathengine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netwkpathengine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwkpathengine'}{'port'}{'tcp'} = '3209'	; 
#	$srvcobjects_ref->{'netwkpathengine'}{'ports'}{'tcp'}{'3209'}++	; 
#	$ports_ref->{'tcp'}{'3209'}{'name'} = 'netwkpathengine'		; 
#	$srvcobjects_ref->{'time'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'time'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'time'}{'port'}{'udp'} = '37'	; 
#	$srvcobjects_ref->{'time'}{'ports'}{'udp'}{'37'}++	; 
#	$ports_ref->{'udp'}{'37'}{'name'} = 'time'		; 
#	$srvcobjects_ref->{'time'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'time'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'time'}{'port'}{'tcp'} = '37'	; 
#	$srvcobjects_ref->{'time'}{'ports'}{'tcp'}{'37'}++	; 
#	$ports_ref->{'tcp'}{'37'}{'name'} = 'time'		; 
#	$srvcobjects_ref->{'bgp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bgp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bgp'}{'port'}{'udp'} = '179'	; 
#	$srvcobjects_ref->{'bgp'}{'ports'}{'udp'}{'179'}++	; 
#	$ports_ref->{'udp'}{'179'}{'name'} = 'bgp'		; 
#	$srvcobjects_ref->{'bgp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bgp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bgp'}{'port'}{'tcp'} = '179'	; 
#	$srvcobjects_ref->{'bgp'}{'ports'}{'tcp'}{'179'}++	; 
#	$ports_ref->{'tcp'}{'179'}{'name'} = 'bgp'		; 
#	$srvcobjects_ref->{'murray'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'murray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'murray'}{'port'}{'udp'} = '1123'	; 
#	$srvcobjects_ref->{'murray'}{'ports'}{'udp'}{'1123'}++	; 
#	$ports_ref->{'udp'}{'1123'}{'name'} = 'murray'		; 
#	$srvcobjects_ref->{'murray'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'murray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'murray'}{'port'}{'tcp'} = '1123'	; 
#	$srvcobjects_ref->{'murray'}{'ports'}{'tcp'}{'1123'}++	; 
#	$ports_ref->{'tcp'}{'1123'}{'name'} = 'murray'		; 
#	$srvcobjects_ref->{'dvt-system'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dvt-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dvt-system'}{'port'}{'udp'} = '3246'	; 
#	$srvcobjects_ref->{'dvt-system'}{'ports'}{'udp'}{'3246'}++	; 
#	$ports_ref->{'udp'}{'3246'}{'name'} = 'dvt-system'		; 
#	$srvcobjects_ref->{'dvt-system'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dvt-system'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dvt-system'}{'port'}{'tcp'} = '3246'	; 
#	$srvcobjects_ref->{'dvt-system'}{'ports'}{'tcp'}{'3246'}++	; 
#	$ports_ref->{'tcp'}{'3246'}{'name'} = 'dvt-system'		; 
#	$srvcobjects_ref->{'ddm-dfm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ddm-dfm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddm-dfm'}{'port'}{'udp'} = '447'	; 
#	$srvcobjects_ref->{'ddm-dfm'}{'ports'}{'udp'}{'447'}++	; 
#	$ports_ref->{'udp'}{'447'}{'name'} = 'ddm-dfm'		; 
#	$srvcobjects_ref->{'ddm-dfm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ddm-dfm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ddm-dfm'}{'port'}{'tcp'} = '447'	; 
#	$srvcobjects_ref->{'ddm-dfm'}{'ports'}{'tcp'}{'447'}++	; 
#	$ports_ref->{'tcp'}{'447'}{'name'} = 'ddm-dfm'		; 
#	$srvcobjects_ref->{'med-supp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'med-supp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-supp'}{'port'}{'udp'} = '24003'	; 
#	$srvcobjects_ref->{'med-supp'}{'ports'}{'udp'}{'24003'}++	; 
#	$ports_ref->{'udp'}{'24003'}{'name'} = 'med-supp'		; 
#	$srvcobjects_ref->{'med-supp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'med-supp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'med-supp'}{'port'}{'tcp'} = '24003'	; 
#	$srvcobjects_ref->{'med-supp'}{'ports'}{'tcp'}{'24003'}++	; 
#	$ports_ref->{'tcp'}{'24003'}{'name'} = 'med-supp'		; 
#	$srvcobjects_ref->{'mpsserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpsserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpsserver'}{'port'}{'udp'} = '6106'	; 
#	$srvcobjects_ref->{'mpsserver'}{'ports'}{'udp'}{'6106'}++	; 
#	$ports_ref->{'udp'}{'6106'}{'name'} = 'mpsserver'		; 
#	$srvcobjects_ref->{'mpsserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpsserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpsserver'}{'port'}{'tcp'} = '6106'	; 
#	$srvcobjects_ref->{'mpsserver'}{'ports'}{'tcp'}{'6106'}++	; 
#	$ports_ref->{'tcp'}{'6106'}{'name'} = 'mpsserver'		; 
#	$srvcobjects_ref->{'call-logging'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'call-logging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'call-logging'}{'port'}{'udp'} = '2552'	; 
#	$srvcobjects_ref->{'call-logging'}{'ports'}{'udp'}{'2552'}++	; 
#	$ports_ref->{'udp'}{'2552'}{'name'} = 'call-logging'		; 
#	$srvcobjects_ref->{'call-logging'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'call-logging'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'call-logging'}{'port'}{'tcp'} = '2552'	; 
#	$srvcobjects_ref->{'call-logging'}{'ports'}{'tcp'}{'2552'}++	; 
#	$ports_ref->{'tcp'}{'2552'}{'name'} = 'call-logging'		; 
#	$srvcobjects_ref->{'at-5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'at-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-5'}{'port'}{'udp'} = '205'	; 
#	$srvcobjects_ref->{'at-5'}{'ports'}{'udp'}{'205'}++	; 
#	$ports_ref->{'udp'}{'205'}{'name'} = 'at-5'		; 
#	$srvcobjects_ref->{'at-5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'at-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'at-5'}{'port'}{'tcp'} = '205'	; 
#	$srvcobjects_ref->{'at-5'}{'ports'}{'tcp'}{'205'}++	; 
#	$ports_ref->{'tcp'}{'205'}{'name'} = 'at-5'		; 
#	$srvcobjects_ref->{'rwhois'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rwhois'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rwhois'}{'port'}{'udp'} = '4321'	; 
#	$srvcobjects_ref->{'rwhois'}{'ports'}{'udp'}{'4321'}++	; 
#	$ports_ref->{'udp'}{'4321'}{'name'} = 'rwhois'		; 
#	$srvcobjects_ref->{'rwhois'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rwhois'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rwhois'}{'port'}{'tcp'} = '4321'	; 
#	$srvcobjects_ref->{'rwhois'}{'ports'}{'tcp'}{'4321'}++	; 
#	$ports_ref->{'tcp'}{'4321'}{'name'} = 'rwhois'		; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'port'}{'udp'} = '3071'	; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'ports'}{'udp'}{'3071'}++	; 
#	$ports_ref->{'udp'}{'3071'}{'name'} = 'csd-mgmt-port'		; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'port'}{'tcp'} = '3071'	; 
#	$srvcobjects_ref->{'csd-mgmt-port'}{'ports'}{'tcp'}{'3071'}++	; 
#	$ports_ref->{'tcp'}{'3071'}{'name'} = 'csd-mgmt-port'		; 
#	$srvcobjects_ref->{'oracle-vp1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'oracle-vp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-vp1'}{'port'}{'udp'} = '1809'	; 
#	$srvcobjects_ref->{'oracle-vp1'}{'ports'}{'udp'}{'1809'}++	; 
#	$ports_ref->{'udp'}{'1809'}{'name'} = 'oracle-vp1'		; 
#	$srvcobjects_ref->{'oracle-vp1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'oracle-vp1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'oracle-vp1'}{'port'}{'tcp'} = '1809'	; 
#	$srvcobjects_ref->{'oracle-vp1'}{'ports'}{'tcp'}{'1809'}++	; 
#	$ports_ref->{'tcp'}{'1809'}{'name'} = 'oracle-vp1'		; 
#	$srvcobjects_ref->{'jacobus-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jacobus-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jacobus-lm'}{'port'}{'udp'} = '1578'	; 
#	$srvcobjects_ref->{'jacobus-lm'}{'ports'}{'udp'}{'1578'}++	; 
#	$ports_ref->{'udp'}{'1578'}{'name'} = 'jacobus-lm'		; 
#	$srvcobjects_ref->{'jacobus-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jacobus-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jacobus-lm'}{'port'}{'tcp'} = '1578'	; 
#	$srvcobjects_ref->{'jacobus-lm'}{'ports'}{'tcp'}{'1578'}++	; 
#	$ports_ref->{'tcp'}{'1578'}{'name'} = 'jacobus-lm'		; 
#	$srvcobjects_ref->{'sco-aip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sco-aip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-aip'}{'port'}{'udp'} = '5307'	; 
#	$srvcobjects_ref->{'sco-aip'}{'ports'}{'udp'}{'5307'}++	; 
#	$ports_ref->{'udp'}{'5307'}{'name'} = 'sco-aip'		; 
#	$srvcobjects_ref->{'sco-aip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sco-aip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-aip'}{'port'}{'tcp'} = '5307'	; 
#	$srvcobjects_ref->{'sco-aip'}{'ports'}{'tcp'}{'5307'}++	; 
#	$ports_ref->{'tcp'}{'5307'}{'name'} = 'sco-aip'		; 
#	$srvcobjects_ref->{'http-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'http-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-mgmt'}{'port'}{'udp'} = '280'	; 
#	$srvcobjects_ref->{'http-mgmt'}{'ports'}{'udp'}{'280'}++	; 
#	$ports_ref->{'udp'}{'280'}{'name'} = 'http-mgmt'		; 
#	$srvcobjects_ref->{'http-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'http-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'http-mgmt'}{'port'}{'tcp'} = '280'	; 
#	$srvcobjects_ref->{'http-mgmt'}{'ports'}{'tcp'}{'280'}++	; 
#	$ports_ref->{'tcp'}{'280'}{'name'} = 'http-mgmt'		; 
#	$srvcobjects_ref->{'eserver-pap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eserver-pap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eserver-pap'}{'port'}{'udp'} = '3666'	; 
#	$srvcobjects_ref->{'eserver-pap'}{'ports'}{'udp'}{'3666'}++	; 
#	$ports_ref->{'udp'}{'3666'}{'name'} = 'eserver-pap'		; 
#	$srvcobjects_ref->{'eserver-pap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eserver-pap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eserver-pap'}{'port'}{'tcp'} = '3666'	; 
#	$srvcobjects_ref->{'eserver-pap'}{'ports'}{'tcp'}{'3666'}++	; 
#	$ports_ref->{'tcp'}{'3666'}{'name'} = 'eserver-pap'		; 
#	$srvcobjects_ref->{'gcm-app'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gcm-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gcm-app'}{'port'}{'udp'} = '14145'	; 
#	$srvcobjects_ref->{'gcm-app'}{'ports'}{'udp'}{'14145'}++	; 
#	$ports_ref->{'udp'}{'14145'}{'name'} = 'gcm-app'		; 
#	$srvcobjects_ref->{'gcm-app'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gcm-app'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gcm-app'}{'port'}{'tcp'} = '14145'	; 
#	$srvcobjects_ref->{'gcm-app'}{'ports'}{'tcp'}{'14145'}++	; 
#	$ports_ref->{'tcp'}{'14145'}{'name'} = 'gcm-app'		; 
#	$srvcobjects_ref->{'neon24x7'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'neon24x7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neon24x7'}{'port'}{'udp'} = '3213'	; 
#	$srvcobjects_ref->{'neon24x7'}{'ports'}{'udp'}{'3213'}++	; 
#	$ports_ref->{'udp'}{'3213'}{'name'} = 'neon24x7'		; 
#	$srvcobjects_ref->{'neon24x7'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'neon24x7'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neon24x7'}{'port'}{'tcp'} = '3213'	; 
#	$srvcobjects_ref->{'neon24x7'}{'ports'}{'tcp'}{'3213'}++	; 
#	$ports_ref->{'tcp'}{'3213'}{'name'} = 'neon24x7'		; 
#	$srvcobjects_ref->{'camac'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'camac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'camac'}{'port'}{'udp'} = '3545'	; 
#	$srvcobjects_ref->{'camac'}{'ports'}{'udp'}{'3545'}++	; 
#	$ports_ref->{'udp'}{'3545'}{'name'} = 'camac'		; 
#	$srvcobjects_ref->{'camac'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'camac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'camac'}{'port'}{'tcp'} = '3545'	; 
#	$srvcobjects_ref->{'camac'}{'ports'}{'tcp'}{'3545'}++	; 
#	$ports_ref->{'tcp'}{'3545'}{'name'} = 'camac'		; 
#	$srvcobjects_ref->{'docstor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'docstor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'docstor'}{'port'}{'udp'} = '1488'	; 
#	$srvcobjects_ref->{'docstor'}{'ports'}{'udp'}{'1488'}++	; 
#	$ports_ref->{'udp'}{'1488'}{'name'} = 'docstor'		; 
#	$srvcobjects_ref->{'docstor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'docstor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'docstor'}{'port'}{'tcp'} = '1488'	; 
#	$srvcobjects_ref->{'docstor'}{'ports'}{'tcp'}{'1488'}++	; 
#	$ports_ref->{'tcp'}{'1488'}{'name'} = 'docstor'		; 
#	$srvcobjects_ref->{'cert-initiator'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cert-initiator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cert-initiator'}{'port'}{'udp'} = '1639'	; 
#	$srvcobjects_ref->{'cert-initiator'}{'ports'}{'udp'}{'1639'}++	; 
#	$ports_ref->{'udp'}{'1639'}{'name'} = 'cert-initiator'		; 
#	$srvcobjects_ref->{'cert-initiator'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cert-initiator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cert-initiator'}{'port'}{'tcp'} = '1639'	; 
#	$srvcobjects_ref->{'cert-initiator'}{'ports'}{'tcp'}{'1639'}++	; 
#	$ports_ref->{'tcp'}{'1639'}{'name'} = 'cert-initiator'		; 
#	$srvcobjects_ref->{'adobeserver-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'adobeserver-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-1'}{'port'}{'udp'} = '1102'	; 
#	$srvcobjects_ref->{'adobeserver-1'}{'ports'}{'udp'}{'1102'}++	; 
#	$ports_ref->{'udp'}{'1102'}{'name'} = 'adobeserver-1'		; 
#	$srvcobjects_ref->{'adobeserver-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'adobeserver-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'adobeserver-1'}{'port'}{'tcp'} = '1102'	; 
#	$srvcobjects_ref->{'adobeserver-1'}{'ports'}{'tcp'}{'1102'}++	; 
#	$ports_ref->{'tcp'}{'1102'}{'name'} = 'adobeserver-1'		; 
#	$srvcobjects_ref->{'discp-client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'discp-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discp-client'}{'port'}{'udp'} = '2601'	; 
#	$srvcobjects_ref->{'discp-client'}{'ports'}{'udp'}{'2601'}++	; 
#	$ports_ref->{'udp'}{'2601'}{'name'} = 'discp-client'		; 
#	$srvcobjects_ref->{'discp-client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'discp-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discp-client'}{'port'}{'tcp'} = '2601'	; 
#	$srvcobjects_ref->{'discp-client'}{'ports'}{'tcp'}{'2601'}++	; 
#	$ports_ref->{'tcp'}{'2601'}{'name'} = 'discp-client'		; 
#	$srvcobjects_ref->{'ads'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ads'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ads'}{'port'}{'udp'} = '2550'	; 
#	$srvcobjects_ref->{'ads'}{'ports'}{'udp'}{'2550'}++	; 
#	$ports_ref->{'udp'}{'2550'}{'name'} = 'ads'		; 
#	$srvcobjects_ref->{'ads'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ads'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ads'}{'port'}{'tcp'} = '2550'	; 
#	$srvcobjects_ref->{'ads'}{'ports'}{'tcp'}{'2550'}++	; 
#	$ports_ref->{'tcp'}{'2550'}{'name'} = 'ads'		; 
#	$srvcobjects_ref->{'server-find'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'server-find'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'server-find'}{'port'}{'udp'} = '8351'	; 
#	$srvcobjects_ref->{'server-find'}{'ports'}{'udp'}{'8351'}++	; 
#	$ports_ref->{'udp'}{'8351'}{'name'} = 'server-find'		; 
#	$srvcobjects_ref->{'server-find'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'server-find'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'server-find'}{'port'}{'tcp'} = '8351'	; 
#	$srvcobjects_ref->{'server-find'}{'ports'}{'tcp'}{'8351'}++	; 
#	$ports_ref->{'tcp'}{'8351'}{'name'} = 'server-find'		; 
#	$srvcobjects_ref->{'excerpt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'excerpt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'excerpt'}{'port'}{'udp'} = '5400'	; 
#	$srvcobjects_ref->{'excerpt'}{'ports'}{'udp'}{'5400'}++	; 
#	$ports_ref->{'udp'}{'5400'}{'name'} = 'excerpt'		; 
#	$srvcobjects_ref->{'excerpt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'excerpt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'excerpt'}{'port'}{'tcp'} = '5400'	; 
#	$srvcobjects_ref->{'excerpt'}{'ports'}{'tcp'}{'5400'}++	; 
#	$ports_ref->{'tcp'}{'5400'}{'name'} = 'excerpt'		; 
#	$srvcobjects_ref->{'cops-tls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cops-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cops-tls'}{'port'}{'udp'} = '3183'	; 
#	$srvcobjects_ref->{'cops-tls'}{'ports'}{'udp'}{'3183'}++	; 
#	$ports_ref->{'udp'}{'3183'}{'name'} = 'cops-tls'		; 
#	$srvcobjects_ref->{'cops-tls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cops-tls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cops-tls'}{'port'}{'tcp'} = '3183'	; 
#	$srvcobjects_ref->{'cops-tls'}{'ports'}{'tcp'}{'3183'}++	; 
#	$ports_ref->{'tcp'}{'3183'}{'name'} = 'cops-tls'		; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'port'}{'udp'} = '1904'	; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'ports'}{'udp'}{'1904'}++	; 
#	$ports_ref->{'udp'}{'1904'}{'name'} = 'fjicl-tep-c'		; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'port'}{'tcp'} = '1904'	; 
#	$srvcobjects_ref->{'fjicl-tep-c'}{'ports'}{'tcp'}{'1904'}++	; 
#	$ports_ref->{'tcp'}{'1904'}{'name'} = 'fjicl-tep-c'		; 
#	$srvcobjects_ref->{'ph'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ph'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ph'}{'port'}{'udp'} = '481'	; 
#	$srvcobjects_ref->{'ph'}{'ports'}{'udp'}{'481'}++	; 
#	$ports_ref->{'udp'}{'481'}{'name'} = 'ph'		; 
#	$srvcobjects_ref->{'ph'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ph'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ph'}{'port'}{'tcp'} = '481'	; 
#	$srvcobjects_ref->{'ph'}{'ports'}{'tcp'}{'481'}++	; 
#	$ports_ref->{'tcp'}{'481'}{'name'} = 'ph'		; 
#	$srvcobjects_ref->{'slc-systemlog'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slc-systemlog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slc-systemlog'}{'port'}{'udp'} = '2826'	; 
#	$srvcobjects_ref->{'slc-systemlog'}{'ports'}{'udp'}{'2826'}++	; 
#	$ports_ref->{'udp'}{'2826'}{'name'} = 'slc-systemlog'		; 
#	$srvcobjects_ref->{'slc-systemlog'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slc-systemlog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slc-systemlog'}{'port'}{'tcp'} = '2826'	; 
#	$srvcobjects_ref->{'slc-systemlog'}{'ports'}{'tcp'}{'2826'}++	; 
#	$ports_ref->{'tcp'}{'2826'}{'name'} = 'slc-systemlog'		; 
#	$srvcobjects_ref->{'urbisnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'urbisnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'urbisnet'}{'port'}{'udp'} = '2745'	; 
#	$srvcobjects_ref->{'urbisnet'}{'ports'}{'udp'}{'2745'}++	; 
#	$ports_ref->{'udp'}{'2745'}{'name'} = 'urbisnet'		; 
#	$srvcobjects_ref->{'urbisnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'urbisnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'urbisnet'}{'port'}{'tcp'} = '2745'	; 
#	$srvcobjects_ref->{'urbisnet'}{'ports'}{'tcp'}{'2745'}++	; 
#	$ports_ref->{'tcp'}{'2745'}{'name'} = 'urbisnet'		; 
#	$srvcobjects_ref->{'parsec-peer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'parsec-peer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parsec-peer'}{'port'}{'udp'} = '6581'	; 
#	$srvcobjects_ref->{'parsec-peer'}{'ports'}{'udp'}{'6581'}++	; 
#	$ports_ref->{'udp'}{'6581'}{'name'} = 'parsec-peer'		; 
#	$srvcobjects_ref->{'parsec-peer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'parsec-peer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'parsec-peer'}{'port'}{'tcp'} = '6581'	; 
#	$srvcobjects_ref->{'parsec-peer'}{'ports'}{'tcp'}{'6581'}++	; 
#	$ports_ref->{'tcp'}{'6581'}{'name'} = 'parsec-peer'		; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'port'}{'udp'} = '3062'	; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'ports'}{'udp'}{'3062'}++	; 
#	$ports_ref->{'udp'}{'3062'}{'name'} = 'ncacn-ip-tcp'		; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'port'}{'tcp'} = '3062'	; 
#	$srvcobjects_ref->{'ncacn-ip-tcp'}{'ports'}{'tcp'}{'3062'}++	; 
#	$ports_ref->{'tcp'}{'3062'}{'name'} = 'ncacn-ip-tcp'		; 
#	$srvcobjects_ref->{'opsession-clnt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsession-clnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsession-clnt'}{'port'}{'udp'} = '3303'	; 
#	$srvcobjects_ref->{'opsession-clnt'}{'ports'}{'udp'}{'3303'}++	; 
#	$ports_ref->{'udp'}{'3303'}{'name'} = 'opsession-clnt'		; 
#	$srvcobjects_ref->{'opsession-clnt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsession-clnt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsession-clnt'}{'port'}{'tcp'} = '3303'	; 
#	$srvcobjects_ref->{'opsession-clnt'}{'ports'}{'tcp'}{'3303'}++	; 
#	$ports_ref->{'tcp'}{'3303'}{'name'} = 'opsession-clnt'		; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'port'}{'udp'} = '5306'	; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'ports'}{'udp'}{'5306'}++	; 
#	$ports_ref->{'udp'}{'5306'}{'name'} = 'sun-mc-grp'		; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'port'}{'tcp'} = '5306'	; 
#	$srvcobjects_ref->{'sun-mc-grp'}{'ports'}{'tcp'}{'5306'}++	; 
#	$ports_ref->{'tcp'}{'5306'}{'name'} = 'sun-mc-grp'		; 
#	$srvcobjects_ref->{'cordataport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cordataport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cordataport'}{'port'}{'udp'} = '3193'	; 
#	$srvcobjects_ref->{'cordataport'}{'ports'}{'udp'}{'3193'}++	; 
#	$ports_ref->{'udp'}{'3193'}{'name'} = 'cordataport'		; 
#	$srvcobjects_ref->{'cordataport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cordataport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cordataport'}{'port'}{'tcp'} = '3193'	; 
#	$srvcobjects_ref->{'cordataport'}{'ports'}{'tcp'}{'3193'}++	; 
#	$ports_ref->{'tcp'}{'3193'}{'name'} = 'cordataport'		; 
#	$srvcobjects_ref->{'acp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'acp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acp-port'}{'port'}{'udp'} = '2071'	; 
#	$srvcobjects_ref->{'acp-port'}{'ports'}{'udp'}{'2071'}++	; 
#	$ports_ref->{'udp'}{'2071'}{'name'} = 'acp-port'		; 
#	$srvcobjects_ref->{'acp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'acp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'acp-port'}{'port'}{'tcp'} = '2071'	; 
#	$srvcobjects_ref->{'acp-port'}{'ports'}{'tcp'}{'2071'}++	; 
#	$ports_ref->{'tcp'}{'2071'}{'name'} = 'acp-port'		; 
#	$srvcobjects_ref->{'fs-qos'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fs-qos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fs-qos'}{'port'}{'udp'} = '41111'	; 
#	$srvcobjects_ref->{'fs-qos'}{'ports'}{'udp'}{'41111'}++	; 
#	$ports_ref->{'udp'}{'41111'}{'name'} = 'fs-qos'		; 
#	$srvcobjects_ref->{'fs-qos'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fs-qos'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fs-qos'}{'port'}{'tcp'} = '41111'	; 
#	$srvcobjects_ref->{'fs-qos'}{'ports'}{'tcp'}{'41111'}++	; 
#	$ports_ref->{'tcp'}{'41111'}{'name'} = 'fs-qos'		; 
#	$srvcobjects_ref->{'cruise-update'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cruise-update'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-update'}{'port'}{'udp'} = '8380'	; 
#	$srvcobjects_ref->{'cruise-update'}{'ports'}{'udp'}{'8380'}++	; 
#	$ports_ref->{'udp'}{'8380'}{'name'} = 'cruise-update'		; 
#	$srvcobjects_ref->{'cruise-update'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cruise-update'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cruise-update'}{'port'}{'tcp'} = '8380'	; 
#	$srvcobjects_ref->{'cruise-update'}{'ports'}{'tcp'}{'8380'}++	; 
#	$ports_ref->{'tcp'}{'8380'}{'name'} = 'cruise-update'		; 
#	$srvcobjects_ref->{'netwall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netwall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwall'}{'port'}{'udp'} = '533'	; 
#	$srvcobjects_ref->{'netwall'}{'ports'}{'udp'}{'533'}++	; 
#	$ports_ref->{'udp'}{'533'}{'name'} = 'netwall'		; 
#	$srvcobjects_ref->{'netwall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netwall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwall'}{'port'}{'tcp'} = '533'	; 
#	$srvcobjects_ref->{'netwall'}{'ports'}{'tcp'}{'533'}++	; 
#	$ports_ref->{'tcp'}{'533'}{'name'} = 'netwall'		; 
#	$srvcobjects_ref->{'sxuptp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sxuptp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sxuptp'}{'port'}{'udp'} = '19540'	; 
#	$srvcobjects_ref->{'sxuptp'}{'ports'}{'udp'}{'19540'}++	; 
#	$ports_ref->{'udp'}{'19540'}{'name'} = 'sxuptp'		; 
#	$srvcobjects_ref->{'sxuptp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sxuptp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sxuptp'}{'port'}{'tcp'} = '19540'	; 
#	$srvcobjects_ref->{'sxuptp'}{'ports'}{'tcp'}{'19540'}++	; 
#	$ports_ref->{'tcp'}{'19540'}{'name'} = 'sxuptp'		; 
#	$srvcobjects_ref->{'radio-sm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'radio-sm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'radio-sm'}{'port'}{'tcp'} = '1596'	; 
#	$srvcobjects_ref->{'radio-sm'}{'ports'}{'tcp'}{'1596'}++	; 
#	$ports_ref->{'tcp'}{'1596'}{'name'} = 'radio-sm'		; 
#	$srvcobjects_ref->{'rtraceroute'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtraceroute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtraceroute'}{'port'}{'udp'} = '3765'	; 
#	$srvcobjects_ref->{'rtraceroute'}{'ports'}{'udp'}{'3765'}++	; 
#	$ports_ref->{'udp'}{'3765'}{'name'} = 'rtraceroute'		; 
#	$srvcobjects_ref->{'rtraceroute'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtraceroute'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtraceroute'}{'port'}{'tcp'} = '3765'	; 
#	$srvcobjects_ref->{'rtraceroute'}{'ports'}{'tcp'}{'3765'}++	; 
#	$ports_ref->{'tcp'}{'3765'}{'name'} = 'rtraceroute'		; 
#	$srvcobjects_ref->{'mloadd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mloadd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mloadd'}{'port'}{'udp'} = '1427'	; 
#	$srvcobjects_ref->{'mloadd'}{'ports'}{'udp'}{'1427'}++	; 
#	$ports_ref->{'udp'}{'1427'}{'name'} = 'mloadd'		; 
#	$srvcobjects_ref->{'mloadd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mloadd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mloadd'}{'port'}{'tcp'} = '1427'	; 
#	$srvcobjects_ref->{'mloadd'}{'ports'}{'tcp'}{'1427'}++	; 
#	$ports_ref->{'tcp'}{'1427'}{'name'} = 'mloadd'		; 
#	$srvcobjects_ref->{'cal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cal'}{'port'}{'udp'} = '588'	; 
#	$srvcobjects_ref->{'cal'}{'ports'}{'udp'}{'588'}++	; 
#	$ports_ref->{'udp'}{'588'}{'name'} = 'cal'		; 
#	$srvcobjects_ref->{'cal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cal'}{'port'}{'tcp'} = '588'	; 
#	$srvcobjects_ref->{'cal'}{'ports'}{'tcp'}{'588'}++	; 
#	$ports_ref->{'tcp'}{'588'}{'name'} = 'cal'		; 
#	$srvcobjects_ref->{'interintelli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'interintelli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interintelli'}{'port'}{'udp'} = '2633'	; 
#	$srvcobjects_ref->{'interintelli'}{'ports'}{'udp'}{'2633'}++	; 
#	$ports_ref->{'udp'}{'2633'}{'name'} = 'interintelli'		; 
#	$srvcobjects_ref->{'interintelli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'interintelli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'interintelli'}{'port'}{'tcp'} = '2633'	; 
#	$srvcobjects_ref->{'interintelli'}{'ports'}{'tcp'}{'2633'}++	; 
#	$ports_ref->{'tcp'}{'2633'}{'name'} = 'interintelli'		; 
#	$srvcobjects_ref->{'knet-cmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'knet-cmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'knet-cmp'}{'port'}{'udp'} = '157'	; 
#	$srvcobjects_ref->{'knet-cmp'}{'ports'}{'udp'}{'157'}++	; 
#	$ports_ref->{'udp'}{'157'}{'name'} = 'knet-cmp'		; 
#	$srvcobjects_ref->{'knet-cmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'knet-cmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'knet-cmp'}{'port'}{'tcp'} = '157'	; 
#	$srvcobjects_ref->{'knet-cmp'}{'ports'}{'tcp'}{'157'}++	; 
#	$ports_ref->{'tcp'}{'157'}{'name'} = 'knet-cmp'		; 
#	$srvcobjects_ref->{'crestron-ctp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'crestron-ctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crestron-ctp'}{'port'}{'udp'} = '41795'	; 
#	$srvcobjects_ref->{'crestron-ctp'}{'ports'}{'udp'}{'41795'}++	; 
#	$ports_ref->{'udp'}{'41795'}{'name'} = 'crestron-ctp'		; 
#	$srvcobjects_ref->{'crestron-ctp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'crestron-ctp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'crestron-ctp'}{'port'}{'tcp'} = '41795'	; 
#	$srvcobjects_ref->{'crestron-ctp'}{'ports'}{'tcp'}{'41795'}++	; 
#	$ports_ref->{'tcp'}{'41795'}{'name'} = 'crestron-ctp'		; 
#	$srvcobjects_ref->{'metaconsole'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metaconsole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metaconsole'}{'port'}{'udp'} = '2850'	; 
#	$srvcobjects_ref->{'metaconsole'}{'ports'}{'udp'}{'2850'}++	; 
#	$ports_ref->{'udp'}{'2850'}{'name'} = 'metaconsole'		; 
#	$srvcobjects_ref->{'metaconsole'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metaconsole'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metaconsole'}{'port'}{'tcp'} = '2850'	; 
#	$srvcobjects_ref->{'metaconsole'}{'ports'}{'tcp'}{'2850'}++	; 
#	$ports_ref->{'tcp'}{'2850'}{'name'} = 'metaconsole'		; 
#	$srvcobjects_ref->{'sanity'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sanity'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sanity'}{'port'}{'udp'} = '643'	; 
#	$srvcobjects_ref->{'sanity'}{'ports'}{'udp'}{'643'}++	; 
#	$ports_ref->{'udp'}{'643'}{'name'} = 'sanity'		; 
#	$srvcobjects_ref->{'sanity'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sanity'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sanity'}{'port'}{'tcp'} = '643'	; 
#	$srvcobjects_ref->{'sanity'}{'ports'}{'tcp'}{'643'}++	; 
#	$ports_ref->{'tcp'}{'643'}{'name'} = 'sanity'		; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'port'}{'udp'} = '1855'	; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'ports'}{'udp'}{'1855'}++	; 
#	$ports_ref->{'udp'}{'1855'}{'name'} = 'fiorano-rtrsvc'		; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'port'}{'tcp'} = '1855'	; 
#	$srvcobjects_ref->{'fiorano-rtrsvc'}{'ports'}{'tcp'}{'1855'}++	; 
#	$ports_ref->{'tcp'}{'1855'}{'name'} = 'fiorano-rtrsvc'		; 
#	$srvcobjects_ref->{'flashfiler'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'flashfiler'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flashfiler'}{'port'}{'udp'} = '24677'	; 
#	$srvcobjects_ref->{'flashfiler'}{'ports'}{'udp'}{'24677'}++	; 
#	$ports_ref->{'udp'}{'24677'}{'name'} = 'flashfiler'		; 
#	$srvcobjects_ref->{'flashfiler'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'flashfiler'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flashfiler'}{'port'}{'tcp'} = '24677'	; 
#	$srvcobjects_ref->{'flashfiler'}{'ports'}{'tcp'}{'24677'}++	; 
#	$ports_ref->{'tcp'}{'24677'}{'name'} = 'flashfiler'		; 
#	$srvcobjects_ref->{'cso'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cso'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cso'}{'port'}{'udp'} = '105'	; 
#	$srvcobjects_ref->{'cso'}{'ports'}{'udp'}{'105'}++	; 
#	$ports_ref->{'udp'}{'105'}{'name'} = 'cso'		; 
#	$srvcobjects_ref->{'cso'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cso'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cso'}{'port'}{'tcp'} = '105'	; 
#	$srvcobjects_ref->{'cso'}{'ports'}{'tcp'}{'105'}++	; 
#	$ports_ref->{'tcp'}{'105'}{'name'} = 'cso'		; 
#	$srvcobjects_ref->{'openmath'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openmath'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmath'}{'port'}{'udp'} = '1473'	; 
#	$srvcobjects_ref->{'openmath'}{'ports'}{'udp'}{'1473'}++	; 
#	$ports_ref->{'udp'}{'1473'}{'name'} = 'openmath'		; 
#	$srvcobjects_ref->{'openmath'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openmath'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmath'}{'port'}{'tcp'} = '1473'	; 
#	$srvcobjects_ref->{'openmath'}{'ports'}{'tcp'}{'1473'}++	; 
#	$ports_ref->{'tcp'}{'1473'}{'name'} = 'openmath'		; 
#	$srvcobjects_ref->{'wwiotalk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wwiotalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wwiotalk'}{'port'}{'udp'} = '5413'	; 
#	$srvcobjects_ref->{'wwiotalk'}{'ports'}{'udp'}{'5413'}++	; 
#	$ports_ref->{'udp'}{'5413'}{'name'} = 'wwiotalk'		; 
#	$srvcobjects_ref->{'wwiotalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wwiotalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wwiotalk'}{'port'}{'tcp'} = '5413'	; 
#	$srvcobjects_ref->{'wwiotalk'}{'ports'}{'tcp'}{'5413'}++	; 
#	$ports_ref->{'tcp'}{'5413'}{'name'} = 'wwiotalk'		; 
#	$srvcobjects_ref->{'tftps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tftps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tftps'}{'port'}{'udp'} = '3713'	; 
#	$srvcobjects_ref->{'tftps'}{'ports'}{'udp'}{'3713'}++	; 
#	$ports_ref->{'udp'}{'3713'}{'name'} = 'tftps'		; 
#	$srvcobjects_ref->{'tftps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tftps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tftps'}{'port'}{'tcp'} = '3713'	; 
#	$srvcobjects_ref->{'tftps'}{'ports'}{'tcp'}{'3713'}++	; 
#	$ports_ref->{'tcp'}{'3713'}{'name'} = 'tftps'		; 
#	$srvcobjects_ref->{'vsaiport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsaiport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsaiport'}{'port'}{'udp'} = '3317'	; 
#	$srvcobjects_ref->{'vsaiport'}{'ports'}{'udp'}{'3317'}++	; 
#	$ports_ref->{'udp'}{'3317'}{'name'} = 'vsaiport'		; 
#	$srvcobjects_ref->{'vsaiport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsaiport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsaiport'}{'port'}{'tcp'} = '3317'	; 
#	$srvcobjects_ref->{'vsaiport'}{'ports'}{'tcp'}{'3317'}++	; 
#	$ports_ref->{'tcp'}{'3317'}{'name'} = 'vsaiport'		; 
#	$srvcobjects_ref->{'nati-dstp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nati-dstp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-dstp'}{'port'}{'udp'} = '3015'	; 
#	$srvcobjects_ref->{'nati-dstp'}{'ports'}{'udp'}{'3015'}++	; 
#	$ports_ref->{'udp'}{'3015'}{'name'} = 'nati-dstp'		; 
#	$srvcobjects_ref->{'nati-dstp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nati-dstp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nati-dstp'}{'port'}{'tcp'} = '3015'	; 
#	$srvcobjects_ref->{'nati-dstp'}{'ports'}{'tcp'}{'3015'}++	; 
#	$ports_ref->{'tcp'}{'3015'}{'name'} = 'nati-dstp'		; 
#	$srvcobjects_ref->{'asi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'asi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asi'}{'port'}{'udp'} = '1827'	; 
#	$srvcobjects_ref->{'asi'}{'ports'}{'udp'}{'1827'}++	; 
#	$ports_ref->{'udp'}{'1827'}{'name'} = 'asi'		; 
#	$srvcobjects_ref->{'asi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'asi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'asi'}{'port'}{'tcp'} = '1827'	; 
#	$srvcobjects_ref->{'asi'}{'ports'}{'tcp'}{'1827'}++	; 
#	$ports_ref->{'tcp'}{'1827'}{'name'} = 'asi'		; 
#	$srvcobjects_ref->{'finle-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'finle-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'finle-lm'}{'port'}{'udp'} = '1784'	; 
#	$srvcobjects_ref->{'finle-lm'}{'ports'}{'udp'}{'1784'}++	; 
#	$ports_ref->{'udp'}{'1784'}{'name'} = 'finle-lm'		; 
#	$srvcobjects_ref->{'finle-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'finle-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'finle-lm'}{'port'}{'tcp'} = '1784'	; 
#	$srvcobjects_ref->{'finle-lm'}{'ports'}{'tcp'}{'1784'}++	; 
#	$ports_ref->{'tcp'}{'1784'}{'name'} = 'finle-lm'		; 
#	$srvcobjects_ref->{'madcap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'madcap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'madcap'}{'port'}{'udp'} = '2535'	; 
#	$srvcobjects_ref->{'madcap'}{'ports'}{'udp'}{'2535'}++	; 
#	$ports_ref->{'udp'}{'2535'}{'name'} = 'madcap'		; 
#	$srvcobjects_ref->{'madcap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'madcap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'madcap'}{'port'}{'tcp'} = '2535'	; 
#	$srvcobjects_ref->{'madcap'}{'ports'}{'tcp'}{'2535'}++	; 
#	$ports_ref->{'tcp'}{'2535'}{'name'} = 'madcap'		; 
#	$srvcobjects_ref->{'rt-event'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rt-event'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rt-event'}{'port'}{'udp'} = '3706'	; 
#	$srvcobjects_ref->{'rt-event'}{'ports'}{'udp'}{'3706'}++	; 
#	$ports_ref->{'udp'}{'3706'}{'name'} = 'rt-event'		; 
#	$srvcobjects_ref->{'rt-event'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rt-event'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rt-event'}{'port'}{'tcp'} = '3706'	; 
#	$srvcobjects_ref->{'rt-event'}{'ports'}{'tcp'}{'3706'}++	; 
#	$ports_ref->{'tcp'}{'3706'}{'name'} = 'rt-event'		; 
#	$srvcobjects_ref->{'is99s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'is99s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'is99s'}{'port'}{'udp'} = '380'	; 
#	$srvcobjects_ref->{'is99s'}{'ports'}{'udp'}{'380'}++	; 
#	$ports_ref->{'udp'}{'380'}{'name'} = 'is99s'		; 
#	$srvcobjects_ref->{'is99s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'is99s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'is99s'}{'port'}{'tcp'} = '380'	; 
#	$srvcobjects_ref->{'is99s'}{'ports'}{'tcp'}{'380'}++	; 
#	$ports_ref->{'tcp'}{'380'}{'name'} = 'is99s'		; 
#	$srvcobjects_ref->{'taskman-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'taskman-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taskman-port'}{'port'}{'udp'} = '2470'	; 
#	$srvcobjects_ref->{'taskman-port'}{'ports'}{'udp'}{'2470'}++	; 
#	$ports_ref->{'udp'}{'2470'}{'name'} = 'taskman-port'		; 
#	$srvcobjects_ref->{'taskman-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'taskman-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taskman-port'}{'port'}{'tcp'} = '2470'	; 
#	$srvcobjects_ref->{'taskman-port'}{'ports'}{'tcp'}{'2470'}++	; 
#	$ports_ref->{'tcp'}{'2470'}{'name'} = 'taskman-port'		; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'port'}{'udp'} = '5403'	; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'ports'}{'udp'}{'5403'}++	; 
#	$ports_ref->{'udp'}{'5403'}{'name'} = 'hpoms-ci-lstn'		; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'port'}{'tcp'} = '5403'	; 
#	$srvcobjects_ref->{'hpoms-ci-lstn'}{'ports'}{'tcp'}{'5403'}++	; 
#	$ports_ref->{'tcp'}{'5403'}{'name'} = 'hpoms-ci-lstn'		; 
#	$srvcobjects_ref->{'watcomdebug'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'watcomdebug'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watcomdebug'}{'port'}{'udp'} = '3563'	; 
#	$srvcobjects_ref->{'watcomdebug'}{'ports'}{'udp'}{'3563'}++	; 
#	$ports_ref->{'udp'}{'3563'}{'name'} = 'watcomdebug'		; 
#	$srvcobjects_ref->{'watcomdebug'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'watcomdebug'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'watcomdebug'}{'port'}{'tcp'} = '3563'	; 
#	$srvcobjects_ref->{'watcomdebug'}{'ports'}{'tcp'}{'3563'}++	; 
#	$ports_ref->{'tcp'}{'3563'}{'name'} = 'watcomdebug'		; 
#	$srvcobjects_ref->{'anet-b'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'anet-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-b'}{'port'}{'udp'} = '3338'	; 
#	$srvcobjects_ref->{'anet-b'}{'ports'}{'udp'}{'3338'}++	; 
#	$ports_ref->{'udp'}{'3338'}{'name'} = 'anet-b'		; 
#	$srvcobjects_ref->{'anet-b'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'anet-b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'anet-b'}{'port'}{'tcp'} = '3338'	; 
#	$srvcobjects_ref->{'anet-b'}{'ports'}{'tcp'}{'3338'}++	; 
#	$ports_ref->{'tcp'}{'3338'}{'name'} = 'anet-b'		; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'port'}{'udp'} = '2638'	; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'ports'}{'udp'}{'2638'}++	; 
#	$ports_ref->{'udp'}{'2638'}{'name'} = 'sybaseanywhere'		; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'port'}{'tcp'} = '2638'	; 
#	$srvcobjects_ref->{'sybaseanywhere'}{'ports'}{'tcp'}{'2638'}++	; 
#	$ports_ref->{'tcp'}{'2638'}{'name'} = 'sybaseanywhere'		; 
#	$srvcobjects_ref->{'csi-sgwp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'csi-sgwp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csi-sgwp'}{'port'}{'udp'} = '348'	; 
#	$srvcobjects_ref->{'csi-sgwp'}{'ports'}{'udp'}{'348'}++	; 
#	$ports_ref->{'udp'}{'348'}{'name'} = 'csi-sgwp'		; 
#	$srvcobjects_ref->{'csi-sgwp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'csi-sgwp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'csi-sgwp'}{'port'}{'tcp'} = '348'	; 
#	$srvcobjects_ref->{'csi-sgwp'}{'ports'}{'tcp'}{'348'}++	; 
#	$ports_ref->{'tcp'}{'348'}{'name'} = 'csi-sgwp'		; 
#	$srvcobjects_ref->{'cncp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cncp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cncp'}{'port'}{'udp'} = '1636'	; 
#	$srvcobjects_ref->{'cncp'}{'ports'}{'udp'}{'1636'}++	; 
#	$ports_ref->{'udp'}{'1636'}{'name'} = 'cncp'		; 
#	$srvcobjects_ref->{'cncp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cncp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cncp'}{'port'}{'tcp'} = '1636'	; 
#	$srvcobjects_ref->{'cncp'}{'ports'}{'tcp'}{'1636'}++	; 
#	$ports_ref->{'tcp'}{'1636'}{'name'} = 'cncp'		; 
#	$srvcobjects_ref->{'distinct32'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'distinct32'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'distinct32'}{'port'}{'udp'} = '9998'	; 
#	$srvcobjects_ref->{'distinct32'}{'ports'}{'udp'}{'9998'}++	; 
#	$ports_ref->{'udp'}{'9998'}{'name'} = 'distinct32'		; 
#	$srvcobjects_ref->{'distinct32'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'distinct32'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'distinct32'}{'port'}{'tcp'} = '9998'	; 
#	$srvcobjects_ref->{'distinct32'}{'ports'}{'tcp'}{'9998'}++	; 
#	$ports_ref->{'tcp'}{'9998'}{'name'} = 'distinct32'		; 
#	$srvcobjects_ref->{'vsi-omega'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vsi-omega'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsi-omega'}{'port'}{'udp'} = '7566'	; 
#	$srvcobjects_ref->{'vsi-omega'}{'ports'}{'udp'}{'7566'}++	; 
#	$ports_ref->{'udp'}{'7566'}{'name'} = 'vsi-omega'		; 
#	$srvcobjects_ref->{'vsi-omega'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vsi-omega'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vsi-omega'}{'port'}{'tcp'} = '7566'	; 
#	$srvcobjects_ref->{'vsi-omega'}{'ports'}{'tcp'}{'7566'}++	; 
#	$ports_ref->{'tcp'}{'7566'}{'name'} = 'vsi-omega'		; 
#	$srvcobjects_ref->{'ultrabac'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ultrabac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultrabac'}{'port'}{'udp'} = '1910'	; 
#	$srvcobjects_ref->{'ultrabac'}{'ports'}{'udp'}{'1910'}++	; 
#	$ports_ref->{'udp'}{'1910'}{'name'} = 'ultrabac'		; 
#	$srvcobjects_ref->{'ultrabac'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ultrabac'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ultrabac'}{'port'}{'tcp'} = '1910'	; 
#	$srvcobjects_ref->{'ultrabac'}{'ports'}{'tcp'}{'1910'}++	; 
#	$ports_ref->{'tcp'}{'1910'}{'name'} = 'ultrabac'		; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'port'}{'udp'} = '2747'	; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'ports'}{'udp'}{'2747'}++	; 
#	$ports_ref->{'udp'}{'2747'}{'name'} = 'fjippol-swrly'		; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'port'}{'tcp'} = '2747'	; 
#	$srvcobjects_ref->{'fjippol-swrly'}{'ports'}{'tcp'}{'2747'}++	; 
#	$ports_ref->{'tcp'}{'2747'}{'name'} = 'fjippol-swrly'		; 
#	$srvcobjects_ref->{'ipdd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipdd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipdd'}{'port'}{'udp'} = '578'	; 
#	$srvcobjects_ref->{'ipdd'}{'ports'}{'udp'}{'578'}++	; 
#	$ports_ref->{'udp'}{'578'}{'name'} = 'ipdd'		; 
#	$srvcobjects_ref->{'ipdd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipdd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipdd'}{'port'}{'tcp'} = '578'	; 
#	$srvcobjects_ref->{'ipdd'}{'ports'}{'tcp'}{'578'}++	; 
#	$ports_ref->{'tcp'}{'578'}{'name'} = 'ipdd'		; 
#	$srvcobjects_ref->{'irisa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'irisa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irisa'}{'port'}{'udp'} = '11000'	; 
#	$srvcobjects_ref->{'irisa'}{'ports'}{'udp'}{'11000'}++	; 
#	$ports_ref->{'udp'}{'11000'}{'name'} = 'irisa'		; 
#	$srvcobjects_ref->{'irisa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'irisa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irisa'}{'port'}{'tcp'} = '11000'	; 
#	$srvcobjects_ref->{'irisa'}{'ports'}{'tcp'}{'11000'}++	; 
#	$ports_ref->{'tcp'}{'11000'}{'name'} = 'irisa'		; 
#	$srvcobjects_ref->{'xns-mail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xns-mail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-mail'}{'port'}{'udp'} = '58'	; 
#	$srvcobjects_ref->{'xns-mail'}{'ports'}{'udp'}{'58'}++	; 
#	$ports_ref->{'udp'}{'58'}{'name'} = 'xns-mail'		; 
#	$srvcobjects_ref->{'xns-mail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xns-mail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xns-mail'}{'port'}{'tcp'} = '58'	; 
#	$srvcobjects_ref->{'xns-mail'}{'ports'}{'tcp'}{'58'}++	; 
#	$ports_ref->{'tcp'}{'58'}{'name'} = 'xns-mail'		; 
#	$srvcobjects_ref->{'uucp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uucp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uucp'}{'port'}{'udp'} = '540'	; 
#	$srvcobjects_ref->{'uucp'}{'ports'}{'udp'}{'540'}++	; 
#	$ports_ref->{'udp'}{'540'}{'name'} = 'uucp'		; 
#	$srvcobjects_ref->{'uucp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uucp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uucp'}{'port'}{'tcp'} = '540'	; 
#	$srvcobjects_ref->{'uucp'}{'ports'}{'tcp'}{'540'}++	; 
#	$ports_ref->{'tcp'}{'540'}{'name'} = 'uucp'		; 
#	$srvcobjects_ref->{'nfsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nfsd'}{'port'}{'udp'} = '2049'	; 
#	$srvcobjects_ref->{'nfsd'}{'ports'}{'udp'}{'2049'}++	; 
#	$ports_ref->{'udp'}{'2049'}{'name'} = 'nfsd'		; 
#	$srvcobjects_ref->{'nfsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nfsd'}{'port'}{'tcp'} = '2049'	; 
#	$srvcobjects_ref->{'nfsd'}{'ports'}{'tcp'}{'2049'}++	; 
#	$ports_ref->{'tcp'}{'2049'}{'name'} = 'nfsd'		; 
#	$srvcobjects_ref->{'pk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pk'}{'port'}{'udp'} = '5272'	; 
#	$srvcobjects_ref->{'pk'}{'ports'}{'udp'}{'5272'}++	; 
#	$ports_ref->{'udp'}{'5272'}{'name'} = 'pk'		; 
#	$srvcobjects_ref->{'pk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pk'}{'port'}{'tcp'} = '5272'	; 
#	$srvcobjects_ref->{'pk'}{'ports'}{'tcp'}{'5272'}++	; 
#	$ports_ref->{'tcp'}{'5272'}{'name'} = 'pk'		; 
#	$srvcobjects_ref->{'proactivate'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'proactivate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proactivate'}{'port'}{'udp'} = '24678'	; 
#	$srvcobjects_ref->{'proactivate'}{'ports'}{'udp'}{'24678'}++	; 
#	$ports_ref->{'udp'}{'24678'}{'name'} = 'proactivate'		; 
#	$srvcobjects_ref->{'proactivate'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'proactivate'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'proactivate'}{'port'}{'tcp'} = '24678'	; 
#	$srvcobjects_ref->{'proactivate'}{'ports'}{'tcp'}{'24678'}++	; 
#	$ports_ref->{'tcp'}{'24678'}{'name'} = 'proactivate'		; 
#	$srvcobjects_ref->{'tcpmux'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tcpmux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcpmux'}{'port'}{'udp'} = '1'	; 
#	$srvcobjects_ref->{'tcpmux'}{'ports'}{'udp'}{'1'}++	; 
#	$ports_ref->{'udp'}{'1'}{'name'} = 'tcpmux'		; 
#	$srvcobjects_ref->{'tcpmux'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcpmux'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcpmux'}{'port'}{'tcp'} = '1'	; 
#	$srvcobjects_ref->{'tcpmux'}{'ports'}{'tcp'}{'1'}++	; 
#	$ports_ref->{'tcp'}{'1'}{'name'} = 'tcpmux'		; 
#	$srvcobjects_ref->{'shadowserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shadowserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shadowserver'}{'port'}{'udp'} = '2027'	; 
#	$srvcobjects_ref->{'shadowserver'}{'ports'}{'udp'}{'2027'}++	; 
#	$ports_ref->{'udp'}{'2027'}{'name'} = 'shadowserver'		; 
#	$srvcobjects_ref->{'shadowserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shadowserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shadowserver'}{'port'}{'tcp'} = '2027'	; 
#	$srvcobjects_ref->{'shadowserver'}{'ports'}{'tcp'}{'2027'}++	; 
#	$ports_ref->{'tcp'}{'2027'}{'name'} = 'shadowserver'		; 
#	$srvcobjects_ref->{'miles-apart'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'miles-apart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miles-apart'}{'port'}{'udp'} = '2621'	; 
#	$srvcobjects_ref->{'miles-apart'}{'ports'}{'udp'}{'2621'}++	; 
#	$ports_ref->{'udp'}{'2621'}{'name'} = 'miles-apart'		; 
#	$srvcobjects_ref->{'miles-apart'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'miles-apart'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'miles-apart'}{'port'}{'tcp'} = '2621'	; 
#	$srvcobjects_ref->{'miles-apart'}{'ports'}{'tcp'}{'2621'}++	; 
#	$ports_ref->{'tcp'}{'2621'}{'name'} = 'miles-apart'		; 
#	$srvcobjects_ref->{'netmap_lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netmap_lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmap_lm'}{'port'}{'udp'} = '1493'	; 
#	$srvcobjects_ref->{'netmap_lm'}{'ports'}{'udp'}{'1493'}++	; 
#	$ports_ref->{'udp'}{'1493'}{'name'} = 'netmap_lm'		; 
#	$srvcobjects_ref->{'netmap_lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netmap_lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netmap_lm'}{'port'}{'tcp'} = '1493'	; 
#	$srvcobjects_ref->{'netmap_lm'}{'ports'}{'tcp'}{'1493'}++	; 
#	$ports_ref->{'tcp'}{'1493'}{'name'} = 'netmap_lm'		; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'port'}{'udp'} = '5069'	; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'ports'}{'udp'}{'5069'}++	; 
#	$ports_ref->{'udp'}{'5069'}{'name'} = 'i-net-2000-npr'		; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'port'}{'tcp'} = '5069'	; 
#	$srvcobjects_ref->{'i-net-2000-npr'}{'ports'}{'tcp'}{'5069'}++	; 
#	$ports_ref->{'tcp'}{'5069'}{'name'} = 'i-net-2000-npr'		; 
#	$srvcobjects_ref->{'mpnjsocl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpnjsocl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsocl'}{'port'}{'udp'} = '2685'	; 
#	$srvcobjects_ref->{'mpnjsocl'}{'ports'}{'udp'}{'2685'}++	; 
#	$ports_ref->{'udp'}{'2685'}{'name'} = 'mpnjsocl'		; 
#	$srvcobjects_ref->{'mpnjsocl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpnjsocl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsocl'}{'port'}{'tcp'} = '2685'	; 
#	$srvcobjects_ref->{'mpnjsocl'}{'ports'}{'tcp'}{'2685'}++	; 
#	$ports_ref->{'tcp'}{'2685'}{'name'} = 'mpnjsocl'		; 
#	$srvcobjects_ref->{'la-maint'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'la-maint'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'la-maint'}{'port'}{'udp'} = '51'	; 
#	$srvcobjects_ref->{'la-maint'}{'ports'}{'udp'}{'51'}++	; 
#	$ports_ref->{'udp'}{'51'}{'name'} = 'la-maint'		; 
#	$srvcobjects_ref->{'la-maint'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'la-maint'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'la-maint'}{'port'}{'tcp'} = '51'	; 
#	$srvcobjects_ref->{'la-maint'}{'ports'}{'tcp'}{'51'}++	; 
#	$ports_ref->{'tcp'}{'51'}{'name'} = 'la-maint'		; 
#	$srvcobjects_ref->{'globe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'globe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'globe'}{'port'}{'udp'} = '2002'	; 
#	$srvcobjects_ref->{'globe'}{'ports'}{'udp'}{'2002'}++	; 
#	$ports_ref->{'udp'}{'2002'}{'name'} = 'globe'		; 
#	$srvcobjects_ref->{'globe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'globe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'globe'}{'port'}{'tcp'} = '2002'	; 
#	$srvcobjects_ref->{'globe'}{'ports'}{'tcp'}{'2002'}++	; 
#	$ports_ref->{'tcp'}{'2002'}{'name'} = 'globe'		; 
#	$srvcobjects_ref->{'cnrp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cnrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnrp'}{'port'}{'udp'} = '2757'	; 
#	$srvcobjects_ref->{'cnrp'}{'ports'}{'udp'}{'2757'}++	; 
#	$ports_ref->{'udp'}{'2757'}{'name'} = 'cnrp'		; 
#	$srvcobjects_ref->{'cnrp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cnrp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cnrp'}{'port'}{'tcp'} = '2757'	; 
#	$srvcobjects_ref->{'cnrp'}{'ports'}{'tcp'}{'2757'}++	; 
#	$ports_ref->{'tcp'}{'2757'}{'name'} = 'cnrp'		; 
#	$srvcobjects_ref->{'emc-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'emc-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emc-gateway'}{'port'}{'udp'} = '1273'	; 
#	$srvcobjects_ref->{'emc-gateway'}{'ports'}{'udp'}{'1273'}++	; 
#	$ports_ref->{'udp'}{'1273'}{'name'} = 'emc-gateway'		; 
#	$srvcobjects_ref->{'emc-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'emc-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'emc-gateway'}{'port'}{'tcp'} = '1273'	; 
#	$srvcobjects_ref->{'emc-gateway'}{'ports'}{'tcp'}{'1273'}++	; 
#	$ports_ref->{'tcp'}{'1273'}{'name'} = 'emc-gateway'		; 
#	$srvcobjects_ref->{'ssmpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssmpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssmpp'}{'port'}{'udp'} = '3550'	; 
#	$srvcobjects_ref->{'ssmpp'}{'ports'}{'udp'}{'3550'}++	; 
#	$ports_ref->{'udp'}{'3550'}{'name'} = 'ssmpp'		; 
#	$srvcobjects_ref->{'ssmpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssmpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssmpp'}{'port'}{'tcp'} = '3550'	; 
#	$srvcobjects_ref->{'ssmpp'}{'ports'}{'tcp'}{'3550'}++	; 
#	$ports_ref->{'tcp'}{'3550'}{'name'} = 'ssmpp'		; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'port'}{'udp'} = '13722'	; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'ports'}{'udp'}{'13722'}++	; 
#	$ports_ref->{'udp'}{'13722'}{'name'} = 'bpjava-msvc'		; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'port'}{'tcp'} = '13722'	; 
#	$srvcobjects_ref->{'bpjava-msvc'}{'ports'}{'tcp'}{'13722'}++	; 
#	$ports_ref->{'tcp'}{'13722'}{'name'} = 'bpjava-msvc'		; 
#	$srvcobjects_ref->{'atex_elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'atex_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atex_elmd'}{'port'}{'udp'} = '1385'	; 
#	$srvcobjects_ref->{'atex_elmd'}{'ports'}{'udp'}{'1385'}++	; 
#	$ports_ref->{'udp'}{'1385'}{'name'} = 'atex_elmd'		; 
#	$srvcobjects_ref->{'atex_elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'atex_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atex_elmd'}{'port'}{'tcp'} = '1385'	; 
#	$srvcobjects_ref->{'atex_elmd'}{'ports'}{'tcp'}{'1385'}++	; 
#	$ports_ref->{'tcp'}{'1385'}{'name'} = 'atex_elmd'		; 
#	$srvcobjects_ref->{'autocueds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'autocueds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autocueds'}{'port'}{'udp'} = '3437'	; 
#	$srvcobjects_ref->{'autocueds'}{'ports'}{'udp'}{'3437'}++	; 
#	$ports_ref->{'udp'}{'3437'}{'name'} = 'autocueds'		; 
#	$srvcobjects_ref->{'autocueds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'autocueds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'autocueds'}{'port'}{'tcp'} = '3437'	; 
#	$srvcobjects_ref->{'autocueds'}{'ports'}{'tcp'}{'3437'}++	; 
#	$ports_ref->{'tcp'}{'3437'}{'name'} = 'autocueds'		; 
#	$srvcobjects_ref->{'dvt-data'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dvt-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dvt-data'}{'port'}{'udp'} = '3247'	; 
#	$srvcobjects_ref->{'dvt-data'}{'ports'}{'udp'}{'3247'}++	; 
#	$ports_ref->{'udp'}{'3247'}{'name'} = 'dvt-data'		; 
#	$srvcobjects_ref->{'dvt-data'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dvt-data'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dvt-data'}{'port'}{'tcp'} = '3247'	; 
#	$srvcobjects_ref->{'dvt-data'}{'ports'}{'tcp'}{'3247'}++	; 
#	$ports_ref->{'tcp'}{'3247'}{'name'} = 'dvt-data'		; 
#	$srvcobjects_ref->{'isg-uda-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'isg-uda-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isg-uda-server'}{'port'}{'udp'} = '2551'	; 
#	$srvcobjects_ref->{'isg-uda-server'}{'ports'}{'udp'}{'2551'}++	; 
#	$ports_ref->{'udp'}{'2551'}{'name'} = 'isg-uda-server'		; 
#	$srvcobjects_ref->{'isg-uda-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'isg-uda-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'isg-uda-server'}{'port'}{'tcp'} = '2551'	; 
#	$srvcobjects_ref->{'isg-uda-server'}{'ports'}{'tcp'}{'2551'}++	; 
#	$ports_ref->{'tcp'}{'2551'}{'name'} = 'isg-uda-server'		; 
#	$srvcobjects_ref->{'hostname'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hostname'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hostname'}{'port'}{'udp'} = '101'	; 
#	$srvcobjects_ref->{'hostname'}{'ports'}{'udp'}{'101'}++	; 
#	$ports_ref->{'udp'}{'101'}{'name'} = 'hostname'		; 
#	$srvcobjects_ref->{'hostname'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hostname'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hostname'}{'port'}{'tcp'} = '101'	; 
#	$srvcobjects_ref->{'hostname'}{'ports'}{'tcp'}{'101'}++	; 
#	$ports_ref->{'tcp'}{'101'}{'name'} = 'hostname'		; 
#	$srvcobjects_ref->{'confluent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'confluent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'confluent'}{'port'}{'udp'} = '1484'	; 
#	$srvcobjects_ref->{'confluent'}{'ports'}{'udp'}{'1484'}++	; 
#	$ports_ref->{'udp'}{'1484'}{'name'} = 'confluent'		; 
#	$srvcobjects_ref->{'confluent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'confluent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'confluent'}{'port'}{'tcp'} = '1484'	; 
#	$srvcobjects_ref->{'confluent'}{'ports'}{'tcp'}{'1484'}++	; 
#	$ports_ref->{'tcp'}{'1484'}{'name'} = 'confluent'		; 
#	$srvcobjects_ref->{'iso-tp0s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iso-tp0s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tp0s'}{'port'}{'udp'} = '3782'	; 
#	$srvcobjects_ref->{'iso-tp0s'}{'ports'}{'udp'}{'3782'}++	; 
#	$ports_ref->{'udp'}{'3782'}{'name'} = 'iso-tp0s'		; 
#	$srvcobjects_ref->{'iso-tp0s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iso-tp0s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tp0s'}{'port'}{'tcp'} = '3782'	; 
#	$srvcobjects_ref->{'iso-tp0s'}{'ports'}{'tcp'}{'3782'}++	; 
#	$ports_ref->{'tcp'}{'3782'}{'name'} = 'iso-tp0s'		; 
#	$srvcobjects_ref->{'ecomm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ecomm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecomm'}{'port'}{'udp'} = '3477'	; 
#	$srvcobjects_ref->{'ecomm'}{'ports'}{'udp'}{'3477'}++	; 
#	$ports_ref->{'udp'}{'3477'}{'name'} = 'ecomm'		; 
#	$srvcobjects_ref->{'ecomm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ecomm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ecomm'}{'port'}{'tcp'} = '3477'	; 
#	$srvcobjects_ref->{'ecomm'}{'ports'}{'tcp'}{'3477'}++	; 
#	$ports_ref->{'tcp'}{'3477'}{'name'} = 'ecomm'		; 
#	$srvcobjects_ref->{'netview-aix-10'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-10'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-10'}{'port'}{'udp'} = '1670'	; 
#	$srvcobjects_ref->{'netview-aix-10'}{'ports'}{'udp'}{'1670'}++	; 
#	$ports_ref->{'udp'}{'1670'}{'name'} = 'netview-aix-10'		; 
#	$srvcobjects_ref->{'netview-aix-10'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-10'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-10'}{'port'}{'tcp'} = '1670'	; 
#	$srvcobjects_ref->{'netview-aix-10'}{'ports'}{'tcp'}{'1670'}++	; 
#	$ports_ref->{'tcp'}{'1670'}{'name'} = 'netview-aix-10'		; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'port'}{'udp'} = '3013'	; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'ports'}{'udp'}{'3013'}++	; 
#	$ports_ref->{'udp'}{'3013'}{'name'} = 'gilatskysurfer'		; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'port'}{'tcp'} = '3013'	; 
#	$srvcobjects_ref->{'gilatskysurfer'}{'ports'}{'tcp'}{'3013'}++	; 
#	$ports_ref->{'tcp'}{'3013'}{'name'} = 'gilatskysurfer'		; 
#	$srvcobjects_ref->{'codima-rtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'codima-rtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codima-rtp'}{'port'}{'udp'} = '2415'	; 
#	$srvcobjects_ref->{'codima-rtp'}{'ports'}{'udp'}{'2415'}++	; 
#	$ports_ref->{'udp'}{'2415'}{'name'} = 'codima-rtp'		; 
#	$srvcobjects_ref->{'codima-rtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'codima-rtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'codima-rtp'}{'port'}{'tcp'} = '2415'	; 
#	$srvcobjects_ref->{'codima-rtp'}{'ports'}{'tcp'}{'2415'}++	; 
#	$ports_ref->{'tcp'}{'2415'}{'name'} = 'codima-rtp'		; 
#	$srvcobjects_ref->{'pda-sys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pda-sys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pda-sys'}{'port'}{'udp'} = '3254'	; 
#	$srvcobjects_ref->{'pda-sys'}{'ports'}{'udp'}{'3254'}++	; 
#	$ports_ref->{'udp'}{'3254'}{'name'} = 'pda-sys'		; 
#	$srvcobjects_ref->{'pda-sys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pda-sys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pda-sys'}{'port'}{'tcp'} = '3254'	; 
#	$srvcobjects_ref->{'pda-sys'}{'ports'}{'tcp'}{'3254'}++	; 
#	$ports_ref->{'tcp'}{'3254'}{'name'} = 'pda-sys'		; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'port'}{'udp'} = '2860'	; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'ports'}{'udp'}{'2860'}++	; 
#	$ports_ref->{'udp'}{'2860'}{'name'} = 'dialpad-voice1'		; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'port'}{'tcp'} = '2860'	; 
#	$srvcobjects_ref->{'dialpad-voice1'}{'ports'}{'tcp'}{'2860'}++	; 
#	$ports_ref->{'tcp'}{'2860'}{'name'} = 'dialpad-voice1'		; 
#	$srvcobjects_ref->{'dlsrpn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dlsrpn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlsrpn'}{'port'}{'udp'} = '2065'	; 
#	$srvcobjects_ref->{'dlsrpn'}{'ports'}{'udp'}{'2065'}++	; 
#	$ports_ref->{'udp'}{'2065'}{'name'} = 'dlsrpn'		; 
#	$srvcobjects_ref->{'dlsrpn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dlsrpn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dlsrpn'}{'port'}{'tcp'} = '2065'	; 
#	$srvcobjects_ref->{'dlsrpn'}{'ports'}{'tcp'}{'2065'}++	; 
#	$ports_ref->{'tcp'}{'2065'}{'name'} = 'dlsrpn'		; 
#	$srvcobjects_ref->{'microtalon-dis'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'microtalon-dis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microtalon-dis'}{'port'}{'udp'} = '7013'	; 
#	$srvcobjects_ref->{'microtalon-dis'}{'ports'}{'udp'}{'7013'}++	; 
#	$ports_ref->{'udp'}{'7013'}{'name'} = 'microtalon-dis'		; 
#	$srvcobjects_ref->{'microtalon-dis'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'microtalon-dis'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microtalon-dis'}{'port'}{'tcp'} = '7013'	; 
#	$srvcobjects_ref->{'microtalon-dis'}{'ports'}{'tcp'}{'7013'}++	; 
#	$ports_ref->{'tcp'}{'7013'}{'name'} = 'microtalon-dis'		; 
#	$srvcobjects_ref->{'macon-udp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'macon-udp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'macon-udp'}{'port'}{'udp'} = '456'	; 
#	$srvcobjects_ref->{'macon-udp'}{'ports'}{'udp'}{'456'}++	; 
#	$ports_ref->{'udp'}{'456'}{'name'} = 'macon-udp'		; 
#	$srvcobjects_ref->{'unbind-cluster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'unbind-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unbind-cluster'}{'port'}{'udp'} = '2138'	; 
#	$srvcobjects_ref->{'unbind-cluster'}{'ports'}{'udp'}{'2138'}++	; 
#	$ports_ref->{'udp'}{'2138'}{'name'} = 'unbind-cluster'		; 
#	$srvcobjects_ref->{'unbind-cluster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'unbind-cluster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'unbind-cluster'}{'port'}{'tcp'} = '2138'	; 
#	$srvcobjects_ref->{'unbind-cluster'}{'ports'}{'tcp'}{'2138'}++	; 
#	$ports_ref->{'tcp'}{'2138'}{'name'} = 'unbind-cluster'		; 
#	$srvcobjects_ref->{'esp-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esp-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esp-lm'}{'port'}{'udp'} = '3383'	; 
#	$srvcobjects_ref->{'esp-lm'}{'ports'}{'udp'}{'3383'}++	; 
#	$ports_ref->{'udp'}{'3383'}{'name'} = 'esp-lm'		; 
#	$srvcobjects_ref->{'esp-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esp-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esp-lm'}{'port'}{'tcp'} = '3383'	; 
#	$srvcobjects_ref->{'esp-lm'}{'ports'}{'tcp'}{'3383'}++	; 
#	$ports_ref->{'tcp'}{'3383'}{'name'} = 'esp-lm'		; 
#	$srvcobjects_ref->{'ldap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ldap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldap'}{'port'}{'udp'} = '389'	; 
#	$srvcobjects_ref->{'ldap'}{'ports'}{'udp'}{'389'}++	; 
#	$ports_ref->{'udp'}{'389'}{'name'} = 'ldap'		; 
#	$srvcobjects_ref->{'ldap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ldap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ldap'}{'port'}{'tcp'} = '389'	; 
#	$srvcobjects_ref->{'ldap'}{'ports'}{'tcp'}{'389'}++	; 
#	$ports_ref->{'tcp'}{'389'}{'name'} = 'ldap'		; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'port'}{'udp'} = '2363'	; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'ports'}{'udp'}{'2363'}++	; 
#	$ports_ref->{'udp'}{'2363'}{'name'} = 'mediacntrlnfsd'		; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'port'}{'tcp'} = '2363'	; 
#	$srvcobjects_ref->{'mediacntrlnfsd'}{'ports'}{'tcp'}{'2363'}++	; 
#	$ports_ref->{'tcp'}{'2363'}{'name'} = 'mediacntrlnfsd'		; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'port'}{'udp'} = '4358'	; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'ports'}{'udp'}{'4358'}++	; 
#	$ports_ref->{'udp'}{'4358'}{'name'} = 'qsnet-nucl'		; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'port'}{'tcp'} = '4358'	; 
#	$srvcobjects_ref->{'qsnet-nucl'}{'ports'}{'tcp'}{'4358'}++	; 
#	$ports_ref->{'tcp'}{'4358'}{'name'} = 'qsnet-nucl'		; 
#	$srvcobjects_ref->{'cecsvc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cecsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cecsvc'}{'port'}{'udp'} = '2571'	; 
#	$srvcobjects_ref->{'cecsvc'}{'ports'}{'udp'}{'2571'}++	; 
#	$ports_ref->{'udp'}{'2571'}{'name'} = 'cecsvc'		; 
#	$srvcobjects_ref->{'cecsvc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cecsvc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cecsvc'}{'port'}{'tcp'} = '2571'	; 
#	$srvcobjects_ref->{'cecsvc'}{'ports'}{'tcp'}{'2571'}++	; 
#	$ports_ref->{'tcp'}{'2571'}{'name'} = 'cecsvc'		; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'port'}{'udp'} = '356'	; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'ports'}{'udp'}{'356'}++	; 
#	$ports_ref->{'udp'}{'356'}{'name'} = 'cloanto-net-1'		; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'port'}{'tcp'} = '356'	; 
#	$srvcobjects_ref->{'cloanto-net-1'}{'ports'}{'tcp'}{'356'}++	; 
#	$ports_ref->{'tcp'}{'356'}{'name'} = 'cloanto-net-1'		; 
#	$srvcobjects_ref->{'apparenet-as'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apparenet-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-as'}{'port'}{'udp'} = '3238'	; 
#	$srvcobjects_ref->{'apparenet-as'}{'ports'}{'udp'}{'3238'}++	; 
#	$ports_ref->{'udp'}{'3238'}{'name'} = 'apparenet-as'		; 
#	$srvcobjects_ref->{'apparenet-as'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apparenet-as'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apparenet-as'}{'port'}{'tcp'} = '3238'	; 
#	$srvcobjects_ref->{'apparenet-as'}{'ports'}{'tcp'}{'3238'}++	; 
#	$ports_ref->{'tcp'}{'3238'}{'name'} = 'apparenet-as'		; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'port'}{'udp'} = '1088'	; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'ports'}{'udp'}{'1088'}++	; 
#	$ports_ref->{'udp'}{'1088'}{'name'} = 'cplscrambler-al'		; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'port'}{'tcp'} = '1088'	; 
#	$srvcobjects_ref->{'cplscrambler-al'}{'ports'}{'tcp'}{'1088'}++	; 
#	$ports_ref->{'tcp'}{'1088'}{'name'} = 'cplscrambler-al'		; 
#	$srvcobjects_ref->{'tell'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tell'}{'port'}{'udp'} = '754'	; 
#	$srvcobjects_ref->{'tell'}{'ports'}{'udp'}{'754'}++	; 
#	$ports_ref->{'udp'}{'754'}{'name'} = 'tell'		; 
#	$srvcobjects_ref->{'tell'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tell'}{'port'}{'tcp'} = '754'	; 
#	$srvcobjects_ref->{'tell'}{'ports'}{'tcp'}{'754'}++	; 
#	$ports_ref->{'tcp'}{'754'}{'name'} = 'tell'		; 
#	$srvcobjects_ref->{'sabarsd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sabarsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sabarsd'}{'port'}{'udp'} = '8401'	; 
#	$srvcobjects_ref->{'sabarsd'}{'ports'}{'udp'}{'8401'}++	; 
#	$ports_ref->{'udp'}{'8401'}{'name'} = 'sabarsd'		; 
#	$srvcobjects_ref->{'sabarsd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sabarsd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sabarsd'}{'port'}{'tcp'} = '8401'	; 
#	$srvcobjects_ref->{'sabarsd'}{'ports'}{'tcp'}{'8401'}++	; 
#	$ports_ref->{'tcp'}{'8401'}{'name'} = 'sabarsd'		; 
#	$srvcobjects_ref->{'valisys-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'valisys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'valisys-lm'}{'port'}{'udp'} = '1457'	; 
#	$srvcobjects_ref->{'valisys-lm'}{'ports'}{'udp'}{'1457'}++	; 
#	$ports_ref->{'udp'}{'1457'}{'name'} = 'valisys-lm'		; 
#	$srvcobjects_ref->{'valisys-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'valisys-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'valisys-lm'}{'port'}{'tcp'} = '1457'	; 
#	$srvcobjects_ref->{'valisys-lm'}{'ports'}{'tcp'}{'1457'}++	; 
#	$ports_ref->{'tcp'}{'1457'}{'name'} = 'valisys-lm'		; 
#	$srvcobjects_ref->{'canon-capt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'canon-capt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canon-capt'}{'port'}{'udp'} = '3756'	; 
#	$srvcobjects_ref->{'canon-capt'}{'ports'}{'udp'}{'3756'}++	; 
#	$ports_ref->{'udp'}{'3756'}{'name'} = 'canon-capt'		; 
#	$srvcobjects_ref->{'canon-capt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'canon-capt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'canon-capt'}{'port'}{'tcp'} = '3756'	; 
#	$srvcobjects_ref->{'canon-capt'}{'ports'}{'tcp'}{'3756'}++	; 
#	$ports_ref->{'tcp'}{'3756'}{'name'} = 'canon-capt'		; 
#	$srvcobjects_ref->{'ifcp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ifcp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ifcp-port'}{'port'}{'udp'} = '3420'	; 
#	$srvcobjects_ref->{'ifcp-port'}{'ports'}{'udp'}{'3420'}++	; 
#	$ports_ref->{'udp'}{'3420'}{'name'} = 'ifcp-port'		; 
#	$srvcobjects_ref->{'ifcp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ifcp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ifcp-port'}{'port'}{'tcp'} = '3420'	; 
#	$srvcobjects_ref->{'ifcp-port'}{'ports'}{'tcp'}{'3420'}++	; 
#	$ports_ref->{'tcp'}{'3420'}{'name'} = 'ifcp-port'		; 
#	$srvcobjects_ref->{'vt-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vt-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vt-ssl'}{'port'}{'udp'} = '3509'	; 
#	$srvcobjects_ref->{'vt-ssl'}{'ports'}{'udp'}{'3509'}++	; 
#	$ports_ref->{'udp'}{'3509'}{'name'} = 'vt-ssl'		; 
#	$srvcobjects_ref->{'vt-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vt-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vt-ssl'}{'port'}{'tcp'} = '3509'	; 
#	$srvcobjects_ref->{'vt-ssl'}{'ports'}{'tcp'}{'3509'}++	; 
#	$ports_ref->{'tcp'}{'3509'}{'name'} = 'vt-ssl'		; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'port'}{'udp'} = '3028'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'ports'}{'udp'}{'3028'}++	; 
#	$ports_ref->{'udp'}{'3028'}{'name'} = 'LiebDevMgmt_DM'		; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'port'}{'tcp'} = '3028'	; 
#	$srvcobjects_ref->{'LiebDevMgmt_DM'}{'ports'}{'tcp'}{'3028'}++	; 
#	$ports_ref->{'tcp'}{'3028'}{'name'} = 'LiebDevMgmt_DM'		; 
#	$srvcobjects_ref->{'sti-envision'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sti-envision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sti-envision'}{'port'}{'udp'} = '1312'	; 
#	$srvcobjects_ref->{'sti-envision'}{'ports'}{'udp'}{'1312'}++	; 
#	$ports_ref->{'udp'}{'1312'}{'name'} = 'sti-envision'		; 
#	$srvcobjects_ref->{'sti-envision'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sti-envision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sti-envision'}{'port'}{'tcp'} = '1312'	; 
#	$srvcobjects_ref->{'sti-envision'}{'ports'}{'tcp'}{'1312'}++	; 
#	$ports_ref->{'tcp'}{'1312'}{'name'} = 'sti-envision'		; 
#	$srvcobjects_ref->{'abatjss'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abatjss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abatjss'}{'port'}{'udp'} = '3656'	; 
#	$srvcobjects_ref->{'abatjss'}{'ports'}{'udp'}{'3656'}++	; 
#	$ports_ref->{'udp'}{'3656'}{'name'} = 'abatjss'		; 
#	$srvcobjects_ref->{'abatjss'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abatjss'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abatjss'}{'port'}{'tcp'} = '3656'	; 
#	$srvcobjects_ref->{'abatjss'}{'ports'}{'tcp'}{'3656'}++	; 
#	$ports_ref->{'tcp'}{'3656'}{'name'} = 'abatjss'		; 
#	$srvcobjects_ref->{'domain'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'domain'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'domain'}{'port'}{'udp'} = '53'	; 
#	$srvcobjects_ref->{'domain'}{'ports'}{'udp'}{'53'}++	; 
#	$ports_ref->{'udp'}{'53'}{'name'} = 'domain'		; 
#	$srvcobjects_ref->{'domain'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'domain'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'domain'}{'port'}{'tcp'} = '53'	; 
#	$srvcobjects_ref->{'domain'}{'ports'}{'tcp'}{'53'}++	; 
#	$ports_ref->{'tcp'}{'53'}{'name'} = 'domain'		; 
#	$srvcobjects_ref->{'rtsps'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rtsps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsps'}{'port'}{'udp'} = '322'	; 
#	$srvcobjects_ref->{'rtsps'}{'ports'}{'udp'}{'322'}++	; 
#	$ports_ref->{'udp'}{'322'}{'name'} = 'rtsps'		; 
#	$srvcobjects_ref->{'rtsps'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rtsps'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rtsps'}{'port'}{'tcp'} = '322'	; 
#	$srvcobjects_ref->{'rtsps'}{'ports'}{'tcp'}{'322'}++	; 
#	$ports_ref->{'tcp'}{'322'}{'name'} = 'rtsps'		; 
#	$srvcobjects_ref->{'cardbox'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cardbox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cardbox'}{'port'}{'udp'} = '3105'	; 
#	$srvcobjects_ref->{'cardbox'}{'ports'}{'udp'}{'3105'}++	; 
#	$ports_ref->{'udp'}{'3105'}{'name'} = 'cardbox'		; 
#	$srvcobjects_ref->{'cardbox'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cardbox'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cardbox'}{'port'}{'tcp'} = '3105'	; 
#	$srvcobjects_ref->{'cardbox'}{'ports'}{'tcp'}{'3105'}++	; 
#	$ports_ref->{'tcp'}{'3105'}{'name'} = 'cardbox'		; 
#	$srvcobjects_ref->{'sshell'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sshell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sshell'}{'port'}{'udp'} = '614'	; 
#	$srvcobjects_ref->{'sshell'}{'ports'}{'udp'}{'614'}++	; 
#	$ports_ref->{'udp'}{'614'}{'name'} = 'sshell'		; 
#	$srvcobjects_ref->{'sshell'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sshell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sshell'}{'port'}{'tcp'} = '614'	; 
#	$srvcobjects_ref->{'sshell'}{'ports'}{'tcp'}{'614'}++	; 
#	$ports_ref->{'tcp'}{'614'}{'name'} = 'sshell'		; 
#	$srvcobjects_ref->{'webemshttp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webemshttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webemshttp'}{'port'}{'udp'} = '2851'	; 
#	$srvcobjects_ref->{'webemshttp'}{'ports'}{'udp'}{'2851'}++	; 
#	$ports_ref->{'udp'}{'2851'}{'name'} = 'webemshttp'		; 
#	$srvcobjects_ref->{'webemshttp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webemshttp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webemshttp'}{'port'}{'tcp'} = '2851'	; 
#	$srvcobjects_ref->{'webemshttp'}{'ports'}{'tcp'}{'2851'}++	; 
#	$ports_ref->{'tcp'}{'2851'}{'name'} = 'webemshttp'		; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'port'}{'udp'} = '3346'	; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'ports'}{'udp'}{'3346'}++	; 
#	$ports_ref->{'udp'}{'3346'}{'name'} = 'trnsprntproxy'		; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'port'}{'tcp'} = '3346'	; 
#	$srvcobjects_ref->{'trnsprntproxy'}{'ports'}{'tcp'}{'3346'}++	; 
#	$ports_ref->{'tcp'}{'3346'}{'name'} = 'trnsprntproxy'		; 
#	$srvcobjects_ref->{'flexlm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'flexlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flexlm'}{'port'}{'udp'} = '744'	; 
#	$srvcobjects_ref->{'flexlm'}{'ports'}{'udp'}{'744'}++	; 
#	$ports_ref->{'udp'}{'744'}{'name'} = 'flexlm'		; 
#	$srvcobjects_ref->{'flexlm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'flexlm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'flexlm'}{'port'}{'tcp'} = '744'	; 
#	$srvcobjects_ref->{'flexlm'}{'ports'}{'tcp'}{'744'}++	; 
#	$ports_ref->{'tcp'}{'744'}{'name'} = 'flexlm'		; 
#	$srvcobjects_ref->{'dsf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsf'}{'port'}{'udp'} = '555'	; 
#	$srvcobjects_ref->{'dsf'}{'ports'}{'udp'}{'555'}++	; 
#	$ports_ref->{'udp'}{'555'}{'name'} = 'dsf'		; 
#	$srvcobjects_ref->{'dsf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsf'}{'port'}{'tcp'} = '555'	; 
#	$srvcobjects_ref->{'dsf'}{'ports'}{'tcp'}{'555'}++	; 
#	$ports_ref->{'tcp'}{'555'}{'name'} = 'dsf'		; 
#	$srvcobjects_ref->{'ft-role'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ft-role'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ft-role'}{'port'}{'udp'} = '2429'	; 
#	$srvcobjects_ref->{'ft-role'}{'ports'}{'udp'}{'2429'}++	; 
#	$ports_ref->{'udp'}{'2429'}{'name'} = 'ft-role'		; 
#	$srvcobjects_ref->{'ft-role'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ft-role'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ft-role'}{'port'}{'tcp'} = '2429'	; 
#	$srvcobjects_ref->{'ft-role'}{'ports'}{'tcp'}{'2429'}++	; 
#	$ports_ref->{'tcp'}{'2429'}{'name'} = 'ft-role'		; 
#	$srvcobjects_ref->{'wap-vcard'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-vcard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcard'}{'port'}{'udp'} = '9204'	; 
#	$srvcobjects_ref->{'wap-vcard'}{'ports'}{'udp'}{'9204'}++	; 
#	$ports_ref->{'udp'}{'9204'}{'name'} = 'wap-vcard'		; 
#	$srvcobjects_ref->{'wap-vcard'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-vcard'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-vcard'}{'port'}{'tcp'} = '9204'	; 
#	$srvcobjects_ref->{'wap-vcard'}{'ports'}{'tcp'}{'9204'}++	; 
#	$ports_ref->{'tcp'}{'9204'}{'name'} = 'wap-vcard'		; 
#	$srvcobjects_ref->{'uadtc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'uadtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uadtc'}{'port'}{'udp'} = '2767'	; 
#	$srvcobjects_ref->{'uadtc'}{'ports'}{'udp'}{'2767'}++	; 
#	$ports_ref->{'udp'}{'2767'}{'name'} = 'uadtc'		; 
#	$srvcobjects_ref->{'uadtc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'uadtc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'uadtc'}{'port'}{'tcp'} = '2767'	; 
#	$srvcobjects_ref->{'uadtc'}{'ports'}{'tcp'}{'2767'}++	; 
#	$ports_ref->{'tcp'}{'2767'}{'name'} = 'uadtc'		; 
#	$srvcobjects_ref->{'dcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dcp'}{'port'}{'udp'} = '93'	; 
#	$srvcobjects_ref->{'dcp'}{'ports'}{'udp'}{'93'}++	; 
#	$ports_ref->{'udp'}{'93'}{'name'} = 'dcp'		; 
#	$srvcobjects_ref->{'dcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dcp'}{'port'}{'tcp'} = '93'	; 
#	$srvcobjects_ref->{'dcp'}{'ports'}{'tcp'}{'93'}++	; 
#	$ports_ref->{'tcp'}{'93'}{'name'} = 'dcp'		; 
#	$srvcobjects_ref->{'scrabble'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'scrabble'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scrabble'}{'port'}{'udp'} = '2026'	; 
#	$srvcobjects_ref->{'scrabble'}{'ports'}{'udp'}{'2026'}++	; 
#	$ports_ref->{'udp'}{'2026'}{'name'} = 'scrabble'		; 
#	$srvcobjects_ref->{'scrabble'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'scrabble'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'scrabble'}{'port'}{'tcp'} = '2026'	; 
#	$srvcobjects_ref->{'scrabble'}{'ports'}{'tcp'}{'2026'}++	; 
#	$ports_ref->{'tcp'}{'2026'}{'name'} = 'scrabble'		; 
#	$srvcobjects_ref->{'newwavesearch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newwavesearch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newwavesearch'}{'port'}{'udp'} = '2058'	; 
#	$srvcobjects_ref->{'newwavesearch'}{'ports'}{'udp'}{'2058'}++	; 
#	$ports_ref->{'udp'}{'2058'}{'name'} = 'newwavesearch'		; 
#	$srvcobjects_ref->{'newwavesearch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newwavesearch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newwavesearch'}{'port'}{'tcp'} = '2058'	; 
#	$srvcobjects_ref->{'newwavesearch'}{'ports'}{'tcp'}{'2058'}++	; 
#	$ports_ref->{'tcp'}{'2058'}{'name'} = 'newwavesearch'		; 
#	$srvcobjects_ref->{'invokator'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'invokator'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'invokator'}{'port'}{'tcp'} = '2006'	; 
#	$srvcobjects_ref->{'invokator'}{'ports'}{'tcp'}{'2006'}++	; 
#	$ports_ref->{'tcp'}{'2006'}{'name'} = 'invokator'		; 
#	$srvcobjects_ref->{'igateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'igateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igateway'}{'port'}{'udp'} = '5250'	; 
#	$srvcobjects_ref->{'igateway'}{'ports'}{'udp'}{'5250'}++	; 
#	$ports_ref->{'udp'}{'5250'}{'name'} = 'igateway'		; 
#	$srvcobjects_ref->{'igateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'igateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igateway'}{'port'}{'tcp'} = '5250'	; 
#	$srvcobjects_ref->{'igateway'}{'ports'}{'tcp'}{'5250'}++	; 
#	$ports_ref->{'tcp'}{'5250'}{'name'} = 'igateway'		; 
#	$srvcobjects_ref->{'objcall'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'objcall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'objcall'}{'port'}{'udp'} = '94'	; 
#	$srvcobjects_ref->{'objcall'}{'ports'}{'udp'}{'94'}++	; 
#	$ports_ref->{'udp'}{'94'}{'name'} = 'objcall'		; 
#	$srvcobjects_ref->{'objcall'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'objcall'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'objcall'}{'port'}{'tcp'} = '94'	; 
#	$srvcobjects_ref->{'objcall'}{'ports'}{'tcp'}{'94'}++	; 
#	$ports_ref->{'tcp'}{'94'}{'name'} = 'objcall'		; 
#	$srvcobjects_ref->{'netviewdm2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netviewdm2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netviewdm2'}{'port'}{'udp'} = '730'	; 
#	$srvcobjects_ref->{'netviewdm2'}{'ports'}{'udp'}{'730'}++	; 
#	$ports_ref->{'udp'}{'730'}{'name'} = 'netviewdm2'		; 
#	$srvcobjects_ref->{'netviewdm2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netviewdm2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netviewdm2'}{'port'}{'tcp'} = '730'	; 
#	$srvcobjects_ref->{'netviewdm2'}{'ports'}{'tcp'}{'730'}++	; 
#	$ports_ref->{'tcp'}{'730'}{'name'} = 'netviewdm2'		; 
#	$srvcobjects_ref->{'copysnap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'copysnap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'copysnap'}{'port'}{'udp'} = '3403'	; 
#	$srvcobjects_ref->{'copysnap'}{'ports'}{'udp'}{'3403'}++	; 
#	$ports_ref->{'udp'}{'3403'}{'name'} = 'copysnap'		; 
#	$srvcobjects_ref->{'copysnap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'copysnap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'copysnap'}{'port'}{'tcp'} = '3403'	; 
#	$srvcobjects_ref->{'copysnap'}{'ports'}{'tcp'}{'3403'}++	; 
#	$ports_ref->{'tcp'}{'3403'}{'name'} = 'copysnap'		; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'port'}{'udp'} = '2949'	; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'ports'}{'udp'}{'2949'}++	; 
#	$ports_ref->{'udp'}{'2949'}{'name'} = 'wap-pushsecure'		; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'port'}{'tcp'} = '2949'	; 
#	$srvcobjects_ref->{'wap-pushsecure'}{'ports'}{'tcp'}{'2949'}++	; 
#	$ports_ref->{'tcp'}{'2949'}{'name'} = 'wap-pushsecure'		; 
#	$srvcobjects_ref->{'lif-mlp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lif-mlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lif-mlp'}{'port'}{'udp'} = '9210'	; 
#	$srvcobjects_ref->{'lif-mlp'}{'ports'}{'udp'}{'9210'}++	; 
#	$ports_ref->{'udp'}{'9210'}{'name'} = 'lif-mlp'		; 
#	$srvcobjects_ref->{'lif-mlp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lif-mlp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lif-mlp'}{'port'}{'tcp'} = '9210'	; 
#	$srvcobjects_ref->{'lif-mlp'}{'ports'}{'tcp'}{'9210'}++	; 
#	$ports_ref->{'tcp'}{'9210'}{'name'} = 'lif-mlp'		; 
#	$srvcobjects_ref->{'licensedaemon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'licensedaemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'licensedaemon'}{'port'}{'udp'} = '1986'	; 
#	$srvcobjects_ref->{'licensedaemon'}{'ports'}{'udp'}{'1986'}++	; 
#	$ports_ref->{'udp'}{'1986'}{'name'} = 'licensedaemon'		; 
#	$srvcobjects_ref->{'licensedaemon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'licensedaemon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'licensedaemon'}{'port'}{'tcp'} = '1986'	; 
#	$srvcobjects_ref->{'licensedaemon'}{'ports'}{'tcp'}{'1986'}++	; 
#	$ports_ref->{'tcp'}{'1986'}{'name'} = 'licensedaemon'		; 
#	$srvcobjects_ref->{'itb301'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'itb301'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itb301'}{'port'}{'udp'} = '2992'	; 
#	$srvcobjects_ref->{'itb301'}{'ports'}{'udp'}{'2992'}++	; 
#	$ports_ref->{'udp'}{'2992'}{'name'} = 'itb301'		; 
#	$srvcobjects_ref->{'itb301'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'itb301'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'itb301'}{'port'}{'tcp'} = '2992'	; 
#	$srvcobjects_ref->{'itb301'}{'ports'}{'tcp'}{'2992'}++	; 
#	$ports_ref->{'tcp'}{'2992'}{'name'} = 'itb301'		; 
#	$srvcobjects_ref->{'pvsw-inet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pvsw-inet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pvsw-inet'}{'port'}{'udp'} = '2441'	; 
#	$srvcobjects_ref->{'pvsw-inet'}{'ports'}{'udp'}{'2441'}++	; 
#	$ports_ref->{'udp'}{'2441'}{'name'} = 'pvsw-inet'		; 
#	$srvcobjects_ref->{'pvsw-inet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pvsw-inet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pvsw-inet'}{'port'}{'tcp'} = '2441'	; 
#	$srvcobjects_ref->{'pvsw-inet'}{'ports'}{'tcp'}{'2441'}++	; 
#	$ports_ref->{'tcp'}{'2441'}{'name'} = 'pvsw-inet'		; 
#	$srvcobjects_ref->{'vp2p'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vp2p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vp2p'}{'port'}{'udp'} = '8473'	; 
#	$srvcobjects_ref->{'vp2p'}{'ports'}{'udp'}{'8473'}++	; 
#	$ports_ref->{'udp'}{'8473'}{'name'} = 'vp2p'		; 
#	$srvcobjects_ref->{'vp2p'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vp2p'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vp2p'}{'port'}{'tcp'} = '8473'	; 
#	$srvcobjects_ref->{'vp2p'}{'ports'}{'tcp'}{'8473'}++	; 
#	$ports_ref->{'tcp'}{'8473'}{'name'} = 'vp2p'		; 
#	$srvcobjects_ref->{'netlock3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netlock3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock3'}{'port'}{'udp'} = '9162'	; 
#	$srvcobjects_ref->{'netlock3'}{'ports'}{'udp'}{'9162'}++	; 
#	$ports_ref->{'udp'}{'9162'}{'name'} = 'netlock3'		; 
#	$srvcobjects_ref->{'netlock3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netlock3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netlock3'}{'port'}{'tcp'} = '9162'	; 
#	$srvcobjects_ref->{'netlock3'}{'ports'}{'tcp'}{'9162'}++	; 
#	$ports_ref->{'tcp'}{'9162'}{'name'} = 'netlock3'		; 
#	$srvcobjects_ref->{'enpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'enpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enpp'}{'port'}{'udp'} = '2968'	; 
#	$srvcobjects_ref->{'enpp'}{'ports'}{'udp'}{'2968'}++	; 
#	$ports_ref->{'udp'}{'2968'}{'name'} = 'enpp'		; 
#	$srvcobjects_ref->{'enpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'enpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'enpp'}{'port'}{'tcp'} = '2968'	; 
#	$srvcobjects_ref->{'enpp'}{'ports'}{'tcp'}{'2968'}++	; 
#	$ports_ref->{'tcp'}{'2968'}{'name'} = 'enpp'		; 
#	$srvcobjects_ref->{'tunnel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tunnel'}{'port'}{'udp'} = '604'	; 
#	$srvcobjects_ref->{'tunnel'}{'ports'}{'udp'}{'604'}++	; 
#	$ports_ref->{'udp'}{'604'}{'name'} = 'tunnel'		; 
#	$srvcobjects_ref->{'tunnel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tunnel'}{'port'}{'tcp'} = '604'	; 
#	$srvcobjects_ref->{'tunnel'}{'ports'}{'tcp'}{'604'}++	; 
#	$ports_ref->{'tcp'}{'604'}{'name'} = 'tunnel'		; 
#	$srvcobjects_ref->{'stargatealerts'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'stargatealerts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stargatealerts'}{'port'}{'udp'} = '1654'	; 
#	$srvcobjects_ref->{'stargatealerts'}{'ports'}{'udp'}{'1654'}++	; 
#	$ports_ref->{'udp'}{'1654'}{'name'} = 'stargatealerts'		; 
#	$srvcobjects_ref->{'stargatealerts'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'stargatealerts'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'stargatealerts'}{'port'}{'tcp'} = '1654'	; 
#	$srvcobjects_ref->{'stargatealerts'}{'ports'}{'tcp'}{'1654'}++	; 
#	$ports_ref->{'tcp'}{'1654'}{'name'} = 'stargatealerts'		; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'port'}{'udp'} = '1877'	; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'ports'}{'udp'}{'1877'}++	; 
#	$ports_ref->{'udp'}{'1877'}{'name'} = 'hp-webqosdb'		; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'port'}{'tcp'} = '1877'	; 
#	$srvcobjects_ref->{'hp-webqosdb'}{'ports'}{'tcp'}{'1877'}++	; 
#	$ports_ref->{'tcp'}{'1877'}{'name'} = 'hp-webqosdb'		; 
#	$srvcobjects_ref->{'meter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'meter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meter'}{'port'}{'udp'} = '571'	; 
#	$srvcobjects_ref->{'meter'}{'ports'}{'udp'}{'571'}++	; 
#	$ports_ref->{'udp'}{'571'}{'name'} = 'meter'		; 
#	$srvcobjects_ref->{'meter'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'meter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meter'}{'port'}{'udp'} = '570'	; 
#	$srvcobjects_ref->{'meter'}{'ports'}{'udp'}{'570'}++	; 
#	$ports_ref->{'udp'}{'570'}{'name'} = 'meter'		; 
#	$srvcobjects_ref->{'meter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'meter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meter'}{'port'}{'tcp'} = '571'	; 
#	$srvcobjects_ref->{'meter'}{'ports'}{'tcp'}{'571'}++	; 
#	$ports_ref->{'tcp'}{'571'}{'name'} = 'meter'		; 
#	$srvcobjects_ref->{'meter'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'meter'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'meter'}{'port'}{'tcp'} = '570'	; 
#	$srvcobjects_ref->{'meter'}{'ports'}{'tcp'}{'570'}++	; 
#	$ports_ref->{'tcp'}{'570'}{'name'} = 'meter'		; 
#	$srvcobjects_ref->{'chmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chmd'}{'port'}{'udp'} = '3099'	; 
#	$srvcobjects_ref->{'chmd'}{'ports'}{'udp'}{'3099'}++	; 
#	$ports_ref->{'udp'}{'3099'}{'name'} = 'chmd'		; 
#	$srvcobjects_ref->{'chmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chmd'}{'port'}{'tcp'} = '3099'	; 
#	$srvcobjects_ref->{'chmd'}{'ports'}{'tcp'}{'3099'}++	; 
#	$ports_ref->{'tcp'}{'3099'}{'name'} = 'chmd'		; 
#	$srvcobjects_ref->{'password-chg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'password-chg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'password-chg'}{'port'}{'udp'} = '586'	; 
#	$srvcobjects_ref->{'password-chg'}{'ports'}{'udp'}{'586'}++	; 
#	$ports_ref->{'udp'}{'586'}{'name'} = 'password-chg'		; 
#	$srvcobjects_ref->{'password-chg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'password-chg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'password-chg'}{'port'}{'tcp'} = '586'	; 
#	$srvcobjects_ref->{'password-chg'}{'ports'}{'tcp'}{'586'}++	; 
#	$ports_ref->{'tcp'}{'586'}{'name'} = 'password-chg'		; 
#	$srvcobjects_ref->{'avt-profile-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'avt-profile-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avt-profile-2'}{'port'}{'udp'} = '5005'	; 
#	$srvcobjects_ref->{'avt-profile-2'}{'ports'}{'udp'}{'5005'}++	; 
#	$ports_ref->{'udp'}{'5005'}{'name'} = 'avt-profile-2'		; 
#	$srvcobjects_ref->{'avt-profile-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'avt-profile-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'avt-profile-2'}{'port'}{'tcp'} = '5005'	; 
#	$srvcobjects_ref->{'avt-profile-2'}{'ports'}{'tcp'}{'5005'}++	; 
#	$ports_ref->{'tcp'}{'5005'}{'name'} = 'avt-profile-2'		; 
#	$srvcobjects_ref->{'trusted-web'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'trusted-web'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trusted-web'}{'port'}{'udp'} = '3011'	; 
#	$srvcobjects_ref->{'trusted-web'}{'ports'}{'udp'}{'3011'}++	; 
#	$ports_ref->{'udp'}{'3011'}{'name'} = 'trusted-web'		; 
#	$srvcobjects_ref->{'trusted-web'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'trusted-web'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'trusted-web'}{'port'}{'tcp'} = '3011'	; 
#	$srvcobjects_ref->{'trusted-web'}{'ports'}{'tcp'}{'3011'}++	; 
#	$ports_ref->{'tcp'}{'3011'}{'name'} = 'trusted-web'		; 
#	$srvcobjects_ref->{'www-dev'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'www-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'www-dev'}{'port'}{'udp'} = '2784'	; 
#	$srvcobjects_ref->{'www-dev'}{'ports'}{'udp'}{'2784'}++	; 
#	$ports_ref->{'udp'}{'2784'}{'name'} = 'www-dev'		; 
#	$srvcobjects_ref->{'www-dev'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'www-dev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'www-dev'}{'port'}{'tcp'} = '2784'	; 
#	$srvcobjects_ref->{'www-dev'}{'ports'}{'tcp'}{'2784'}++	; 
#	$ports_ref->{'tcp'}{'2784'}{'name'} = 'www-dev'		; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'port'}{'udp'} = '1313'	; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'ports'}{'udp'}{'1313'}++	; 
#	$ports_ref->{'udp'}{'1313'}{'name'} = 'bmc_patroldb'		; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'port'}{'tcp'} = '1313'	; 
#	$srvcobjects_ref->{'bmc_patroldb'}{'ports'}{'tcp'}{'1313'}++	; 
#	$ports_ref->{'tcp'}{'1313'}{'name'} = 'bmc_patroldb'		; 
#	$srvcobjects_ref->{'webtie'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webtie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webtie'}{'port'}{'udp'} = '3342'	; 
#	$srvcobjects_ref->{'webtie'}{'ports'}{'udp'}{'3342'}++	; 
#	$ports_ref->{'udp'}{'3342'}{'name'} = 'webtie'		; 
#	$srvcobjects_ref->{'webtie'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webtie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webtie'}{'port'}{'tcp'} = '3342'	; 
#	$srvcobjects_ref->{'webtie'}{'ports'}{'tcp'}{'3342'}++	; 
#	$ports_ref->{'tcp'}{'3342'}{'name'} = 'webtie'		; 
#	$srvcobjects_ref->{'esro-gen'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esro-gen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esro-gen'}{'port'}{'udp'} = '259'	; 
#	$srvcobjects_ref->{'esro-gen'}{'ports'}{'udp'}{'259'}++	; 
#	$ports_ref->{'udp'}{'259'}{'name'} = 'esro-gen'		; 
#	$srvcobjects_ref->{'esro-gen'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esro-gen'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esro-gen'}{'port'}{'tcp'} = '259'	; 
#	$srvcobjects_ref->{'esro-gen'}{'ports'}{'tcp'}{'259'}++	; 
#	$ports_ref->{'tcp'}{'259'}{'name'} = 'esro-gen'		; 
#	$srvcobjects_ref->{'atmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'atmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atmp'}{'port'}{'udp'} = '5150'	; 
#	$srvcobjects_ref->{'atmp'}{'ports'}{'udp'}{'5150'}++	; 
#	$ports_ref->{'udp'}{'5150'}{'name'} = 'atmp'		; 
#	$srvcobjects_ref->{'atmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'atmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'atmp'}{'port'}{'tcp'} = '5150'	; 
#	$srvcobjects_ref->{'atmp'}{'ports'}{'tcp'}{'5150'}++	; 
#	$ports_ref->{'tcp'}{'5150'}{'name'} = 'atmp'		; 
#	$srvcobjects_ref->{'xact-backup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xact-backup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xact-backup'}{'port'}{'udp'} = '911'	; 
#	$srvcobjects_ref->{'xact-backup'}{'ports'}{'udp'}{'911'}++	; 
#	$ports_ref->{'udp'}{'911'}{'name'} = 'xact-backup'		; 
#	$srvcobjects_ref->{'xact-backup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xact-backup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xact-backup'}{'port'}{'tcp'} = '911'	; 
#	$srvcobjects_ref->{'xact-backup'}{'ports'}{'tcp'}{'911'}++	; 
#	$ports_ref->{'tcp'}{'911'}{'name'} = 'xact-backup'		; 
#	$srvcobjects_ref->{'robcad-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'robcad-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'robcad-lm'}{'port'}{'udp'} = '1509'	; 
#	$srvcobjects_ref->{'robcad-lm'}{'ports'}{'udp'}{'1509'}++	; 
#	$ports_ref->{'udp'}{'1509'}{'name'} = 'robcad-lm'		; 
#	$srvcobjects_ref->{'robcad-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'robcad-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'robcad-lm'}{'port'}{'tcp'} = '1509'	; 
#	$srvcobjects_ref->{'robcad-lm'}{'ports'}{'tcp'}{'1509'}++	; 
#	$ports_ref->{'tcp'}{'1509'}{'name'} = 'robcad-lm'		; 
#	$srvcobjects_ref->{'iclpv-sas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclpv-sas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-sas'}{'port'}{'udp'} = '1391'	; 
#	$srvcobjects_ref->{'iclpv-sas'}{'ports'}{'udp'}{'1391'}++	; 
#	$ports_ref->{'udp'}{'1391'}{'name'} = 'iclpv-sas'		; 
#	$srvcobjects_ref->{'iclpv-sas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclpv-sas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-sas'}{'port'}{'tcp'} = '1391'	; 
#	$srvcobjects_ref->{'iclpv-sas'}{'ports'}{'tcp'}{'1391'}++	; 
#	$ports_ref->{'tcp'}{'1391'}{'name'} = 'iclpv-sas'		; 
#	$srvcobjects_ref->{'pump'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pump'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pump'}{'port'}{'udp'} = '751'	; 
#	$srvcobjects_ref->{'pump'}{'ports'}{'udp'}{'751'}++	; 
#	$ports_ref->{'udp'}{'751'}{'name'} = 'pump'		; 
#	$srvcobjects_ref->{'pump'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pump'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pump'}{'port'}{'tcp'} = '751'	; 
#	$srvcobjects_ref->{'pump'}{'ports'}{'tcp'}{'751'}++	; 
#	$ports_ref->{'tcp'}{'751'}{'name'} = 'pump'		; 
#	$srvcobjects_ref->{'invision'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'invision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'invision'}{'port'}{'udp'} = '1641'	; 
#	$srvcobjects_ref->{'invision'}{'ports'}{'udp'}{'1641'}++	; 
#	$ports_ref->{'udp'}{'1641'}{'name'} = 'invision'		; 
#	$srvcobjects_ref->{'invision'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'invision'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'invision'}{'port'}{'tcp'} = '1641'	; 
#	$srvcobjects_ref->{'invision'}{'ports'}{'tcp'}{'1641'}++	; 
#	$ports_ref->{'tcp'}{'1641'}{'name'} = 'invision'		; 
#	$srvcobjects_ref->{'rsmtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsmtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsmtp'}{'port'}{'udp'} = '2390'	; 
#	$srvcobjects_ref->{'rsmtp'}{'ports'}{'udp'}{'2390'}++	; 
#	$ports_ref->{'udp'}{'2390'}{'name'} = 'rsmtp'		; 
#	$srvcobjects_ref->{'rsmtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsmtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsmtp'}{'port'}{'tcp'} = '2390'	; 
#	$srvcobjects_ref->{'rsmtp'}{'ports'}{'tcp'}{'2390'}++	; 
#	$ports_ref->{'tcp'}{'2390'}{'name'} = 'rsmtp'		; 
#	$srvcobjects_ref->{'mailq'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mailq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mailq'}{'port'}{'udp'} = '174'	; 
#	$srvcobjects_ref->{'mailq'}{'ports'}{'udp'}{'174'}++	; 
#	$ports_ref->{'udp'}{'174'}{'name'} = 'mailq'		; 
#	$srvcobjects_ref->{'mailq'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mailq'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mailq'}{'port'}{'tcp'} = '174'	; 
#	$srvcobjects_ref->{'mailq'}{'ports'}{'tcp'}{'174'}++	; 
#	$ports_ref->{'tcp'}{'174'}{'name'} = 'mailq'		; 
#	$srvcobjects_ref->{'prism-deploy'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prism-deploy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prism-deploy'}{'port'}{'udp'} = '3133'	; 
#	$srvcobjects_ref->{'prism-deploy'}{'ports'}{'udp'}{'3133'}++	; 
#	$ports_ref->{'udp'}{'3133'}{'name'} = 'prism-deploy'		; 
#	$srvcobjects_ref->{'prism-deploy'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prism-deploy'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prism-deploy'}{'port'}{'tcp'} = '3133'	; 
#	$srvcobjects_ref->{'prism-deploy'}{'ports'}{'tcp'}{'3133'}++	; 
#	$ports_ref->{'tcp'}{'3133'}{'name'} = 'prism-deploy'		; 
#	$srvcobjects_ref->{'mpidcmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpidcmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpidcmgr'}{'port'}{'udp'} = '9343'	; 
#	$srvcobjects_ref->{'mpidcmgr'}{'ports'}{'udp'}{'9343'}++	; 
#	$ports_ref->{'udp'}{'9343'}{'name'} = 'mpidcmgr'		; 
#	$srvcobjects_ref->{'mpidcmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpidcmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpidcmgr'}{'port'}{'tcp'} = '9343'	; 
#	$srvcobjects_ref->{'mpidcmgr'}{'ports'}{'tcp'}{'9343'}++	; 
#	$ports_ref->{'tcp'}{'9343'}{'name'} = 'mpidcmgr'		; 
#	$srvcobjects_ref->{'compressnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'compressnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compressnet'}{'port'}{'udp'} = '3'	; 
#	$srvcobjects_ref->{'compressnet'}{'ports'}{'udp'}{'3'}++	; 
#	$ports_ref->{'udp'}{'3'}{'name'} = 'compressnet'		; 
#	$srvcobjects_ref->{'compressnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'compressnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compressnet'}{'port'}{'udp'} = '2'	; 
#	$srvcobjects_ref->{'compressnet'}{'ports'}{'udp'}{'2'}++	; 
#	$ports_ref->{'udp'}{'2'}{'name'} = 'compressnet'		; 
#	$srvcobjects_ref->{'compressnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'compressnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compressnet'}{'port'}{'tcp'} = '3'	; 
#	$srvcobjects_ref->{'compressnet'}{'ports'}{'tcp'}{'3'}++	; 
#	$ports_ref->{'tcp'}{'3'}{'name'} = 'compressnet'		; 
#	$srvcobjects_ref->{'compressnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'compressnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'compressnet'}{'port'}{'tcp'} = '2'	; 
#	$srvcobjects_ref->{'compressnet'}{'ports'}{'tcp'}{'2'}++	; 
#	$ports_ref->{'tcp'}{'2'}{'name'} = 'compressnet'		; 
#	$srvcobjects_ref->{'ipdtp-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipdtp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipdtp-port'}{'port'}{'udp'} = '20202'	; 
#	$srvcobjects_ref->{'ipdtp-port'}{'ports'}{'udp'}{'20202'}++	; 
#	$ports_ref->{'udp'}{'20202'}{'name'} = 'ipdtp-port'		; 
#	$srvcobjects_ref->{'ipdtp-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipdtp-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipdtp-port'}{'port'}{'tcp'} = '20202'	; 
#	$srvcobjects_ref->{'ipdtp-port'}{'ports'}{'tcp'}{'20202'}++	; 
#	$ports_ref->{'tcp'}{'20202'}{'name'} = 'ipdtp-port'		; 
#	$srvcobjects_ref->{'efi-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'efi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'efi-lm'}{'port'}{'udp'} = '3392'	; 
#	$srvcobjects_ref->{'efi-lm'}{'ports'}{'udp'}{'3392'}++	; 
#	$ports_ref->{'udp'}{'3392'}{'name'} = 'efi-lm'		; 
#	$srvcobjects_ref->{'efi-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'efi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'efi-lm'}{'port'}{'tcp'} = '3392'	; 
#	$srvcobjects_ref->{'efi-lm'}{'ports'}{'tcp'}{'3392'}++	; 
#	$ports_ref->{'tcp'}{'3392'}{'name'} = 'efi-lm'		; 
#	$srvcobjects_ref->{'snmptrap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snmptrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snmptrap'}{'port'}{'udp'} = '162'	; 
#	$srvcobjects_ref->{'snmptrap'}{'ports'}{'udp'}{'162'}++	; 
#	$ports_ref->{'udp'}{'162'}{'name'} = 'snmptrap'		; 
#	$srvcobjects_ref->{'snmptrap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snmptrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snmptrap'}{'port'}{'tcp'} = '162'	; 
#	$srvcobjects_ref->{'snmptrap'}{'ports'}{'tcp'}{'162'}++	; 
#	$ports_ref->{'tcp'}{'162'}{'name'} = 'snmptrap'		; 
#	$srvcobjects_ref->{'lmsocialserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lmsocialserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lmsocialserver'}{'port'}{'udp'} = '1111'	; 
#	$srvcobjects_ref->{'lmsocialserver'}{'ports'}{'udp'}{'1111'}++	; 
#	$ports_ref->{'udp'}{'1111'}{'name'} = 'lmsocialserver'		; 
#	$srvcobjects_ref->{'lmsocialserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lmsocialserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lmsocialserver'}{'port'}{'tcp'} = '1111'	; 
#	$srvcobjects_ref->{'lmsocialserver'}{'ports'}{'tcp'}{'1111'}++	; 
#	$ports_ref->{'tcp'}{'1111'}{'name'} = 'lmsocialserver'		; 
#	$srvcobjects_ref->{'jabber-client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jabber-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jabber-client'}{'port'}{'udp'} = '5222'	; 
#	$srvcobjects_ref->{'jabber-client'}{'ports'}{'udp'}{'5222'}++	; 
#	$ports_ref->{'udp'}{'5222'}{'name'} = 'jabber-client'		; 
#	$srvcobjects_ref->{'jabber-client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jabber-client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jabber-client'}{'port'}{'tcp'} = '5222'	; 
#	$srvcobjects_ref->{'jabber-client'}{'ports'}{'tcp'}{'5222'}++	; 
#	$ports_ref->{'tcp'}{'5222'}{'name'} = 'jabber-client'		; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'port'}{'udp'} = '2180'	; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'ports'}{'udp'}{'2180'}++	; 
#	$ports_ref->{'udp'}{'2180'}{'name'} = 'mc-gt-srv'		; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'port'}{'tcp'} = '2180'	; 
#	$srvcobjects_ref->{'mc-gt-srv'}{'ports'}{'tcp'}{'2180'}++	; 
#	$ports_ref->{'tcp'}{'2180'}{'name'} = 'mc-gt-srv'		; 
#	$srvcobjects_ref->{'graphics'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'graphics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'graphics'}{'port'}{'udp'} = '41'	; 
#	$srvcobjects_ref->{'graphics'}{'ports'}{'udp'}{'41'}++	; 
#	$ports_ref->{'udp'}{'41'}{'name'} = 'graphics'		; 
#	$srvcobjects_ref->{'graphics'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'graphics'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'graphics'}{'port'}{'tcp'} = '41'	; 
#	$srvcobjects_ref->{'graphics'}{'ports'}{'tcp'}{'41'}++	; 
#	$ports_ref->{'tcp'}{'41'}{'name'} = 'graphics'		; 
#	$srvcobjects_ref->{'de-spot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'de-spot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-spot'}{'port'}{'udp'} = '2753'	; 
#	$srvcobjects_ref->{'de-spot'}{'ports'}{'udp'}{'2753'}++	; 
#	$ports_ref->{'udp'}{'2753'}{'name'} = 'de-spot'		; 
#	$srvcobjects_ref->{'de-spot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'de-spot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-spot'}{'port'}{'tcp'} = '2753'	; 
#	$srvcobjects_ref->{'de-spot'}{'ports'}{'tcp'}{'2753'}++	; 
#	$ports_ref->{'tcp'}{'2753'}{'name'} = 'de-spot'		; 
#	$srvcobjects_ref->{'sasg'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sasg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sasg'}{'port'}{'udp'} = '3744'	; 
#	$srvcobjects_ref->{'sasg'}{'ports'}{'udp'}{'3744'}++	; 
#	$ports_ref->{'udp'}{'3744'}{'name'} = 'sasg'		; 
#	$srvcobjects_ref->{'sasg'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sasg'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sasg'}{'port'}{'tcp'} = '3744'	; 
#	$srvcobjects_ref->{'sasg'}{'ports'}{'tcp'}{'3744'}++	; 
#	$ports_ref->{'tcp'}{'3744'}{'name'} = 'sasg'		; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'port'}{'udp'} = '1597'	; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'ports'}{'udp'}{'1597'}++	; 
#	$ports_ref->{'udp'}{'1597'}{'name'} = 'orbplus-iiop'		; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'port'}{'tcp'} = '1597'	; 
#	$srvcobjects_ref->{'orbplus-iiop'}{'ports'}{'tcp'}{'1597'}++	; 
#	$ports_ref->{'tcp'}{'1597'}{'name'} = 'orbplus-iiop'		; 
#	$srvcobjects_ref->{'hbci'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hbci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hbci'}{'port'}{'udp'} = '3000'	; 
#	$srvcobjects_ref->{'hbci'}{'ports'}{'udp'}{'3000'}++	; 
#	$ports_ref->{'udp'}{'3000'}{'name'} = 'hbci'		; 
#	$srvcobjects_ref->{'hbci'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hbci'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hbci'}{'port'}{'tcp'} = '3000'	; 
#	$srvcobjects_ref->{'hbci'}{'ports'}{'tcp'}{'3000'}++	; 
#	$ports_ref->{'tcp'}{'3000'}{'name'} = 'hbci'		; 
#	$srvcobjects_ref->{'gamelobby'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gamelobby'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gamelobby'}{'port'}{'udp'} = '2914'	; 
#	$srvcobjects_ref->{'gamelobby'}{'ports'}{'udp'}{'2914'}++	; 
#	$ports_ref->{'udp'}{'2914'}{'name'} = 'gamelobby'		; 
#	$srvcobjects_ref->{'gamelobby'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gamelobby'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gamelobby'}{'port'}{'tcp'} = '2914'	; 
#	$srvcobjects_ref->{'gamelobby'}{'ports'}{'tcp'}{'2914'}++	; 
#	$ports_ref->{'tcp'}{'2914'}{'name'} = 'gamelobby'		; 
#	$srvcobjects_ref->{'opsec-sam'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsec-sam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-sam'}{'port'}{'udp'} = '18183'	; 
#	$srvcobjects_ref->{'opsec-sam'}{'ports'}{'udp'}{'18183'}++	; 
#	$ports_ref->{'udp'}{'18183'}{'name'} = 'opsec-sam'		; 
#	$srvcobjects_ref->{'opsec-sam'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsec-sam'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-sam'}{'port'}{'tcp'} = '18183'	; 
#	$srvcobjects_ref->{'opsec-sam'}{'ports'}{'tcp'}{'18183'}++	; 
#	$ports_ref->{'tcp'}{'18183'}{'name'} = 'opsec-sam'		; 
#	$srvcobjects_ref->{'epp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'epp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epp'}{'port'}{'udp'} = '3044'	; 
#	$srvcobjects_ref->{'epp'}{'ports'}{'udp'}{'3044'}++	; 
#	$ports_ref->{'udp'}{'3044'}{'name'} = 'epp'		; 
#	$srvcobjects_ref->{'epp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'epp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'epp'}{'port'}{'tcp'} = '3044'	; 
#	$srvcobjects_ref->{'epp'}{'ports'}{'tcp'}{'3044'}++	; 
#	$ports_ref->{'tcp'}{'3044'}{'name'} = 'epp'		; 
#	$srvcobjects_ref->{'qencp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qencp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qencp'}{'port'}{'udp'} = '2120'	; 
#	$srvcobjects_ref->{'qencp'}{'ports'}{'udp'}{'2120'}++	; 
#	$ports_ref->{'udp'}{'2120'}{'name'} = 'qencp'		; 
#	$srvcobjects_ref->{'qencp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qencp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qencp'}{'port'}{'tcp'} = '2120'	; 
#	$srvcobjects_ref->{'qencp'}{'ports'}{'tcp'}{'2120'}++	; 
#	$ports_ref->{'tcp'}{'2120'}{'name'} = 'qencp'		; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'port'}{'udp'} = '5503'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'ports'}{'udp'}{'5503'}++	; 
#	$ports_ref->{'udp'}{'5503'}{'name'} = 'fcp-srvr-inst2'		; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'port'}{'tcp'} = '5503'	; 
#	$srvcobjects_ref->{'fcp-srvr-inst2'}{'ports'}{'tcp'}{'5503'}++	; 
#	$ports_ref->{'tcp'}{'5503'}{'name'} = 'fcp-srvr-inst2'		; 
#	$srvcobjects_ref->{'hkp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hkp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hkp'}{'port'}{'udp'} = '11371'	; 
#	$srvcobjects_ref->{'hkp'}{'ports'}{'udp'}{'11371'}++	; 
#	$ports_ref->{'udp'}{'11371'}{'name'} = 'hkp'		; 
#	$srvcobjects_ref->{'hkp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hkp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hkp'}{'port'}{'tcp'} = '11371'	; 
#	$srvcobjects_ref->{'hkp'}{'ports'}{'tcp'}{'11371'}++	; 
#	$ports_ref->{'tcp'}{'11371'}{'name'} = 'hkp'		; 
#	$srvcobjects_ref->{'bacnet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bacnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacnet'}{'port'}{'udp'} = '47808'	; 
#	$srvcobjects_ref->{'bacnet'}{'ports'}{'udp'}{'47808'}++	; 
#	$ports_ref->{'udp'}{'47808'}{'name'} = 'bacnet'		; 
#	$srvcobjects_ref->{'bacnet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bacnet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bacnet'}{'port'}{'tcp'} = '47808'	; 
#	$srvcobjects_ref->{'bacnet'}{'ports'}{'tcp'}{'47808'}++	; 
#	$ports_ref->{'tcp'}{'47808'}{'name'} = 'bacnet'		; 
#	$srvcobjects_ref->{'entomb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entomb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entomb'}{'port'}{'tcp'} = '775'	; 
#	$srvcobjects_ref->{'entomb'}{'ports'}{'tcp'}{'775'}++	; 
#	$ports_ref->{'tcp'}{'775'}{'name'} = 'entomb'		; 
#	$srvcobjects_ref->{'aodv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aodv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aodv'}{'port'}{'udp'} = '654'	; 
#	$srvcobjects_ref->{'aodv'}{'ports'}{'udp'}{'654'}++	; 
#	$ports_ref->{'udp'}{'654'}{'name'} = 'aodv'		; 
#	$srvcobjects_ref->{'aodv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aodv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aodv'}{'port'}{'tcp'} = '654'	; 
#	$srvcobjects_ref->{'aodv'}{'ports'}{'tcp'}{'654'}++	; 
#	$ports_ref->{'tcp'}{'654'}{'name'} = 'aodv'		; 
#	$srvcobjects_ref->{'netview-aix-5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-5'}{'port'}{'udp'} = '1665'	; 
#	$srvcobjects_ref->{'netview-aix-5'}{'ports'}{'udp'}{'1665'}++	; 
#	$ports_ref->{'udp'}{'1665'}{'name'} = 'netview-aix-5'		; 
#	$srvcobjects_ref->{'netview-aix-5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-5'}{'port'}{'tcp'} = '1665'	; 
#	$srvcobjects_ref->{'netview-aix-5'}{'ports'}{'tcp'}{'1665'}++	; 
#	$ports_ref->{'tcp'}{'1665'}{'name'} = 'netview-aix-5'		; 
#	$srvcobjects_ref->{'serverview-asn'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'serverview-asn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-asn'}{'port'}{'udp'} = '3170'	; 
#	$srvcobjects_ref->{'serverview-asn'}{'ports'}{'udp'}{'3170'}++	; 
#	$ports_ref->{'udp'}{'3170'}{'name'} = 'serverview-asn'		; 
#	$srvcobjects_ref->{'serverview-asn'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'serverview-asn'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'serverview-asn'}{'port'}{'tcp'} = '3170'	; 
#	$srvcobjects_ref->{'serverview-asn'}{'ports'}{'tcp'}{'3170'}++	; 
#	$ports_ref->{'tcp'}{'3170'}{'name'} = 'serverview-asn'		; 
#	$srvcobjects_ref->{'goahead-fldup'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'goahead-fldup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'goahead-fldup'}{'port'}{'udp'} = '3057'	; 
#	$srvcobjects_ref->{'goahead-fldup'}{'ports'}{'udp'}{'3057'}++	; 
#	$ports_ref->{'udp'}{'3057'}{'name'} = 'goahead-fldup'		; 
#	$srvcobjects_ref->{'goahead-fldup'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'goahead-fldup'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'goahead-fldup'}{'port'}{'tcp'} = '3057'	; 
#	$srvcobjects_ref->{'goahead-fldup'}{'ports'}{'tcp'}{'3057'}++	; 
#	$ports_ref->{'tcp'}{'3057'}{'name'} = 'goahead-fldup'		; 
#	$srvcobjects_ref->{'cadsi-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadsi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadsi-lm'}{'port'}{'udp'} = '1387'	; 
#	$srvcobjects_ref->{'cadsi-lm'}{'ports'}{'udp'}{'1387'}++	; 
#	$ports_ref->{'udp'}{'1387'}{'name'} = 'cadsi-lm'		; 
#	$srvcobjects_ref->{'cadsi-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadsi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadsi-lm'}{'port'}{'tcp'} = '1387'	; 
#	$srvcobjects_ref->{'cadsi-lm'}{'ports'}{'tcp'}{'1387'}++	; 
#	$ports_ref->{'tcp'}{'1387'}{'name'} = 'cadsi-lm'		; 
#	$srvcobjects_ref->{'apex-edge'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apex-edge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apex-edge'}{'port'}{'udp'} = '913'	; 
#	$srvcobjects_ref->{'apex-edge'}{'ports'}{'udp'}{'913'}++	; 
#	$ports_ref->{'udp'}{'913'}{'name'} = 'apex-edge'		; 
#	$srvcobjects_ref->{'apex-edge'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apex-edge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apex-edge'}{'port'}{'tcp'} = '913'	; 
#	$srvcobjects_ref->{'apex-edge'}{'ports'}{'tcp'}{'913'}++	; 
#	$ports_ref->{'tcp'}{'913'}{'name'} = 'apex-edge'		; 
#	$srvcobjects_ref->{'chshell'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chshell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chshell'}{'port'}{'udp'} = '562'	; 
#	$srvcobjects_ref->{'chshell'}{'ports'}{'udp'}{'562'}++	; 
#	$ports_ref->{'udp'}{'562'}{'name'} = 'chshell'		; 
#	$srvcobjects_ref->{'chshell'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chshell'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chshell'}{'port'}{'tcp'} = '562'	; 
#	$srvcobjects_ref->{'chshell'}{'ports'}{'tcp'}{'562'}++	; 
#	$ports_ref->{'tcp'}{'562'}{'name'} = 'chshell'		; 
#	$srvcobjects_ref->{'appman-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appman-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appman-server'}{'port'}{'udp'} = '3312'	; 
#	$srvcobjects_ref->{'appman-server'}{'ports'}{'udp'}{'3312'}++	; 
#	$ports_ref->{'udp'}{'3312'}{'name'} = 'appman-server'		; 
#	$srvcobjects_ref->{'appman-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appman-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appman-server'}{'port'}{'tcp'} = '3312'	; 
#	$srvcobjects_ref->{'appman-server'}{'ports'}{'tcp'}{'3312'}++	; 
#	$ports_ref->{'tcp'}{'3312'}{'name'} = 'appman-server'		; 
#	$srvcobjects_ref->{'commerce'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'commerce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commerce'}{'port'}{'udp'} = '542'	; 
#	$srvcobjects_ref->{'commerce'}{'ports'}{'udp'}{'542'}++	; 
#	$ports_ref->{'udp'}{'542'}{'name'} = 'commerce'		; 
#	$srvcobjects_ref->{'commerce'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'commerce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'commerce'}{'port'}{'tcp'} = '542'	; 
#	$srvcobjects_ref->{'commerce'}{'ports'}{'tcp'}{'542'}++	; 
#	$ports_ref->{'tcp'}{'542'}{'name'} = 'commerce'		; 
#	$srvcobjects_ref->{'vnas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vnas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnas'}{'port'}{'udp'} = '577'	; 
#	$srvcobjects_ref->{'vnas'}{'ports'}{'udp'}{'577'}++	; 
#	$ports_ref->{'udp'}{'577'}{'name'} = 'vnas'		; 
#	$srvcobjects_ref->{'vnas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vnas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vnas'}{'port'}{'tcp'} = '577'	; 
#	$srvcobjects_ref->{'vnas'}{'ports'}{'tcp'}{'577'}++	; 
#	$ports_ref->{'tcp'}{'577'}{'name'} = 'vnas'		; 
#	$srvcobjects_ref->{'irdg-post'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'irdg-post'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irdg-post'}{'port'}{'udp'} = '2632'	; 
#	$srvcobjects_ref->{'irdg-post'}{'ports'}{'udp'}{'2632'}++	; 
#	$ports_ref->{'udp'}{'2632'}{'name'} = 'irdg-post'		; 
#	$srvcobjects_ref->{'irdg-post'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'irdg-post'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'irdg-post'}{'port'}{'tcp'} = '2632'	; 
#	$srvcobjects_ref->{'irdg-post'}{'ports'}{'tcp'}{'2632'}++	; 
#	$ports_ref->{'tcp'}{'2632'}{'name'} = 'irdg-post'		; 
#	$srvcobjects_ref->{'h323gatestat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'h323gatestat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323gatestat'}{'port'}{'udp'} = '1719'	; 
#	$srvcobjects_ref->{'h323gatestat'}{'ports'}{'udp'}{'1719'}++	; 
#	$ports_ref->{'udp'}{'1719'}{'name'} = 'h323gatestat'		; 
#	$srvcobjects_ref->{'h323gatestat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'h323gatestat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'h323gatestat'}{'port'}{'tcp'} = '1719'	; 
#	$srvcobjects_ref->{'h323gatestat'}{'ports'}{'tcp'}{'1719'}++	; 
#	$ports_ref->{'tcp'}{'1719'}{'name'} = 'h323gatestat'		; 
#	$srvcobjects_ref->{'palace-1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'palace-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-1'}{'port'}{'udp'} = '9992'	; 
#	$srvcobjects_ref->{'palace-1'}{'ports'}{'udp'}{'9992'}++	; 
#	$ports_ref->{'udp'}{'9992'}{'name'} = 'palace-1'		; 
#	$srvcobjects_ref->{'palace-1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'palace-1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'palace-1'}{'port'}{'tcp'} = '9992'	; 
#	$srvcobjects_ref->{'palace-1'}{'ports'}{'tcp'}{'9992'}++	; 
#	$ports_ref->{'tcp'}{'9992'}{'name'} = 'palace-1'		; 
#	$srvcobjects_ref->{'a13-an'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'a13-an'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a13-an'}{'port'}{'udp'} = '3125'	; 
#	$srvcobjects_ref->{'a13-an'}{'ports'}{'udp'}{'3125'}++	; 
#	$ports_ref->{'udp'}{'3125'}{'name'} = 'a13-an'		; 
#	$srvcobjects_ref->{'a13-an'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'a13-an'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a13-an'}{'port'}{'tcp'} = '3125'	; 
#	$srvcobjects_ref->{'a13-an'}{'ports'}{'tcp'}{'3125'}++	; 
#	$ports_ref->{'tcp'}{'3125'}{'name'} = 'a13-an'		; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'port'}{'udp'} = '3527'	; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'ports'}{'udp'}{'3527'}++	; 
#	$ports_ref->{'udp'}{'3527'}{'name'} = 'beserver-msg-q'		; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'port'}{'tcp'} = '3527'	; 
#	$srvcobjects_ref->{'beserver-msg-q'}{'ports'}{'tcp'}{'3527'}++	; 
#	$ports_ref->{'tcp'}{'3527'}{'name'} = 'beserver-msg-q'		; 
#	$srvcobjects_ref->{'discp-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'discp-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discp-server'}{'port'}{'udp'} = '2602'	; 
#	$srvcobjects_ref->{'discp-server'}{'ports'}{'udp'}{'2602'}++	; 
#	$ports_ref->{'udp'}{'2602'}{'name'} = 'discp-server'		; 
#	$srvcobjects_ref->{'discp-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'discp-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'discp-server'}{'port'}{'tcp'} = '2602'	; 
#	$srvcobjects_ref->{'discp-server'}{'ports'}{'tcp'}{'2602'}++	; 
#	$ports_ref->{'tcp'}{'2602'}{'name'} = 'discp-server'		; 
#	$srvcobjects_ref->{'imip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imip'}{'port'}{'udp'} = '11319'	; 
#	$srvcobjects_ref->{'imip'}{'ports'}{'udp'}{'11319'}++	; 
#	$ports_ref->{'udp'}{'11319'}{'name'} = 'imip'		; 
#	$srvcobjects_ref->{'imip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imip'}{'port'}{'tcp'} = '11319'	; 
#	$srvcobjects_ref->{'imip'}{'ports'}{'tcp'}{'11319'}++	; 
#	$ports_ref->{'tcp'}{'11319'}{'name'} = 'imip'		; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'port'}{'udp'} = '598'	; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'ports'}{'udp'}{'598'}++	; 
#	$ports_ref->{'udp'}{'598'}{'name'} = 'sco-websrvrmg3'		; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'port'}{'tcp'} = '598'	; 
#	$srvcobjects_ref->{'sco-websrvrmg3'}{'ports'}{'tcp'}{'598'}++	; 
#	$ports_ref->{'tcp'}{'598'}{'name'} = 'sco-websrvrmg3'		; 
#	$srvcobjects_ref->{'zarkov'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'zarkov'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zarkov'}{'port'}{'udp'} = '2989'	; 
#	$srvcobjects_ref->{'zarkov'}{'ports'}{'udp'}{'2989'}++	; 
#	$ports_ref->{'udp'}{'2989'}{'name'} = 'zarkov'		; 
#	$srvcobjects_ref->{'zarkov'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'zarkov'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'zarkov'}{'port'}{'tcp'} = '2989'	; 
#	$srvcobjects_ref->{'zarkov'}{'ports'}{'tcp'}{'2989'}++	; 
#	$ports_ref->{'tcp'}{'2989'}{'name'} = 'zarkov'		; 
#	$srvcobjects_ref->{'taserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'taserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taserver'}{'port'}{'udp'} = '3552'	; 
#	$srvcobjects_ref->{'taserver'}{'ports'}{'udp'}{'3552'}++	; 
#	$ports_ref->{'udp'}{'3552'}{'name'} = 'taserver'		; 
#	$srvcobjects_ref->{'taserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'taserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'taserver'}{'port'}{'tcp'} = '3552'	; 
#	$srvcobjects_ref->{'taserver'}{'ports'}{'tcp'}{'3552'}++	; 
#	$ports_ref->{'tcp'}{'3552'}{'name'} = 'taserver'		; 
#	$srvcobjects_ref->{'imqtunnel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imqtunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imqtunnel'}{'port'}{'udp'} = '7675'	; 
#	$srvcobjects_ref->{'imqtunnel'}{'ports'}{'udp'}{'7675'}++	; 
#	$ports_ref->{'udp'}{'7675'}{'name'} = 'imqtunnel'		; 
#	$srvcobjects_ref->{'imqtunnel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imqtunnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imqtunnel'}{'port'}{'tcp'} = '7675'	; 
#	$srvcobjects_ref->{'imqtunnel'}{'ports'}{'tcp'}{'7675'}++	; 
#	$ports_ref->{'tcp'}{'7675'}{'name'} = 'imqtunnel'		; 
#	$srvcobjects_ref->{'fc-cli'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fc-cli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fc-cli'}{'port'}{'udp'} = '1371'	; 
#	$srvcobjects_ref->{'fc-cli'}{'ports'}{'udp'}{'1371'}++	; 
#	$ports_ref->{'udp'}{'1371'}{'name'} = 'fc-cli'		; 
#	$srvcobjects_ref->{'fc-cli'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fc-cli'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fc-cli'}{'port'}{'tcp'} = '1371'	; 
#	$srvcobjects_ref->{'fc-cli'}{'ports'}{'tcp'}{'1371'}++	; 
#	$ports_ref->{'tcp'}{'1371'}{'name'} = 'fc-cli'		; 
#	$srvcobjects_ref->{'editbench'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'editbench'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'editbench'}{'port'}{'udp'} = '1350'	; 
#	$srvcobjects_ref->{'editbench'}{'ports'}{'udp'}{'1350'}++	; 
#	$ports_ref->{'udp'}{'1350'}{'name'} = 'editbench'		; 
#	$srvcobjects_ref->{'editbench'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'editbench'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'editbench'}{'port'}{'tcp'} = '1350'	; 
#	$srvcobjects_ref->{'editbench'}{'ports'}{'tcp'}{'1350'}++	; 
#	$ports_ref->{'tcp'}{'1350'}{'name'} = 'editbench'		; 
#	$srvcobjects_ref->{'entextmed'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'entextmed'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextmed'}{'port'}{'udp'} = '12003'	; 
#	$srvcobjects_ref->{'entextmed'}{'ports'}{'udp'}{'12003'}++	; 
#	$ports_ref->{'udp'}{'12003'}{'name'} = 'entextmed'		; 
#	$srvcobjects_ref->{'entextmed'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'entextmed'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'entextmed'}{'port'}{'tcp'} = '12003'	; 
#	$srvcobjects_ref->{'entextmed'}{'ports'}{'tcp'}{'12003'}++	; 
#	$ports_ref->{'tcp'}{'12003'}{'name'} = 'entextmed'		; 
#	$srvcobjects_ref->{'dbisamserver2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbisamserver2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbisamserver2'}{'port'}{'udp'} = '12006'	; 
#	$srvcobjects_ref->{'dbisamserver2'}{'ports'}{'udp'}{'12006'}++	; 
#	$ports_ref->{'udp'}{'12006'}{'name'} = 'dbisamserver2'		; 
#	$srvcobjects_ref->{'dbisamserver2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbisamserver2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbisamserver2'}{'port'}{'tcp'} = '12006'	; 
#	$srvcobjects_ref->{'dbisamserver2'}{'ports'}{'tcp'}{'12006'}++	; 
#	$ports_ref->{'tcp'}{'12006'}{'name'} = 'dbisamserver2'		; 
#	$srvcobjects_ref->{'objective-dbc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'objective-dbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'objective-dbc'}{'port'}{'udp'} = '1388'	; 
#	$srvcobjects_ref->{'objective-dbc'}{'ports'}{'udp'}{'1388'}++	; 
#	$ports_ref->{'udp'}{'1388'}{'name'} = 'objective-dbc'		; 
#	$srvcobjects_ref->{'objective-dbc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'objective-dbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'objective-dbc'}{'port'}{'tcp'} = '1388'	; 
#	$srvcobjects_ref->{'objective-dbc'}{'ports'}{'tcp'}{'1388'}++	; 
#	$ports_ref->{'tcp'}{'1388'}{'name'} = 'objective-dbc'		; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'port'}{'udp'} = '545'	; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'ports'}{'udp'}{'545'}++	; 
#	$ports_ref->{'udp'}{'545'}{'name'} = 'appleqtcsrvr'		; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'port'}{'tcp'} = '545'	; 
#	$srvcobjects_ref->{'appleqtcsrvr'}{'ports'}{'tcp'}{'545'}++	; 
#	$ports_ref->{'tcp'}{'545'}{'name'} = 'appleqtcsrvr'		; 
#	$srvcobjects_ref->{'cft-5'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cft-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-5'}{'port'}{'udp'} = '1766'	; 
#	$srvcobjects_ref->{'cft-5'}{'ports'}{'udp'}{'1766'}++	; 
#	$ports_ref->{'udp'}{'1766'}{'name'} = 'cft-5'		; 
#	$srvcobjects_ref->{'cft-5'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cft-5'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cft-5'}{'port'}{'tcp'} = '1766'	; 
#	$srvcobjects_ref->{'cft-5'}{'ports'}{'tcp'}{'1766'}++	; 
#	$ports_ref->{'tcp'}{'1766'}{'name'} = 'cft-5'		; 
#	$srvcobjects_ref->{'dbase'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbase'}{'port'}{'udp'} = '217'	; 
#	$srvcobjects_ref->{'dbase'}{'ports'}{'udp'}{'217'}++	; 
#	$ports_ref->{'udp'}{'217'}{'name'} = 'dbase'		; 
#	$srvcobjects_ref->{'dbase'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dbase'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dbase'}{'port'}{'tcp'} = '217'	; 
#	$srvcobjects_ref->{'dbase'}{'ports'}{'tcp'}{'217'}++	; 
#	$ports_ref->{'tcp'}{'217'}{'name'} = 'dbase'		; 
#	$srvcobjects_ref->{'teedtap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'teedtap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teedtap'}{'port'}{'udp'} = '559'	; 
#	$srvcobjects_ref->{'teedtap'}{'ports'}{'udp'}{'559'}++	; 
#	$ports_ref->{'udp'}{'559'}{'name'} = 'teedtap'		; 
#	$srvcobjects_ref->{'teedtap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'teedtap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'teedtap'}{'port'}{'tcp'} = '559'	; 
#	$srvcobjects_ref->{'teedtap'}{'ports'}{'tcp'}{'559'}++	; 
#	$ports_ref->{'tcp'}{'559'}{'name'} = 'teedtap'		; 
#	$srvcobjects_ref->{'bhmds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bhmds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhmds'}{'port'}{'udp'} = '310'	; 
#	$srvcobjects_ref->{'bhmds'}{'ports'}{'udp'}{'310'}++	; 
#	$ports_ref->{'udp'}{'310'}{'name'} = 'bhmds'		; 
#	$srvcobjects_ref->{'bhmds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bhmds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bhmds'}{'port'}{'tcp'} = '310'	; 
#	$srvcobjects_ref->{'bhmds'}{'ports'}{'tcp'}{'310'}++	; 
#	$ports_ref->{'tcp'}{'310'}{'name'} = 'bhmds'		; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'port'}{'udp'} = '9612'	; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'ports'}{'udp'}{'9612'}++	; 
#	$ports_ref->{'udp'}{'9612'}{'name'} = 'streamcomm-ds'		; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'port'}{'tcp'} = '9612'	; 
#	$srvcobjects_ref->{'streamcomm-ds'}{'ports'}{'tcp'}{'9612'}++	; 
#	$ports_ref->{'tcp'}{'9612'}{'name'} = 'streamcomm-ds'		; 
#	$srvcobjects_ref->{'ttc-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ttc-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-ssl'}{'port'}{'udp'} = '2484'	; 
#	$srvcobjects_ref->{'ttc-ssl'}{'ports'}{'udp'}{'2484'}++	; 
#	$ports_ref->{'udp'}{'2484'}{'name'} = 'ttc-ssl'		; 
#	$srvcobjects_ref->{'ttc-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ttc-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ttc-ssl'}{'port'}{'tcp'} = '2484'	; 
#	$srvcobjects_ref->{'ttc-ssl'}{'ports'}{'tcp'}{'2484'}++	; 
#	$ports_ref->{'tcp'}{'2484'}{'name'} = 'ttc-ssl'		; 
#	$srvcobjects_ref->{'empire-empuma'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'empire-empuma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'empire-empuma'}{'port'}{'udp'} = '1691'	; 
#	$srvcobjects_ref->{'empire-empuma'}{'ports'}{'udp'}{'1691'}++	; 
#	$ports_ref->{'udp'}{'1691'}{'name'} = 'empire-empuma'		; 
#	$srvcobjects_ref->{'empire-empuma'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'empire-empuma'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'empire-empuma'}{'port'}{'tcp'} = '1691'	; 
#	$srvcobjects_ref->{'empire-empuma'}{'ports'}{'tcp'}{'1691'}++	; 
#	$ports_ref->{'tcp'}{'1691'}{'name'} = 'empire-empuma'		; 
#	$srvcobjects_ref->{'as-debug'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'as-debug'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'as-debug'}{'port'}{'udp'} = '4026'	; 
#	$srvcobjects_ref->{'as-debug'}{'ports'}{'udp'}{'4026'}++	; 
#	$ports_ref->{'udp'}{'4026'}{'name'} = 'as-debug'		; 
#	$srvcobjects_ref->{'as-debug'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'as-debug'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'as-debug'}{'port'}{'tcp'} = '4026'	; 
#	$srvcobjects_ref->{'as-debug'}{'ports'}{'tcp'}{'4026'}++	; 
#	$ports_ref->{'tcp'}{'4026'}{'name'} = 'as-debug'		; 
#	$srvcobjects_ref->{'kastenchasepad'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kastenchasepad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kastenchasepad'}{'port'}{'udp'} = '2918'	; 
#	$srvcobjects_ref->{'kastenchasepad'}{'ports'}{'udp'}{'2918'}++	; 
#	$ports_ref->{'udp'}{'2918'}{'name'} = 'kastenchasepad'		; 
#	$srvcobjects_ref->{'kastenchasepad'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kastenchasepad'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kastenchasepad'}{'port'}{'tcp'} = '2918'	; 
#	$srvcobjects_ref->{'kastenchasepad'}{'ports'}{'tcp'}{'2918'}++	; 
#	$ports_ref->{'tcp'}{'2918'}{'name'} = 'kastenchasepad'		; 
#	$srvcobjects_ref->{'abatemgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abatemgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abatemgr'}{'port'}{'udp'} = '3655'	; 
#	$srvcobjects_ref->{'abatemgr'}{'ports'}{'udp'}{'3655'}++	; 
#	$ports_ref->{'udp'}{'3655'}{'name'} = 'abatemgr'		; 
#	$srvcobjects_ref->{'abatemgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abatemgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abatemgr'}{'port'}{'tcp'} = '3655'	; 
#	$srvcobjects_ref->{'abatemgr'}{'ports'}{'tcp'}{'3655'}++	; 
#	$ports_ref->{'tcp'}{'3655'}{'name'} = 'abatemgr'		; 
#	$srvcobjects_ref->{'name'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'name'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'name'}{'port'}{'udp'} = '42'	; 
#	$srvcobjects_ref->{'name'}{'ports'}{'udp'}{'42'}++	; 
#	$ports_ref->{'udp'}{'42'}{'name'} = 'name'		; 
#	$srvcobjects_ref->{'name'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'name'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'name'}{'port'}{'tcp'} = '42'	; 
#	$srvcobjects_ref->{'name'}{'ports'}{'tcp'}{'42'}++	; 
#	$ports_ref->{'tcp'}{'42'}{'name'} = 'name'		; 
#	$srvcobjects_ref->{'pwrsevent'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pwrsevent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwrsevent'}{'port'}{'udp'} = '2694'	; 
#	$srvcobjects_ref->{'pwrsevent'}{'ports'}{'udp'}{'2694'}++	; 
#	$ports_ref->{'udp'}{'2694'}{'name'} = 'pwrsevent'		; 
#	$srvcobjects_ref->{'pwrsevent'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pwrsevent'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pwrsevent'}{'port'}{'tcp'} = '2694'	; 
#	$srvcobjects_ref->{'pwrsevent'}{'ports'}{'tcp'}{'2694'}++	; 
#	$ports_ref->{'tcp'}{'2694'}{'name'} = 'pwrsevent'		; 
#	$srvcobjects_ref->{'klogin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'klogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'klogin'}{'port'}{'udp'} = '543'	; 
#	$srvcobjects_ref->{'klogin'}{'ports'}{'udp'}{'543'}++	; 
#	$ports_ref->{'udp'}{'543'}{'name'} = 'klogin'		; 
#	$srvcobjects_ref->{'klogin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'klogin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'klogin'}{'port'}{'tcp'} = '543'	; 
#	$srvcobjects_ref->{'klogin'}{'ports'}{'tcp'}{'543'}++	; 
#	$ports_ref->{'tcp'}{'543'}{'name'} = 'klogin'		; 
#	$srvcobjects_ref->{'v5ua'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'v5ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'v5ua'}{'port'}{'udp'} = '5675'	; 
#	$srvcobjects_ref->{'v5ua'}{'ports'}{'udp'}{'5675'}++	; 
#	$ports_ref->{'udp'}{'5675'}{'name'} = 'v5ua'		; 
#	$srvcobjects_ref->{'v5ua'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'v5ua'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'v5ua'}{'port'}{'tcp'} = '5675'	; 
#	$srvcobjects_ref->{'v5ua'}{'ports'}{'tcp'}{'5675'}++	; 
#	$ports_ref->{'tcp'}{'5675'}{'name'} = 'v5ua'		; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'port'}{'udp'} = '3463'	; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'ports'}{'udp'}{'3463'}++	; 
#	$ports_ref->{'udp'}{'3463'}{'name'} = 'edm-adm-notify'		; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'port'}{'tcp'} = '3463'	; 
#	$srvcobjects_ref->{'edm-adm-notify'}{'ports'}{'tcp'}{'3463'}++	; 
#	$ports_ref->{'tcp'}{'3463'}{'name'} = 'edm-adm-notify'		; 
#	$srvcobjects_ref->{'qip-msgd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'qip-msgd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-msgd'}{'port'}{'udp'} = '2468'	; 
#	$srvcobjects_ref->{'qip-msgd'}{'ports'}{'udp'}{'2468'}++	; 
#	$ports_ref->{'udp'}{'2468'}{'name'} = 'qip-msgd'		; 
#	$srvcobjects_ref->{'qip-msgd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'qip-msgd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'qip-msgd'}{'port'}{'tcp'} = '2468'	; 
#	$srvcobjects_ref->{'qip-msgd'}{'ports'}{'tcp'}{'2468'}++	; 
#	$ports_ref->{'tcp'}{'2468'}{'name'} = 'qip-msgd'		; 
#	$srvcobjects_ref->{'roketz'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'roketz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roketz'}{'port'}{'udp'} = '1730'	; 
#	$srvcobjects_ref->{'roketz'}{'ports'}{'udp'}{'1730'}++	; 
#	$ports_ref->{'udp'}{'1730'}{'name'} = 'roketz'		; 
#	$srvcobjects_ref->{'roketz'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'roketz'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roketz'}{'port'}{'tcp'} = '1730'	; 
#	$srvcobjects_ref->{'roketz'}{'ports'}{'tcp'}{'1730'}++	; 
#	$ports_ref->{'tcp'}{'1730'}{'name'} = 'roketz'		; 
#	$srvcobjects_ref->{'hs-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hs-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hs-port'}{'port'}{'udp'} = '2570'	; 
#	$srvcobjects_ref->{'hs-port'}{'ports'}{'udp'}{'2570'}++	; 
#	$ports_ref->{'udp'}{'2570'}{'name'} = 'hs-port'		; 
#	$srvcobjects_ref->{'hs-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hs-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hs-port'}{'port'}{'tcp'} = '2570'	; 
#	$srvcobjects_ref->{'hs-port'}{'ports'}{'tcp'}{'2570'}++	; 
#	$ports_ref->{'tcp'}{'2570'}{'name'} = 'hs-port'		; 
#	$srvcobjects_ref->{'integra-sme'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'integra-sme'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'integra-sme'}{'port'}{'udp'} = '484'	; 
#	$srvcobjects_ref->{'integra-sme'}{'ports'}{'udp'}{'484'}++	; 
#	$ports_ref->{'udp'}{'484'}{'name'} = 'integra-sme'		; 
#	$srvcobjects_ref->{'integra-sme'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'integra-sme'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'integra-sme'}{'port'}{'tcp'} = '484'	; 
#	$srvcobjects_ref->{'integra-sme'}{'ports'}{'tcp'}{'484'}++	; 
#	$ports_ref->{'tcp'}{'484'}{'name'} = 'integra-sme'		; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'port'}{'udp'} = '1571'	; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'ports'}{'udp'}{'1571'}++	; 
#	$ports_ref->{'udp'}{'1571'}{'name'} = 'rdb-dbs-disp'		; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'port'}{'tcp'} = '1571'	; 
#	$srvcobjects_ref->{'rdb-dbs-disp'}{'ports'}{'tcp'}{'1571'}++	; 
#	$ports_ref->{'tcp'}{'1571'}{'name'} = 'rdb-dbs-disp'		; 
#	$srvcobjects_ref->{'mm-admin'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mm-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mm-admin'}{'port'}{'udp'} = '534'	; 
#	$srvcobjects_ref->{'mm-admin'}{'ports'}{'udp'}{'534'}++	; 
#	$ports_ref->{'udp'}{'534'}{'name'} = 'mm-admin'		; 
#	$srvcobjects_ref->{'mm-admin'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mm-admin'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mm-admin'}{'port'}{'tcp'} = '534'	; 
#	$srvcobjects_ref->{'mm-admin'}{'ports'}{'tcp'}{'534'}++	; 
#	$ports_ref->{'tcp'}{'534'}{'name'} = 'mm-admin'		; 
#	$srvcobjects_ref->{'instl_bootc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'instl_bootc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'instl_bootc'}{'port'}{'udp'} = '1068'	; 
#	$srvcobjects_ref->{'instl_bootc'}{'ports'}{'udp'}{'1068'}++	; 
#	$ports_ref->{'udp'}{'1068'}{'name'} = 'instl_bootc'		; 
#	$srvcobjects_ref->{'instl_bootc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'instl_bootc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'instl_bootc'}{'port'}{'tcp'} = '1068'	; 
#	$srvcobjects_ref->{'instl_bootc'}{'ports'}{'tcp'}{'1068'}++	; 
#	$ports_ref->{'tcp'}{'1068'}{'name'} = 'instl_bootc'		; 
#	$srvcobjects_ref->{'con'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'con'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'con'}{'port'}{'udp'} = '759'	; 
#	$srvcobjects_ref->{'con'}{'ports'}{'udp'}{'759'}++	; 
#	$ports_ref->{'udp'}{'759'}{'name'} = 'con'		; 
#	$srvcobjects_ref->{'con'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'con'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'con'}{'port'}{'tcp'} = '759'	; 
#	$srvcobjects_ref->{'con'}{'ports'}{'tcp'}{'759'}++	; 
#	$ports_ref->{'tcp'}{'759'}{'name'} = 'con'		; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'port'}{'udp'} = '2786'	; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'ports'}{'udp'}{'2786'}++	; 
#	$ports_ref->{'udp'}{'2786'}{'name'} = 'aic-oncrpc'		; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'port'}{'tcp'} = '2786'	; 
#	$srvcobjects_ref->{'aic-oncrpc'}{'ports'}{'tcp'}{'2786'}++	; 
#	$ports_ref->{'tcp'}{'2786'}{'name'} = 'aic-oncrpc'		; 
#	$srvcobjects_ref->{'nsw-fe'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nsw-fe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsw-fe'}{'port'}{'udp'} = '27'	; 
#	$srvcobjects_ref->{'nsw-fe'}{'ports'}{'udp'}{'27'}++	; 
#	$ports_ref->{'udp'}{'27'}{'name'} = 'nsw-fe'		; 
#	$srvcobjects_ref->{'nsw-fe'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nsw-fe'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nsw-fe'}{'port'}{'tcp'} = '27'	; 
#	$srvcobjects_ref->{'nsw-fe'}{'ports'}{'tcp'}{'27'}++	; 
#	$ports_ref->{'tcp'}{'27'}{'name'} = 'nsw-fe'		; 
#	$srvcobjects_ref->{'conference'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'conference'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'conference'}{'port'}{'udp'} = '531'	; 
#	$srvcobjects_ref->{'conference'}{'ports'}{'udp'}{'531'}++	; 
#	$ports_ref->{'udp'}{'531'}{'name'} = 'conference'		; 
#	$srvcobjects_ref->{'conference'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'conference'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'conference'}{'port'}{'tcp'} = '531'	; 
#	$srvcobjects_ref->{'conference'}{'ports'}{'tcp'}{'531'}++	; 
#	$ports_ref->{'tcp'}{'531'}{'name'} = 'conference'		; 
#	$srvcobjects_ref->{'soundsvirtual'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'soundsvirtual'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'soundsvirtual'}{'port'}{'udp'} = '17185'	; 
#	$srvcobjects_ref->{'soundsvirtual'}{'ports'}{'udp'}{'17185'}++	; 
#	$ports_ref->{'udp'}{'17185'}{'name'} = 'soundsvirtual'		; 
#	$srvcobjects_ref->{'soundsvirtual'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'soundsvirtual'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'soundsvirtual'}{'port'}{'tcp'} = '17185'	; 
#	$srvcobjects_ref->{'soundsvirtual'}{'ports'}{'tcp'}{'17185'}++	; 
#	$ports_ref->{'tcp'}{'17185'}{'name'} = 'soundsvirtual'		; 
#	$srvcobjects_ref->{'igi-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'igi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igi-lm'}{'port'}{'udp'} = '1404'	; 
#	$srvcobjects_ref->{'igi-lm'}{'ports'}{'udp'}{'1404'}++	; 
#	$ports_ref->{'udp'}{'1404'}{'name'} = 'igi-lm'		; 
#	$srvcobjects_ref->{'igi-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'igi-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igi-lm'}{'port'}{'tcp'} = '1404'	; 
#	$srvcobjects_ref->{'igi-lm'}{'ports'}{'tcp'}{'1404'}++	; 
#	$ports_ref->{'tcp'}{'1404'}{'name'} = 'igi-lm'		; 
#	$srvcobjects_ref->{'apc-6548'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-6548'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-6548'}{'port'}{'udp'} = '6548'	; 
#	$srvcobjects_ref->{'apc-6548'}{'ports'}{'udp'}{'6548'}++	; 
#	$ports_ref->{'udp'}{'6548'}{'name'} = 'apc-6548'		; 
#	$srvcobjects_ref->{'apc-6548'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-6548'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-6548'}{'port'}{'tcp'} = '6548'	; 
#	$srvcobjects_ref->{'apc-6548'}{'ports'}{'tcp'}{'6548'}++	; 
#	$ports_ref->{'tcp'}{'6548'}{'name'} = 'apc-6548'		; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'port'}{'udp'} = '2024'	; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'ports'}{'udp'}{'2024'}++	; 
#	$ports_ref->{'udp'}{'2024'}{'name'} = 'xinuexpansion4'		; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'port'}{'tcp'} = '2024'	; 
#	$srvcobjects_ref->{'xinuexpansion4'}{'ports'}{'tcp'}{'2024'}++	; 
#	$ports_ref->{'tcp'}{'2024'}{'name'} = 'xinuexpansion4'		; 
#	$srvcobjects_ref->{'agps-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'agps-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agps-port'}{'port'}{'udp'} = '3425'	; 
#	$srvcobjects_ref->{'agps-port'}{'ports'}{'udp'}{'3425'}++	; 
#	$ports_ref->{'udp'}{'3425'}{'name'} = 'agps-port'		; 
#	$srvcobjects_ref->{'agps-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'agps-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'agps-port'}{'port'}{'tcp'} = '3425'	; 
#	$srvcobjects_ref->{'agps-port'}{'ports'}{'tcp'}{'3425'}++	; 
#	$ports_ref->{'tcp'}{'3425'}{'name'} = 'agps-port'		; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'port'}{'udp'} = '3126'	; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'ports'}{'udp'}{'3126'}++	; 
#	$ports_ref->{'udp'}{'3126'}{'name'} = 'ms-dotnetster'		; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'port'}{'tcp'} = '3126'	; 
#	$srvcobjects_ref->{'ms-dotnetster'}{'ports'}{'tcp'}{'3126'}++	; 
#	$ports_ref->{'tcp'}{'3126'}{'name'} = 'ms-dotnetster'		; 
#	$srvcobjects_ref->{'mpnjsomb'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpnjsomb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsomb'}{'port'}{'udp'} = '2681'	; 
#	$srvcobjects_ref->{'mpnjsomb'}{'ports'}{'udp'}{'2681'}++	; 
#	$ports_ref->{'udp'}{'2681'}{'name'} = 'mpnjsomb'		; 
#	$srvcobjects_ref->{'mpnjsomb'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpnjsomb'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpnjsomb'}{'port'}{'tcp'} = '2681'	; 
#	$srvcobjects_ref->{'mpnjsomb'}{'ports'}{'tcp'}{'2681'}++	; 
#	$ports_ref->{'tcp'}{'2681'}{'name'} = 'mpnjsomb'		; 
#	$srvcobjects_ref->{'phrelay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'phrelay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phrelay'}{'port'}{'udp'} = '4868'	; 
#	$srvcobjects_ref->{'phrelay'}{'ports'}{'udp'}{'4868'}++	; 
#	$ports_ref->{'udp'}{'4868'}{'name'} = 'phrelay'		; 
#	$srvcobjects_ref->{'phrelay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'phrelay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'phrelay'}{'port'}{'tcp'} = '4868'	; 
#	$srvcobjects_ref->{'phrelay'}{'ports'}{'tcp'}{'4868'}++	; 
#	$ports_ref->{'tcp'}{'4868'}{'name'} = 'phrelay'		; 
#	$srvcobjects_ref->{'roverlog'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'roverlog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roverlog'}{'port'}{'udp'} = '3677'	; 
#	$srvcobjects_ref->{'roverlog'}{'ports'}{'udp'}{'3677'}++	; 
#	$ports_ref->{'udp'}{'3677'}{'name'} = 'roverlog'		; 
#	$srvcobjects_ref->{'roverlog'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'roverlog'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'roverlog'}{'port'}{'tcp'} = '3677'	; 
#	$srvcobjects_ref->{'roverlog'}{'ports'}{'tcp'}{'3677'}++	; 
#	$ports_ref->{'tcp'}{'3677'}{'name'} = 'roverlog'		; 
#	$srvcobjects_ref->{'whois++'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'whois++'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whois++'}{'port'}{'udp'} = '63'	; 
#	$srvcobjects_ref->{'whois++'}{'ports'}{'udp'}{'63'}++	; 
#	$ports_ref->{'udp'}{'63'}{'name'} = 'whois++'		; 
#	$srvcobjects_ref->{'whois++'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'whois++'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'whois++'}{'port'}{'tcp'} = '63'	; 
#	$srvcobjects_ref->{'whois++'}{'ports'}{'tcp'}{'63'}++	; 
#	$ports_ref->{'tcp'}{'63'}{'name'} = 'whois++'		; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'port'}{'udp'} = '1846'	; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'ports'}{'udp'}{'1846'}++	; 
#	$ports_ref->{'udp'}{'1846'}{'name'} = 'tunstall-pnc'		; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'port'}{'tcp'} = '1846'	; 
#	$srvcobjects_ref->{'tunstall-pnc'}{'ports'}{'tcp'}{'1846'}++	; 
#	$ports_ref->{'tcp'}{'1846'}{'name'} = 'tunstall-pnc'		; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'port'}{'udp'} = '2222'	; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'ports'}{'udp'}{'2222'}++	; 
#	$ports_ref->{'udp'}{'2222'}{'name'} = 'rockwell-csp2'		; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'port'}{'tcp'} = '2222'	; 
#	$srvcobjects_ref->{'rockwell-csp2'}{'ports'}{'tcp'}{'2222'}++	; 
#	$ports_ref->{'tcp'}{'2222'}{'name'} = 'rockwell-csp2'		; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'port'}{'udp'} = '1859'	; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'ports'}{'udp'}{'1859'}++	; 
#	$ports_ref->{'udp'}{'1859'}{'name'} = 'gammafetchsvr'		; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'port'}{'tcp'} = '1859'	; 
#	$srvcobjects_ref->{'gammafetchsvr'}{'ports'}{'tcp'}{'1859'}++	; 
#	$ports_ref->{'tcp'}{'1859'}{'name'} = 'gammafetchsvr'		; 
#	$srvcobjects_ref->{'smap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'smap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smap'}{'port'}{'udp'} = '3731'	; 
#	$srvcobjects_ref->{'smap'}{'ports'}{'udp'}{'3731'}++	; 
#	$ports_ref->{'udp'}{'3731'}{'name'} = 'smap'		; 
#	$srvcobjects_ref->{'smap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'smap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'smap'}{'port'}{'tcp'} = '3731'	; 
#	$srvcobjects_ref->{'smap'}{'ports'}{'tcp'}{'3731'}++	; 
#	$ports_ref->{'tcp'}{'3731'}{'name'} = 'smap'		; 
#	$srvcobjects_ref->{'elvin_server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elvin_server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elvin_server'}{'port'}{'udp'} = '2916'	; 
#	$srvcobjects_ref->{'elvin_server'}{'ports'}{'udp'}{'2916'}++	; 
#	$ports_ref->{'udp'}{'2916'}{'name'} = 'elvin_server'		; 
#	$srvcobjects_ref->{'elvin_server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elvin_server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elvin_server'}{'port'}{'tcp'} = '2916'	; 
#	$srvcobjects_ref->{'elvin_server'}{'ports'}{'tcp'}{'2916'}++	; 
#	$ports_ref->{'tcp'}{'2916'}{'name'} = 'elvin_server'		; 
#	$srvcobjects_ref->{'slim-devices'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'slim-devices'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slim-devices'}{'port'}{'udp'} = '3483'	; 
#	$srvcobjects_ref->{'slim-devices'}{'ports'}{'udp'}{'3483'}++	; 
#	$ports_ref->{'udp'}{'3483'}{'name'} = 'slim-devices'		; 
#	$srvcobjects_ref->{'slim-devices'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'slim-devices'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'slim-devices'}{'port'}{'tcp'} = '3483'	; 
#	$srvcobjects_ref->{'slim-devices'}{'ports'}{'tcp'}{'3483'}++	; 
#	$ports_ref->{'tcp'}{'3483'}{'name'} = 'slim-devices'		; 
#	$srvcobjects_ref->{'ardus-cntl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ardus-cntl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardus-cntl'}{'port'}{'udp'} = '1116'	; 
#	$srvcobjects_ref->{'ardus-cntl'}{'ports'}{'udp'}{'1116'}++	; 
#	$ports_ref->{'udp'}{'1116'}{'name'} = 'ardus-cntl'		; 
#	$srvcobjects_ref->{'ardus-cntl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ardus-cntl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ardus-cntl'}{'port'}{'tcp'} = '1116'	; 
#	$srvcobjects_ref->{'ardus-cntl'}{'ports'}{'tcp'}{'1116'}++	; 
#	$ports_ref->{'tcp'}{'1116'}{'name'} = 'ardus-cntl'		; 
#	$srvcobjects_ref->{'t128-gateway'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'t128-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t128-gateway'}{'port'}{'udp'} = '1627'	; 
#	$srvcobjects_ref->{'t128-gateway'}{'ports'}{'udp'}{'1627'}++	; 
#	$ports_ref->{'udp'}{'1627'}{'name'} = 't128-gateway'		; 
#	$srvcobjects_ref->{'t128-gateway'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'t128-gateway'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'t128-gateway'}{'port'}{'tcp'} = '1627'	; 
#	$srvcobjects_ref->{'t128-gateway'}{'ports'}{'tcp'}{'1627'}++	; 
#	$ports_ref->{'tcp'}{'1627'}{'name'} = 't128-gateway'		; 
#	$srvcobjects_ref->{'hp-sco'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-sco'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sco'}{'port'}{'udp'} = '19410'	; 
#	$srvcobjects_ref->{'hp-sco'}{'ports'}{'udp'}{'19410'}++	; 
#	$ports_ref->{'udp'}{'19410'}{'name'} = 'hp-sco'		; 
#	$srvcobjects_ref->{'hp-sco'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-sco'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-sco'}{'port'}{'tcp'} = '19410'	; 
#	$srvcobjects_ref->{'hp-sco'}{'ports'}{'tcp'}{'19410'}++	; 
#	$ports_ref->{'tcp'}{'19410'}{'name'} = 'hp-sco'		; 
#	$srvcobjects_ref->{'sophia-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sophia-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sophia-lm'}{'port'}{'udp'} = '1408'	; 
#	$srvcobjects_ref->{'sophia-lm'}{'ports'}{'udp'}{'1408'}++	; 
#	$ports_ref->{'udp'}{'1408'}{'name'} = 'sophia-lm'		; 
#	$srvcobjects_ref->{'sophia-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sophia-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sophia-lm'}{'port'}{'tcp'} = '1408'	; 
#	$srvcobjects_ref->{'sophia-lm'}{'ports'}{'tcp'}{'1408'}++	; 
#	$ports_ref->{'tcp'}{'1408'}{'name'} = 'sophia-lm'		; 
#	$srvcobjects_ref->{'els'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'els'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'els'}{'port'}{'udp'} = '1315'	; 
#	$srvcobjects_ref->{'els'}{'ports'}{'udp'}{'1315'}++	; 
#	$ports_ref->{'udp'}{'1315'}{'name'} = 'els'		; 
#	$srvcobjects_ref->{'els'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'els'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'els'}{'port'}{'tcp'} = '1315'	; 
#	$srvcobjects_ref->{'els'}{'ports'}{'tcp'}{'1315'}++	; 
#	$ports_ref->{'tcp'}{'1315'}{'name'} = 'els'		; 
#	$srvcobjects_ref->{'topflow-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'topflow-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'topflow-ssl'}{'port'}{'udp'} = '3885'	; 
#	$srvcobjects_ref->{'topflow-ssl'}{'ports'}{'udp'}{'3885'}++	; 
#	$ports_ref->{'udp'}{'3885'}{'name'} = 'topflow-ssl'		; 
#	$srvcobjects_ref->{'topflow-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'topflow-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'topflow-ssl'}{'port'}{'tcp'} = '3885'	; 
#	$srvcobjects_ref->{'topflow-ssl'}{'ports'}{'tcp'}{'3885'}++	; 
#	$ports_ref->{'tcp'}{'3885'}{'name'} = 'topflow-ssl'		; 
#	$srvcobjects_ref->{'elm-momentum'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elm-momentum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elm-momentum'}{'port'}{'udp'} = '1914'	; 
#	$srvcobjects_ref->{'elm-momentum'}{'ports'}{'udp'}{'1914'}++	; 
#	$ports_ref->{'udp'}{'1914'}{'name'} = 'elm-momentum'		; 
#	$srvcobjects_ref->{'elm-momentum'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elm-momentum'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elm-momentum'}{'port'}{'tcp'} = '1914'	; 
#	$srvcobjects_ref->{'elm-momentum'}{'ports'}{'tcp'}{'1914'}++	; 
#	$ports_ref->{'tcp'}{'1914'}{'name'} = 'elm-momentum'		; 
#	$srvcobjects_ref->{'ita-manager'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ita-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ita-manager'}{'port'}{'udp'} = '5052'	; 
#	$srvcobjects_ref->{'ita-manager'}{'ports'}{'udp'}{'5052'}++	; 
#	$ports_ref->{'udp'}{'5052'}{'name'} = 'ita-manager'		; 
#	$srvcobjects_ref->{'ita-manager'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ita-manager'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ita-manager'}{'port'}{'tcp'} = '5052'	; 
#	$srvcobjects_ref->{'ita-manager'}{'ports'}{'tcp'}{'5052'}++	; 
#	$ports_ref->{'tcp'}{'5052'}{'name'} = 'ita-manager'		; 
#	$srvcobjects_ref->{'tcim-control'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tcim-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcim-control'}{'port'}{'udp'} = '2729'	; 
#	$srvcobjects_ref->{'tcim-control'}{'ports'}{'udp'}{'2729'}++	; 
#	$ports_ref->{'udp'}{'2729'}{'name'} = 'tcim-control'		; 
#	$srvcobjects_ref->{'tcim-control'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcim-control'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tcim-control'}{'port'}{'tcp'} = '2729'	; 
#	$srvcobjects_ref->{'tcim-control'}{'ports'}{'tcp'}{'2729'}++	; 
#	$ports_ref->{'tcp'}{'2729'}{'name'} = 'tcim-control'		; 
#	$srvcobjects_ref->{'pcs-pcw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pcs-pcw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcs-pcw'}{'port'}{'udp'} = '2566'	; 
#	$srvcobjects_ref->{'pcs-pcw'}{'ports'}{'udp'}{'2566'}++	; 
#	$ports_ref->{'udp'}{'2566'}{'name'} = 'pcs-pcw'		; 
#	$srvcobjects_ref->{'pcs-pcw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pcs-pcw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pcs-pcw'}{'port'}{'tcp'} = '2566'	; 
#	$srvcobjects_ref->{'pcs-pcw'}{'ports'}{'tcp'}{'2566'}++	; 
#	$ports_ref->{'tcp'}{'2566'}{'name'} = 'pcs-pcw'		; 
#	$srvcobjects_ref->{'de-noc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'de-noc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-noc'}{'port'}{'udp'} = '1254'	; 
#	$srvcobjects_ref->{'de-noc'}{'ports'}{'udp'}{'1254'}++	; 
#	$ports_ref->{'udp'}{'1254'}{'name'} = 'de-noc'		; 
#	$srvcobjects_ref->{'de-noc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'de-noc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'de-noc'}{'port'}{'tcp'} = '1254'	; 
#	$srvcobjects_ref->{'de-noc'}{'ports'}{'tcp'}{'1254'}++	; 
#	$ports_ref->{'tcp'}{'1254'}{'name'} = 'de-noc'		; 
#	$srvcobjects_ref->{'manyone-xml'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'manyone-xml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'manyone-xml'}{'port'}{'udp'} = '8911'	; 
#	$srvcobjects_ref->{'manyone-xml'}{'ports'}{'udp'}{'8911'}++	; 
#	$ports_ref->{'udp'}{'8911'}{'name'} = 'manyone-xml'		; 
#	$srvcobjects_ref->{'manyone-xml'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'manyone-xml'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'manyone-xml'}{'port'}{'tcp'} = '8911'	; 
#	$srvcobjects_ref->{'manyone-xml'}{'ports'}{'tcp'}{'8911'}++	; 
#	$ports_ref->{'tcp'}{'8911'}{'name'} = 'manyone-xml'		; 
#	$srvcobjects_ref->{'imtc-mcs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imtc-mcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imtc-mcs'}{'port'}{'udp'} = '1503'	; 
#	$srvcobjects_ref->{'imtc-mcs'}{'ports'}{'udp'}{'1503'}++	; 
#	$ports_ref->{'udp'}{'1503'}{'name'} = 'imtc-mcs'		; 
#	$srvcobjects_ref->{'imtc-mcs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imtc-mcs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imtc-mcs'}{'port'}{'tcp'} = '1503'	; 
#	$srvcobjects_ref->{'imtc-mcs'}{'ports'}{'tcp'}{'1503'}++	; 
#	$ports_ref->{'tcp'}{'1503'}{'name'} = 'imtc-mcs'		; 
#	$srvcobjects_ref->{'vrcommerce'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vrcommerce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrcommerce'}{'port'}{'udp'} = '2530'	; 
#	$srvcobjects_ref->{'vrcommerce'}{'ports'}{'udp'}{'2530'}++	; 
#	$ports_ref->{'udp'}{'2530'}{'name'} = 'vrcommerce'		; 
#	$srvcobjects_ref->{'vrcommerce'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vrcommerce'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vrcommerce'}{'port'}{'tcp'} = '2530'	; 
#	$srvcobjects_ref->{'vrcommerce'}{'ports'}{'tcp'}{'2530'}++	; 
#	$ports_ref->{'tcp'}{'2530'}{'name'} = 'vrcommerce'		; 
#	$srvcobjects_ref->{'delta-mcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'delta-mcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'delta-mcp'}{'port'}{'udp'} = '1324'	; 
#	$srvcobjects_ref->{'delta-mcp'}{'ports'}{'udp'}{'1324'}++	; 
#	$ports_ref->{'udp'}{'1324'}{'name'} = 'delta-mcp'		; 
#	$srvcobjects_ref->{'delta-mcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'delta-mcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'delta-mcp'}{'port'}{'tcp'} = '1324'	; 
#	$srvcobjects_ref->{'delta-mcp'}{'ports'}{'tcp'}{'1324'}++	; 
#	$ports_ref->{'tcp'}{'1324'}{'name'} = 'delta-mcp'		; 
#	$srvcobjects_ref->{'findviatv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'findviatv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'findviatv'}{'port'}{'udp'} = '3350'	; 
#	$srvcobjects_ref->{'findviatv'}{'ports'}{'udp'}{'3350'}++	; 
#	$ports_ref->{'udp'}{'3350'}{'name'} = 'findviatv'		; 
#	$srvcobjects_ref->{'findviatv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'findviatv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'findviatv'}{'port'}{'tcp'} = '3350'	; 
#	$srvcobjects_ref->{'findviatv'}{'ports'}{'tcp'}{'3350'}++	; 
#	$ports_ref->{'tcp'}{'3350'}{'name'} = 'findviatv'		; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'port'}{'udp'} = '2933'	; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'ports'}{'udp'}{'2933'}++	; 
#	$ports_ref->{'udp'}{'2933'}{'name'} = '4-tieropmgw'		; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'port'}{'tcp'} = '2933'	; 
#	$srvcobjects_ref->{'4-tieropmgw'}{'ports'}{'tcp'}{'2933'}++	; 
#	$ports_ref->{'tcp'}{'2933'}{'name'} = '4-tieropmgw'		; 
#	$srvcobjects_ref->{'dmdocbroker'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dmdocbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmdocbroker'}{'port'}{'udp'} = '1489'	; 
#	$srvcobjects_ref->{'dmdocbroker'}{'ports'}{'udp'}{'1489'}++	; 
#	$ports_ref->{'udp'}{'1489'}{'name'} = 'dmdocbroker'		; 
#	$srvcobjects_ref->{'dmdocbroker'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dmdocbroker'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmdocbroker'}{'port'}{'tcp'} = '1489'	; 
#	$srvcobjects_ref->{'dmdocbroker'}{'ports'}{'tcp'}{'1489'}++	; 
#	$ports_ref->{'tcp'}{'1489'}{'name'} = 'dmdocbroker'		; 
#	$srvcobjects_ref->{'dell-rm-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dell-rm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dell-rm-port'}{'port'}{'udp'} = '3668'	; 
#	$srvcobjects_ref->{'dell-rm-port'}{'ports'}{'udp'}{'3668'}++	; 
#	$ports_ref->{'udp'}{'3668'}{'name'} = 'dell-rm-port'		; 
#	$srvcobjects_ref->{'dell-rm-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dell-rm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dell-rm-port'}{'port'}{'tcp'} = '3668'	; 
#	$srvcobjects_ref->{'dell-rm-port'}{'ports'}{'tcp'}{'3668'}++	; 
#	$ports_ref->{'tcp'}{'3668'}{'name'} = 'dell-rm-port'		; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'port'}{'udp'} = '2972'	; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'ports'}{'udp'}{'2972'}++	; 
#	$ports_ref->{'udp'}{'2972'}{'name'} = 'pmsm-webrctl'		; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'port'}{'tcp'} = '2972'	; 
#	$srvcobjects_ref->{'pmsm-webrctl'}{'ports'}{'tcp'}{'2972'}++	; 
#	$ports_ref->{'tcp'}{'2972'}{'name'} = 'pmsm-webrctl'		; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'port'}{'udp'} = '3203'	; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'ports'}{'udp'}{'3203'}++	; 
#	$ports_ref->{'udp'}{'3203'}{'name'} = 'netwatcher-mon'		; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'port'}{'tcp'} = '3203'	; 
#	$srvcobjects_ref->{'netwatcher-mon'}{'ports'}{'tcp'}{'3203'}++	; 
#	$ports_ref->{'tcp'}{'3203'}{'name'} = 'netwatcher-mon'		; 
#	$srvcobjects_ref->{'fjsvmpor'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjsvmpor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjsvmpor'}{'port'}{'udp'} = '2946'	; 
#	$srvcobjects_ref->{'fjsvmpor'}{'ports'}{'udp'}{'2946'}++	; 
#	$ports_ref->{'udp'}{'2946'}{'name'} = 'fjsvmpor'		; 
#	$srvcobjects_ref->{'fjsvmpor'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjsvmpor'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjsvmpor'}{'port'}{'tcp'} = '2946'	; 
#	$srvcobjects_ref->{'fjsvmpor'}{'ports'}{'tcp'}{'2946'}++	; 
#	$ports_ref->{'tcp'}{'2946'}{'name'} = 'fjsvmpor'		; 
#	$srvcobjects_ref->{'matip-type-a'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'matip-type-a'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'matip-type-a'}{'port'}{'udp'} = '350'	; 
#	$srvcobjects_ref->{'matip-type-a'}{'ports'}{'udp'}{'350'}++	; 
#	$ports_ref->{'udp'}{'350'}{'name'} = 'matip-type-a'		; 
#	$srvcobjects_ref->{'matip-type-a'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'matip-type-a'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'matip-type-a'}{'port'}{'tcp'} = '350'	; 
#	$srvcobjects_ref->{'matip-type-a'}{'ports'}{'tcp'}{'350'}++	; 
#	$ports_ref->{'tcp'}{'350'}{'name'} = 'matip-type-a'		; 
#	$srvcobjects_ref->{'icl-twobase2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icl-twobase2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase2'}{'port'}{'udp'} = '25001'	; 
#	$srvcobjects_ref->{'icl-twobase2'}{'ports'}{'udp'}{'25001'}++	; 
#	$ports_ref->{'udp'}{'25001'}{'name'} = 'icl-twobase2'		; 
#	$srvcobjects_ref->{'icl-twobase2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icl-twobase2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icl-twobase2'}{'port'}{'tcp'} = '25001'	; 
#	$srvcobjects_ref->{'icl-twobase2'}{'ports'}{'tcp'}{'25001'}++	; 
#	$ports_ref->{'tcp'}{'25001'}{'name'} = 'icl-twobase2'		; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'port'}{'udp'} = '1400'	; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'ports'}{'udp'}{'1400'}++	; 
#	$ports_ref->{'udp'}{'1400'}{'name'} = 'cadkey-tablet'		; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'port'}{'tcp'} = '1400'	; 
#	$srvcobjects_ref->{'cadkey-tablet'}{'ports'}{'tcp'}{'1400'}++	; 
#	$ports_ref->{'tcp'}{'1400'}{'name'} = 'cadkey-tablet'		; 
#	$srvcobjects_ref->{'telesis-licman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'telesis-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telesis-licman'}{'port'}{'udp'} = '1380'	; 
#	$srvcobjects_ref->{'telesis-licman'}{'ports'}{'udp'}{'1380'}++	; 
#	$ports_ref->{'udp'}{'1380'}{'name'} = 'telesis-licman'		; 
#	$srvcobjects_ref->{'telesis-licman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'telesis-licman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'telesis-licman'}{'port'}{'tcp'} = '1380'	; 
#	$srvcobjects_ref->{'telesis-licman'}{'ports'}{'tcp'}{'1380'}++	; 
#	$ports_ref->{'tcp'}{'1380'}{'name'} = 'telesis-licman'		; 
#	$srvcobjects_ref->{'ssdispatch'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssdispatch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssdispatch'}{'port'}{'udp'} = '3430'	; 
#	$srvcobjects_ref->{'ssdispatch'}{'ports'}{'udp'}{'3430'}++	; 
#	$ports_ref->{'udp'}{'3430'}{'name'} = 'ssdispatch'		; 
#	$srvcobjects_ref->{'ssdispatch'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssdispatch'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssdispatch'}{'port'}{'tcp'} = '3430'	; 
#	$srvcobjects_ref->{'ssdispatch'}{'ports'}{'tcp'}{'3430'}++	; 
#	$ports_ref->{'tcp'}{'3430'}{'name'} = 'ssdispatch'		; 
#	$srvcobjects_ref->{'timelot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timelot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timelot'}{'port'}{'udp'} = '3243'	; 
#	$srvcobjects_ref->{'timelot'}{'ports'}{'udp'}{'3243'}++	; 
#	$ports_ref->{'udp'}{'3243'}{'name'} = 'timelot'		; 
#	$srvcobjects_ref->{'timelot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timelot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timelot'}{'port'}{'tcp'} = '3243'	; 
#	$srvcobjects_ref->{'timelot'}{'ports'}{'tcp'}{'3243'}++	; 
#	$ports_ref->{'tcp'}{'3243'}{'name'} = 'timelot'		; 
#	$srvcobjects_ref->{'metatude-mds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'metatude-mds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metatude-mds'}{'port'}{'udp'} = '6382'	; 
#	$srvcobjects_ref->{'metatude-mds'}{'ports'}{'udp'}{'6382'}++	; 
#	$ports_ref->{'udp'}{'6382'}{'name'} = 'metatude-mds'		; 
#	$srvcobjects_ref->{'metatude-mds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'metatude-mds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'metatude-mds'}{'port'}{'tcp'} = '6382'	; 
#	$srvcobjects_ref->{'metatude-mds'}{'ports'}{'tcp'}{'6382'}++	; 
#	$ports_ref->{'tcp'}{'6382'}{'name'} = 'metatude-mds'		; 
#	$srvcobjects_ref->{'productinfo'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'productinfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'productinfo'}{'port'}{'udp'} = '1283'	; 
#	$srvcobjects_ref->{'productinfo'}{'ports'}{'udp'}{'1283'}++	; 
#	$ports_ref->{'udp'}{'1283'}{'name'} = 'productinfo'		; 
#	$srvcobjects_ref->{'productinfo'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'productinfo'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'productinfo'}{'port'}{'tcp'} = '1283'	; 
#	$srvcobjects_ref->{'productinfo'}{'ports'}{'tcp'}{'1283'}++	; 
#	$ports_ref->{'tcp'}{'1283'}{'name'} = 'productinfo'		; 
#	$srvcobjects_ref->{'pdl-datastream'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pdl-datastream'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdl-datastream'}{'port'}{'udp'} = '9100'	; 
#	$srvcobjects_ref->{'pdl-datastream'}{'ports'}{'udp'}{'9100'}++	; 
#	$ports_ref->{'udp'}{'9100'}{'name'} = 'pdl-datastream'		; 
#	$srvcobjects_ref->{'pdl-datastream'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pdl-datastream'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pdl-datastream'}{'port'}{'tcp'} = '9100'	; 
#	$srvcobjects_ref->{'pdl-datastream'}{'ports'}{'tcp'}{'9100'}++	; 
#	$ports_ref->{'tcp'}{'9100'}{'name'} = 'pdl-datastream'		; 
#	$srvcobjects_ref->{'rushd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rushd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rushd'}{'port'}{'udp'} = '696'	; 
#	$srvcobjects_ref->{'rushd'}{'ports'}{'udp'}{'696'}++	; 
#	$ports_ref->{'udp'}{'696'}{'name'} = 'rushd'		; 
#	$srvcobjects_ref->{'rushd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rushd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rushd'}{'port'}{'tcp'} = '696'	; 
#	$srvcobjects_ref->{'rushd'}{'ports'}{'tcp'}{'696'}++	; 
#	$ports_ref->{'tcp'}{'696'}{'name'} = 'rushd'		; 
#	$srvcobjects_ref->{'nuxsl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nuxsl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nuxsl'}{'port'}{'udp'} = '5991'	; 
#	$srvcobjects_ref->{'nuxsl'}{'ports'}{'udp'}{'5991'}++	; 
#	$ports_ref->{'udp'}{'5991'}{'name'} = 'nuxsl'		; 
#	$srvcobjects_ref->{'nuxsl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nuxsl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nuxsl'}{'port'}{'tcp'} = '5991'	; 
#	$srvcobjects_ref->{'nuxsl'}{'ports'}{'tcp'}{'5991'}++	; 
#	$ports_ref->{'tcp'}{'5991'}{'name'} = 'nuxsl'		; 
#	$srvcobjects_ref->{'gtrack-ne'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gtrack-ne'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtrack-ne'}{'port'}{'udp'} = '3592'	; 
#	$srvcobjects_ref->{'gtrack-ne'}{'ports'}{'udp'}{'3592'}++	; 
#	$ports_ref->{'udp'}{'3592'}{'name'} = 'gtrack-ne'		; 
#	$srvcobjects_ref->{'gtrack-ne'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gtrack-ne'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gtrack-ne'}{'port'}{'tcp'} = '3592'	; 
#	$srvcobjects_ref->{'gtrack-ne'}{'ports'}{'tcp'}{'3592'}++	; 
#	$ports_ref->{'tcp'}{'3592'}{'name'} = 'gtrack-ne'		; 
#	$srvcobjects_ref->{'personnel'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'personnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personnel'}{'port'}{'udp'} = '3109'	; 
#	$srvcobjects_ref->{'personnel'}{'ports'}{'udp'}{'3109'}++	; 
#	$ports_ref->{'udp'}{'3109'}{'name'} = 'personnel'		; 
#	$srvcobjects_ref->{'personnel'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'personnel'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'personnel'}{'port'}{'tcp'} = '3109'	; 
#	$srvcobjects_ref->{'personnel'}{'ports'}{'tcp'}{'3109'}++	; 
#	$ports_ref->{'tcp'}{'3109'}{'name'} = 'personnel'		; 
#	$srvcobjects_ref->{'hp-pxpib'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-pxpib'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-pxpib'}{'port'}{'udp'} = '3101'	; 
#	$srvcobjects_ref->{'hp-pxpib'}{'ports'}{'udp'}{'3101'}++	; 
#	$ports_ref->{'udp'}{'3101'}{'name'} = 'hp-pxpib'		; 
#	$srvcobjects_ref->{'hp-pxpib'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-pxpib'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-pxpib'}{'port'}{'tcp'} = '3101'	; 
#	$srvcobjects_ref->{'hp-pxpib'}{'ports'}{'tcp'}{'3101'}++	; 
#	$ports_ref->{'tcp'}{'3101'}{'name'} = 'hp-pxpib'		; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'port'}{'udp'} = '1881'	; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'ports'}{'udp'}{'1881'}++	; 
#	$ports_ref->{'udp'}{'1881'}{'name'} = 'ibm-mqseries2'		; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'port'}{'tcp'} = '1881'	; 
#	$srvcobjects_ref->{'ibm-mqseries2'}{'ports'}{'tcp'}{'1881'}++	; 
#	$ports_ref->{'tcp'}{'1881'}{'name'} = 'ibm-mqseries2'		; 
#	$srvcobjects_ref->{'amanda'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amanda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amanda'}{'port'}{'udp'} = '10080'	; 
#	$srvcobjects_ref->{'amanda'}{'ports'}{'udp'}{'10080'}++	; 
#	$ports_ref->{'udp'}{'10080'}{'name'} = 'amanda'		; 
#	$srvcobjects_ref->{'amanda'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amanda'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amanda'}{'port'}{'tcp'} = '10080'	; 
#	$srvcobjects_ref->{'amanda'}{'ports'}{'tcp'}{'10080'}++	; 
#	$ports_ref->{'tcp'}{'10080'}{'name'} = 'amanda'		; 
#	$srvcobjects_ref->{'ep-pcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ep-pcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ep-pcp'}{'port'}{'udp'} = '3620'	; 
#	$srvcobjects_ref->{'ep-pcp'}{'ports'}{'udp'}{'3620'}++	; 
#	$ports_ref->{'udp'}{'3620'}{'name'} = 'ep-pcp'		; 
#	$srvcobjects_ref->{'ep-pcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ep-pcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ep-pcp'}{'port'}{'tcp'} = '3620'	; 
#	$srvcobjects_ref->{'ep-pcp'}{'ports'}{'tcp'}{'3620'}++	; 
#	$ports_ref->{'tcp'}{'3620'}{'name'} = 'ep-pcp'		; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'port'}{'udp'} = '1063'	; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'ports'}{'udp'}{'1063'}++	; 
#	$ports_ref->{'udp'}{'1063'}{'name'} = 'kyoceranetdev'		; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'port'}{'tcp'} = '1063'	; 
#	$srvcobjects_ref->{'kyoceranetdev'}{'ports'}{'tcp'}{'1063'}++	; 
#	$ports_ref->{'tcp'}{'1063'}{'name'} = 'kyoceranetdev'		; 
#	$srvcobjects_ref->{'pop3s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pop3s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pop3s'}{'port'}{'udp'} = '995'	; 
#	$srvcobjects_ref->{'pop3s'}{'ports'}{'udp'}{'995'}++	; 
#	$ports_ref->{'udp'}{'995'}{'name'} = 'pop3s'		; 
#	$srvcobjects_ref->{'pop3s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pop3s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pop3s'}{'port'}{'tcp'} = '995'	; 
#	$srvcobjects_ref->{'pop3s'}{'ports'}{'tcp'}{'995'}++	; 
#	$ports_ref->{'tcp'}{'995'}{'name'} = 'pop3s'		; 
#	$srvcobjects_ref->{'bmc-grx'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-grx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-grx'}{'port'}{'udp'} = '6300'	; 
#	$srvcobjects_ref->{'bmc-grx'}{'ports'}{'udp'}{'6300'}++	; 
#	$ports_ref->{'udp'}{'6300'}{'name'} = 'bmc-grx'		; 
#	$srvcobjects_ref->{'bmc-grx'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-grx'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-grx'}{'port'}{'tcp'} = '6300'	; 
#	$srvcobjects_ref->{'bmc-grx'}{'ports'}{'tcp'}{'6300'}++	; 
#	$ports_ref->{'tcp'}{'6300'}{'name'} = 'bmc-grx'		; 
#	$srvcobjects_ref->{'imprs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'imprs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imprs'}{'port'}{'udp'} = '3164'	; 
#	$srvcobjects_ref->{'imprs'}{'ports'}{'udp'}{'3164'}++	; 
#	$ports_ref->{'udp'}{'3164'}{'name'} = 'imprs'		; 
#	$srvcobjects_ref->{'imprs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'imprs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'imprs'}{'port'}{'tcp'} = '3164'	; 
#	$srvcobjects_ref->{'imprs'}{'ports'}{'tcp'}{'3164'}++	; 
#	$ports_ref->{'tcp'}{'3164'}{'name'} = 'imprs'		; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'port'}{'udp'} = '1203'	; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'ports'}{'udp'}{'1203'}++	; 
#	$ports_ref->{'udp'}{'1203'}{'name'} = 'ssslic-mgr'		; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'port'}{'tcp'} = '1203'	; 
#	$srvcobjects_ref->{'ssslic-mgr'}{'ports'}{'tcp'}{'1203'}++	; 
#	$ports_ref->{'tcp'}{'1203'}{'name'} = 'ssslic-mgr'		; 
#	$srvcobjects_ref->{'redstorm_join'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'redstorm_join'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_join'}{'port'}{'udp'} = '2346'	; 
#	$srvcobjects_ref->{'redstorm_join'}{'ports'}{'udp'}{'2346'}++	; 
#	$ports_ref->{'udp'}{'2346'}{'name'} = 'redstorm_join'		; 
#	$srvcobjects_ref->{'redstorm_join'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'redstorm_join'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_join'}{'port'}{'tcp'} = '2346'	; 
#	$srvcobjects_ref->{'redstorm_join'}{'ports'}{'tcp'}{'2346'}++	; 
#	$ports_ref->{'tcp'}{'2346'}{'name'} = 'redstorm_join'		; 
#	$srvcobjects_ref->{'ocs_amu'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ocs_amu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocs_amu'}{'port'}{'udp'} = '429'	; 
#	$srvcobjects_ref->{'ocs_amu'}{'ports'}{'udp'}{'429'}++	; 
#	$ports_ref->{'udp'}{'429'}{'name'} = 'ocs_amu'		; 
#	$srvcobjects_ref->{'ocs_amu'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ocs_amu'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ocs_amu'}{'port'}{'tcp'} = '429'	; 
#	$srvcobjects_ref->{'ocs_amu'}{'ports'}{'tcp'}{'429'}++	; 
#	$ports_ref->{'tcp'}{'429'}{'name'} = 'ocs_amu'		; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'port'}{'udp'} = '1204'	; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'ports'}{'udp'}{'1204'}++	; 
#	$ports_ref->{'udp'}{'1204'}{'name'} = 'ssslog-mgr'		; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'port'}{'tcp'} = '1204'	; 
#	$srvcobjects_ref->{'ssslog-mgr'}{'ports'}{'tcp'}{'1204'}++	; 
#	$ports_ref->{'tcp'}{'1204'}{'name'} = 'ssslog-mgr'		; 
#	$srvcobjects_ref->{'intecom-ps1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intecom-ps1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intecom-ps1'}{'port'}{'udp'} = '5056'	; 
#	$srvcobjects_ref->{'intecom-ps1'}{'ports'}{'udp'}{'5056'}++	; 
#	$ports_ref->{'udp'}{'5056'}{'name'} = 'intecom-ps1'		; 
#	$srvcobjects_ref->{'intecom-ps1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intecom-ps1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intecom-ps1'}{'port'}{'tcp'} = '5056'	; 
#	$srvcobjects_ref->{'intecom-ps1'}{'ports'}{'tcp'}{'5056'}++	; 
#	$ports_ref->{'tcp'}{'5056'}{'name'} = 'intecom-ps1'		; 
#	$srvcobjects_ref->{'conferencetalk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'conferencetalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'conferencetalk'}{'port'}{'udp'} = '1713'	; 
#	$srvcobjects_ref->{'conferencetalk'}{'ports'}{'udp'}{'1713'}++	; 
#	$ports_ref->{'udp'}{'1713'}{'name'} = 'conferencetalk'		; 
#	$srvcobjects_ref->{'conferencetalk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'conferencetalk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'conferencetalk'}{'port'}{'tcp'} = '1713'	; 
#	$srvcobjects_ref->{'conferencetalk'}{'ports'}{'tcp'}{'1713'}++	; 
#	$ports_ref->{'tcp'}{'1713'}{'name'} = 'conferencetalk'		; 
#	$srvcobjects_ref->{'netview-aix-11'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netview-aix-11'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-11'}{'port'}{'udp'} = '1671'	; 
#	$srvcobjects_ref->{'netview-aix-11'}{'ports'}{'udp'}{'1671'}++	; 
#	$ports_ref->{'udp'}{'1671'}{'name'} = 'netview-aix-11'		; 
#	$srvcobjects_ref->{'netview-aix-11'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netview-aix-11'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netview-aix-11'}{'port'}{'tcp'} = '1671'	; 
#	$srvcobjects_ref->{'netview-aix-11'}{'ports'}{'tcp'}{'1671'}++	; 
#	$ports_ref->{'tcp'}{'1671'}{'name'} = 'netview-aix-11'		; 
#	$srvcobjects_ref->{'hotu-chat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hotu-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hotu-chat'}{'port'}{'udp'} = '3449'	; 
#	$srvcobjects_ref->{'hotu-chat'}{'ports'}{'udp'}{'3449'}++	; 
#	$ports_ref->{'udp'}{'3449'}{'name'} = 'hotu-chat'		; 
#	$srvcobjects_ref->{'hotu-chat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hotu-chat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hotu-chat'}{'port'}{'tcp'} = '3449'	; 
#	$srvcobjects_ref->{'hotu-chat'}{'ports'}{'tcp'}{'3449'}++	; 
#	$ports_ref->{'tcp'}{'3449'}{'name'} = 'hotu-chat'		; 
#	$srvcobjects_ref->{'prm-sm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prm-sm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-sm'}{'port'}{'udp'} = '408'	; 
#	$srvcobjects_ref->{'prm-sm'}{'ports'}{'udp'}{'408'}++	; 
#	$ports_ref->{'udp'}{'408'}{'name'} = 'prm-sm'		; 
#	$srvcobjects_ref->{'prm-sm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prm-sm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prm-sm'}{'port'}{'tcp'} = '408'	; 
#	$srvcobjects_ref->{'prm-sm'}{'ports'}{'tcp'}{'408'}++	; 
#	$ports_ref->{'tcp'}{'408'}{'name'} = 'prm-sm'		; 
#	$srvcobjects_ref->{'linktest'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'linktest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'linktest'}{'port'}{'udp'} = '3746'	; 
#	$srvcobjects_ref->{'linktest'}{'ports'}{'udp'}{'3746'}++	; 
#	$ports_ref->{'udp'}{'3746'}{'name'} = 'linktest'		; 
#	$srvcobjects_ref->{'linktest'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'linktest'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'linktest'}{'port'}{'tcp'} = '3746'	; 
#	$srvcobjects_ref->{'linktest'}{'ports'}{'tcp'}{'3746'}++	; 
#	$ports_ref->{'tcp'}{'3746'}{'name'} = 'linktest'		; 
#	$srvcobjects_ref->{'aurp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aurp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aurp'}{'port'}{'udp'} = '387'	; 
#	$srvcobjects_ref->{'aurp'}{'ports'}{'udp'}{'387'}++	; 
#	$ports_ref->{'udp'}{'387'}{'name'} = 'aurp'		; 
#	$srvcobjects_ref->{'aurp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aurp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aurp'}{'port'}{'tcp'} = '387'	; 
#	$srvcobjects_ref->{'aurp'}{'ports'}{'tcp'}{'387'}++	; 
#	$ports_ref->{'tcp'}{'387'}{'name'} = 'aurp'		; 
#	$srvcobjects_ref->{'grf-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'grf-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'grf-port'}{'port'}{'udp'} = '3757'	; 
#	$srvcobjects_ref->{'grf-port'}{'ports'}{'udp'}{'3757'}++	; 
#	$ports_ref->{'udp'}{'3757'}{'name'} = 'grf-port'		; 
#	$srvcobjects_ref->{'grf-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'grf-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'grf-port'}{'port'}{'tcp'} = '3757'	; 
#	$srvcobjects_ref->{'grf-port'}{'ports'}{'tcp'}{'3757'}++	; 
#	$ports_ref->{'tcp'}{'3757'}{'name'} = 'grf-port'		; 
#	$srvcobjects_ref->{'connect-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'connect-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connect-server'}{'port'}{'udp'} = '3442'	; 
#	$srvcobjects_ref->{'connect-server'}{'ports'}{'udp'}{'3442'}++	; 
#	$ports_ref->{'udp'}{'3442'}{'name'} = 'connect-server'		; 
#	$srvcobjects_ref->{'connect-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'connect-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'connect-server'}{'port'}{'tcp'} = '3442'	; 
#	$srvcobjects_ref->{'connect-server'}{'ports'}{'tcp'}{'3442'}++	; 
#	$ports_ref->{'tcp'}{'3442'}{'name'} = 'connect-server'		; 
#	$srvcobjects_ref->{'xaapi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xaapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xaapi'}{'port'}{'udp'} = '1934'	; 
#	$srvcobjects_ref->{'xaapi'}{'ports'}{'udp'}{'1934'}++	; 
#	$ports_ref->{'udp'}{'1934'}{'name'} = 'xaapi'		; 
#	$srvcobjects_ref->{'xaapi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xaapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xaapi'}{'port'}{'tcp'} = '1934'	; 
#	$srvcobjects_ref->{'xaapi'}{'ports'}{'tcp'}{'1934'}++	; 
#	$ports_ref->{'tcp'}{'1934'}{'name'} = 'xaapi'		; 
#	$srvcobjects_ref->{'opentable'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opentable'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opentable'}{'port'}{'udp'} = '2368'	; 
#	$srvcobjects_ref->{'opentable'}{'ports'}{'udp'}{'2368'}++	; 
#	$ports_ref->{'udp'}{'2368'}{'name'} = 'opentable'		; 
#	$srvcobjects_ref->{'opentable'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opentable'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opentable'}{'port'}{'tcp'} = '2368'	; 
#	$srvcobjects_ref->{'opentable'}{'ports'}{'tcp'}{'2368'}++	; 
#	$ports_ref->{'tcp'}{'2368'}{'name'} = 'opentable'		; 
#	$srvcobjects_ref->{'tgp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tgp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tgp'}{'port'}{'udp'} = '1223'	; 
#	$srvcobjects_ref->{'tgp'}{'ports'}{'udp'}{'1223'}++	; 
#	$ports_ref->{'udp'}{'1223'}{'name'} = 'tgp'		; 
#	$srvcobjects_ref->{'tgp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tgp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tgp'}{'port'}{'tcp'} = '1223'	; 
#	$srvcobjects_ref->{'tgp'}{'ports'}{'tcp'}{'1223'}++	; 
#	$ports_ref->{'tcp'}{'1223'}{'name'} = 'tgp'		; 
#	$srvcobjects_ref->{'xmapi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xmapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmapi'}{'port'}{'udp'} = '1933'	; 
#	$srvcobjects_ref->{'xmapi'}{'ports'}{'udp'}{'1933'}++	; 
#	$ports_ref->{'udp'}{'1933'}{'name'} = 'xmapi'		; 
#	$srvcobjects_ref->{'xmapi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xmapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xmapi'}{'port'}{'tcp'} = '1933'	; 
#	$srvcobjects_ref->{'xmapi'}{'ports'}{'tcp'}{'1933'}++	; 
#	$ports_ref->{'tcp'}{'1933'}{'name'} = 'xmapi'		; 
#	$srvcobjects_ref->{'icmpd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icmpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icmpd'}{'port'}{'udp'} = '5813'	; 
#	$srvcobjects_ref->{'icmpd'}{'ports'}{'udp'}{'5813'}++	; 
#	$ports_ref->{'udp'}{'5813'}{'name'} = 'icmpd'		; 
#	$srvcobjects_ref->{'icmpd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icmpd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icmpd'}{'port'}{'tcp'} = '5813'	; 
#	$srvcobjects_ref->{'icmpd'}{'ports'}{'tcp'}{'5813'}++	; 
#	$ports_ref->{'tcp'}{'5813'}{'name'} = 'icmpd'		; 
#	$srvcobjects_ref->{'ftranhc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ftranhc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftranhc'}{'port'}{'udp'} = '1105'	; 
#	$srvcobjects_ref->{'ftranhc'}{'ports'}{'udp'}{'1105'}++	; 
#	$ports_ref->{'udp'}{'1105'}{'name'} = 'ftranhc'		; 
#	$srvcobjects_ref->{'ftranhc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ftranhc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ftranhc'}{'port'}{'tcp'} = '1105'	; 
#	$srvcobjects_ref->{'ftranhc'}{'ports'}{'tcp'}{'1105'}++	; 
#	$ports_ref->{'tcp'}{'1105'}{'name'} = 'ftranhc'		; 
#	$srvcobjects_ref->{'novell-zfs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'novell-zfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-zfs'}{'port'}{'udp'} = '1229'	; 
#	$srvcobjects_ref->{'novell-zfs'}{'ports'}{'udp'}{'1229'}++	; 
#	$ports_ref->{'udp'}{'1229'}{'name'} = 'novell-zfs'		; 
#	$srvcobjects_ref->{'novell-zfs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'novell-zfs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novell-zfs'}{'port'}{'tcp'} = '1229'	; 
#	$srvcobjects_ref->{'novell-zfs'}{'ports'}{'tcp'}{'1229'}++	; 
#	$ports_ref->{'tcp'}{'1229'}{'name'} = 'novell-zfs'		; 
#	$srvcobjects_ref->{'genie'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'genie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genie'}{'port'}{'udp'} = '402'	; 
#	$srvcobjects_ref->{'genie'}{'ports'}{'udp'}{'402'}++	; 
#	$ports_ref->{'udp'}{'402'}{'name'} = 'genie'		; 
#	$srvcobjects_ref->{'genie'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'genie'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'genie'}{'port'}{'tcp'} = '402'	; 
#	$srvcobjects_ref->{'genie'}{'ports'}{'tcp'}{'402'}++	; 
#	$ports_ref->{'tcp'}{'402'}{'name'} = 'genie'		; 
#	$srvcobjects_ref->{'snifferclient'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'snifferclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snifferclient'}{'port'}{'udp'} = '2452'	; 
#	$srvcobjects_ref->{'snifferclient'}{'ports'}{'udp'}{'2452'}++	; 
#	$ports_ref->{'udp'}{'2452'}{'name'} = 'snifferclient'		; 
#	$srvcobjects_ref->{'snifferclient'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'snifferclient'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'snifferclient'}{'port'}{'tcp'} = '2452'	; 
#	$srvcobjects_ref->{'snifferclient'}{'ports'}{'tcp'}{'2452'}++	; 
#	$ports_ref->{'tcp'}{'2452'}{'name'} = 'snifferclient'		; 
#	$srvcobjects_ref->{'jboss-iiop'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jboss-iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jboss-iiop'}{'port'}{'udp'} = '3528'	; 
#	$srvcobjects_ref->{'jboss-iiop'}{'ports'}{'udp'}{'3528'}++	; 
#	$ports_ref->{'udp'}{'3528'}{'name'} = 'jboss-iiop'		; 
#	$srvcobjects_ref->{'jboss-iiop'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jboss-iiop'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jboss-iiop'}{'port'}{'tcp'} = '3528'	; 
#	$srvcobjects_ref->{'jboss-iiop'}{'ports'}{'tcp'}{'3528'}++	; 
#	$ports_ref->{'tcp'}{'3528'}{'name'} = 'jboss-iiop'		; 
#	$srvcobjects_ref->{'foresyte-sec'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'foresyte-sec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'foresyte-sec'}{'port'}{'udp'} = '5408'	; 
#	$srvcobjects_ref->{'foresyte-sec'}{'ports'}{'udp'}{'5408'}++	; 
#	$ports_ref->{'udp'}{'5408'}{'name'} = 'foresyte-sec'		; 
#	$srvcobjects_ref->{'foresyte-sec'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'foresyte-sec'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'foresyte-sec'}{'port'}{'tcp'} = '5408'	; 
#	$srvcobjects_ref->{'foresyte-sec'}{'ports'}{'tcp'}{'5408'}++	; 
#	$ports_ref->{'tcp'}{'5408'}{'name'} = 'foresyte-sec'		; 
#	$srvcobjects_ref->{'seaview'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'seaview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seaview'}{'port'}{'udp'} = '3143'	; 
#	$srvcobjects_ref->{'seaview'}{'ports'}{'udp'}{'3143'}++	; 
#	$ports_ref->{'udp'}{'3143'}{'name'} = 'seaview'		; 
#	$srvcobjects_ref->{'seaview'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'seaview'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'seaview'}{'port'}{'tcp'} = '3143'	; 
#	$srvcobjects_ref->{'seaview'}{'ports'}{'tcp'}{'3143'}++	; 
#	$ports_ref->{'tcp'}{'3143'}{'name'} = 'seaview'		; 
#	$srvcobjects_ref->{'opsec-omi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opsec-omi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-omi'}{'port'}{'udp'} = '18185'	; 
#	$srvcobjects_ref->{'opsec-omi'}{'ports'}{'udp'}{'18185'}++	; 
#	$ports_ref->{'udp'}{'18185'}{'name'} = 'opsec-omi'		; 
#	$srvcobjects_ref->{'opsec-omi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opsec-omi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opsec-omi'}{'port'}{'tcp'} = '18185'	; 
#	$srvcobjects_ref->{'opsec-omi'}{'ports'}{'tcp'}{'18185'}++	; 
#	$ports_ref->{'tcp'}{'18185'}{'name'} = 'opsec-omi'		; 
#	$srvcobjects_ref->{'skronk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'skronk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skronk'}{'port'}{'udp'} = '460'	; 
#	$srvcobjects_ref->{'skronk'}{'ports'}{'udp'}{'460'}++	; 
#	$ports_ref->{'udp'}{'460'}{'name'} = 'skronk'		; 
#	$srvcobjects_ref->{'skronk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'skronk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'skronk'}{'port'}{'tcp'} = '460'	; 
#	$srvcobjects_ref->{'skronk'}{'ports'}{'tcp'}{'460'}++	; 
#	$ports_ref->{'tcp'}{'460'}{'name'} = 'skronk'		; 
#	$srvcobjects_ref->{'kdm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'kdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kdm'}{'port'}{'udp'} = '2115'	; 
#	$srvcobjects_ref->{'kdm'}{'ports'}{'udp'}{'2115'}++	; 
#	$ports_ref->{'udp'}{'2115'}{'name'} = 'kdm'		; 
#	$srvcobjects_ref->{'kdm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'kdm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'kdm'}{'port'}{'tcp'} = '2115'	; 
#	$srvcobjects_ref->{'kdm'}{'ports'}{'tcp'}{'2115'}++	; 
#	$ports_ref->{'tcp'}{'2115'}{'name'} = 'kdm'		; 
#	$srvcobjects_ref->{'dynamid'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dynamid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dynamid'}{'port'}{'udp'} = '9002'	; 
#	$srvcobjects_ref->{'dynamid'}{'ports'}{'udp'}{'9002'}++	; 
#	$ports_ref->{'udp'}{'9002'}{'name'} = 'dynamid'		; 
#	$srvcobjects_ref->{'dynamid'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dynamid'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dynamid'}{'port'}{'tcp'} = '9002'	; 
#	$srvcobjects_ref->{'dynamid'}{'ports'}{'tcp'}{'9002'}++	; 
#	$ports_ref->{'tcp'}{'9002'}{'name'} = 'dynamid'		; 
#	$srvcobjects_ref->{'aic-np'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'aic-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aic-np'}{'port'}{'udp'} = '2785'	; 
#	$srvcobjects_ref->{'aic-np'}{'ports'}{'udp'}{'2785'}++	; 
#	$ports_ref->{'udp'}{'2785'}{'name'} = 'aic-np'		; 
#	$srvcobjects_ref->{'aic-np'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'aic-np'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'aic-np'}{'port'}{'tcp'} = '2785'	; 
#	$srvcobjects_ref->{'aic-np'}{'ports'}{'tcp'}{'2785'}++	; 
#	$ports_ref->{'tcp'}{'2785'}{'name'} = 'aic-np'		; 
#	$srvcobjects_ref->{'jargon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jargon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jargon'}{'port'}{'udp'} = '148'	; 
#	$srvcobjects_ref->{'jargon'}{'ports'}{'udp'}{'148'}++	; 
#	$ports_ref->{'udp'}{'148'}{'name'} = 'jargon'		; 
#	$srvcobjects_ref->{'jargon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jargon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jargon'}{'port'}{'tcp'} = '148'	; 
#	$srvcobjects_ref->{'jargon'}{'ports'}{'tcp'}{'148'}++	; 
#	$ports_ref->{'tcp'}{'148'}{'name'} = 'jargon'		; 
#	$srvcobjects_ref->{'glbp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'glbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glbp'}{'port'}{'udp'} = '3222'	; 
#	$srvcobjects_ref->{'glbp'}{'ports'}{'udp'}{'3222'}++	; 
#	$ports_ref->{'udp'}{'3222'}{'name'} = 'glbp'		; 
#	$srvcobjects_ref->{'glbp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'glbp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'glbp'}{'port'}{'tcp'} = '3222'	; 
#	$srvcobjects_ref->{'glbp'}{'ports'}{'tcp'}{'3222'}++	; 
#	$ports_ref->{'tcp'}{'3222'}{'name'} = 'glbp'		; 
#	$srvcobjects_ref->{'icad-el'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icad-el'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icad-el'}{'port'}{'udp'} = '425'	; 
#	$srvcobjects_ref->{'icad-el'}{'ports'}{'udp'}{'425'}++	; 
#	$ports_ref->{'udp'}{'425'}{'name'} = 'icad-el'		; 
#	$srvcobjects_ref->{'icad-el'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icad-el'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icad-el'}{'port'}{'tcp'} = '425'	; 
#	$srvcobjects_ref->{'icad-el'}{'ports'}{'tcp'}{'425'}++	; 
#	$ports_ref->{'tcp'}{'425'}{'name'} = 'icad-el'		; 
#	$srvcobjects_ref->{'dsmcc-download'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsmcc-download'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-download'}{'port'}{'udp'} = '13821'	; 
#	$srvcobjects_ref->{'dsmcc-download'}{'ports'}{'udp'}{'13821'}++	; 
#	$ports_ref->{'udp'}{'13821'}{'name'} = 'dsmcc-download'		; 
#	$srvcobjects_ref->{'dsmcc-download'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsmcc-download'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsmcc-download'}{'port'}{'tcp'} = '13821'	; 
#	$srvcobjects_ref->{'dsmcc-download'}{'ports'}{'tcp'}{'13821'}++	; 
#	$ports_ref->{'tcp'}{'13821'}{'name'} = 'dsmcc-download'		; 
#	$srvcobjects_ref->{'wsm-server'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wsm-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsm-server'}{'port'}{'udp'} = '5006'	; 
#	$srvcobjects_ref->{'wsm-server'}{'ports'}{'udp'}{'5006'}++	; 
#	$ports_ref->{'udp'}{'5006'}{'name'} = 'wsm-server'		; 
#	$srvcobjects_ref->{'wsm-server'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wsm-server'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wsm-server'}{'port'}{'tcp'} = '5006'	; 
#	$srvcobjects_ref->{'wsm-server'}{'ports'}{'tcp'}{'5006'}++	; 
#	$ports_ref->{'tcp'}{'5006'}{'name'} = 'wsm-server'		; 
#	$srvcobjects_ref->{'lansource'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lansource'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lansource'}{'port'}{'udp'} = '1485'	; 
#	$srvcobjects_ref->{'lansource'}{'ports'}{'udp'}{'1485'}++	; 
#	$ports_ref->{'udp'}{'1485'}{'name'} = 'lansource'		; 
#	$srvcobjects_ref->{'lansource'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lansource'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lansource'}{'port'}{'tcp'} = '1485'	; 
#	$srvcobjects_ref->{'lansource'}{'ports'}{'tcp'}{'1485'}++	; 
#	$ports_ref->{'tcp'}{'1485'}{'name'} = 'lansource'		; 
#	$srvcobjects_ref->{'giop-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'giop-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'giop-ssl'}{'port'}{'udp'} = '2482'	; 
#	$srvcobjects_ref->{'giop-ssl'}{'ports'}{'udp'}{'2482'}++	; 
#	$ports_ref->{'udp'}{'2482'}{'name'} = 'giop-ssl'		; 
#	$srvcobjects_ref->{'giop-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'giop-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'giop-ssl'}{'port'}{'tcp'} = '2482'	; 
#	$srvcobjects_ref->{'giop-ssl'}{'ports'}{'tcp'}{'2482'}++	; 
#	$ports_ref->{'tcp'}{'2482'}{'name'} = 'giop-ssl'		; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'port'}{'udp'} = '1419'	; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'ports'}{'udp'}{'1419'}++	; 
#	$ports_ref->{'udp'}{'1419'}{'name'} = 'timbuktu-srv3'		; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'port'}{'tcp'} = '1419'	; 
#	$srvcobjects_ref->{'timbuktu-srv3'}{'ports'}{'tcp'}{'1419'}++	; 
#	$ports_ref->{'tcp'}{'1419'}{'name'} = 'timbuktu-srv3'		; 
#	$srvcobjects_ref->{'sonuscallsig'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sonuscallsig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonuscallsig'}{'port'}{'udp'} = '2569'	; 
#	$srvcobjects_ref->{'sonuscallsig'}{'ports'}{'udp'}{'2569'}++	; 
#	$ports_ref->{'udp'}{'2569'}{'name'} = 'sonuscallsig'		; 
#	$srvcobjects_ref->{'sonuscallsig'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sonuscallsig'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sonuscallsig'}{'port'}{'tcp'} = '2569'	; 
#	$srvcobjects_ref->{'sonuscallsig'}{'ports'}{'tcp'}{'2569'}++	; 
#	$ports_ref->{'tcp'}{'2569'}{'name'} = 'sonuscallsig'		; 
#	$srvcobjects_ref->{'expresspay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'expresspay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'expresspay'}{'port'}{'udp'} = '2755'	; 
#	$srvcobjects_ref->{'expresspay'}{'ports'}{'udp'}{'2755'}++	; 
#	$ports_ref->{'udp'}{'2755'}{'name'} = 'expresspay'		; 
#	$srvcobjects_ref->{'expresspay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'expresspay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'expresspay'}{'port'}{'tcp'} = '2755'	; 
#	$srvcobjects_ref->{'expresspay'}{'ports'}{'tcp'}{'2755'}++	; 
#	$ports_ref->{'tcp'}{'2755'}{'name'} = 'expresspay'		; 
#	$srvcobjects_ref->{'cfdptkt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cfdptkt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cfdptkt'}{'port'}{'udp'} = '120'	; 
#	$srvcobjects_ref->{'cfdptkt'}{'ports'}{'udp'}{'120'}++	; 
#	$ports_ref->{'udp'}{'120'}{'name'} = 'cfdptkt'		; 
#	$srvcobjects_ref->{'cfdptkt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cfdptkt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cfdptkt'}{'port'}{'tcp'} = '120'	; 
#	$srvcobjects_ref->{'cfdptkt'}{'ports'}{'tcp'}{'120'}++	; 
#	$ports_ref->{'tcp'}{'120'}{'name'} = 'cfdptkt'		; 
#	$srvcobjects_ref->{'infoman'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'infoman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infoman'}{'port'}{'udp'} = '1451'	; 
#	$srvcobjects_ref->{'infoman'}{'ports'}{'udp'}{'1451'}++	; 
#	$ports_ref->{'udp'}{'1451'}{'name'} = 'infoman'		; 
#	$srvcobjects_ref->{'infoman'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'infoman'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'infoman'}{'port'}{'tcp'} = '1451'	; 
#	$srvcobjects_ref->{'infoman'}{'ports'}{'tcp'}{'1451'}++	; 
#	$ports_ref->{'tcp'}{'1451'}{'name'} = 'infoman'		; 
#	$srvcobjects_ref->{'openmail'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'openmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmail'}{'port'}{'udp'} = '5729'	; 
#	$srvcobjects_ref->{'openmail'}{'ports'}{'udp'}{'5729'}++	; 
#	$ports_ref->{'udp'}{'5729'}{'name'} = 'openmail'		; 
#	$srvcobjects_ref->{'openmail'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'openmail'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'openmail'}{'port'}{'tcp'} = '5729'	; 
#	$srvcobjects_ref->{'openmail'}{'ports'}{'tcp'}{'5729'}++	; 
#	$ports_ref->{'tcp'}{'5729'}{'name'} = 'openmail'		; 
#	$srvcobjects_ref->{'ridgeway1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ridgeway1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ridgeway1'}{'port'}{'udp'} = '2776'	; 
#	$srvcobjects_ref->{'ridgeway1'}{'ports'}{'udp'}{'2776'}++	; 
#	$ports_ref->{'udp'}{'2776'}{'name'} = 'ridgeway1'		; 
#	$srvcobjects_ref->{'ridgeway1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ridgeway1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ridgeway1'}{'port'}{'tcp'} = '2776'	; 
#	$srvcobjects_ref->{'ridgeway1'}{'ports'}{'tcp'}{'2776'}++	; 
#	$ports_ref->{'tcp'}{'2776'}{'name'} = 'ridgeway1'		; 
#	$srvcobjects_ref->{'haipe-otnk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'haipe-otnk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'haipe-otnk'}{'port'}{'udp'} = '3769'	; 
#	$srvcobjects_ref->{'haipe-otnk'}{'ports'}{'udp'}{'3769'}++	; 
#	$ports_ref->{'udp'}{'3769'}{'name'} = 'haipe-otnk'		; 
#	$srvcobjects_ref->{'haipe-otnk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'haipe-otnk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'haipe-otnk'}{'port'}{'tcp'} = '3769'	; 
#	$srvcobjects_ref->{'haipe-otnk'}{'ports'}{'tcp'}{'3769'}++	; 
#	$ports_ref->{'tcp'}{'3769'}{'name'} = 'haipe-otnk'		; 
#	$srvcobjects_ref->{'socks'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'socks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'socks'}{'port'}{'udp'} = '1080'	; 
#	$srvcobjects_ref->{'socks'}{'ports'}{'udp'}{'1080'}++	; 
#	$ports_ref->{'udp'}{'1080'}{'name'} = 'socks'		; 
#	$srvcobjects_ref->{'socks'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'socks'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'socks'}{'port'}{'tcp'} = '1080'	; 
#	$srvcobjects_ref->{'socks'}{'ports'}{'tcp'}{'1080'}++	; 
#	$ports_ref->{'tcp'}{'1080'}{'name'} = 'socks'		; 
#	$srvcobjects_ref->{'visd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'visd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visd'}{'port'}{'udp'} = '9284'	; 
#	$srvcobjects_ref->{'visd'}{'ports'}{'udp'}{'9284'}++	; 
#	$ports_ref->{'udp'}{'9284'}{'name'} = 'visd'		; 
#	$srvcobjects_ref->{'visd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'visd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'visd'}{'port'}{'tcp'} = '9284'	; 
#	$srvcobjects_ref->{'visd'}{'ports'}{'tcp'}{'9284'}++	; 
#	$ports_ref->{'tcp'}{'9284'}{'name'} = 'visd'		; 
#	$srvcobjects_ref->{'responselogic'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'responselogic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'responselogic'}{'port'}{'udp'} = '2886'	; 
#	$srvcobjects_ref->{'responselogic'}{'ports'}{'udp'}{'2886'}++	; 
#	$ports_ref->{'udp'}{'2886'}{'name'} = 'responselogic'		; 
#	$srvcobjects_ref->{'responselogic'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'responselogic'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'responselogic'}{'port'}{'tcp'} = '2886'	; 
#	$srvcobjects_ref->{'responselogic'}{'ports'}{'tcp'}{'2886'}++	; 
#	$ports_ref->{'tcp'}{'2886'}{'name'} = 'responselogic'		; 
#	$srvcobjects_ref->{'hp-collector'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hp-collector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-collector'}{'port'}{'udp'} = '381'	; 
#	$srvcobjects_ref->{'hp-collector'}{'ports'}{'udp'}{'381'}++	; 
#	$ports_ref->{'udp'}{'381'}{'name'} = 'hp-collector'		; 
#	$srvcobjects_ref->{'hp-collector'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hp-collector'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hp-collector'}{'port'}{'tcp'} = '381'	; 
#	$srvcobjects_ref->{'hp-collector'}{'ports'}{'tcp'}{'381'}++	; 
#	$ports_ref->{'tcp'}{'381'}{'name'} = 'hp-collector'		; 
#	$srvcobjects_ref->{'redstorm_diag'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'redstorm_diag'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_diag'}{'port'}{'udp'} = '2349'	; 
#	$srvcobjects_ref->{'redstorm_diag'}{'ports'}{'udp'}{'2349'}++	; 
#	$ports_ref->{'udp'}{'2349'}{'name'} = 'redstorm_diag'		; 
#	$srvcobjects_ref->{'redstorm_diag'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'redstorm_diag'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'redstorm_diag'}{'port'}{'tcp'} = '2349'	; 
#	$srvcobjects_ref->{'redstorm_diag'}{'ports'}{'tcp'}{'2349'}++	; 
#	$ports_ref->{'tcp'}{'2349'}{'name'} = 'redstorm_diag'		; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'port'}{'udp'} = '1087'	; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'ports'}{'udp'}{'1087'}++	; 
#	$ports_ref->{'udp'}{'1087'}{'name'} = 'cplscrambler-in'		; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'port'}{'tcp'} = '1087'	; 
#	$srvcobjects_ref->{'cplscrambler-in'}{'ports'}{'tcp'}{'1087'}++	; 
#	$ports_ref->{'tcp'}{'1087'}{'name'} = 'cplscrambler-in'		; 
#	$srvcobjects_ref->{'esl-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'esl-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esl-lm'}{'port'}{'udp'} = '1455'	; 
#	$srvcobjects_ref->{'esl-lm'}{'ports'}{'udp'}{'1455'}++	; 
#	$ports_ref->{'udp'}{'1455'}{'name'} = 'esl-lm'		; 
#	$srvcobjects_ref->{'esl-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'esl-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'esl-lm'}{'port'}{'tcp'} = '1455'	; 
#	$srvcobjects_ref->{'esl-lm'}{'ports'}{'tcp'}{'1455'}++	; 
#	$ports_ref->{'tcp'}{'1455'}{'name'} = 'esl-lm'		; 
#	$srvcobjects_ref->{'lm-mon'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lm-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-mon'}{'port'}{'udp'} = '31620'	; 
#	$srvcobjects_ref->{'lm-mon'}{'ports'}{'udp'}{'31620'}++	; 
#	$ports_ref->{'udp'}{'31620'}{'name'} = 'lm-mon'		; 
#	$srvcobjects_ref->{'lm-mon'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lm-mon'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lm-mon'}{'port'}{'tcp'} = '31620'	; 
#	$srvcobjects_ref->{'lm-mon'}{'ports'}{'tcp'}{'31620'}++	; 
#	$ports_ref->{'tcp'}{'31620'}{'name'} = 'lm-mon'		; 
#	$srvcobjects_ref->{'ccm-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ccm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccm-port'}{'port'}{'udp'} = '3575'	; 
#	$srvcobjects_ref->{'ccm-port'}{'ports'}{'udp'}{'3575'}++	; 
#	$ports_ref->{'udp'}{'3575'}{'name'} = 'ccm-port'		; 
#	$srvcobjects_ref->{'ccm-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ccm-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ccm-port'}{'port'}{'tcp'} = '3575'	; 
#	$srvcobjects_ref->{'ccm-port'}{'ports'}{'tcp'}{'3575'}++	; 
#	$ports_ref->{'tcp'}{'3575'}{'name'} = 'ccm-port'		; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'port'}{'udp'} = '1949'	; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'ports'}{'udp'}{'1949'}++	; 
#	$ports_ref->{'udp'}{'1949'}{'name'} = 'ismaeasdaqlive'		; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'port'}{'tcp'} = '1949'	; 
#	$srvcobjects_ref->{'ismaeasdaqlive'}{'ports'}{'tcp'}{'1949'}++	; 
#	$ports_ref->{'tcp'}{'1949'}{'name'} = 'ismaeasdaqlive'		; 
#	$srvcobjects_ref->{'cylink-c'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cylink-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cylink-c'}{'port'}{'udp'} = '5420'	; 
#	$srvcobjects_ref->{'cylink-c'}{'ports'}{'udp'}{'5420'}++	; 
#	$ports_ref->{'udp'}{'5420'}{'name'} = 'cylink-c'		; 
#	$srvcobjects_ref->{'cylink-c'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cylink-c'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cylink-c'}{'port'}{'tcp'} = '5420'	; 
#	$srvcobjects_ref->{'cylink-c'}{'ports'}{'tcp'}{'5420'}++	; 
#	$ports_ref->{'tcp'}{'5420'}{'name'} = 'cylink-c'		; 
#	$srvcobjects_ref->{'q55-pcc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'q55-pcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'q55-pcc'}{'port'}{'udp'} = '1253'	; 
#	$srvcobjects_ref->{'q55-pcc'}{'ports'}{'udp'}{'1253'}++	; 
#	$ports_ref->{'udp'}{'1253'}{'name'} = 'q55-pcc'		; 
#	$srvcobjects_ref->{'q55-pcc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'q55-pcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'q55-pcc'}{'port'}{'tcp'} = '1253'	; 
#	$srvcobjects_ref->{'q55-pcc'}{'ports'}{'tcp'}{'1253'}++	; 
#	$ports_ref->{'tcp'}{'1253'}{'name'} = 'q55-pcc'		; 
#	$srvcobjects_ref->{'sur-meas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sur-meas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sur-meas'}{'port'}{'udp'} = '243'	; 
#	$srvcobjects_ref->{'sur-meas'}{'ports'}{'udp'}{'243'}++	; 
#	$ports_ref->{'udp'}{'243'}{'name'} = 'sur-meas'		; 
#	$srvcobjects_ref->{'sur-meas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sur-meas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sur-meas'}{'port'}{'tcp'} = '243'	; 
#	$srvcobjects_ref->{'sur-meas'}{'ports'}{'tcp'}{'243'}++	; 
#	$ports_ref->{'tcp'}{'243'}{'name'} = 'sur-meas'		; 
#	$srvcobjects_ref->{'hypercube-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hypercube-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hypercube-lm'}{'port'}{'udp'} = '1577'	; 
#	$srvcobjects_ref->{'hypercube-lm'}{'ports'}{'udp'}{'1577'}++	; 
#	$ports_ref->{'udp'}{'1577'}{'name'} = 'hypercube-lm'		; 
#	$srvcobjects_ref->{'hypercube-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hypercube-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hypercube-lm'}{'port'}{'tcp'} = '1577'	; 
#	$srvcobjects_ref->{'hypercube-lm'}{'ports'}{'tcp'}{'1577'}++	; 
#	$ports_ref->{'tcp'}{'1577'}{'name'} = 'hypercube-lm'		; 
#	$srvcobjects_ref->{'armadp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'armadp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'armadp'}{'port'}{'udp'} = '1913'	; 
#	$srvcobjects_ref->{'armadp'}{'ports'}{'udp'}{'1913'}++	; 
#	$ports_ref->{'udp'}{'1913'}{'name'} = 'armadp'		; 
#	$srvcobjects_ref->{'armadp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'armadp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'armadp'}{'port'}{'tcp'} = '1913'	; 
#	$srvcobjects_ref->{'armadp'}{'ports'}{'tcp'}{'1913'}++	; 
#	$ports_ref->{'tcp'}{'1913'}{'name'} = 'armadp'		; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'port'}{'udp'} = '2557'	; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'ports'}{'udp'}{'2557'}++	; 
#	$ports_ref->{'udp'}{'2557'}{'name'} = 'nicetec-mgmt'		; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'port'}{'tcp'} = '2557'	; 
#	$srvcobjects_ref->{'nicetec-mgmt'}{'ports'}{'tcp'}{'2557'}++	; 
#	$ports_ref->{'tcp'}{'2557'}{'name'} = 'nicetec-mgmt'		; 
#	$srvcobjects_ref->{'faxportwinport'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'faxportwinport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'faxportwinport'}{'port'}{'udp'} = '1620'	; 
#	$srvcobjects_ref->{'faxportwinport'}{'ports'}{'udp'}{'1620'}++	; 
#	$ports_ref->{'udp'}{'1620'}{'name'} = 'faxportwinport'		; 
#	$srvcobjects_ref->{'faxportwinport'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'faxportwinport'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'faxportwinport'}{'port'}{'tcp'} = '1620'	; 
#	$srvcobjects_ref->{'faxportwinport'}{'ports'}{'tcp'}{'1620'}++	; 
#	$ports_ref->{'tcp'}{'1620'}{'name'} = 'faxportwinport'		; 
#	$srvcobjects_ref->{'cvd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvd'}{'port'}{'udp'} = '8400'	; 
#	$srvcobjects_ref->{'cvd'}{'ports'}{'udp'}{'8400'}++	; 
#	$ports_ref->{'udp'}{'8400'}{'name'} = 'cvd'		; 
#	$srvcobjects_ref->{'cvd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvd'}{'port'}{'tcp'} = '8400'	; 
#	$srvcobjects_ref->{'cvd'}{'ports'}{'tcp'}{'8400'}++	; 
#	$ports_ref->{'tcp'}{'8400'}{'name'} = 'cvd'		; 
#	$srvcobjects_ref->{'netrisk'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netrisk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrisk'}{'port'}{'udp'} = '1799'	; 
#	$srvcobjects_ref->{'netrisk'}{'ports'}{'udp'}{'1799'}++	; 
#	$ports_ref->{'udp'}{'1799'}{'name'} = 'netrisk'		; 
#	$srvcobjects_ref->{'netrisk'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netrisk'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netrisk'}{'port'}{'tcp'} = '1799'	; 
#	$srvcobjects_ref->{'netrisk'}{'ports'}{'tcp'}{'1799'}++	; 
#	$ports_ref->{'tcp'}{'1799'}{'name'} = 'netrisk'		; 
#	$srvcobjects_ref->{'idotdist'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'idotdist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idotdist'}{'port'}{'udp'} = '2590'	; 
#	$srvcobjects_ref->{'idotdist'}{'ports'}{'udp'}{'2590'}++	; 
#	$ports_ref->{'udp'}{'2590'}{'name'} = 'idotdist'		; 
#	$srvcobjects_ref->{'idotdist'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'idotdist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'idotdist'}{'port'}{'tcp'} = '2590'	; 
#	$srvcobjects_ref->{'idotdist'}{'ports'}{'tcp'}{'2590'}++	; 
#	$ports_ref->{'tcp'}{'2590'}{'name'} = 'idotdist'		; 
#	$srvcobjects_ref->{'nvd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nvd'}{'port'}{'udp'} = '2329'	; 
#	$srvcobjects_ref->{'nvd'}{'ports'}{'udp'}{'2329'}++	; 
#	$ports_ref->{'udp'}{'2329'}{'name'} = 'nvd'		; 
#	$srvcobjects_ref->{'nvd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nvd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nvd'}{'port'}{'tcp'} = '2329'	; 
#	$srvcobjects_ref->{'nvd'}{'ports'}{'tcp'}{'2329'}++	; 
#	$ports_ref->{'tcp'}{'2329'}{'name'} = 'nvd'		; 
#	$srvcobjects_ref->{'wlbs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wlbs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wlbs'}{'port'}{'udp'} = '2504'	; 
#	$srvcobjects_ref->{'wlbs'}{'ports'}{'udp'}{'2504'}++	; 
#	$ports_ref->{'udp'}{'2504'}{'name'} = 'wlbs'		; 
#	$srvcobjects_ref->{'wlbs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wlbs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wlbs'}{'port'}{'tcp'} = '2504'	; 
#	$srvcobjects_ref->{'wlbs'}{'ports'}{'tcp'}{'2504'}++	; 
#	$ports_ref->{'tcp'}{'2504'}{'name'} = 'wlbs'		; 
#	$srvcobjects_ref->{'dmod-workspace'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dmod-workspace'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmod-workspace'}{'port'}{'udp'} = '3199'	; 
#	$srvcobjects_ref->{'dmod-workspace'}{'ports'}{'udp'}{'3199'}++	; 
#	$ports_ref->{'udp'}{'3199'}{'name'} = 'dmod-workspace'		; 
#	$srvcobjects_ref->{'dmod-workspace'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dmod-workspace'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dmod-workspace'}{'port'}{'tcp'} = '3199'	; 
#	$srvcobjects_ref->{'dmod-workspace'}{'ports'}{'tcp'}{'3199'}++	; 
#	$ports_ref->{'tcp'}{'3199'}{'name'} = 'dmod-workspace'		; 
#	$srvcobjects_ref->{'picodbc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'picodbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'picodbc'}{'port'}{'udp'} = '1603'	; 
#	$srvcobjects_ref->{'picodbc'}{'ports'}{'udp'}{'1603'}++	; 
#	$ports_ref->{'udp'}{'1603'}{'name'} = 'picodbc'		; 
#	$srvcobjects_ref->{'picodbc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'picodbc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'picodbc'}{'port'}{'tcp'} = '1603'	; 
#	$srvcobjects_ref->{'picodbc'}{'ports'}{'tcp'}{'1603'}++	; 
#	$ports_ref->{'tcp'}{'1603'}{'name'} = 'picodbc'		; 
#	$srvcobjects_ref->{'microtalon-com'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'microtalon-com'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microtalon-com'}{'port'}{'udp'} = '7014'	; 
#	$srvcobjects_ref->{'microtalon-com'}{'ports'}{'udp'}{'7014'}++	; 
#	$ports_ref->{'udp'}{'7014'}{'name'} = 'microtalon-com'		; 
#	$srvcobjects_ref->{'microtalon-com'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'microtalon-com'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'microtalon-com'}{'port'}{'tcp'} = '7014'	; 
#	$srvcobjects_ref->{'microtalon-com'}{'ports'}{'tcp'}{'7014'}++	; 
#	$ports_ref->{'tcp'}{'7014'}{'name'} = 'microtalon-com'		; 
#	$srvcobjects_ref->{'repscmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'repscmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'repscmd'}{'port'}{'udp'} = '653'	; 
#	$srvcobjects_ref->{'repscmd'}{'ports'}{'udp'}{'653'}++	; 
#	$ports_ref->{'udp'}{'653'}{'name'} = 'repscmd'		; 
#	$srvcobjects_ref->{'repscmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'repscmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'repscmd'}{'port'}{'tcp'} = '653'	; 
#	$srvcobjects_ref->{'repscmd'}{'ports'}{'tcp'}{'653'}++	; 
#	$ports_ref->{'tcp'}{'653'}{'name'} = 'repscmd'		; 
#	$srvcobjects_ref->{'swc-xds'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'swc-xds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swc-xds'}{'port'}{'udp'} = '2130'	; 
#	$srvcobjects_ref->{'swc-xds'}{'ports'}{'udp'}{'2130'}++	; 
#	$ports_ref->{'udp'}{'2130'}{'name'} = 'swc-xds'		; 
#	$srvcobjects_ref->{'swc-xds'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'swc-xds'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'swc-xds'}{'port'}{'tcp'} = '2130'	; 
#	$srvcobjects_ref->{'swc-xds'}{'ports'}{'tcp'}{'2130'}++	; 
#	$ports_ref->{'tcp'}{'2130'}{'name'} = 'swc-xds'		; 
#	$srvcobjects_ref->{'icg-bridge'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'icg-bridge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icg-bridge'}{'port'}{'udp'} = '2063'	; 
#	$srvcobjects_ref->{'icg-bridge'}{'ports'}{'udp'}{'2063'}++	; 
#	$ports_ref->{'udp'}{'2063'}{'name'} = 'icg-bridge'		; 
#	$srvcobjects_ref->{'icg-bridge'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'icg-bridge'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'icg-bridge'}{'port'}{'tcp'} = '2063'	; 
#	$srvcobjects_ref->{'icg-bridge'}{'ports'}{'tcp'}{'2063'}++	; 
#	$ports_ref->{'tcp'}{'2063'}{'name'} = 'icg-bridge'		; 
#	$srvcobjects_ref->{'ellpack'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ellpack'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ellpack'}{'port'}{'tcp'} = '2025'	; 
#	$srvcobjects_ref->{'ellpack'}{'ports'}{'tcp'}{'2025'}++	; 
#	$ports_ref->{'tcp'}{'2025'}{'name'} = 'ellpack'		; 
#	$srvcobjects_ref->{'ums'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ums'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ums'}{'port'}{'udp'} = '2248'	; 
#	$srvcobjects_ref->{'ums'}{'ports'}{'udp'}{'2248'}++	; 
#	$ports_ref->{'udp'}{'2248'}{'name'} = 'ums'		; 
#	$srvcobjects_ref->{'ums'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ums'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ums'}{'port'}{'tcp'} = '2248'	; 
#	$srvcobjects_ref->{'ums'}{'ports'}{'tcp'}{'2248'}++	; 
#	$ports_ref->{'tcp'}{'2248'}{'name'} = 'ums'		; 
#	$srvcobjects_ref->{'realsecure'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'realsecure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'realsecure'}{'port'}{'udp'} = '2998'	; 
#	$srvcobjects_ref->{'realsecure'}{'ports'}{'udp'}{'2998'}++	; 
#	$ports_ref->{'udp'}{'2998'}{'name'} = 'realsecure'		; 
#	$srvcobjects_ref->{'realsecure'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'realsecure'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'realsecure'}{'port'}{'tcp'} = '2998'	; 
#	$srvcobjects_ref->{'realsecure'}{'ports'}{'tcp'}{'2998'}++	; 
#	$ports_ref->{'tcp'}{'2998'}{'name'} = 'realsecure'		; 
#	$srvcobjects_ref->{'ndtp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ndtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndtp'}{'port'}{'udp'} = '2882'	; 
#	$srvcobjects_ref->{'ndtp'}{'ports'}{'udp'}{'2882'}++	; 
#	$ports_ref->{'udp'}{'2882'}{'name'} = 'ndtp'		; 
#	$srvcobjects_ref->{'ndtp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ndtp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ndtp'}{'port'}{'tcp'} = '2882'	; 
#	$srvcobjects_ref->{'ndtp'}{'ports'}{'tcp'}{'2882'}++	; 
#	$ports_ref->{'tcp'}{'2882'}{'name'} = 'ndtp'		; 
#	$srvcobjects_ref->{'banyan-vip'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'banyan-vip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'banyan-vip'}{'port'}{'udp'} = '573'	; 
#	$srvcobjects_ref->{'banyan-vip'}{'ports'}{'udp'}{'573'}++	; 
#	$ports_ref->{'udp'}{'573'}{'name'} = 'banyan-vip'		; 
#	$srvcobjects_ref->{'banyan-vip'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'banyan-vip'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'banyan-vip'}{'port'}{'tcp'} = '573'	; 
#	$srvcobjects_ref->{'banyan-vip'}{'ports'}{'tcp'}{'573'}++	; 
#	$ports_ref->{'tcp'}{'573'}{'name'} = 'banyan-vip'		; 
#	$srvcobjects_ref->{'sabp-signal'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sabp-signal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sabp-signal'}{'port'}{'udp'} = '3452'	; 
#	$srvcobjects_ref->{'sabp-signal'}{'ports'}{'udp'}{'3452'}++	; 
#	$ports_ref->{'udp'}{'3452'}{'name'} = 'sabp-signal'		; 
#	$srvcobjects_ref->{'sabp-signal'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sabp-signal'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sabp-signal'}{'port'}{'tcp'} = '3452'	; 
#	$srvcobjects_ref->{'sabp-signal'}{'ports'}{'tcp'}{'3452'}++	; 
#	$ports_ref->{'tcp'}{'3452'}{'name'} = 'sabp-signal'		; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'port'}{'udp'} = '3215'	; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'ports'}{'udp'}{'3215'}++	; 
#	$ports_ref->{'udp'}{'3215'}{'name'} = 'jmq-daemon-2'		; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'port'}{'tcp'} = '3215'	; 
#	$srvcobjects_ref->{'jmq-daemon-2'}{'ports'}{'tcp'}{'3215'}++	; 
#	$ports_ref->{'tcp'}{'3215'}{'name'} = 'jmq-daemon-2'		; 
#	$srvcobjects_ref->{'bbars'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bbars'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bbars'}{'port'}{'udp'} = '3327'	; 
#	$srvcobjects_ref->{'bbars'}{'ports'}{'udp'}{'3327'}++	; 
#	$ports_ref->{'udp'}{'3327'}{'name'} = 'bbars'		; 
#	$srvcobjects_ref->{'bbars'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bbars'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bbars'}{'port'}{'tcp'} = '3327'	; 
#	$srvcobjects_ref->{'bbars'}{'ports'}{'tcp'}{'3327'}++	; 
#	$ports_ref->{'tcp'}{'3327'}{'name'} = 'bbars'		; 
#	$srvcobjects_ref->{'pciarray'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pciarray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pciarray'}{'port'}{'udp'} = '1552'	; 
#	$srvcobjects_ref->{'pciarray'}{'ports'}{'udp'}{'1552'}++	; 
#	$ports_ref->{'udp'}{'1552'}{'name'} = 'pciarray'		; 
#	$srvcobjects_ref->{'pciarray'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pciarray'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pciarray'}{'port'}{'tcp'} = '1552'	; 
#	$srvcobjects_ref->{'pciarray'}{'ports'}{'tcp'}{'1552'}++	; 
#	$ports_ref->{'tcp'}{'1552'}{'name'} = 'pciarray'		; 
#	$srvcobjects_ref->{'filenet-rmi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filenet-rmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-rmi'}{'port'}{'udp'} = '32771'	; 
#	$srvcobjects_ref->{'filenet-rmi'}{'ports'}{'udp'}{'32771'}++	; 
#	$ports_ref->{'udp'}{'32771'}{'name'} = 'filenet-rmi'		; 
#	$srvcobjects_ref->{'filenet-rmi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filenet-rmi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-rmi'}{'port'}{'tcp'} = '32771'	; 
#	$srvcobjects_ref->{'filenet-rmi'}{'ports'}{'tcp'}{'32771'}++	; 
#	$ports_ref->{'tcp'}{'32771'}{'name'} = 'filenet-rmi'		; 
#	$srvcobjects_ref->{'newoak'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'newoak'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newoak'}{'port'}{'udp'} = '4001'	; 
#	$srvcobjects_ref->{'newoak'}{'ports'}{'udp'}{'4001'}++	; 
#	$ports_ref->{'udp'}{'4001'}{'name'} = 'newoak'		; 
#	$srvcobjects_ref->{'newoak'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'newoak'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'newoak'}{'port'}{'tcp'} = '4001'	; 
#	$srvcobjects_ref->{'newoak'}{'ports'}{'tcp'}{'4001'}++	; 
#	$ports_ref->{'tcp'}{'4001'}{'name'} = 'newoak'		; 
#	$srvcobjects_ref->{'worldscores'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'worldscores'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldscores'}{'port'}{'udp'} = '4545'	; 
#	$srvcobjects_ref->{'worldscores'}{'ports'}{'udp'}{'4545'}++	; 
#	$ports_ref->{'udp'}{'4545'}{'name'} = 'worldscores'		; 
#	$srvcobjects_ref->{'worldscores'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'worldscores'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'worldscores'}{'port'}{'tcp'} = '4545'	; 
#	$srvcobjects_ref->{'worldscores'}{'ports'}{'tcp'}{'4545'}++	; 
#	$ports_ref->{'tcp'}{'4545'}{'name'} = 'worldscores'		; 
#	$srvcobjects_ref->{'desktop-dna'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'desktop-dna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'desktop-dna'}{'port'}{'udp'} = '2763'	; 
#	$srvcobjects_ref->{'desktop-dna'}{'ports'}{'udp'}{'2763'}++	; 
#	$ports_ref->{'udp'}{'2763'}{'name'} = 'desktop-dna'		; 
#	$srvcobjects_ref->{'desktop-dna'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'desktop-dna'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'desktop-dna'}{'port'}{'tcp'} = '2763'	; 
#	$srvcobjects_ref->{'desktop-dna'}{'ports'}{'tcp'}{'2763'}++	; 
#	$ports_ref->{'tcp'}{'2763'}{'name'} = 'desktop-dna'		; 
#	$srvcobjects_ref->{'arbortext-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arbortext-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arbortext-lm'}{'port'}{'udp'} = '1557'	; 
#	$srvcobjects_ref->{'arbortext-lm'}{'ports'}{'udp'}{'1557'}++	; 
#	$ports_ref->{'udp'}{'1557'}{'name'} = 'arbortext-lm'		; 
#	$srvcobjects_ref->{'arbortext-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arbortext-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arbortext-lm'}{'port'}{'tcp'} = '1557'	; 
#	$srvcobjects_ref->{'arbortext-lm'}{'ports'}{'tcp'}{'1557'}++	; 
#	$ports_ref->{'tcp'}{'1557'}{'name'} = 'arbortext-lm'		; 
#	$srvcobjects_ref->{'rrifmm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rrifmm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrifmm'}{'port'}{'udp'} = '1696'	; 
#	$srvcobjects_ref->{'rrifmm'}{'ports'}{'udp'}{'1696'}++	; 
#	$ports_ref->{'udp'}{'1696'}{'name'} = 'rrifmm'		; 
#	$srvcobjects_ref->{'rrifmm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rrifmm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rrifmm'}{'port'}{'tcp'} = '1696'	; 
#	$srvcobjects_ref->{'rrifmm'}{'ports'}{'tcp'}{'1696'}++	; 
#	$ports_ref->{'tcp'}{'1696'}{'name'} = 'rrifmm'		; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'port'}{'udp'} = '3269'	; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'ports'}{'udp'}{'3269'}++	; 
#	$ports_ref->{'udp'}{'3269'}{'name'} = 'msft-gc-ssl'		; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'port'}{'tcp'} = '3269'	; 
#	$srvcobjects_ref->{'msft-gc-ssl'}{'ports'}{'tcp'}{'3269'}++	; 
#	$ports_ref->{'tcp'}{'3269'}{'name'} = 'msft-gc-ssl'		; 
#	$srvcobjects_ref->{'netop-school'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'netop-school'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netop-school'}{'port'}{'udp'} = '1971'	; 
#	$srvcobjects_ref->{'netop-school'}{'ports'}{'udp'}{'1971'}++	; 
#	$ports_ref->{'udp'}{'1971'}{'name'} = 'netop-school'		; 
#	$srvcobjects_ref->{'netop-school'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'netop-school'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'netop-school'}{'port'}{'tcp'} = '1971'	; 
#	$srvcobjects_ref->{'netop-school'}{'ports'}{'tcp'}{'1971'}++	; 
#	$ports_ref->{'tcp'}{'1971'}{'name'} = 'netop-school'		; 
#	$srvcobjects_ref->{'shareapp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shareapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shareapp'}{'port'}{'udp'} = '3595'	; 
#	$srvcobjects_ref->{'shareapp'}{'ports'}{'udp'}{'3595'}++	; 
#	$ports_ref->{'udp'}{'3595'}{'name'} = 'shareapp'		; 
#	$srvcobjects_ref->{'shareapp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shareapp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shareapp'}{'port'}{'tcp'} = '3595'	; 
#	$srvcobjects_ref->{'shareapp'}{'ports'}{'tcp'}{'3595'}++	; 
#	$ports_ref->{'tcp'}{'3595'}{'name'} = 'shareapp'		; 
#	$srvcobjects_ref->{'cns-srv-port'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cns-srv-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cns-srv-port'}{'port'}{'udp'} = '2976'	; 
#	$srvcobjects_ref->{'cns-srv-port'}{'ports'}{'udp'}{'2976'}++	; 
#	$ports_ref->{'udp'}{'2976'}{'name'} = 'cns-srv-port'		; 
#	$srvcobjects_ref->{'cns-srv-port'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cns-srv-port'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cns-srv-port'}{'port'}{'tcp'} = '2976'	; 
#	$srvcobjects_ref->{'cns-srv-port'}{'ports'}{'tcp'}{'2976'}++	; 
#	$ports_ref->{'tcp'}{'2976'}{'name'} = 'cns-srv-port'		; 
#	$srvcobjects_ref->{'elvin_client'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'elvin_client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elvin_client'}{'port'}{'udp'} = '2917'	; 
#	$srvcobjects_ref->{'elvin_client'}{'ports'}{'udp'}{'2917'}++	; 
#	$ports_ref->{'udp'}{'2917'}{'name'} = 'elvin_client'		; 
#	$srvcobjects_ref->{'elvin_client'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'elvin_client'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'elvin_client'}{'port'}{'tcp'} = '2917'	; 
#	$srvcobjects_ref->{'elvin_client'}{'ports'}{'tcp'}{'2917'}++	; 
#	$ports_ref->{'tcp'}{'2917'}{'name'} = 'elvin_client'		; 
#	$srvcobjects_ref->{'homesteadglory'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'homesteadglory'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'homesteadglory'}{'port'}{'udp'} = '2597'	; 
#	$srvcobjects_ref->{'homesteadglory'}{'ports'}{'udp'}{'2597'}++	; 
#	$ports_ref->{'udp'}{'2597'}{'name'} = 'homesteadglory'		; 
#	$srvcobjects_ref->{'homesteadglory'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'homesteadglory'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'homesteadglory'}{'port'}{'tcp'} = '2597'	; 
#	$srvcobjects_ref->{'homesteadglory'}{'ports'}{'tcp'}{'2597'}++	; 
#	$ports_ref->{'tcp'}{'2597'}{'name'} = 'homesteadglory'		; 
#	$srvcobjects_ref->{'filenet-pa'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filenet-pa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-pa'}{'port'}{'udp'} = '32772'	; 
#	$srvcobjects_ref->{'filenet-pa'}{'ports'}{'udp'}{'32772'}++	; 
#	$ports_ref->{'udp'}{'32772'}{'name'} = 'filenet-pa'		; 
#	$srvcobjects_ref->{'filenet-pa'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filenet-pa'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filenet-pa'}{'port'}{'tcp'} = '32772'	; 
#	$srvcobjects_ref->{'filenet-pa'}{'ports'}{'tcp'}{'32772'}++	; 
#	$ports_ref->{'tcp'}{'32772'}{'name'} = 'filenet-pa'		; 
#	$srvcobjects_ref->{'pmdmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pmdmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmdmgr'}{'port'}{'udp'} = '7426'	; 
#	$srvcobjects_ref->{'pmdmgr'}{'ports'}{'udp'}{'7426'}++	; 
#	$ports_ref->{'udp'}{'7426'}{'name'} = 'pmdmgr'		; 
#	$srvcobjects_ref->{'pmdmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pmdmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pmdmgr'}{'port'}{'tcp'} = '7426'	; 
#	$srvcobjects_ref->{'pmdmgr'}{'ports'}{'tcp'}{'7426'}++	; 
#	$ports_ref->{'tcp'}{'7426'}{'name'} = 'pmdmgr'		; 
#	$srvcobjects_ref->{'intraintra'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'intraintra'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intraintra'}{'port'}{'udp'} = '3202'	; 
#	$srvcobjects_ref->{'intraintra'}{'ports'}{'udp'}{'3202'}++	; 
#	$ports_ref->{'udp'}{'3202'}{'name'} = 'intraintra'		; 
#	$srvcobjects_ref->{'intraintra'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'intraintra'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'intraintra'}{'port'}{'tcp'} = '3202'	; 
#	$srvcobjects_ref->{'intraintra'}{'ports'}{'tcp'}{'3202'}++	; 
#	$ports_ref->{'tcp'}{'3202'}{'name'} = 'intraintra'		; 
#	$srvcobjects_ref->{'tabula'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tabula'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tabula'}{'port'}{'udp'} = '1437'	; 
#	$srvcobjects_ref->{'tabula'}{'ports'}{'udp'}{'1437'}++	; 
#	$ports_ref->{'udp'}{'1437'}{'name'} = 'tabula'		; 
#	$srvcobjects_ref->{'tabula'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tabula'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tabula'}{'port'}{'tcp'} = '1437'	; 
#	$srvcobjects_ref->{'tabula'}{'ports'}{'tcp'}{'1437'}++	; 
#	$ports_ref->{'tcp'}{'1437'}{'name'} = 'tabula'		; 
#	$srvcobjects_ref->{'accessbuilder'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'accessbuilder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accessbuilder'}{'port'}{'udp'} = '888'	; 
#	$srvcobjects_ref->{'accessbuilder'}{'ports'}{'udp'}{'888'}++	; 
#	$ports_ref->{'udp'}{'888'}{'name'} = 'accessbuilder'		; 
#	$srvcobjects_ref->{'accessbuilder'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'accessbuilder'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'accessbuilder'}{'port'}{'tcp'} = '888'	; 
#	$srvcobjects_ref->{'accessbuilder'}{'ports'}{'tcp'}{'888'}++	; 
#	$ports_ref->{'tcp'}{'888'}{'name'} = 'accessbuilder'		; 
#	$srvcobjects_ref->{'search'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'search'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'search'}{'port'}{'tcp'} = '2010'	; 
#	$srvcobjects_ref->{'search'}{'ports'}{'tcp'}{'2010'}++	; 
#	$ports_ref->{'tcp'}{'2010'}{'name'} = 'search'		; 
#	$srvcobjects_ref->{'gw'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gw'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gw'}{'port'}{'tcp'} = '3010'	; 
#	$srvcobjects_ref->{'gw'}{'ports'}{'tcp'}{'3010'}++	; 
#	$ports_ref->{'tcp'}{'3010'}{'name'} = 'gw'		; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'port'}{'udp'} = '399'	; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'ports'}{'udp'}{'399'}++	; 
#	$ports_ref->{'udp'}{'399'}{'name'} = 'iso-tsap-c2'		; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'port'}{'tcp'} = '399'	; 
#	$srvcobjects_ref->{'iso-tsap-c2'}{'ports'}{'tcp'}{'399'}++	; 
#	$ports_ref->{'tcp'}{'399'}{'name'} = 'iso-tsap-c2'		; 
#	$srvcobjects_ref->{'cfengine'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cfengine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cfengine'}{'port'}{'udp'} = '5308'	; 
#	$srvcobjects_ref->{'cfengine'}{'ports'}{'udp'}{'5308'}++	; 
#	$ports_ref->{'udp'}{'5308'}{'name'} = 'cfengine'		; 
#	$srvcobjects_ref->{'cfengine'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cfengine'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cfengine'}{'port'}{'tcp'} = '5308'	; 
#	$srvcobjects_ref->{'cfengine'}{'ports'}{'tcp'}{'5308'}++	; 
#	$ports_ref->{'tcp'}{'5308'}{'name'} = 'cfengine'		; 
#	$srvcobjects_ref->{'sms-xfer'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'sms-xfer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-xfer'}{'port'}{'udp'} = '2702'	; 
#	$srvcobjects_ref->{'sms-xfer'}{'ports'}{'udp'}{'2702'}++	; 
#	$ports_ref->{'udp'}{'2702'}{'name'} = 'sms-xfer'		; 
#	$srvcobjects_ref->{'sms-xfer'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'sms-xfer'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'sms-xfer'}{'port'}{'tcp'} = '2702'	; 
#	$srvcobjects_ref->{'sms-xfer'}{'ports'}{'tcp'}{'2702'}++	; 
#	$ports_ref->{'tcp'}{'2702'}{'name'} = 'sms-xfer'		; 
#	$srvcobjects_ref->{'community'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'community'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'community'}{'port'}{'udp'} = '2459'	; 
#	$srvcobjects_ref->{'community'}{'ports'}{'udp'}{'2459'}++	; 
#	$ports_ref->{'udp'}{'2459'}{'name'} = 'community'		; 
#	$srvcobjects_ref->{'community'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'community'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'community'}{'port'}{'tcp'} = '2459'	; 
#	$srvcobjects_ref->{'community'}{'ports'}{'tcp'}{'2459'}++	; 
#	$ports_ref->{'tcp'}{'2459'}{'name'} = 'community'		; 
#	$srvcobjects_ref->{'rsync'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rsync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsync'}{'port'}{'udp'} = '873'	; 
#	$srvcobjects_ref->{'rsync'}{'ports'}{'udp'}{'873'}++	; 
#	$ports_ref->{'udp'}{'873'}{'name'} = 'rsync'		; 
#	$srvcobjects_ref->{'rsync'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rsync'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rsync'}{'port'}{'tcp'} = '873'	; 
#	$srvcobjects_ref->{'rsync'}{'ports'}{'tcp'}{'873'}++	; 
#	$ports_ref->{'tcp'}{'873'}{'name'} = 'rsync'		; 
#	$srvcobjects_ref->{'vpps-via'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vpps-via'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpps-via'}{'port'}{'udp'} = '676'	; 
#	$srvcobjects_ref->{'vpps-via'}{'ports'}{'udp'}{'676'}++	; 
#	$ports_ref->{'udp'}{'676'}{'name'} = 'vpps-via'		; 
#	$srvcobjects_ref->{'vpps-via'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vpps-via'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vpps-via'}{'port'}{'tcp'} = '676'	; 
#	$srvcobjects_ref->{'vpps-via'}{'ports'}{'tcp'}{'676'}++	; 
#	$ports_ref->{'tcp'}{'676'}{'name'} = 'vpps-via'		; 
#	$srvcobjects_ref->{'dsp3270'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'dsp3270'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsp3270'}{'port'}{'udp'} = '246'	; 
#	$srvcobjects_ref->{'dsp3270'}{'ports'}{'udp'}{'246'}++	; 
#	$ports_ref->{'udp'}{'246'}{'name'} = 'dsp3270'		; 
#	$srvcobjects_ref->{'dsp3270'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'dsp3270'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'dsp3270'}{'port'}{'tcp'} = '246'	; 
#	$srvcobjects_ref->{'dsp3270'}{'ports'}{'tcp'}{'246'}++	; 
#	$ports_ref->{'tcp'}{'246'}{'name'} = 'dsp3270'		; 
#	$srvcobjects_ref->{'chimera-hwm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'chimera-hwm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chimera-hwm'}{'port'}{'udp'} = '4009'	; 
#	$srvcobjects_ref->{'chimera-hwm'}{'ports'}{'udp'}{'4009'}++	; 
#	$ports_ref->{'udp'}{'4009'}{'name'} = 'chimera-hwm'		; 
#	$srvcobjects_ref->{'chimera-hwm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'chimera-hwm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'chimera-hwm'}{'port'}{'tcp'} = '4009'	; 
#	$srvcobjects_ref->{'chimera-hwm'}{'ports'}{'tcp'}{'4009'}++	; 
#	$ports_ref->{'tcp'}{'4009'}{'name'} = 'chimera-hwm'		; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'port'}{'udp'} = '2907'	; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'ports'}{'udp'}{'2907'}++	; 
#	$ports_ref->{'udp'}{'2907'}{'name'} = 'webmethods-b2b'		; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'port'}{'tcp'} = '2907'	; 
#	$srvcobjects_ref->{'webmethods-b2b'}{'ports'}{'tcp'}{'2907'}++	; 
#	$ports_ref->{'tcp'}{'2907'}{'name'} = 'webmethods-b2b'		; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'port'}{'udp'} = '2805'	; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'ports'}{'udp'}{'2805'}++	; 
#	$ports_ref->{'udp'}{'2805'}{'name'} = 'wta-wsp-s'		; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'port'}{'tcp'} = '2805'	; 
#	$srvcobjects_ref->{'wta-wsp-s'}{'ports'}{'tcp'}{'2805'}++	; 
#	$ports_ref->{'tcp'}{'2805'}{'name'} = 'wta-wsp-s'		; 
#	$srvcobjects_ref->{'novation'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'novation'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novation'}{'port'}{'udp'} = '1322'	; 
#	$srvcobjects_ref->{'novation'}{'ports'}{'udp'}{'1322'}++	; 
#	$ports_ref->{'udp'}{'1322'}{'name'} = 'novation'		; 
#	$srvcobjects_ref->{'novation'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'novation'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'novation'}{'port'}{'tcp'} = '1322'	; 
#	$srvcobjects_ref->{'novation'}{'ports'}{'tcp'}{'1322'}++	; 
#	$ports_ref->{'tcp'}{'1322'}{'name'} = 'novation'		; 
#	$srvcobjects_ref->{'iscsi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iscsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iscsi'}{'port'}{'udp'} = '860'	; 
#	$srvcobjects_ref->{'iscsi'}{'ports'}{'udp'}{'860'}++	; 
#	$ports_ref->{'udp'}{'860'}{'name'} = 'iscsi'		; 
#	$srvcobjects_ref->{'iscsi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iscsi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iscsi'}{'port'}{'tcp'} = '860'	; 
#	$srvcobjects_ref->{'iscsi'}{'ports'}{'tcp'}{'860'}++	; 
#	$ports_ref->{'tcp'}{'860'}{'name'} = 'iscsi'		; 
#	$srvcobjects_ref->{'xfr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'xfr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xfr'}{'port'}{'udp'} = '682'	; 
#	$srvcobjects_ref->{'xfr'}{'ports'}{'udp'}{'682'}++	; 
#	$ports_ref->{'udp'}{'682'}{'name'} = 'xfr'		; 
#	$srvcobjects_ref->{'xfr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'xfr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'xfr'}{'port'}{'tcp'} = '682'	; 
#	$srvcobjects_ref->{'xfr'}{'ports'}{'tcp'}{'682'}++	; 
#	$ports_ref->{'tcp'}{'682'}{'name'} = 'xfr'		; 
#	$srvcobjects_ref->{'mosaixcc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mosaixcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mosaixcc'}{'port'}{'udp'} = '2561'	; 
#	$srvcobjects_ref->{'mosaixcc'}{'ports'}{'udp'}{'2561'}++	; 
#	$ports_ref->{'udp'}{'2561'}{'name'} = 'mosaixcc'		; 
#	$srvcobjects_ref->{'mosaixcc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mosaixcc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mosaixcc'}{'port'}{'tcp'} = '2561'	; 
#	$srvcobjects_ref->{'mosaixcc'}{'ports'}{'tcp'}{'2561'}++	; 
#	$ports_ref->{'tcp'}{'2561'}{'name'} = 'mosaixcc'		; 
#	$srvcobjects_ref->{'vdmplay'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'vdmplay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vdmplay'}{'port'}{'udp'} = '1707'	; 
#	$srvcobjects_ref->{'vdmplay'}{'ports'}{'udp'}{'1707'}++	; 
#	$ports_ref->{'udp'}{'1707'}{'name'} = 'vdmplay'		; 
#	$srvcobjects_ref->{'vdmplay'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'vdmplay'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'vdmplay'}{'port'}{'tcp'} = '1707'	; 
#	$srvcobjects_ref->{'vdmplay'}{'ports'}{'tcp'}{'1707'}++	; 
#	$ports_ref->{'tcp'}{'1707'}{'name'} = 'vdmplay'		; 
#	$srvcobjects_ref->{'cypress'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cypress'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cypress'}{'port'}{'tcp'} = '2015'	; 
#	$srvcobjects_ref->{'cypress'}{'ports'}{'tcp'}{'2015'}++	; 
#	$ports_ref->{'tcp'}{'2015'}{'name'} = 'cypress'		; 
#	$srvcobjects_ref->{'rmc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'rmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmc'}{'port'}{'udp'} = '657'	; 
#	$srvcobjects_ref->{'rmc'}{'ports'}{'udp'}{'657'}++	; 
#	$ports_ref->{'udp'}{'657'}{'name'} = 'rmc'		; 
#	$srvcobjects_ref->{'rmc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'rmc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'rmc'}{'port'}{'tcp'} = '657'	; 
#	$srvcobjects_ref->{'rmc'}{'ports'}{'tcp'}{'657'}++	; 
#	$ports_ref->{'tcp'}{'657'}{'name'} = 'rmc'		; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'port'}{'udp'} = '2425'	; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'ports'}{'udp'}{'2425'}++	; 
#	$ports_ref->{'udp'}{'2425'}{'name'} = 'fjitsuappmgr'		; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'port'}{'tcp'} = '2425'	; 
#	$srvcobjects_ref->{'fjitsuappmgr'}{'ports'}{'tcp'}{'2425'}++	; 
#	$ports_ref->{'tcp'}{'2425'}{'name'} = 'fjitsuappmgr'		; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'port'}{'udp'} = '4002'	; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'ports'}{'udp'}{'4002'}++	; 
#	$ports_ref->{'udp'}{'4002'}{'name'} = 'pxc-spvr-ft'		; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'port'}{'tcp'} = '4002'	; 
#	$srvcobjects_ref->{'pxc-spvr-ft'}{'ports'}{'tcp'}{'4002'}++	; 
#	$ports_ref->{'tcp'}{'4002'}{'name'} = 'pxc-spvr-ft'		; 
#	$srvcobjects_ref->{'iclpv-nls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'iclpv-nls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-nls'}{'port'}{'udp'} = '1393'	; 
#	$srvcobjects_ref->{'iclpv-nls'}{'ports'}{'udp'}{'1393'}++	; 
#	$ports_ref->{'udp'}{'1393'}{'name'} = 'iclpv-nls'		; 
#	$srvcobjects_ref->{'iclpv-nls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'iclpv-nls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'iclpv-nls'}{'port'}{'tcp'} = '1393'	; 
#	$srvcobjects_ref->{'iclpv-nls'}{'ports'}{'tcp'}{'1393'}++	; 
#	$ports_ref->{'tcp'}{'1393'}{'name'} = 'iclpv-nls'		; 
#	$srvcobjects_ref->{'systat'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'systat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'systat'}{'port'}{'udp'} = '11'	; 
#	$srvcobjects_ref->{'systat'}{'ports'}{'udp'}{'11'}++	; 
#	$ports_ref->{'udp'}{'11'}{'name'} = 'systat'		; 
#	$srvcobjects_ref->{'systat'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'systat'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'systat'}{'port'}{'tcp'} = '11'	; 
#	$srvcobjects_ref->{'systat'}{'ports'}{'tcp'}{'11'}++	; 
#	$ports_ref->{'tcp'}{'11'}{'name'} = 'systat'		; 
#	$srvcobjects_ref->{'gemini-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'gemini-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gemini-lm'}{'port'}{'udp'} = '1590'	; 
#	$srvcobjects_ref->{'gemini-lm'}{'ports'}{'udp'}{'1590'}++	; 
#	$ports_ref->{'udp'}{'1590'}{'name'} = 'gemini-lm'		; 
#	$srvcobjects_ref->{'gemini-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'gemini-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'gemini-lm'}{'port'}{'tcp'} = '1590'	; 
#	$srvcobjects_ref->{'gemini-lm'}{'ports'}{'tcp'}{'1590'}++	; 
#	$ports_ref->{'tcp'}{'1590'}{'name'} = 'gemini-lm'		; 
#	$srvcobjects_ref->{'athand-mmp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'athand-mmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'athand-mmp'}{'port'}{'udp'} = '20999'	; 
#	$srvcobjects_ref->{'athand-mmp'}{'ports'}{'udp'}{'20999'}++	; 
#	$ports_ref->{'udp'}{'20999'}{'name'} = 'athand-mmp'		; 
#	$srvcobjects_ref->{'athand-mmp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'athand-mmp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'athand-mmp'}{'port'}{'tcp'} = '20999'	; 
#	$srvcobjects_ref->{'athand-mmp'}{'ports'}{'tcp'}{'20999'}++	; 
#	$ports_ref->{'tcp'}{'20999'}{'name'} = 'athand-mmp'		; 
#	$srvcobjects_ref->{'privilege'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'privilege'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privilege'}{'port'}{'udp'} = '2588'	; 
#	$srvcobjects_ref->{'privilege'}{'ports'}{'udp'}{'2588'}++	; 
#	$ports_ref->{'udp'}{'2588'}{'name'} = 'privilege'		; 
#	$srvcobjects_ref->{'privilege'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'privilege'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'privilege'}{'port'}{'tcp'} = '2588'	; 
#	$srvcobjects_ref->{'privilege'}{'ports'}{'tcp'}{'2588'}++	; 
#	$ports_ref->{'tcp'}{'2588'}{'name'} = 'privilege'		; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'port'}{'udp'} = '5314'	; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'ports'}{'udp'}{'5314'}++	; 
#	$ports_ref->{'udp'}{'5314'}{'name'} = 'opalis-rbt-ipc'		; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'port'}{'tcp'} = '5314'	; 
#	$srvcobjects_ref->{'opalis-rbt-ipc'}{'ports'}{'tcp'}{'5314'}++	; 
#	$ports_ref->{'tcp'}{'5314'}{'name'} = 'opalis-rbt-ipc'		; 
#	$srvcobjects_ref->{'feitianrockey'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'feitianrockey'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'feitianrockey'}{'port'}{'udp'} = '3152'	; 
#	$srvcobjects_ref->{'feitianrockey'}{'ports'}{'udp'}{'3152'}++	; 
#	$ports_ref->{'udp'}{'3152'}{'name'} = 'feitianrockey'		; 
#	$srvcobjects_ref->{'feitianrockey'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'feitianrockey'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'feitianrockey'}{'port'}{'tcp'} = '3152'	; 
#	$srvcobjects_ref->{'feitianrockey'}{'ports'}{'tcp'}{'3152'}++	; 
#	$ports_ref->{'tcp'}{'3152'}{'name'} = 'feitianrockey'		; 
#	$srvcobjects_ref->{'bintec-capi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bintec-capi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bintec-capi'}{'port'}{'udp'} = '2662'	; 
#	$srvcobjects_ref->{'bintec-capi'}{'ports'}{'udp'}{'2662'}++	; 
#	$ports_ref->{'udp'}{'2662'}{'name'} = 'bintec-capi'		; 
#	$srvcobjects_ref->{'bintec-capi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bintec-capi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bintec-capi'}{'port'}{'tcp'} = '2662'	; 
#	$srvcobjects_ref->{'bintec-capi'}{'ports'}{'tcp'}{'2662'}++	; 
#	$ports_ref->{'tcp'}{'2662'}{'name'} = 'bintec-capi'		; 
#	$srvcobjects_ref->{'a4-sdunode'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'a4-sdunode'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a4-sdunode'}{'port'}{'udp'} = '5605'	; 
#	$srvcobjects_ref->{'a4-sdunode'}{'ports'}{'udp'}{'5605'}++	; 
#	$ports_ref->{'udp'}{'5605'}{'name'} = 'a4-sdunode'		; 
#	$srvcobjects_ref->{'a4-sdunode'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'a4-sdunode'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'a4-sdunode'}{'port'}{'tcp'} = '5605'	; 
#	$srvcobjects_ref->{'a4-sdunode'}{'ports'}{'tcp'}{'5605'}++	; 
#	$ports_ref->{'tcp'}{'5605'}{'name'} = 'a4-sdunode'		; 
#	$srvcobjects_ref->{'nas'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'nas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nas'}{'port'}{'udp'} = '991'	; 
#	$srvcobjects_ref->{'nas'}{'ports'}{'udp'}{'991'}++	; 
#	$ports_ref->{'udp'}{'991'}{'name'} = 'nas'		; 
#	$srvcobjects_ref->{'nas'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'nas'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'nas'}{'port'}{'tcp'} = '991'	; 
#	$srvcobjects_ref->{'nas'}{'ports'}{'tcp'}{'991'}++	; 
#	$ports_ref->{'tcp'}{'991'}{'name'} = 'nas'		; 
#	$srvcobjects_ref->{'onesaf'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'onesaf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'onesaf'}{'port'}{'udp'} = '3244'	; 
#	$srvcobjects_ref->{'onesaf'}{'ports'}{'udp'}{'3244'}++	; 
#	$ports_ref->{'udp'}{'3244'}{'name'} = 'onesaf'		; 
#	$srvcobjects_ref->{'onesaf'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'onesaf'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'onesaf'}{'port'}{'tcp'} = '3244'	; 
#	$srvcobjects_ref->{'onesaf'}{'ports'}{'tcp'}{'3244'}++	; 
#	$ports_ref->{'tcp'}{'3244'}{'name'} = 'onesaf'		; 
#	$srvcobjects_ref->{'mtport-regist'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mtport-regist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtport-regist'}{'port'}{'udp'} = '2791'	; 
#	$srvcobjects_ref->{'mtport-regist'}{'ports'}{'udp'}{'2791'}++	; 
#	$ports_ref->{'udp'}{'2791'}{'name'} = 'mtport-regist'		; 
#	$srvcobjects_ref->{'mtport-regist'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mtport-regist'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mtport-regist'}{'port'}{'tcp'} = '2791'	; 
#	$srvcobjects_ref->{'mtport-regist'}{'ports'}{'tcp'}{'2791'}++	; 
#	$ports_ref->{'tcp'}{'2791'}{'name'} = 'mtport-regist'		; 
#	$srvcobjects_ref->{'b-novative-ls'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'b-novative-ls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'b-novative-ls'}{'port'}{'udp'} = '1896'	; 
#	$srvcobjects_ref->{'b-novative-ls'}{'ports'}{'udp'}{'1896'}++	; 
#	$ports_ref->{'udp'}{'1896'}{'name'} = 'b-novative-ls'		; 
#	$srvcobjects_ref->{'b-novative-ls'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'b-novative-ls'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'b-novative-ls'}{'port'}{'tcp'} = '1896'	; 
#	$srvcobjects_ref->{'b-novative-ls'}{'ports'}{'tcp'}{'1896'}++	; 
#	$ports_ref->{'tcp'}{'1896'}{'name'} = 'b-novative-ls'		; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'port'}{'udp'} = '1082'	; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'ports'}{'udp'}{'1082'}++	; 
#	$ports_ref->{'udp'}{'1082'}{'name'} = 'amt-esd-prot'		; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'port'}{'tcp'} = '1082'	; 
#	$srvcobjects_ref->{'amt-esd-prot'}{'ports'}{'tcp'}{'1082'}++	; 
#	$ports_ref->{'tcp'}{'1082'}{'name'} = 'amt-esd-prot'		; 
#	$srvcobjects_ref->{'igmpv3lite'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'igmpv3lite'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'igmpv3lite'}{'port'}{'udp'} = '465'	; 
#	$srvcobjects_ref->{'igmpv3lite'}{'ports'}{'udp'}{'465'}++	; 
#	$ports_ref->{'udp'}{'465'}{'name'} = 'igmpv3lite'		; 
#	$srvcobjects_ref->{'mctet-jserv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mctet-jserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctet-jserv'}{'port'}{'udp'} = '3117'	; 
#	$srvcobjects_ref->{'mctet-jserv'}{'ports'}{'udp'}{'3117'}++	; 
#	$ports_ref->{'udp'}{'3117'}{'name'} = 'mctet-jserv'		; 
#	$srvcobjects_ref->{'mctet-jserv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mctet-jserv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mctet-jserv'}{'port'}{'tcp'} = '3117'	; 
#	$srvcobjects_ref->{'mctet-jserv'}{'ports'}{'tcp'}{'3117'}++	; 
#	$ports_ref->{'tcp'}{'3117'}{'name'} = 'mctet-jserv'		; 
#	$srvcobjects_ref->{'neod1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'neod1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neod1'}{'port'}{'udp'} = '1047'	; 
#	$srvcobjects_ref->{'neod1'}{'ports'}{'udp'}{'1047'}++	; 
#	$ports_ref->{'udp'}{'1047'}{'name'} = 'neod1'		; 
#	$srvcobjects_ref->{'neod1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'neod1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'neod1'}{'port'}{'tcp'} = '1047'	; 
#	$srvcobjects_ref->{'neod1'}{'ports'}{'tcp'}{'1047'}++	; 
#	$ports_ref->{'tcp'}{'1047'}{'name'} = 'neod1'		; 
#	$srvcobjects_ref->{'pra_elmd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'pra_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pra_elmd'}{'port'}{'udp'} = '1587'	; 
#	$srvcobjects_ref->{'pra_elmd'}{'ports'}{'udp'}{'1587'}++	; 
#	$ports_ref->{'udp'}{'1587'}{'name'} = 'pra_elmd'		; 
#	$srvcobjects_ref->{'pra_elmd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'pra_elmd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'pra_elmd'}{'port'}{'tcp'} = '1587'	; 
#	$srvcobjects_ref->{'pra_elmd'}{'ports'}{'tcp'}{'1587'}++	; 
#	$ports_ref->{'tcp'}{'1587'}{'name'} = 'pra_elmd'		; 
#	$srvcobjects_ref->{'ida-discover1'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ida-discover1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ida-discover1'}{'port'}{'udp'} = '5741'	; 
#	$srvcobjects_ref->{'ida-discover1'}{'ports'}{'udp'}{'5741'}++	; 
#	$ports_ref->{'udp'}{'5741'}{'name'} = 'ida-discover1'		; 
#	$srvcobjects_ref->{'ida-discover1'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ida-discover1'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ida-discover1'}{'port'}{'tcp'} = '5741'	; 
#	$srvcobjects_ref->{'ida-discover1'}{'ports'}{'tcp'}{'5741'}++	; 
#	$ports_ref->{'tcp'}{'5741'}{'name'} = 'ida-discover1'		; 
#	$srvcobjects_ref->{'abbs'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'abbs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abbs'}{'port'}{'udp'} = '4885'	; 
#	$srvcobjects_ref->{'abbs'}{'ports'}{'udp'}{'4885'}++	; 
#	$ports_ref->{'udp'}{'4885'}{'name'} = 'abbs'		; 
#	$srvcobjects_ref->{'abbs'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'abbs'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'abbs'}{'port'}{'tcp'} = '4885'	; 
#	$srvcobjects_ref->{'abbs'}{'ports'}{'tcp'}{'4885'}++	; 
#	$ports_ref->{'tcp'}{'4885'}{'name'} = 'abbs'		; 
#	$srvcobjects_ref->{'shrinkwrap'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'shrinkwrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shrinkwrap'}{'port'}{'udp'} = '358'	; 
#	$srvcobjects_ref->{'shrinkwrap'}{'ports'}{'udp'}{'358'}++	; 
#	$ports_ref->{'udp'}{'358'}{'name'} = 'shrinkwrap'		; 
#	$srvcobjects_ref->{'shrinkwrap'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'shrinkwrap'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'shrinkwrap'}{'port'}{'tcp'} = '358'	; 
#	$srvcobjects_ref->{'shrinkwrap'}{'ports'}{'tcp'}{'358'}++	; 
#	$ports_ref->{'tcp'}{'358'}{'name'} = 'shrinkwrap'		; 
#	$srvcobjects_ref->{'mpp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'mpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpp'}{'port'}{'udp'} = '218'	; 
#	$srvcobjects_ref->{'mpp'}{'ports'}{'udp'}{'218'}++	; 
#	$ports_ref->{'udp'}{'218'}{'name'} = 'mpp'		; 
#	$srvcobjects_ref->{'mpp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'mpp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'mpp'}{'port'}{'tcp'} = '218'	; 
#	$srvcobjects_ref->{'mpp'}{'ports'}{'tcp'}{'218'}++	; 
#	$ports_ref->{'tcp'}{'218'}{'name'} = 'mpp'		; 
#	$srvcobjects_ref->{'apc-7845'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'apc-7845'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-7845'}{'port'}{'udp'} = '7845'	; 
#	$srvcobjects_ref->{'apc-7845'}{'ports'}{'udp'}{'7845'}++	; 
#	$ports_ref->{'udp'}{'7845'}{'name'} = 'apc-7845'		; 
#	$srvcobjects_ref->{'apc-7845'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'apc-7845'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'apc-7845'}{'port'}{'tcp'} = '7845'	; 
#	$srvcobjects_ref->{'apc-7845'}{'ports'}{'tcp'}{'7845'}++	; 
#	$ports_ref->{'tcp'}{'7845'}{'name'} = 'apc-7845'		; 
#	$srvcobjects_ref->{'propel-msgsys'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'propel-msgsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'propel-msgsys'}{'port'}{'udp'} = '1268'	; 
#	$srvcobjects_ref->{'propel-msgsys'}{'ports'}{'udp'}{'1268'}++	; 
#	$ports_ref->{'udp'}{'1268'}{'name'} = 'propel-msgsys'		; 
#	$srvcobjects_ref->{'propel-msgsys'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'propel-msgsys'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'propel-msgsys'}{'port'}{'tcp'} = '1268'	; 
#	$srvcobjects_ref->{'propel-msgsys'}{'ports'}{'tcp'}{'1268'}++	; 
#	$ports_ref->{'tcp'}{'1268'}{'name'} = 'propel-msgsys'		; 
#	$srvcobjects_ref->{'cvspserver'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'cvspserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvspserver'}{'port'}{'udp'} = '2401'	; 
#	$srvcobjects_ref->{'cvspserver'}{'ports'}{'udp'}{'2401'}++	; 
#	$ports_ref->{'udp'}{'2401'}{'name'} = 'cvspserver'		; 
#	$srvcobjects_ref->{'cvspserver'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'cvspserver'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'cvspserver'}{'port'}{'tcp'} = '2401'	; 
#	$srvcobjects_ref->{'cvspserver'}{'ports'}{'tcp'}{'2401'}++	; 
#	$ports_ref->{'tcp'}{'2401'}{'name'} = 'cvspserver'		; 
#	$srvcobjects_ref->{'suitjd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'suitjd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'suitjd'}{'port'}{'udp'} = '3354'	; 
#	$srvcobjects_ref->{'suitjd'}{'ports'}{'udp'}{'3354'}++	; 
#	$ports_ref->{'udp'}{'3354'}{'name'} = 'suitjd'		; 
#	$srvcobjects_ref->{'suitjd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'suitjd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'suitjd'}{'port'}{'tcp'} = '3354'	; 
#	$srvcobjects_ref->{'suitjd'}{'ports'}{'tcp'}{'3354'}++	; 
#	$ports_ref->{'tcp'}{'3354'}{'name'} = 'suitjd'		; 
#	$srvcobjects_ref->{'us-gv'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'us-gv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'us-gv'}{'port'}{'udp'} = '1370'	; 
#	$srvcobjects_ref->{'us-gv'}{'ports'}{'udp'}{'1370'}++	; 
#	$ports_ref->{'udp'}{'1370'}{'name'} = 'us-gv'		; 
#	$srvcobjects_ref->{'us-gv'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'us-gv'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'us-gv'}{'port'}{'tcp'} = '1370'	; 
#	$srvcobjects_ref->{'us-gv'}{'ports'}{'tcp'}{'1370'}++	; 
#	$ports_ref->{'tcp'}{'1370'}{'name'} = 'us-gv'		; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'port'}{'udp'} = '1217'	; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'ports'}{'udp'}{'1217'}++	; 
#	$ports_ref->{'udp'}{'1217'}{'name'} = 'hpss-ndapi'		; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'port'}{'tcp'} = '1217'	; 
#	$srvcobjects_ref->{'hpss-ndapi'}{'ports'}{'tcp'}{'1217'}++	; 
#	$ports_ref->{'tcp'}{'1217'}{'name'} = 'hpss-ndapi'		; 
#	$srvcobjects_ref->{'ipass'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ipass'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipass'}{'port'}{'udp'} = '2549'	; 
#	$srvcobjects_ref->{'ipass'}{'ports'}{'udp'}{'2549'}++	; 
#	$ports_ref->{'udp'}{'2549'}{'name'} = 'ipass'		; 
#	$srvcobjects_ref->{'ipass'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ipass'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ipass'}{'port'}{'tcp'} = '2549'	; 
#	$srvcobjects_ref->{'ipass'}{'ports'}{'tcp'}{'2549'}++	; 
#	$ports_ref->{'tcp'}{'2549'}{'name'} = 'ipass'		; 
#	$srvcobjects_ref->{'tip2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'tip2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tip2'}{'port'}{'udp'} = '3372'	; 
#	$srvcobjects_ref->{'tip2'}{'ports'}{'udp'}{'3372'}++	; 
#	$ports_ref->{'udp'}{'3372'}{'name'} = 'tip2'		; 
#	$srvcobjects_ref->{'tip2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tip2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'tip2'}{'port'}{'tcp'} = '3372'	; 
#	$srvcobjects_ref->{'tip2'}{'ports'}{'tcp'}{'3372'}++	; 
#	$ports_ref->{'tcp'}{'3372'}{'name'} = 'tip2'		; 
#	$srvcobjects_ref->{'jt400-ssl'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jt400-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jt400-ssl'}{'port'}{'udp'} = '3471'	; 
#	$srvcobjects_ref->{'jt400-ssl'}{'ports'}{'udp'}{'3471'}++	; 
#	$ports_ref->{'udp'}{'3471'}{'name'} = 'jt400-ssl'		; 
#	$srvcobjects_ref->{'jt400-ssl'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jt400-ssl'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jt400-ssl'}{'port'}{'tcp'} = '3471'	; 
#	$srvcobjects_ref->{'jt400-ssl'}{'ports'}{'tcp'}{'3471'}++	; 
#	$ports_ref->{'tcp'}{'3471'}{'name'} = 'jt400-ssl'		; 
#	$srvcobjects_ref->{'eicon-slp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'eicon-slp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eicon-slp'}{'port'}{'udp'} = '1440'	; 
#	$srvcobjects_ref->{'eicon-slp'}{'ports'}{'udp'}{'1440'}++	; 
#	$ports_ref->{'udp'}{'1440'}{'name'} = 'eicon-slp'		; 
#	$srvcobjects_ref->{'eicon-slp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'eicon-slp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'eicon-slp'}{'port'}{'tcp'} = '1440'	; 
#	$srvcobjects_ref->{'eicon-slp'}{'ports'}{'tcp'}{'1440'}++	; 
#	$ports_ref->{'tcp'}{'1440'}{'name'} = 'eicon-slp'		; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'port'}{'udp'} = '2053'	; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'ports'}{'udp'}{'2053'}++	; 
#	$ports_ref->{'udp'}{'2053'}{'name'} = 'lot105-ds-upd'		; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'port'}{'tcp'} = '2053'	; 
#	$srvcobjects_ref->{'lot105-ds-upd'}{'ports'}{'tcp'}{'2053'}++	; 
#	$ports_ref->{'tcp'}{'2053'}{'name'} = 'lot105-ds-upd'		; 
#	$srvcobjects_ref->{'ies-lm'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ies-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ies-lm'}{'port'}{'udp'} = '1443'	; 
#	$srvcobjects_ref->{'ies-lm'}{'ports'}{'udp'}{'1443'}++	; 
#	$ports_ref->{'udp'}{'1443'}{'name'} = 'ies-lm'		; 
#	$srvcobjects_ref->{'ies-lm'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ies-lm'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ies-lm'}{'port'}{'tcp'} = '1443'	; 
#	$srvcobjects_ref->{'ies-lm'}{'ports'}{'tcp'}{'1443'}++	; 
#	$ports_ref->{'tcp'}{'1443'}{'name'} = 'ies-lm'		; 
#	$srvcobjects_ref->{'prsvp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'prsvp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prsvp'}{'port'}{'udp'} = '3455'	; 
#	$srvcobjects_ref->{'prsvp'}{'ports'}{'udp'}{'3455'}++	; 
#	$ports_ref->{'udp'}{'3455'}{'name'} = 'prsvp'		; 
#	$srvcobjects_ref->{'prsvp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'prsvp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'prsvp'}{'port'}{'tcp'} = '3455'	; 
#	$srvcobjects_ref->{'prsvp'}{'ports'}{'tcp'}{'3455'}++	; 
#	$ports_ref->{'tcp'}{'3455'}{'name'} = 'prsvp'		; 
#	$srvcobjects_ref->{'silkp2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'silkp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp2'}{'port'}{'udp'} = '2830'	; 
#	$srvcobjects_ref->{'silkp2'}{'ports'}{'udp'}{'2830'}++	; 
#	$ports_ref->{'udp'}{'2830'}{'name'} = 'silkp2'		; 
#	$srvcobjects_ref->{'silkp2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'silkp2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'silkp2'}{'port'}{'tcp'} = '2830'	; 
#	$srvcobjects_ref->{'silkp2'}{'ports'}{'tcp'}{'2830'}++	; 
#	$ports_ref->{'tcp'}{'2830'}{'name'} = 'silkp2'		; 
#	$srvcobjects_ref->{'jcp'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'jcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jcp'}{'port'}{'udp'} = '19541'	; 
#	$srvcobjects_ref->{'jcp'}{'ports'}{'udp'}{'19541'}++	; 
#	$ports_ref->{'udp'}{'19541'}{'name'} = 'jcp'		; 
#	$srvcobjects_ref->{'jcp'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'jcp'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'jcp'}{'port'}{'tcp'} = '19541'	; 
#	$srvcobjects_ref->{'jcp'}{'ports'}{'tcp'}{'19541'}++	; 
#	$ports_ref->{'tcp'}{'19541'}{'name'} = 'jcp'		; 
#	$srvcobjects_ref->{'ida-discover2'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ida-discover2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ida-discover2'}{'port'}{'udp'} = '5742'	; 
#	$srvcobjects_ref->{'ida-discover2'}{'ports'}{'udp'}{'5742'}++	; 
#	$ports_ref->{'udp'}{'5742'}{'name'} = 'ida-discover2'		; 
#	$srvcobjects_ref->{'ida-discover2'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ida-discover2'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ida-discover2'}{'port'}{'tcp'} = '5742'	; 
#	$srvcobjects_ref->{'ida-discover2'}{'ports'}{'tcp'}{'5742'}++	; 
#	$ports_ref->{'tcp'}{'5742'}{'name'} = 'ida-discover2'		; 
#	$srvcobjects_ref->{'bmc-onekey'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'bmc-onekey'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-onekey'}{'port'}{'udp'} = '3561'	; 
#	$srvcobjects_ref->{'bmc-onekey'}{'ports'}{'udp'}{'3561'}++	; 
#	$ports_ref->{'udp'}{'3561'}{'name'} = 'bmc-onekey'		; 
#	$srvcobjects_ref->{'bmc-onekey'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'bmc-onekey'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'bmc-onekey'}{'port'}{'tcp'} = '3561'	; 
#	$srvcobjects_ref->{'bmc-onekey'}{'ports'}{'tcp'}{'3561'}++	; 
#	$ports_ref->{'tcp'}{'3561'}{'name'} = 'bmc-onekey'		; 
#	$srvcobjects_ref->{'ff-annunc'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'ff-annunc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-annunc'}{'port'}{'udp'} = '1089'	; 
#	$srvcobjects_ref->{'ff-annunc'}{'ports'}{'udp'}{'1089'}++	; 
#	$ports_ref->{'udp'}{'1089'}{'name'} = 'ff-annunc'		; 
#	$srvcobjects_ref->{'ff-annunc'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'ff-annunc'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'ff-annunc'}{'port'}{'tcp'} = '1089'	; 
#	$srvcobjects_ref->{'ff-annunc'}{'ports'}{'tcp'}{'1089'}++	; 
#	$ports_ref->{'tcp'}{'1089'}{'name'} = 'ff-annunc'		; 
#	$srvcobjects_ref->{'arns'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'arns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arns'}{'port'}{'udp'} = '384'	; 
#	$srvcobjects_ref->{'arns'}{'ports'}{'udp'}{'384'}++	; 
#	$ports_ref->{'udp'}{'384'}{'name'} = 'arns'		; 
#	$srvcobjects_ref->{'arns'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'arns'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'arns'}{'port'}{'tcp'} = '384'	; 
#	$srvcobjects_ref->{'arns'}{'ports'}{'tcp'}{'384'}++	; 
#	$ports_ref->{'tcp'}{'384'}{'name'} = 'arns'		; 
#	$srvcobjects_ref->{'filecast'}{'type'} = 'udp'	; 
#	$srvcobjects_ref->{'filecast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filecast'}{'port'}{'udp'} = '3401'	; 
#	$srvcobjects_ref->{'filecast'}{'ports'}{'udp'}{'3401'}++	; 
#	$ports_ref->{'udp'}{'3401'}{'name'} = 'filecast'		; 
#	$srvcobjects_ref->{'filecast'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'filecast'}{'default'} = 'OSX'	; 
#	$srvcobjects_ref->{'filecast'}{'port'}{'tcp'} = '3401'	; 
#	$srvcobjects_ref->{'filecast'}{'ports'}{'tcp'}{'3401'}++	; 
#	$ports_ref->{'tcp'}{'3401'}{'name'} = 'filecast'		; 
}

sub set_cisco_defaults {
	my ($srvcobjects_ref, $ports_ref) = @_;

# NOTE: Cisco default services created with servicebuilder.pl by dan !! 

	$srvcobjects_ref->{'udp'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'udp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'udp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'udp'}{'port'}{'udp'}	= '0-65353'	; 
	$srvcobjects_ref->{'tcp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'tcp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'tcp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'tcp'}{'port'}{'tcp'}	= '0-65353'	; 
	$srvcobjects_ref->{'aol'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'aol'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'aol'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'aol'}{'port'}{'tcp'}	= '5120'	; 
	$srvcobjects_ref->{'aol'}{'port'}{'udp'}	= '5120'	; 
	$ports_ref->{'tcp'}{'aol'}{'name'}        = 'aol'    ; 
	$ports_ref->{'udp'}{'aol'}{'name'}        = 'aol'    ; 
	$ports_ref->{'tcp'}{'5120'}{'name'}        	= 'aol'    ; 
	$ports_ref->{'udp'}{'5120'}{'name'}        	= 'aol'    ; 
	$ports_ref->{'tcp'}{'AOL'}{'name'}        = 'aol'    ; 
	$ports_ref->{'udp'}{'AOL'}{'name'}        = 'aol'    ; 
	$srvcobjects_ref->{'bgp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'bgp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'bgp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'bgp'}{'port'}{'tcp'}	= '179'	; 
	$srvcobjects_ref->{'bgp'}{'port'}{'udp'}	= '179'	; 
	$ports_ref->{'tcp'}{'bgp'}{'name'}        = 'bgp'    ; 
	$ports_ref->{'udp'}{'bgp'}{'name'}        = 'bgp'    ; 
	$ports_ref->{'tcp'}{'179'}{'name'}        	= 'bgp'    ; 
	$ports_ref->{'udp'}{'179'}{'name'}        	= 'bgp'    ; 
	$ports_ref->{'tcp'}{'BGP'}{'name'}        = 'bgp'    ; 
	$ports_ref->{'udp'}{'BGP'}{'name'}        = 'bgp'    ; 
	$srvcobjects_ref->{'chargen'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'chargen'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'chargen'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'chargen'}{'port'}{'tcp'}	= '19'	; 
	$srvcobjects_ref->{'chargen'}{'port'}{'udp'}	= '19'	; 
	$ports_ref->{'tcp'}{'chargen'}{'name'}        = 'chargen'    ; 
	$ports_ref->{'udp'}{'chargen'}{'name'}        = 'chargen'    ; 
	$ports_ref->{'tcp'}{'19'}{'name'}        	= 'chargen'    ; 
	$ports_ref->{'udp'}{'19'}{'name'}        	= 'chargen'    ; 
	$ports_ref->{'tcp'}{'CHARGEN'}{'name'}        = 'chargen'    ; 
	$ports_ref->{'udp'}{'CHARGEN'}{'name'}        = 'chargen'    ; 
	$srvcobjects_ref->{'cifs'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'cifs'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'cifs'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'cifs'}{'port'}{'tcp'}	= '3020'	; 
	$srvcobjects_ref->{'cifs'}{'port'}{'udp'}	= '3020'	; 
	$ports_ref->{'tcp'}{'cifs'}{'name'}        = 'cifs'    ; 
	$ports_ref->{'udp'}{'cifs'}{'name'}        = 'cifs'    ; 
	$ports_ref->{'tcp'}{'3020'}{'name'}        	= 'cifs'    ; 
	$ports_ref->{'udp'}{'3020'}{'name'}        	= 'cifs'    ; 
	$ports_ref->{'tcp'}{'CIFS'}{'name'}        = 'cifs'    ; 
	$ports_ref->{'udp'}{'CIFS'}{'name'}        = 'cifs'    ; 
	$srvcobjects_ref->{'citrix-ica'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'citrix-ica'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'citrix-ica'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'citrix-ica'}{'port'}{'tcp'}	= '1494'	; 
	$srvcobjects_ref->{'citrix-ica'}{'port'}{'udp'}	= '1494'	; 
	$ports_ref->{'tcp'}{'citrix-ica'}{'name'}        = 'citrix-ica'    ; 
	$ports_ref->{'udp'}{'citrix-ica'}{'name'}        = 'citrix-ica'    ; 
	$ports_ref->{'tcp'}{'1494'}{'name'}        	= 'citrix-ica'    ; 
	$ports_ref->{'udp'}{'1494'}{'name'}        	= 'citrix-ica'    ; 
	$ports_ref->{'tcp'}{'CITRIX-ICA'}{'name'}        = 'citrix-ica'    ; 
	$ports_ref->{'udp'}{'CITRIX-ICA'}{'name'}        = 'citrix-ica'    ; 
	$srvcobjects_ref->{'cmd'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'cmd'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'cmd'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'cmd'}{'port'}{'tcp'}	= '514'	; 
	$srvcobjects_ref->{'cmd'}{'port'}{'udp'}	= '514'	; 
	$ports_ref->{'tcp'}{'cmd'}{'name'}        = 'cmd'    ; 
	$ports_ref->{'udp'}{'cmd'}{'name'}        = 'cmd'    ; 
	$ports_ref->{'tcp'}{'514'}{'name'}        	= 'cmd'    ; 
	$ports_ref->{'udp'}{'514'}{'name'}        	= 'cmd'    ; 
	$ports_ref->{'tcp'}{'CMD'}{'name'}        = 'cmd'    ; 
	$ports_ref->{'udp'}{'CMD'}{'name'}        = 'cmd'    ; 
	$srvcobjects_ref->{'ctiqbe'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'ctiqbe'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'ctiqbe'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'ctiqbe'}{'port'}{'tcp'}	= '2748'	; 
	$srvcobjects_ref->{'ctiqbe'}{'port'}{'udp'}	= '2748'	; 
	$ports_ref->{'tcp'}{'ctiqbe'}{'name'}        = 'ctiqbe'    ; 
	$ports_ref->{'udp'}{'ctiqbe'}{'name'}        = 'ctiqbe'    ; 
	$ports_ref->{'tcp'}{'2748'}{'name'}        	= 'ctiqbe'    ; 
	$ports_ref->{'udp'}{'2748'}{'name'}        	= 'ctiqbe'    ; 
	$ports_ref->{'tcp'}{'CTIQBE'}{'name'}        = 'ctiqbe'    ; 
	$ports_ref->{'udp'}{'CTIQBE'}{'name'}        = 'ctiqbe'    ; 
	$srvcobjects_ref->{'daytime'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'daytime'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'daytime'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'daytime'}{'port'}{'tcp'}	= '13'	; 
	$srvcobjects_ref->{'daytime'}{'port'}{'udp'}	= '13'	; 
	$ports_ref->{'tcp'}{'daytime'}{'name'}        = 'daytime'    ; 
	$ports_ref->{'udp'}{'daytime'}{'name'}        = 'daytime'    ; 
	$ports_ref->{'tcp'}{'13'}{'name'}        	= 'daytime'    ; 
	$ports_ref->{'udp'}{'13'}{'name'}        	= 'daytime'    ; 
	$ports_ref->{'tcp'}{'DAYTIME'}{'name'}        = 'daytime'    ; 
	$ports_ref->{'udp'}{'DAYTIME'}{'name'}        = 'daytime'    ; 
	$srvcobjects_ref->{'discard'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'discard'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'discard'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'discard'}{'port'}{'tcp'}	= '9'	; 
	$srvcobjects_ref->{'discard'}{'port'}{'udp'}	= '9'	; 
	$ports_ref->{'tcp'}{'discard'}{'name'}        = 'discard'    ; 
	$ports_ref->{'udp'}{'discard'}{'name'}        = 'discard'    ; 
	$ports_ref->{'tcp'}{'9'}{'name'}        	= 'discard'    ; 
	$ports_ref->{'udp'}{'9'}{'name'}        	= 'discard'    ; 
	$ports_ref->{'tcp'}{'DISCARD'}{'name'}        = 'discard'    ; 
	$ports_ref->{'udp'}{'DISCARD'}{'name'}        = 'discard'    ; 
	$srvcobjects_ref->{'domain'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'domain'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'domain'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'domain'}{'port'}{'tcp'}	= '53'	; 
	$srvcobjects_ref->{'domain'}{'port'}{'udp'}	= '53'	; 
	$ports_ref->{'tcp'}{'domain'}{'name'}        = 'domain'    ; 
	$ports_ref->{'udp'}{'domain'}{'name'}        = 'domain'    ; 
	$ports_ref->{'tcp'}{'53'}{'name'}        	= 'domain'    ; 
	$ports_ref->{'udp'}{'53'}{'name'}        	= 'domain'    ; 
	$ports_ref->{'tcp'}{'DOMAIN'}{'name'}        = 'domain'    ; 
	$ports_ref->{'udp'}{'DOMAIN'}{'name'}        = 'domain'    ; 
	$srvcobjects_ref->{'echo'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'echo'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'echo'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'echo'}{'port'}{'tcp'}	= '7'	; 
	$srvcobjects_ref->{'echo'}{'port'}{'udp'}	= '7'	; 
	$ports_ref->{'tcp'}{'echo'}{'name'}        = 'echo'    ; 
	$ports_ref->{'udp'}{'echo'}{'name'}        = 'echo'    ; 
	$ports_ref->{'tcp'}{'7'}{'name'}        	= 'echo'    ; 
	$ports_ref->{'udp'}{'7'}{'name'}        	= 'echo'    ; 
	$ports_ref->{'tcp'}{'ECHO'}{'name'}        = 'echo'    ; 
	$ports_ref->{'udp'}{'ECHO'}{'name'}        = 'echo'    ; 
	$srvcobjects_ref->{'exec'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'exec'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'exec'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'exec'}{'port'}{'tcp'}	= '512'	; 
	$srvcobjects_ref->{'exec'}{'port'}{'udp'}	= '512'	; 
	$ports_ref->{'tcp'}{'exec'}{'name'}        = 'exec'    ; 
	$ports_ref->{'udp'}{'exec'}{'name'}        = 'exec'    ; 
	$ports_ref->{'tcp'}{'512'}{'name'}        	= 'exec'    ; 
	$ports_ref->{'udp'}{'512'}{'name'}        	= 'exec'    ; 
	$ports_ref->{'tcp'}{'EXEC'}{'name'}        = 'exec'    ; 
	$ports_ref->{'udp'}{'EXEC'}{'name'}        = 'exec'    ; 
	$srvcobjects_ref->{'finger'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'finger'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'finger'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'finger'}{'port'}{'tcp'}	= '79'	; 
	$srvcobjects_ref->{'finger'}{'port'}{'udp'}	= '79'	; 
	$ports_ref->{'tcp'}{'finger'}{'name'}        = 'finger'    ; 
	$ports_ref->{'udp'}{'finger'}{'name'}        = 'finger'    ; 
	$ports_ref->{'tcp'}{'79'}{'name'}        	= 'finger'    ; 
	$ports_ref->{'udp'}{'79'}{'name'}        	= 'finger'    ; 
	$ports_ref->{'tcp'}{'FINGER'}{'name'}        = 'finger'    ; 
	$ports_ref->{'udp'}{'FINGER'}{'name'}        = 'finger'    ; 
	$srvcobjects_ref->{'ftp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'ftp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'ftp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'ftp'}{'port'}{'tcp'}	= '21'	; 
	$srvcobjects_ref->{'ftp'}{'port'}{'udp'}	= '21'	; 
	$ports_ref->{'tcp'}{'ftp'}{'name'}        = 'ftp'    ; 
	$ports_ref->{'udp'}{'ftp'}{'name'}        = 'ftp'    ; 
	$ports_ref->{'tcp'}{'21'}{'name'}        	= 'ftp'    ; 
	$ports_ref->{'udp'}{'21'}{'name'}        	= 'ftp'    ; 
	$ports_ref->{'tcp'}{'FTP'}{'name'}        = 'ftp'    ; 
	$ports_ref->{'udp'}{'FTP'}{'name'}        = 'ftp'    ; 
	$srvcobjects_ref->{'ftp-data'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'ftp-data'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'ftp-data'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'ftp-data'}{'port'}{'tcp'}	= '20'	; 
	$srvcobjects_ref->{'ftp-data'}{'port'}{'udp'}	= '20'	; 
	$ports_ref->{'tcp'}{'ftp-data'}{'name'}        = 'ftp-data'    ; 
	$ports_ref->{'udp'}{'ftp-data'}{'name'}        = 'ftp-data'    ; 
	$ports_ref->{'tcp'}{'20'}{'name'}        	= 'ftp-data'    ; 
	$ports_ref->{'udp'}{'20'}{'name'}        	= 'ftp-data'    ; 
	$ports_ref->{'tcp'}{'FTP-DATA'}{'name'}        = 'ftp-data'    ; 
	$ports_ref->{'udp'}{'FTP-DATA'}{'name'}        = 'ftp-data'    ; 
	$srvcobjects_ref->{'gopher'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'gopher'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'gopher'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'gopher'}{'port'}{'tcp'}	= '70'	; 
	$srvcobjects_ref->{'gopher'}{'port'}{'udp'}	= '70'	; 
	$ports_ref->{'tcp'}{'gopher'}{'name'}        = 'gopher'    ; 
	$ports_ref->{'udp'}{'gopher'}{'name'}        = 'gopher'    ; 
	$ports_ref->{'tcp'}{'70'}{'name'}        	= 'gopher'    ; 
	$ports_ref->{'udp'}{'70'}{'name'}        	= 'gopher'    ; 
	$ports_ref->{'tcp'}{'GOPHER'}{'name'}        = 'gopher'    ; 
	$ports_ref->{'udp'}{'GOPHER'}{'name'}        = 'gopher'    ; 
	$srvcobjects_ref->{'h323'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'h323'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'h323'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'h323'}{'port'}{'tcp'}	= '1720'	; 
	$srvcobjects_ref->{'h323'}{'port'}{'udp'}	= '1720'	; 
	$ports_ref->{'tcp'}{'h323'}{'name'}        = 'h323'    ; 
	$ports_ref->{'udp'}{'h323'}{'name'}        = 'h323'    ; 
	$ports_ref->{'tcp'}{'1720'}{'name'}        	= 'h323'    ; 
	$ports_ref->{'udp'}{'1720'}{'name'}        	= 'h323'    ; 
	$ports_ref->{'tcp'}{'H323'}{'name'}        = 'h323'    ; 
	$ports_ref->{'udp'}{'H323'}{'name'}        = 'h323'    ; 
	$srvcobjects_ref->{'hostname'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'hostname'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'hostname'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'hostname'}{'port'}{'tcp'}	= '101'	; 
	$srvcobjects_ref->{'hostname'}{'port'}{'udp'}	= '101'	; 
	$ports_ref->{'tcp'}{'hostname'}{'name'}        = 'hostname'    ; 
	$ports_ref->{'udp'}{'hostname'}{'name'}        = 'hostname'    ; 
	$ports_ref->{'tcp'}{'101'}{'name'}        	= 'hostname'    ; 
	$ports_ref->{'udp'}{'101'}{'name'}        	= 'hostname'    ; 
	$ports_ref->{'tcp'}{'HOSTNAME'}{'name'}        = 'hostname'    ; 
	$ports_ref->{'udp'}{'HOSTNAME'}{'name'}        = 'hostname'    ; 
	$srvcobjects_ref->{'http'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'http'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'http'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'http'}{'port'}{'tcp'}	= '80'	; 
	$srvcobjects_ref->{'http'}{'port'}{'udp'}	= '80'	; 
	$ports_ref->{'tcp'}{'http'}{'name'}        = 'http'    ; 
	$ports_ref->{'udp'}{'http'}{'name'}        = 'http'    ; 
	$ports_ref->{'tcp'}{'80'}{'name'}        	= 'http'    ; 
	$ports_ref->{'udp'}{'80'}{'name'}        	= 'http'    ; 
	$ports_ref->{'tcp'}{'HTTP'}{'name'}        = 'http'    ; 
	$ports_ref->{'udp'}{'HTTP'}{'name'}        = 'http'    ; 
	$srvcobjects_ref->{'https'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'https'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'https'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'https'}{'port'}{'tcp'}	= '443'	; 
	$srvcobjects_ref->{'https'}{'port'}{'udp'}	= '443'	; 
	$ports_ref->{'tcp'}{'https'}{'name'}        = 'https'    ; 
	$ports_ref->{'udp'}{'https'}{'name'}        = 'https'    ; 
	$ports_ref->{'tcp'}{'443'}{'name'}        	= 'https'    ; 
	$ports_ref->{'udp'}{'443'}{'name'}        	= 'https'    ; 
	$ports_ref->{'tcp'}{'HTTPS'}{'name'}        = 'https'    ; 
	$ports_ref->{'udp'}{'HTTPS'}{'name'}        = 'https'    ; 
	$srvcobjects_ref->{'ident'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'ident'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'ident'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'ident'}{'port'}{'tcp'}	= '113'	; 
	$srvcobjects_ref->{'ident'}{'port'}{'udp'}	= '113'	; 
	$ports_ref->{'tcp'}{'ident'}{'name'}        = 'ident'    ; 
	$ports_ref->{'udp'}{'ident'}{'name'}        = 'ident'    ; 
	$ports_ref->{'tcp'}{'113'}{'name'}        	= 'ident'    ; 
	$ports_ref->{'udp'}{'113'}{'name'}        	= 'ident'    ; 
	$ports_ref->{'tcp'}{'IDENT'}{'name'}        = 'ident'    ; 
	$ports_ref->{'udp'}{'IDENT'}{'name'}        = 'ident'    ; 
	$srvcobjects_ref->{'imap4'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'imap4'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'imap4'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'imap4'}{'port'}{'tcp'}	= '143'	; 
	$srvcobjects_ref->{'imap4'}{'port'}{'udp'}	= '143'	; 
	$ports_ref->{'tcp'}{'imap4'}{'name'}        = 'imap4'    ; 
	$ports_ref->{'udp'}{'imap4'}{'name'}        = 'imap4'    ; 
	$ports_ref->{'tcp'}{'143'}{'name'}        	= 'imap4'    ; 
	$ports_ref->{'udp'}{'143'}{'name'}        	= 'imap4'    ; 
	$ports_ref->{'tcp'}{'IMAP4'}{'name'}        = 'imap4'    ; 
	$ports_ref->{'udp'}{'IMAP4'}{'name'}        = 'imap4'    ; 
	$srvcobjects_ref->{'irc'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'irc'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'irc'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'irc'}{'port'}{'tcp'}	= '194'	; 
	$srvcobjects_ref->{'irc'}{'port'}{'udp'}	= '194'	; 
	$ports_ref->{'tcp'}{'irc'}{'name'}        = 'irc'    ; 
	$ports_ref->{'udp'}{'irc'}{'name'}        = 'irc'    ; 
	$ports_ref->{'tcp'}{'194'}{'name'}        	= 'irc'    ; 
	$ports_ref->{'udp'}{'194'}{'name'}        	= 'irc'    ; 
	$ports_ref->{'tcp'}{'IRC'}{'name'}        = 'irc'    ; 
	$ports_ref->{'udp'}{'IRC'}{'name'}        = 'irc'    ; 
	$srvcobjects_ref->{'kerberos'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'kerberos'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'kerberos'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'kerberos'}{'port'}{'tcp'}	= '88'	; 
	$srvcobjects_ref->{'kerberos'}{'port'}{'udp'}	= '88'	; 
	$ports_ref->{'tcp'}{'kerberos'}{'name'}        = 'kerberos'    ; 
	$ports_ref->{'udp'}{'kerberos'}{'name'}        = 'kerberos'    ; 
	$ports_ref->{'tcp'}{'88'}{'name'}        	= 'kerberos'    ; 
	$ports_ref->{'udp'}{'88'}{'name'}        	= 'kerberos'    ; 
	$ports_ref->{'tcp'}{'KERBEROS'}{'name'}        = 'kerberos'    ; 
	$ports_ref->{'udp'}{'KERBEROS'}{'name'}        = 'kerberos'    ; 
	$srvcobjects_ref->{'klogin'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'klogin'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'klogin'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'klogin'}{'port'}{'tcp'}	= '543'	; 
	$srvcobjects_ref->{'klogin'}{'port'}{'udp'}	= '543'	; 
	$ports_ref->{'tcp'}{'klogin'}{'name'}        = 'klogin'    ; 
	$ports_ref->{'udp'}{'klogin'}{'name'}        = 'klogin'    ; 
	$ports_ref->{'tcp'}{'543'}{'name'}        	= 'klogin'    ; 
	$ports_ref->{'udp'}{'543'}{'name'}        	= 'klogin'    ; 
	$ports_ref->{'tcp'}{'KLOGIN'}{'name'}        = 'klogin'    ; 
	$ports_ref->{'udp'}{'KLOGIN'}{'name'}        = 'klogin'    ; 
	$srvcobjects_ref->{'kshell'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'kshell'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'kshell'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'kshell'}{'port'}{'tcp'}	= '544'	; 
	$srvcobjects_ref->{'kshell'}{'port'}{'udp'}	= '544'	; 
	$ports_ref->{'tcp'}{'kshell'}{'name'}        = 'kshell'    ; 
	$ports_ref->{'udp'}{'kshell'}{'name'}        = 'kshell'    ; 
	$ports_ref->{'tcp'}{'544'}{'name'}        	= 'kshell'    ; 
	$ports_ref->{'udp'}{'544'}{'name'}        	= 'kshell'    ; 
	$ports_ref->{'tcp'}{'KSHELL'}{'name'}        = 'kshell'    ; 
	$ports_ref->{'udp'}{'KSHELL'}{'name'}        = 'kshell'    ; 
	$srvcobjects_ref->{'ldap'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'ldap'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'ldap'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'ldap'}{'port'}{'tcp'}	= '389'	; 
	$srvcobjects_ref->{'ldap'}{'port'}{'udp'}	= '389'	; 
	$ports_ref->{'tcp'}{'ldap'}{'name'}        = 'ldap'    ; 
	$ports_ref->{'udp'}{'ldap'}{'name'}        = 'ldap'    ; 
	$ports_ref->{'tcp'}{'389'}{'name'}        	= 'ldap'    ; 
	$ports_ref->{'udp'}{'389'}{'name'}        	= 'ldap'    ; 
	$ports_ref->{'tcp'}{'LDAP'}{'name'}        = 'ldap'    ; 
	$ports_ref->{'udp'}{'LDAP'}{'name'}        = 'ldap'    ; 
	$srvcobjects_ref->{'ldaps'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'ldaps'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'ldaps'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'ldaps'}{'port'}{'tcp'}	= '636'	; 
	$srvcobjects_ref->{'ldaps'}{'port'}{'udp'}	= '636'	; 
	$ports_ref->{'tcp'}{'ldaps'}{'name'}        = 'ldaps'    ; 
	$ports_ref->{'udp'}{'ldaps'}{'name'}        = 'ldaps'    ; 
	$ports_ref->{'tcp'}{'636'}{'name'}        	= 'ldaps'    ; 
	$ports_ref->{'udp'}{'636'}{'name'}        	= 'ldaps'    ; 
	$ports_ref->{'tcp'}{'LDAPS'}{'name'}        = 'ldaps'    ; 
	$ports_ref->{'udp'}{'LDAPS'}{'name'}        = 'ldaps'    ; 
	$srvcobjects_ref->{'login'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'login'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'login'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'login'}{'port'}{'tcp'}	= '513'	; 
	$srvcobjects_ref->{'login'}{'port'}{'udp'}	= '513'	; 
	$ports_ref->{'tcp'}{'login'}{'name'}        = 'login'    ; 
	$ports_ref->{'udp'}{'login'}{'name'}        = 'login'    ; 
	$ports_ref->{'tcp'}{'513'}{'name'}        	= 'login'    ; 
	$ports_ref->{'udp'}{'513'}{'name'}        	= 'login'    ; 
	$ports_ref->{'tcp'}{'LOGIN'}{'name'}        = 'login'    ; 
	$ports_ref->{'udp'}{'LOGIN'}{'name'}        = 'login'    ; 
	$srvcobjects_ref->{'lotusnotes'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'lotusnotes'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'lotusnotes'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'lotusnotes'}{'port'}{'tcp'}	= '1352'	; 
	$srvcobjects_ref->{'lotusnotes'}{'port'}{'udp'}	= '1352'	; 
	$ports_ref->{'tcp'}{'lotusnotes'}{'name'}        = 'lotusnotes'    ; 
	$ports_ref->{'udp'}{'lotusnotes'}{'name'}        = 'lotusnotes'    ; 
	$ports_ref->{'tcp'}{'1352'}{'name'}        	= 'lotusnotes'    ; 
	$ports_ref->{'udp'}{'1352'}{'name'}        	= 'lotusnotes'    ; 
	$ports_ref->{'tcp'}{'LOTUSNOTES'}{'name'}        = 'lotusnotes'    ; 
	$ports_ref->{'udp'}{'LOTUSNOTES'}{'name'}        = 'lotusnotes'    ; 
	$srvcobjects_ref->{'lpd'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'lpd'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'lpd'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'lpd'}{'port'}{'tcp'}	= '515'	; 
	$srvcobjects_ref->{'lpd'}{'port'}{'udp'}	= '515'	; 
	$ports_ref->{'tcp'}{'lpd'}{'name'}        = 'lpd'    ; 
	$ports_ref->{'udp'}{'lpd'}{'name'}        = 'lpd'    ; 
	$ports_ref->{'tcp'}{'515'}{'name'}        	= 'lpd'    ; 
	$ports_ref->{'udp'}{'515'}{'name'}        	= 'lpd'    ; 
	$ports_ref->{'tcp'}{'LPD'}{'name'}        = 'lpd'    ; 
	$ports_ref->{'udp'}{'LPD'}{'name'}        = 'lpd'    ; 
	$srvcobjects_ref->{'netbios-ssn'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'netbios-ssn'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'netbios-ssn'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'netbios-ssn'}{'port'}{'tcp'}	= '139'	; 
	$srvcobjects_ref->{'netbios-ssn'}{'port'}{'udp'}	= '139'	; 
	$ports_ref->{'tcp'}{'netbios-ssn'}{'name'}        = 'netbios-ssn'    ; 
	$ports_ref->{'udp'}{'netbios-ssn'}{'name'}        = 'netbios-ssn'    ; 
	$ports_ref->{'tcp'}{'139'}{'name'}        	= 'netbios-ssn'    ; 
	$ports_ref->{'udp'}{'139'}{'name'}        	= 'netbios-ssn'    ; 
	$ports_ref->{'tcp'}{'NETBIOS-SSN'}{'name'}        = 'netbios-ssn'    ; 
	$ports_ref->{'udp'}{'NETBIOS-SSN'}{'name'}        = 'netbios-ssn'    ; 
	$srvcobjects_ref->{'nfs'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'nfs'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'nfs'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'nfs'}{'port'}{'tcp'}	= '2049'	; 
	$srvcobjects_ref->{'nfs'}{'port'}{'udp'}	= '2049'	; 
	$ports_ref->{'tcp'}{'nfs'}{'name'}        = 'nfs'    ; 
	$ports_ref->{'udp'}{'nfs'}{'name'}        = 'nfs'    ; 
	$ports_ref->{'tcp'}{'2049'}{'name'}        	= 'nfs'    ; 
	$ports_ref->{'udp'}{'2049'}{'name'}        	= 'nfs'    ; 
	$ports_ref->{'tcp'}{'NFS'}{'name'}        = 'nfs'    ; 
	$ports_ref->{'udp'}{'NFS'}{'name'}        = 'nfs'    ; 
	$srvcobjects_ref->{'nntp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'nntp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'nntp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'nntp'}{'port'}{'tcp'}	= '119'	; 
	$srvcobjects_ref->{'nntp'}{'port'}{'udp'}	= '119'	; 
	$ports_ref->{'tcp'}{'nntp'}{'name'}        = 'nntp'    ; 
	$ports_ref->{'udp'}{'nntp'}{'name'}        = 'nntp'    ; 
	$ports_ref->{'tcp'}{'119'}{'name'}        	= 'nntp'    ; 
	$ports_ref->{'udp'}{'119'}{'name'}        	= 'nntp'    ; 
	$ports_ref->{'tcp'}{'NNTP'}{'name'}        = 'nntp'    ; 
	$ports_ref->{'udp'}{'NNTP'}{'name'}        = 'nntp'    ; 
	$srvcobjects_ref->{'pcanywhere-data'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'pcanywhere-data'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'pcanywhere-data'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'pcanywhere-data'}{'port'}{'tcp'}	= '5631'	; 
	$srvcobjects_ref->{'pcanywhere-data'}{'port'}{'udp'}	= '5631'	; 
	$ports_ref->{'tcp'}{'pcanywhere-data'}{'name'}        = 'pcanywhere-data'    ; 
	$ports_ref->{'udp'}{'pcanywhere-data'}{'name'}        = 'pcanywhere-data'    ; 
	$ports_ref->{'tcp'}{'5631'}{'name'}        	= 'pcanywhere-data'    ; 
	$ports_ref->{'udp'}{'5631'}{'name'}        	= 'pcanywhere-data'    ; 
	$ports_ref->{'tcp'}{'PCANYWHERE-DATA'}{'name'}        = 'pcanywhere-data'    ; 
	$ports_ref->{'udp'}{'PCANYWHERE-DATA'}{'name'}        = 'pcanywhere-data'    ; 
	$srvcobjects_ref->{'pim-auto-rp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'pim-auto-rp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'pim-auto-rp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'pim-auto-rp'}{'port'}{'tcp'}	= '496'	; 
	$srvcobjects_ref->{'pim-auto-rp'}{'port'}{'udp'}	= '496'	; 
	$ports_ref->{'tcp'}{'pim-auto-rp'}{'name'}        = 'pim-auto-rp'    ; 
	$ports_ref->{'udp'}{'pim-auto-rp'}{'name'}        = 'pim-auto-rp'    ; 
	$ports_ref->{'tcp'}{'496'}{'name'}        	= 'pim-auto-rp'    ; 
	$ports_ref->{'udp'}{'496'}{'name'}        	= 'pim-auto-rp'    ; 
	$ports_ref->{'tcp'}{'PIM-AUTO-RP'}{'name'}        = 'pim-auto-rp'    ; 
	$ports_ref->{'udp'}{'PIM-AUTO-RP'}{'name'}        = 'pim-auto-rp'    ; 
	$srvcobjects_ref->{'pop2'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'pop2'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'pop2'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'pop2'}{'port'}{'tcp'}	= '109'	; 
	$srvcobjects_ref->{'pop2'}{'port'}{'udp'}	= '109'	; 
	$ports_ref->{'tcp'}{'pop2'}{'name'}        = 'pop2'    ; 
	$ports_ref->{'udp'}{'pop2'}{'name'}        = 'pop2'    ; 
	$ports_ref->{'tcp'}{'109'}{'name'}        	= 'pop2'    ; 
	$ports_ref->{'udp'}{'109'}{'name'}        	= 'pop2'    ; 
	$ports_ref->{'tcp'}{'POP2'}{'name'}        = 'pop2'    ; 
	$ports_ref->{'udp'}{'POP2'}{'name'}        = 'pop2'    ; 
	$srvcobjects_ref->{'pop3'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'pop3'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'pop3'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'pop3'}{'port'}{'tcp'}	= '110'	; 
	$srvcobjects_ref->{'pop3'}{'port'}{'udp'}	= '110'	; 
	$ports_ref->{'tcp'}{'pop3'}{'name'}        = 'pop3'    ; 
	$ports_ref->{'udp'}{'pop3'}{'name'}        = 'pop3'    ; 
	$ports_ref->{'tcp'}{'110'}{'name'}        	= 'pop3'    ; 
	$ports_ref->{'udp'}{'110'}{'name'}        	= 'pop3'    ; 
	$ports_ref->{'tcp'}{'POP3'}{'name'}        = 'pop3'    ; 
	$ports_ref->{'udp'}{'POP3'}{'name'}        = 'pop3'    ; 
	$srvcobjects_ref->{'pptp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'pptp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'pptp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'pptp'}{'port'}{'tcp'}	= '1723'	; 
	$srvcobjects_ref->{'pptp'}{'port'}{'udp'}	= '1723'	; 
	$ports_ref->{'tcp'}{'pptp'}{'name'}        = 'pptp'    ; 
	$ports_ref->{'udp'}{'pptp'}{'name'}        = 'pptp'    ; 
	$ports_ref->{'tcp'}{'1723'}{'name'}        	= 'pptp'    ; 
	$ports_ref->{'udp'}{'1723'}{'name'}        	= 'pptp'    ; 
	$ports_ref->{'tcp'}{'PPTP'}{'name'}        = 'pptp'    ; 
	$ports_ref->{'udp'}{'PPTP'}{'name'}        = 'pptp'    ; 
	$srvcobjects_ref->{'rsh'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'rsh'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'rsh'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'rsh'}{'port'}{'tcp'}	= '514'	; 
	$srvcobjects_ref->{'rsh'}{'port'}{'udp'}	= '514'	; 
	$ports_ref->{'tcp'}{'rsh'}{'name'}        = 'rsh'    ; 
	$ports_ref->{'udp'}{'rsh'}{'name'}        = 'rsh'    ; 
	$ports_ref->{'tcp'}{'514'}{'name'}        	= 'rsh'    ; 
	$ports_ref->{'udp'}{'514'}{'name'}        	= 'rsh'    ; 
	$ports_ref->{'tcp'}{'RSH'}{'name'}        = 'rsh'    ; 
	$ports_ref->{'udp'}{'RSH'}{'name'}        = 'rsh'    ; 
	$srvcobjects_ref->{'rtsp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'rtsp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'rtsp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'rtsp'}{'port'}{'tcp'}	= '554'	; 
	$srvcobjects_ref->{'rtsp'}{'port'}{'udp'}	= '554'	; 
	$ports_ref->{'tcp'}{'rtsp'}{'name'}        = 'rtsp'    ; 
	$ports_ref->{'udp'}{'rtsp'}{'name'}        = 'rtsp'    ; 
	$ports_ref->{'tcp'}{'554'}{'name'}        	= 'rtsp'    ; 
	$ports_ref->{'udp'}{'554'}{'name'}        	= 'rtsp'    ; 
	$ports_ref->{'tcp'}{'RTSP'}{'name'}        = 'rtsp'    ; 
	$ports_ref->{'udp'}{'RTSP'}{'name'}        = 'rtsp'    ; 
	$srvcobjects_ref->{'sip'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'sip'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'sip'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'sip'}{'port'}{'tcp'}	= '5060'	; 
	$srvcobjects_ref->{'sip'}{'port'}{'udp'}	= '5060'	; 
	$ports_ref->{'tcp'}{'sip'}{'name'}        = 'sip'    ; 
	$ports_ref->{'udp'}{'sip'}{'name'}        = 'sip'    ; 
	$ports_ref->{'tcp'}{'5060'}{'name'}        	= 'sip'    ; 
	$ports_ref->{'udp'}{'5060'}{'name'}        	= 'sip'    ; 
	$ports_ref->{'tcp'}{'SIP'}{'name'}        = 'sip'    ; 
	$ports_ref->{'udp'}{'SIP'}{'name'}        = 'sip'    ; 
	$srvcobjects_ref->{'smtp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'smtp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'smtp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'smtp'}{'port'}{'tcp'}	= '25'	; 
	$srvcobjects_ref->{'smtp'}{'port'}{'udp'}	= '25'	; 
	$ports_ref->{'tcp'}{'smtp'}{'name'}        = 'smtp'    ; 
	$ports_ref->{'udp'}{'smtp'}{'name'}        = 'smtp'    ; 
	$ports_ref->{'tcp'}{'25'}{'name'}        	= 'smtp'    ; 
	$ports_ref->{'udp'}{'25'}{'name'}        	= 'smtp'    ; 
	$ports_ref->{'tcp'}{'SMTP'}{'name'}        = 'smtp'    ; 
	$ports_ref->{'udp'}{'SMTP'}{'name'}        = 'smtp'    ; 
	$srvcobjects_ref->{'sqlnet'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'sqlnet'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'sqlnet'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'sqlnet'}{'port'}{'tcp'}	= '1522'	; 
	$srvcobjects_ref->{'sqlnet'}{'port'}{'udp'}	= '1522'	; 
	$ports_ref->{'tcp'}{'sqlnet'}{'name'}        = 'sqlnet'    ; 
	$ports_ref->{'udp'}{'sqlnet'}{'name'}        = 'sqlnet'    ; 
	$ports_ref->{'tcp'}{'1522'}{'name'}        	= 'sqlnet'    ; 
	$ports_ref->{'udp'}{'1522'}{'name'}        	= 'sqlnet'    ; 
	$ports_ref->{'tcp'}{'SQLNET'}{'name'}        = 'sqlnet'    ; 
	$ports_ref->{'udp'}{'SQLNET'}{'name'}        = 'sqlnet'    ; 
	$srvcobjects_ref->{'ssh'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'ssh'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'ssh'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'ssh'}{'port'}{'tcp'}	= '22'	; 
	$srvcobjects_ref->{'ssh'}{'port'}{'udp'}	= '22'	; 
	$ports_ref->{'tcp'}{'ssh'}{'name'}        = 'ssh'    ; 
	$ports_ref->{'udp'}{'ssh'}{'name'}        = 'ssh'    ; 
	$ports_ref->{'tcp'}{'22'}{'name'}        	= 'ssh'    ; 
	$ports_ref->{'udp'}{'22'}{'name'}        	= 'ssh'    ; 
	$ports_ref->{'tcp'}{'SSH'}{'name'}        = 'ssh'    ; 
	$ports_ref->{'udp'}{'SSH'}{'name'}        = 'ssh'    ; 
	$srvcobjects_ref->{'sunrpc'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'sunrpc'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'sunrpc'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'sunrpc'}{'port'}{'tcp'}	= '111'	; 
	$srvcobjects_ref->{'sunrpc'}{'port'}{'udp'}	= '111'	; 
	$ports_ref->{'tcp'}{'sunrpc'}{'name'}        = 'sunrpc'    ; 
	$ports_ref->{'udp'}{'sunrpc'}{'name'}        = 'sunrpc'    ; 
	$ports_ref->{'tcp'}{'111'}{'name'}        	= 'sunrpc'    ; 
	$ports_ref->{'udp'}{'111'}{'name'}        	= 'sunrpc'    ; 
	$ports_ref->{'tcp'}{'SUNRPC'}{'name'}        = 'sunrpc'    ; 
	$ports_ref->{'udp'}{'SUNRPC'}{'name'}        = 'sunrpc'    ; 
	$srvcobjects_ref->{'tacacs'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'tacacs'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'tacacs'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'tacacs'}{'port'}{'tcp'}	= '49'	; 
	$srvcobjects_ref->{'tacacs'}{'port'}{'udp'}	= '49'	; 
	$ports_ref->{'tcp'}{'tacacs'}{'name'}        = 'tacacs'    ; 
	$ports_ref->{'udp'}{'tacacs'}{'name'}        = 'tacacs'    ; 
	$ports_ref->{'tcp'}{'49'}{'name'}        	= 'tacacs'    ; 
	$ports_ref->{'udp'}{'49'}{'name'}        	= 'tacacs'    ; 
	$ports_ref->{'tcp'}{'TACACS'}{'name'}        = 'tacacs'    ; 
	$ports_ref->{'udp'}{'TACACS'}{'name'}        = 'tacacs'    ; 
	$srvcobjects_ref->{'talk'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'talk'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'talk'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'talk'}{'port'}{'tcp'}	= '517'	; 
	$srvcobjects_ref->{'talk'}{'port'}{'udp'}	= '517'	; 
	$ports_ref->{'tcp'}{'talk'}{'name'}        = 'talk'    ; 
	$ports_ref->{'udp'}{'talk'}{'name'}        = 'talk'    ; 
	$ports_ref->{'tcp'}{'517'}{'name'}        	= 'talk'    ; 
	$ports_ref->{'udp'}{'517'}{'name'}        	= 'talk'    ; 
	$ports_ref->{'tcp'}{'TALK'}{'name'}        = 'talk'    ; 
	$ports_ref->{'udp'}{'TALK'}{'name'}        = 'talk'    ; 
	$srvcobjects_ref->{'telnet'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'telnet'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'telnet'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'telnet'}{'port'}{'tcp'}	= '23'	; 
	$srvcobjects_ref->{'telnet'}{'port'}{'udp'}	= '23'	; 
	$ports_ref->{'tcp'}{'telnet'}{'name'}        = 'telnet'    ; 
	$ports_ref->{'udp'}{'telnet'}{'name'}        = 'telnet'    ; 
	$ports_ref->{'tcp'}{'23'}{'name'}        	= 'telnet'    ; 
	$ports_ref->{'udp'}{'23'}{'name'}        	= 'telnet'    ; 
	$ports_ref->{'tcp'}{'TELNET'}{'name'}        = 'telnet'    ; 
	$ports_ref->{'udp'}{'TELNET'}{'name'}        = 'telnet'    ; 
	$srvcobjects_ref->{'uucp'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'uucp'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'uucp'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'uucp'}{'port'}{'tcp'}	= '540'	; 
	$srvcobjects_ref->{'uucp'}{'port'}{'udp'}	= '540'	; 
	$ports_ref->{'tcp'}{'uucp'}{'name'}        = 'uucp'    ; 
	$ports_ref->{'udp'}{'uucp'}{'name'}        = 'uucp'    ; 
	$ports_ref->{'tcp'}{'540'}{'name'}        	= 'uucp'    ; 
	$ports_ref->{'udp'}{'540'}{'name'}        	= 'uucp'    ; 
	$ports_ref->{'tcp'}{'UUCP'}{'name'}        = 'uucp'    ; 
	$ports_ref->{'udp'}{'UUCP'}{'name'}        = 'uucp'    ; 
	$srvcobjects_ref->{'whois'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'whois'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'whois'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'whois'}{'port'}{'tcp'}	= '43'	; 
	$srvcobjects_ref->{'whois'}{'port'}{'udp'}	= '43'	; 
	$ports_ref->{'tcp'}{'whois'}{'name'}        = 'whois'    ; 
	$ports_ref->{'udp'}{'whois'}{'name'}        = 'whois'    ; 
	$ports_ref->{'tcp'}{'43'}{'name'}        	= 'whois'    ; 
	$ports_ref->{'udp'}{'43'}{'name'}        	= 'whois'    ; 
	$ports_ref->{'tcp'}{'WHOIS'}{'name'}        = 'whois'    ; 
	$ports_ref->{'udp'}{'WHOIS'}{'name'}        = 'whois'    ; 
	$srvcobjects_ref->{'www'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'www'}{'default'}    	= 'Default'	; 
	$srvcobjects_ref->{'www'}{'description'}	= 'Cisco_Default'; 
	$srvcobjects_ref->{'www'}{'port'}{'tcp'}	= '80'	; 
	$srvcobjects_ref->{'www'}{'port'}{'udp'}	= '80'	; 
	$ports_ref->{'tcp'}{'www'}{'name'}        = 'www'    ; 
	$ports_ref->{'udp'}{'www'}{'name'}        = 'www'    ; 
	$ports_ref->{'tcp'}{'80'}{'name'}        	= 'www'    ; 
	$ports_ref->{'udp'}{'80'}{'name'}        	= 'www'    ; 
	$ports_ref->{'tcp'}{'WWW'}{'name'}        = 'www'    ; 
	$ports_ref->{'udp'}{'WWW'}{'name'}        = 'www'    ; 

# NOTE: setting default cisco ICMP service definitions

        $srvcobjects_ref->{'echo-reply'}{'port'}{'icmp'}{'0'}++			;
        $srvcobjects_ref->{'echo-rquest'}{'port'}{'icmp'}{'1'}++			;
        $srvcobjects_ref->{'net-unreachable'}{'port'}{'icmp'}{'300'}++		;
        $srvcobjects_ref->{'host-unreachable'}{'port'}{'icmp'}{'301'}++		;
        $srvcobjects_ref->{'protocol-unreachable'}{'port'}{'icmp'}{'302'}++		;
        $srvcobjects_ref->{'port-unreachable'}{'port'}{'icmp'}{'303'}++		;
        $srvcobjects_ref->{'packet-too-big'}{'port'}{'icmp'}{'304'}++		;
        $srvcobjects_ref->{'source-route-failed'}{'port'}{'icmp'}{'305'}++		;
        $srvcobjects_ref->{'network-unknown'}{'port'}{'icmp'}{'306'}++		;
        $srvcobjects_ref->{'host-unknown'}{'port'}{'icmp'}{'307'}++			;
        $srvcobjects_ref->{'dod-net-prohibited'}{'port'}{'icmp'}{'309'}++		;
        $srvcobjects_ref->{'dod-host-prohibited'}{'port'}{'icmp'}{'310'}++		;
        $srvcobjects_ref->{'net-tos-unreachable'}{'port'}{'icmp'}{'311'}++		;
        $srvcobjects_ref->{'host-tos-unreachable'}{'port'}{'icmp'}{'312'}++		;
        $srvcobjects_ref->{'administratively-prohibited'}{'port'}{'icmp'}{'313'}++	;
        $srvcobjects_ref->{'host-precedence-unreachable'}{'port'}{'icmp'}{'314'}++	;
        $srvcobjects_ref->{'precedence-unreachable'}{'port'}{'icmp'}{'315'}++	;
        $srvcobjects_ref->{'source-quench'}{'port'}{'icmp'}{'400'}++			;
        $srvcobjects_ref->{'alternate-address'}{'port'}{'icmp'}{'600'}++		;
        $srvcobjects_ref->{'echo'}{'port'}{'icmp'}{'800'}++				;
        $srvcobjects_ref->{'router-advertisement'}{'port'}{'icmp'}{'900'}++		;
        $srvcobjects_ref->{'router-solicitation'}{'port'}{'icmp'}{'1000'}++		;
        $srvcobjects_ref->{'ttl-exceeded'}{'port'}{'icmp'}{'1100'}++			;
        $srvcobjects_ref->{'reassembly-timeout'}{'port'}{'icmp'}{'1101'}++		;
        $srvcobjects_ref->{'parameter-problem'}{'port'}{'icmp'}{'1200'}++		;
        $srvcobjects_ref->{'option-missing'}{'port'}{'icmp'}{'1201'}++		;
        $srvcobjects_ref->{'no-room-for-option'}{'port'}{'icmp'}{'1202'}++		;
        $srvcobjects_ref->{'timestamp-request'}{'port'}{'icmp'}{'1300'}++		;
        $srvcobjects_ref->{'timestamp-reply'}{'port'}{'icmp'}{'1400'}++		;
        $srvcobjects_ref->{'information-request'}{'port'}{'icmp'}{'1500'}++		;
        $srvcobjects_ref->{'information-reply'}{'port'}{'icmp'}{'1600'}++		;
        $srvcobjects_ref->{'mask-request'}{'port'}{'icmp'}{'1700'}++			;
        $srvcobjects_ref->{'mask-reply'}{'port'}{'icmp'}{'1800'}++			;
        $srvcobjects_ref->{'traceroute'}{'port'}{'icmp'}{'3000'}++			;
        $srvcobjects_ref->{'conversion-error'}{'port'}{'icmp'}{'3100'}++		;
        $srvcobjects_ref->{'mobile-redirect'}{'port'}{'icmp'}{'3200'}++		;
        $srvcobjects_ref->{'dscp'}{'port'}{'icmp'}{'10001'}++			;
        $srvcobjects_ref->{'fragments'}{'port'}{'icmp'}{'10002'}++			;
        $srvcobjects_ref->{'general-parameter-problem'}{'port'}{'icmp'}{'10003'}++	;
        $srvcobjects_ref->{'host-isolated'}{'port'}{'icmp'}{'10004'}++		;
        $srvcobjects_ref->{'host-redirect'}{'port'}{'icmp'}{'10005'}++		;
        $srvcobjects_ref->{'host-tos-redirect'}{'port'}{'icmp'}{'10006'}++		;
        $srvcobjects_ref->{'net-redirect'}{'port'}{'icmp'}{'10007'}++		;
        $srvcobjects_ref->{'net-tos-redirect'}{'port'}{'icmp'}{'10008'}++		;
        $srvcobjects_ref->{'precedence'}{'port'}{'icmp'}{'10009'}++			;
        $srvcobjects_ref->{'redirect'}{'port'}{'icmp'}{'10010'}++			;
        $srvcobjects_ref->{'reflect'}{'port'}{'icmp'}{'10011'}++			;
        $srvcobjects_ref->{'time-exceeded'}{'port'}{'icmp'}{'10012'}++		;
        $srvcobjects_ref->{'time-range'}{'port'}{'icmp'}{'10013'}++			;
        $srvcobjects_ref->{'tos'}{'port'}{'icmp'}{'10014'}++				;
        $srvcobjects_ref->{'unreachable'}{'port'}{'icmp'}{'10015'}++			;

        $srvcobjects_ref->{'icmp'}{'port'}{'icmp'}{'0-65353'}++		;
        $srvcobjects_ref->{'igmp'}{'port'}{'igmp'}{'18'}++		;
        $srvcobjects_ref->{'vrrp'}{'port'}{'vrrp'}{'2'}++		;
}

sub set_checkpoint_defaults {
	my ($srvcobjects_ref, $ports_ref) = @_;

# NOTE: Checkpoint Default UDP ports with non numeric port addresses that also have numeric versions later on that are used for matching in the log files

	$srvcobjects_ref->{'gFW1_sds_logon_NG'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gFW1_sds_logon_NG'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gFW1_sds_logon_NG'}{'port'}{'udp'} = 'gFW1_sds_logon_NG'	; 
	$srvcobjects_ref->{'gFW1_sds_logon_NG'}{'ports'}{'udp'}{'gFW1_sds_logon_NG'}++	; 
	$ports_ref->{'udp'}{'gFW1_sds_logon_NG'}{'name'} = 'gFW1_sds_logon_NG'		; 
	$srvcobjects_ref->{'gHackaTack_31788'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gHackaTack_31788'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gHackaTack_31788'}{'port'}{'udp'} = 'gHackaTack_31788'	; 
	$srvcobjects_ref->{'gHackaTack_31788'}{'ports'}{'udp'}{'gHackaTack_31788'}++	; 
	$ports_ref->{'udp'}{'gHackaTack_31788'}{'name'} = 'gHackaTack_31788'		; 
	$srvcobjects_ref->{'ghttps'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'ghttps'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'ghttps'}{'port'}{'udp'} = 'ghttps'	; 
	$srvcobjects_ref->{'ghttps'}{'ports'}{'udp'}{'ghttps'}++	; 
	$ports_ref->{'udp'}{'ghttps'}{'name'} = 'ghttps'		; 
	$srvcobjects_ref->{'gIKE_tcp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gIKE_tcp'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gIKE_tcp'}{'port'}{'udp'} = 'gIKE_tcp'	; 
	$srvcobjects_ref->{'gIKE_tcp'}{'ports'}{'udp'}{'gIKE_tcp'}++	; 
	$ports_ref->{'udp'}{'gIKE_tcp'}{'name'} = 'gIKE_tcp'		; 
	$srvcobjects_ref->{'gimap'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gimap'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gimap'}{'port'}{'udp'} = 'gimap'	; 
	$srvcobjects_ref->{'gimap'}{'ports'}{'udp'}{'gimap'}++	; 
	$ports_ref->{'udp'}{'gimap'}{'name'} = 'gimap'		; 
	$srvcobjects_ref->{'giMesh'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'giMesh'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'giMesh'}{'port'}{'udp'} = 'giMesh'	; 
	$srvcobjects_ref->{'giMesh'}{'ports'}{'udp'}{'giMesh'}++	; 
	$ports_ref->{'udp'}{'giMesh'}{'name'} = 'giMesh'		; 
	$srvcobjects_ref->{'gKerberos_v5_TCP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gKerberos_v5_TCP'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gKerberos_v5_TCP'}{'port'}{'udp'} = 'gKerberos_v5_TCP'	; 
	$srvcobjects_ref->{'gKerberos_v5_TCP'}{'ports'}{'udp'}{'gKerberos_v5_TCP'}++	; 
	$ports_ref->{'udp'}{'gKerberos_v5_TCP'}{'name'} = 'gKerberos_v5_TCP'		; 
	$srvcobjects_ref->{'gldap'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gldap'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gldap'}{'port'}{'udp'} = 'gldap'	; 
	$srvcobjects_ref->{'gldap'}{'ports'}{'udp'}{'gldap'}++	; 
	$ports_ref->{'udp'}{'gldap'}{'name'} = 'gldap'		; 
	$srvcobjects_ref->{'glogin'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'glogin'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'glogin'}{'port'}{'udp'} = 'glogin'	; 
	$srvcobjects_ref->{'glogin'}{'ports'}{'udp'}{'glogin'}++	; 
	$ports_ref->{'udp'}{'glogin'}{'name'} = 'glogin'		; 
	$srvcobjects_ref->{'glpdw0rm'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'glpdw0rm'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'glpdw0rm'}{'port'}{'udp'} = 'glpdw0rm'	; 
	$srvcobjects_ref->{'glpdw0rm'}{'ports'}{'udp'}{'glpdw0rm'}++	; 
	$ports_ref->{'udp'}{'glpdw0rm'}{'name'} = 'glpdw0rm'		; 
	$srvcobjects_ref->{'gMSN_Messenger_File_Transfer'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMSN_Messenger_File_Transfer'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gMSN_Messenger_File_Transfer'}{'port'}{'udp'} = 'gMSN_Messenger_File_Transfer'	; 
	$srvcobjects_ref->{'gMSN_Messenger_File_Transfer'}{'ports'}{'udp'}{'gMSN_Messenger_File_Transfer'}++	; 
	$ports_ref->{'udp'}{'gMSN_Messenger_File_Transfer'}{'name'} = 'gMSN_Messenger_File_Transfer'		; 
	$srvcobjects_ref->{'gMSNMS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMSNMS'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gMSNMS'}{'port'}{'udp'} = 'gMSNMS'	; 
	$srvcobjects_ref->{'gMSNMS'}{'ports'}{'udp'}{'gMSNMS'}++	; 
	$ports_ref->{'udp'}{'gMSNMS'}{'name'} = 'gMSNMS'		; 
	$srvcobjects_ref->{'gMSNP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMSNP'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gMSNP'}{'port'}{'udp'} = 'gMSNP'	; 
	$srvcobjects_ref->{'gMSNP'}{'ports'}{'udp'}{'gMSNP'}++	; 
	$ports_ref->{'udp'}{'gMSNP'}{'name'} = 'gMSNP'		; 
	$srvcobjects_ref->{'gnbsession'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gnbsession'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gnbsession'}{'port'}{'udp'} = 'gnbsession'	; 
	$srvcobjects_ref->{'gnbsession'}{'ports'}{'udp'}{'gnbsession'}++	; 
	$ports_ref->{'udp'}{'gnbsession'}{'name'} = 'gnbsession'		; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'port'}{'udp'} = 'Napster_directory_5555'	; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'ports'}{'udp'}{'Napster_directory_5555'}++	; 
	$ports_ref->{'udp'}{'Napster_directory_5555'}{'name'} = 'Napster_directory_5555'		; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'port'}{'udp'} = 'StoneBeat-Daemon'	; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'ports'}{'udp'}{'StoneBeat-Daemon'}++	; 
	$ports_ref->{'udp'}{'StoneBeat-Daemon'}{'name'} = 'StoneBeat-Daemon'		; 
	$srvcobjects_ref->{'T.120'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'T.120'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'T.120'}{'port'}{'udp'} = 'T.120'	; 
	$srvcobjects_ref->{'T.120'}{'ports'}{'udp'}{'T.120'}++	; 
	$ports_ref->{'udp'}{'T.120'}{'name'} = 'T.120'		; 
	$srvcobjects_ref->{'Terrortrojan'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Terrortrojan'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'Terrortrojan'}{'port'}{'udp'} = 'Terrortrojan'	; 
	$srvcobjects_ref->{'Terrortrojan'}{'ports'}{'udp'}{'Terrortrojan'}++	; 
	$ports_ref->{'udp'}{'Terrortrojan'}{'name'} = 'Terrortrojan'		; 

# NOTE: Checkpoint Default UDP ports with non numeric port addresses

	$srvcobjects_ref->{'archie'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'archie'}{'port'}{'udp'} = 'archie'	; 
	$srvcobjects_ref->{'archie'}{'ports'}{'udp'}{'archie'}++	; 
	$ports_ref->{'udp'}{'archie'}{'name'} = 'archie'		; 
	$srvcobjects_ref->{'biff'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'biff'}{'port'}{'udp'} = 'biff'	; 
	$srvcobjects_ref->{'biff'}{'ports'}{'udp'}{'biff'}++	; 
	$ports_ref->{'udp'}{'biff'}{'name'} = 'biff'		; 
	$srvcobjects_ref->{'Blubster'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Blubster'}{'port'}{'udp'} = 'Blubster'	; 
	$srvcobjects_ref->{'Blubster'}{'ports'}{'udp'}{'Blubster'}++	; 
	$ports_ref->{'udp'}{'Blubster'}{'name'} = 'Blubster'		; 
	$srvcobjects_ref->{'bootp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'bootp'}{'port'}{'udp'} = 'bootp'	; 
	$srvcobjects_ref->{'bootp'}{'ports'}{'udp'}{'bootp'}++	; 
	$ports_ref->{'udp'}{'bootp'}{'name'} = 'bootp'		; 
	$srvcobjects_ref->{'Citrix_ICA_Browsing'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Citrix_ICA_Browsing'}{'port'}{'udp'} = 'Citrix_ICA_Browsing'	; 
	$srvcobjects_ref->{'Citrix_ICA_Browsing'}{'ports'}{'udp'}{'Citrix_ICA_Browsing'}++	; 
	$ports_ref->{'udp'}{'Citrix_ICA_Browsing'}{'name'} = 'Citrix_ICA_Browsing'		; 
	$srvcobjects_ref->{'CP_SecureAgent-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'CP_SecureAgent-udp'}{'port'}{'udp'} = 'CP_SecureAgent-udp'	; 
	$srvcobjects_ref->{'CP_SecureAgent-udp'}{'ports'}{'udp'}{'CP_SecureAgent-udp'}++	; 
	$ports_ref->{'udp'}{'CP_SecureAgent-udp'}{'name'} = 'CP_SecureAgent-udp'		; 
	$srvcobjects_ref->{'CU-SeeMe'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'CU-SeeMe'}{'port'}{'udp'} = 'CU-SeeMe'	; 
	$srvcobjects_ref->{'CU-SeeMe'}{'ports'}{'udp'}{'CU-SeeMe'}++	; 
	$ports_ref->{'udp'}{'CU-SeeMe'}{'name'} = 'CU-SeeMe'		; 
	$srvcobjects_ref->{'daytime-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'daytime-udp'}{'port'}{'udp'} = 'daytime-udp'	; 
	$srvcobjects_ref->{'daytime-udp'}{'ports'}{'udp'}{'daytime-udp'}++	; 
	$ports_ref->{'udp'}{'daytime-udp'}{'name'} = 'daytime-udp'		; 
	$srvcobjects_ref->{'dhcp-relay'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'dhcp-relay'}{'port'}{'udp'} = 'dhcp-relay'	; 
	$srvcobjects_ref->{'dhcp-relay'}{'ports'}{'udp'}{'dhcp-relay'}++	; 
	$ports_ref->{'udp'}{'dhcp-relay'}{'name'} = 'dhcp-relay'		; 
	$srvcobjects_ref->{'dhcp-rep-localmodule'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'dhcp-rep-localmodule'}{'port'}{'udp'} = 'dhcp-rep-localmodule'	; 
	$srvcobjects_ref->{'dhcp-rep-localmodule'}{'ports'}{'udp'}{'dhcp-rep-localmodule'}++	; 
	$ports_ref->{'udp'}{'dhcp-rep-localmodule'}{'name'} = 'dhcp-rep-localmodule'		; 
	$srvcobjects_ref->{'dhcp-req-localmodule'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'dhcp-req-localmodule'}{'port'}{'udp'} = 'dhcp-req-localmodule'	; 
	$srvcobjects_ref->{'dhcp-req-localmodule'}{'ports'}{'udp'}{'dhcp-req-localmodule'}++	; 
	$ports_ref->{'udp'}{'dhcp-req-localmodule'}{'name'} = 'dhcp-req-localmodule'		; 
	$srvcobjects_ref->{'Direct_Connect_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Direct_Connect_UDP'}{'port'}{'udp'} = 'Direct_Connect_UDP'	; 
	$srvcobjects_ref->{'Direct_Connect_UDP'}{'ports'}{'udp'}{'Direct_Connect_UDP'}++	; 
	$ports_ref->{'udp'}{'Direct_Connect_UDP'}{'name'} = 'Direct_Connect_UDP'		; 
	$srvcobjects_ref->{'discard-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'discard-udp'}{'port'}{'udp'} = 'discard-udp'	; 
	$srvcobjects_ref->{'discard-udp'}{'ports'}{'udp'}{'discard-udp'}++	; 
	$ports_ref->{'udp'}{'discard-udp'}{'name'} = 'discard-udp'		; 
	$srvcobjects_ref->{'domain-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'domain-udp'}{'port'}{'udp'} = 'domain-udp'	; 
	$srvcobjects_ref->{'domain-udp'}{'ports'}{'udp'}{'domain-udp'}++	; 
	$ports_ref->{'udp'}{'domain-udp'}{'name'} = 'domain-udp'		; 
	$srvcobjects_ref->{'E2ECP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'E2ECP'}{'port'}{'udp'} = 'E2ECP'	; 
	$srvcobjects_ref->{'E2ECP'}{'ports'}{'udp'}{'E2ECP'}++	; 
	$ports_ref->{'udp'}{'E2ECP'}{'name'} = 'E2ECP'		; 
	$srvcobjects_ref->{'echo-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'echo-udp'}{'port'}{'udp'} = 'echo-udp'	; 
	$srvcobjects_ref->{'echo-udp'}{'ports'}{'udp'}{'echo-udp'}++	; 
	$ports_ref->{'udp'}{'echo-udp'}{'name'} = 'echo-udp'		; 
	$srvcobjects_ref->{'eDonkey_4665'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'eDonkey_4665'}{'port'}{'udp'} = 'eDonkey_4665'	; 
	$srvcobjects_ref->{'eDonkey_4665'}{'ports'}{'udp'}{'eDonkey_4665'}++	; 
	$ports_ref->{'udp'}{'eDonkey_4665'}{'name'} = 'eDonkey_4665'		; 
	$srvcobjects_ref->{'Revision'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Revision'}{'port'}{'udp'} = 'Revision'	; 
	$srvcobjects_ref->{'Revision'}{'ports'}{'udp'}{'Revision'}++	; 
	$ports_ref->{'udp'}{'Revision'}{'name'} = 'Revision'		; 
	$srvcobjects_ref->{'FreeTel-outgoing-server'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'FreeTel-outgoing-server'}{'port'}{'udp'} = 'FreeTel-outgoing-server'	; 
	$srvcobjects_ref->{'FreeTel-outgoing-server'}{'ports'}{'udp'}{'FreeTel-outgoing-server'}++	; 
	$ports_ref->{'udp'}{'FreeTel-outgoing-server'}{'name'} = 'FreeTel-outgoing-server'		; 
	$srvcobjects_ref->{'FW1_load_agent'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'FW1_load_agent'}{'port'}{'udp'} = 'FW1_load_agent'	; 
	$srvcobjects_ref->{'FW1_load_agent'}{'ports'}{'udp'}{'FW1_load_agent'}++	; 
	$ports_ref->{'udp'}{'FW1_load_agent'}{'name'} = 'FW1_load_agent'		; 
	$srvcobjects_ref->{'FW1_scv_keep_alive'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'FW1_scv_keep_alive'}{'port'}{'udp'} = 'FW1_scv_keep_alive'	; 
	$srvcobjects_ref->{'FW1_scv_keep_alive'}{'ports'}{'udp'}{'FW1_scv_keep_alive'}++	; 
	$ports_ref->{'udp'}{'FW1_scv_keep_alive'}{'name'} = 'FW1_scv_keep_alive'		; 
	$srvcobjects_ref->{'FW1_snmp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'FW1_snmp'}{'port'}{'udp'} = 'FW1_snmp'	; 
	$srvcobjects_ref->{'FW1_snmp'}{'ports'}{'udp'}{'FW1_snmp'}++	; 
	$ports_ref->{'udp'}{'FW1_snmp'}{'name'} = 'FW1_snmp'		; 
	$srvcobjects_ref->{'garchie'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'garchie'}{'port'}{'udp'} = 'garchie'	; 
	$srvcobjects_ref->{'garchie'}{'ports'}{'udp'}{'garchie'}++	; 
	$ports_ref->{'udp'}{'garchie'}{'name'} = 'garchie'		; 
	$srvcobjects_ref->{'gbiff'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gbiff'}{'port'}{'udp'} = 'gbiff'	; 
	$srvcobjects_ref->{'gbiff'}{'ports'}{'udp'}{'gbiff'}++	; 
	$ports_ref->{'udp'}{'gbiff'}{'name'} = 'gbiff'		; 
	$srvcobjects_ref->{'gBlubster'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gBlubster'}{'port'}{'udp'} = 'gBlubster'	; 
	$srvcobjects_ref->{'gBlubster'}{'ports'}{'udp'}{'gBlubster'}++	; 
	$ports_ref->{'udp'}{'gBlubster'}{'name'} = 'gBlubster'		; 
	$srvcobjects_ref->{'gbootp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gbootp'}{'port'}{'udp'} = 'gbootp'	; 
	$srvcobjects_ref->{'gbootp'}{'ports'}{'udp'}{'gbootp'}++	; 
	$ports_ref->{'udp'}{'gbootp'}{'name'} = 'gbootp'		; 
	$srvcobjects_ref->{'gCitrix_ICA_Browsing'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gCitrix_ICA_Browsing'}{'port'}{'udp'} = 'gCitrix_ICA_Browsing'	; 
	$srvcobjects_ref->{'gCitrix_ICA_Browsing'}{'ports'}{'udp'}{'gCitrix_ICA_Browsing'}++	; 
	$ports_ref->{'udp'}{'gCitrix_ICA_Browsing'}{'name'} = 'gCitrix_ICA_Browsing'		; 
	$srvcobjects_ref->{'gCP_SecureAgent-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gCP_SecureAgent-udp'}{'port'}{'udp'} = 'gCP_SecureAgent-udp'	; 
	$srvcobjects_ref->{'gCP_SecureAgent-udp'}{'ports'}{'udp'}{'gCP_SecureAgent-udp'}++	; 
	$ports_ref->{'udp'}{'gCP_SecureAgent-udp'}{'name'} = 'gCP_SecureAgent-udp'		; 
	$srvcobjects_ref->{'gCU-SeeMe'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gCU-SeeMe'}{'port'}{'udp'} = 'gCU-SeeMe'	; 
	$srvcobjects_ref->{'gCU-SeeMe'}{'ports'}{'udp'}{'gCU-SeeMe'}++	; 
	$ports_ref->{'udp'}{'gCU-SeeMe'}{'name'} = 'gCU-SeeMe'		; 
	$srvcobjects_ref->{'gdaytime-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gdaytime-udp'}{'port'}{'udp'} = 'gdaytime-udp'	; 
	$srvcobjects_ref->{'gdaytime-udp'}{'ports'}{'udp'}{'gdaytime-udp'}++	; 
	$ports_ref->{'udp'}{'gdaytime-udp'}{'name'} = 'gdaytime-udp'		; 
	$srvcobjects_ref->{'gdhcp-rep-localmodule'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gdhcp-rep-localmodule'}{'port'}{'udp'} = 'gdhcp-rep-localmodule'	; 
	$srvcobjects_ref->{'gdhcp-rep-localmodule'}{'ports'}{'udp'}{'gdhcp-rep-localmodule'}++	; 
	$ports_ref->{'udp'}{'gdhcp-rep-localmodule'}{'name'} = 'gdhcp-rep-localmodule'		; 
	$srvcobjects_ref->{'gdhcp-req-localmodule'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gdhcp-req-localmodule'}{'port'}{'udp'} = 'gdhcp-req-localmodule'	; 
	$srvcobjects_ref->{'gdhcp-req-localmodule'}{'ports'}{'udp'}{'gdhcp-req-localmodule'}++	; 
	$ports_ref->{'udp'}{'gdhcp-req-localmodule'}{'name'} = 'gdhcp-req-localmodule'		; 
	$srvcobjects_ref->{'gDirect_Connect_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gDirect_Connect_UDP'}{'port'}{'udp'} = 'gDirect_Connect_UDP'	; 
	$srvcobjects_ref->{'gDirect_Connect_UDP'}{'ports'}{'udp'}{'gDirect_Connect_UDP'}++	; 
	$ports_ref->{'udp'}{'gDirect_Connect_UDP'}{'name'} = 'gDirect_Connect_UDP'		; 
	$srvcobjects_ref->{'gdiscard-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gdiscard-udp'}{'port'}{'udp'} = 'gdiscard-udp'	; 
	$srvcobjects_ref->{'gdiscard-udp'}{'ports'}{'udp'}{'gdiscard-udp'}++	; 
	$ports_ref->{'udp'}{'gdiscard-udp'}{'name'} = 'gdiscard-udp'		; 
	$srvcobjects_ref->{'gdomain-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gdomain-udp'}{'port'}{'udp'} = 'gdomain-udp'	; 
	$srvcobjects_ref->{'gdomain-udp'}{'ports'}{'udp'}{'gdomain-udp'}++	; 
	$ports_ref->{'udp'}{'gdomain-udp'}{'name'} = 'gdomain-udp'		; 
	$srvcobjects_ref->{'gE2ECP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gE2ECP'}{'port'}{'udp'} = 'gE2ECP'	; 
	$srvcobjects_ref->{'gE2ECP'}{'ports'}{'udp'}{'gE2ECP'}++	; 
	$ports_ref->{'udp'}{'gE2ECP'}{'name'} = 'gE2ECP'		; 
	$srvcobjects_ref->{'gecho-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gecho-udp'}{'port'}{'udp'} = 'gecho-udp'	; 
	$srvcobjects_ref->{'gecho-udp'}{'ports'}{'udp'}{'gecho-udp'}++	; 
	$ports_ref->{'udp'}{'gecho-udp'}{'name'} = 'gecho-udp'		; 
	$srvcobjects_ref->{'geDonkey_4665'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'geDonkey_4665'}{'port'}{'udp'} = 'geDonkey_4665'	; 
	$srvcobjects_ref->{'geDonkey_4665'}{'ports'}{'udp'}{'geDonkey_4665'}++	; 
	$ports_ref->{'udp'}{'geDonkey_4665'}{'name'} = 'geDonkey_4665'		; 
	$srvcobjects_ref->{'gFreeTel-outgoing-server'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gFreeTel-outgoing-server'}{'port'}{'udp'} = 'gFreeTel-outgoing-server'	; 
	$srvcobjects_ref->{'gFreeTel-outgoing-server'}{'ports'}{'udp'}{'gFreeTel-outgoing-server'}++	; 
	$ports_ref->{'udp'}{'gFreeTel-outgoing-server'}{'name'} = 'gFreeTel-outgoing-server'		; 
	$srvcobjects_ref->{'gFW1_load_agent'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gFW1_load_agent'}{'port'}{'udp'} = 'gFW1_load_agent'	; 
	$srvcobjects_ref->{'gFW1_load_agent'}{'ports'}{'udp'}{'gFW1_load_agent'}++	; 
	$ports_ref->{'udp'}{'gFW1_load_agent'}{'name'} = 'gFW1_load_agent'		; 
	$srvcobjects_ref->{'gFW1_scv_keep_alive'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gFW1_scv_keep_alive'}{'port'}{'udp'} = 'gFW1_scv_keep_alive'	; 
	$srvcobjects_ref->{'gFW1_scv_keep_alive'}{'ports'}{'udp'}{'gFW1_scv_keep_alive'}++	; 
	$ports_ref->{'udp'}{'gFW1_scv_keep_alive'}{'name'} = 'gFW1_scv_keep_alive'		; 
	$srvcobjects_ref->{'gFW1_snmp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gFW1_snmp'}{'port'}{'udp'} = 'gFW1_snmp'	; 
	$srvcobjects_ref->{'gFW1_snmp'}{'ports'}{'udp'}{'gFW1_snmp'}++	; 
	$ports_ref->{'udp'}{'gFW1_snmp'}{'name'} = 'gFW1_snmp'		; 
	$srvcobjects_ref->{'gGNUtella_rtr_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gGNUtella_rtr_UDP'}{'port'}{'udp'} = 'gGNUtella_rtr_UDP'	; 
	$srvcobjects_ref->{'gGNUtella_rtr_UDP'}{'ports'}{'udp'}{'gGNUtella_rtr_UDP'}++	; 
	$ports_ref->{'udp'}{'gGNUtella_rtr_UDP'}{'name'} = 'gGNUtella_rtr_UDP'		; 
	$srvcobjects_ref->{'gGNUtella_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gGNUtella_UDP'}{'port'}{'udp'} = 'gGNUtella_UDP'	; 
	$srvcobjects_ref->{'gGNUtella_UDP'}{'ports'}{'udp'}{'gGNUtella_UDP'}++	; 
	$ports_ref->{'udp'}{'gGNUtella_UDP'}{'name'} = 'gGNUtella_UDP'		; 
	$srvcobjects_ref->{'gGTPv0'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gGTPv0'}{'port'}{'udp'} = 'gGTPv0'	; 
	$srvcobjects_ref->{'gGTPv0'}{'ports'}{'udp'}{'gGTPv0'}++	; 
	$ports_ref->{'udp'}{'gGTPv0'}{'name'} = 'gGTPv0'		; 
	$srvcobjects_ref->{'gGTPv1-C'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gGTPv1-C'}{'port'}{'udp'} = 'gGTPv1-C'	; 
	$srvcobjects_ref->{'gGTPv1-C'}{'ports'}{'udp'}{'gGTPv1-C'}++	; 
	$ports_ref->{'udp'}{'gGTPv1-C'}{'name'} = 'gGTPv1-C'		; 
	$srvcobjects_ref->{'gGTPv1-U'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gGTPv1-U'}{'port'}{'udp'} = 'gGTPv1-U'	; 
	$srvcobjects_ref->{'gGTPv1-U'}{'ports'}{'udp'}{'gGTPv1-U'}++	; 
	$ports_ref->{'udp'}{'gGTPv1-U'}{'name'} = 'gGTPv1-U'		; 
	$srvcobjects_ref->{'gH323_ras'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gH323_ras'}{'port'}{'udp'} = 'gH323_ras'	; 
	$srvcobjects_ref->{'gH323_ras'}{'ports'}{'udp'}{'gH323_ras'}++	; 
	$ports_ref->{'udp'}{'gH323_ras'}{'name'} = 'gH323_ras'		; 
	$srvcobjects_ref->{'gH323_ras_only'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gH323_ras_only'}{'port'}{'udp'} = 'gH323_ras_only'	; 
	$srvcobjects_ref->{'gH323_ras_only'}{'ports'}{'udp'}{'gH323_ras_only'}++	; 
	$ports_ref->{'udp'}{'gH323_ras_only'}{'name'} = 'gH323_ras_only'		; 
	$srvcobjects_ref->{'gHackaTack_31789'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gHackaTack_31789'}{'port'}{'udp'} = 'gHackaTack_31789'	; 
	$srvcobjects_ref->{'gHackaTack_31789'}{'ports'}{'udp'}{'gHackaTack_31789'}++	; 
	$ports_ref->{'udp'}{'gHackaTack_31789'}{'name'} = 'gHackaTack_31789'		; 
	$srvcobjects_ref->{'gHackaTack_31791'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gHackaTack_31791'}{'port'}{'udp'} = 'gHackaTack_31791'	; 
	$srvcobjects_ref->{'gHackaTack_31791'}{'ports'}{'udp'}{'gHackaTack_31791'}++	; 
	$ports_ref->{'udp'}{'gHackaTack_31791'}{'name'} = 'gHackaTack_31791'		; 
	$srvcobjects_ref->{'gHotline_tracker'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gHotline_tracker'}{'port'}{'udp'} = 'gHotline_tracker'	; 
	$srvcobjects_ref->{'gHotline_tracker'}{'ports'}{'udp'}{'gHotline_tracker'}++	; 
	$ports_ref->{'udp'}{'gHotline_tracker'}{'name'} = 'gHotline_tracker'		; 
	$srvcobjects_ref->{'gICQ_locator'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gICQ_locator'}{'port'}{'udp'} = 'gICQ_locator'	; 
	$srvcobjects_ref->{'gICQ_locator'}{'ports'}{'udp'}{'gICQ_locator'}++	; 
	$ports_ref->{'udp'}{'gICQ_locator'}{'name'} = 'gICQ_locator'		; 
	$srvcobjects_ref->{'gIKE'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gIKE'}{'port'}{'udp'} = 'gIKE'	; 
	$srvcobjects_ref->{'gIKE'}{'ports'}{'udp'}{'gIKE'}++	; 
	$ports_ref->{'udp'}{'gIKE'}{'name'} = 'gIKE'		; 
	$srvcobjects_ref->{'gIKE_NAT_TRAVERSAL'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gIKE_NAT_TRAVERSAL'}{'port'}{'udp'} = 'gIKE_NAT_TRAVERSAL'	; 
	$srvcobjects_ref->{'gIKE_NAT_TRAVERSAL'}{'ports'}{'udp'}{'gIKE_NAT_TRAVERSAL'}++	; 
	$ports_ref->{'udp'}{'gIKE_NAT_TRAVERSAL'}{'name'} = 'gIKE_NAT_TRAVERSAL'		; 
	$srvcobjects_ref->{'ginterphone'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'ginterphone'}{'port'}{'udp'} = 'ginterphone'	; 
	$srvcobjects_ref->{'ginterphone'}{'ports'}{'udp'}{'ginterphone'}++	; 
	$ports_ref->{'udp'}{'ginterphone'}{'name'} = 'ginterphone'		; 
	$srvcobjects_ref->{'gKerberos_v5_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gKerberos_v5_UDP'}{'port'}{'udp'} = 'gKerberos_v5_UDP'	; 
	$srvcobjects_ref->{'gKerberos_v5_UDP'}{'ports'}{'udp'}{'gKerberos_v5_UDP'}++	; 
	$ports_ref->{'udp'}{'gKerberos_v5_UDP'}{'name'} = 'gKerberos_v5_UDP'		; 
	$srvcobjects_ref->{'gkerberos-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gkerberos-udp'}{'port'}{'udp'} = 'gkerberos-udp'	; 
	$srvcobjects_ref->{'gkerberos-udp'}{'ports'}{'udp'}{'gkerberos-udp'}++	; 
	$ports_ref->{'udp'}{'gkerberos-udp'}{'name'} = 'gkerberos-udp'		; 
	$srvcobjects_ref->{'gL2TP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gL2TP'}{'port'}{'udp'} = 'gL2TP'	; 
	$srvcobjects_ref->{'gL2TP'}{'ports'}{'udp'}{'gL2TP'}++	; 
	$ports_ref->{'udp'}{'gL2TP'}{'name'} = 'gL2TP'		; 
	$srvcobjects_ref->{'gMetaIP-UAT'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMetaIP-UAT'}{'port'}{'udp'} = 'gMetaIP-UAT'	; 
	$srvcobjects_ref->{'gMetaIP-UAT'}{'ports'}{'udp'}{'gMetaIP-UAT'}++	; 
	$ports_ref->{'udp'}{'gMetaIP-UAT'}{'name'} = 'gMetaIP-UAT'		; 
	$srvcobjects_ref->{'gmgcp_CA'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gmgcp_CA'}{'port'}{'udp'} = 'gmgcp_CA'	; 
	$srvcobjects_ref->{'gmgcp_CA'}{'ports'}{'udp'}{'gmgcp_CA'}++	; 
	$ports_ref->{'udp'}{'gmgcp_CA'}{'name'} = 'gmgcp_CA'		; 
	$srvcobjects_ref->{'gmgcp_MG'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gmgcp_MG'}{'port'}{'udp'} = 'gmgcp_MG'	; 
	$srvcobjects_ref->{'gmgcp_MG'}{'ports'}{'udp'}{'gmgcp_MG'}++	; 
	$ports_ref->{'udp'}{'gmgcp_MG'}{'name'} = 'gmgcp_MG'		; 
	$srvcobjects_ref->{'gmicrosoft-ds-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gmicrosoft-ds-udp'}{'port'}{'udp'} = 'gmicrosoft-ds-udp'	; 
	$srvcobjects_ref->{'gmicrosoft-ds-udp'}{'ports'}{'udp'}{'gmicrosoft-ds-udp'}++	; 
	$ports_ref->{'udp'}{'gmicrosoft-ds-udp'}{'name'} = 'gmicrosoft-ds-udp'		; 
	$srvcobjects_ref->{'gMSN_Messenger_1863_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMSN_Messenger_1863_UDP'}{'port'}{'udp'} = 'gMSN_Messenger_1863_UDP'	; 
	$srvcobjects_ref->{'gMSN_Messenger_1863_UDP'}{'ports'}{'udp'}{'gMSN_Messenger_1863_UDP'}++	; 
	$ports_ref->{'udp'}{'gMSN_Messenger_1863_UDP'}{'name'} = 'gMSN_Messenger_1863_UDP'		; 
	$srvcobjects_ref->{'gMSN_Messenger_5190'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMSN_Messenger_5190'}{'port'}{'udp'} = 'gMSN_Messenger_5190'	; 
	$srvcobjects_ref->{'gMSN_Messenger_5190'}{'ports'}{'udp'}{'gMSN_Messenger_5190'}++	; 
	$ports_ref->{'udp'}{'gMSN_Messenger_5190'}{'name'} = 'gMSN_Messenger_5190'		; 
	$srvcobjects_ref->{'gMSN_Messenger_Voice'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMSN_Messenger_Voice'}{'port'}{'udp'} = 'gMSN_Messenger_Voice'	; 
	$srvcobjects_ref->{'gMSN_Messenger_Voice'}{'ports'}{'udp'}{'gMSN_Messenger_Voice'}++	; 
	$ports_ref->{'udp'}{'gMSN_Messenger_Voice'}{'name'} = 'gMSN_Messenger_Voice'		; 
	$srvcobjects_ref->{'gMSSQL_resolver'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMSSQL_resolver'}{'port'}{'udp'} = 'gMSSQL_resolver'	; 
	$srvcobjects_ref->{'gMSSQL_resolver'}{'ports'}{'udp'}{'gMSSQL_resolver'}++	; 
	$ports_ref->{'udp'}{'gMSSQL_resolver'}{'name'} = 'gMSSQL_resolver'		; 
	$srvcobjects_ref->{'gMS-SQL-Monitor_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMS-SQL-Monitor_UDP'}{'port'}{'udp'} = 'gMS-SQL-Monitor_UDP'	; 
	$srvcobjects_ref->{'gMS-SQL-Monitor_UDP'}{'ports'}{'udp'}{'gMS-SQL-Monitor_UDP'}++	; 
	$ports_ref->{'udp'}{'gMS-SQL-Monitor_UDP'}{'name'} = 'gMS-SQL-Monitor_UDP'		; 
	$srvcobjects_ref->{'gMS-SQL-Server_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gMS-SQL-Server_UDP'}{'port'}{'udp'} = 'gMS-SQL-Server_UDP'	; 
	$srvcobjects_ref->{'gMS-SQL-Server_UDP'}{'ports'}{'udp'}{'gMS-SQL-Server_UDP'}++	; 
	$ports_ref->{'udp'}{'gMS-SQL-Server_UDP'}{'name'} = 'gMS-SQL-Server_UDP'		; 
	$srvcobjects_ref->{'gname'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gname'}{'port'}{'udp'} = 'gname'	; 
	$srvcobjects_ref->{'gname'}{'ports'}{'udp'}{'gname'}++	; 
	$ports_ref->{'udp'}{'gname'}{'name'} = 'gname'		; 
	$srvcobjects_ref->{'gnbdatagram'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gnbdatagram'}{'port'}{'udp'} = 'gnbdatagram'	; 
	$srvcobjects_ref->{'gnbdatagram'}{'ports'}{'udp'}{'gnbdatagram'}++	; 
	$ports_ref->{'udp'}{'gnbdatagram'}{'name'} = 'gnbdatagram'		; 
	$srvcobjects_ref->{'gnbname'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gnbname'}{'port'}{'udp'} = 'gnbname'	; 
	$srvcobjects_ref->{'gnbname'}{'ports'}{'udp'}{'gnbname'}++	; 
	$ports_ref->{'udp'}{'gnbname'}{'name'} = 'gnbname'		; 
	$srvcobjects_ref->{'gNEW-RADIUS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gNEW-RADIUS'}{'port'}{'udp'} = 'gNEW-RADIUS'	; 
	$srvcobjects_ref->{'gNEW-RADIUS'}{'ports'}{'udp'}{'gNEW-RADIUS'}++	; 
	$ports_ref->{'udp'}{'gNEW-RADIUS'}{'name'} = 'gNEW-RADIUS'		; 
	$srvcobjects_ref->{'gNEW-RADIUS-ACCOUNTING'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gNEW-RADIUS-ACCOUNTING'}{'port'}{'udp'} = 'gNEW-RADIUS-ACCOUNTING'	; 
	$srvcobjects_ref->{'gNEW-RADIUS-ACCOUNTING'}{'ports'}{'udp'}{'gNEW-RADIUS-ACCOUNTING'}++	; 
	$ports_ref->{'udp'}{'gNEW-RADIUS-ACCOUNTING'}{'name'} = 'gNEW-RADIUS-ACCOUNTING'		; 
	$srvcobjects_ref->{'gnfsd'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gnfsd'}{'port'}{'udp'} = 'gnfsd'	; 
	$srvcobjects_ref->{'gnfsd'}{'ports'}{'udp'}{'gnfsd'}++	; 
	$ports_ref->{'udp'}{'gnfsd'}{'name'} = 'gnfsd'		; 
	$srvcobjects_ref->{'gNoBackO'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gNoBackO'}{'port'}{'udp'} = 'gNoBackO'	; 
	$srvcobjects_ref->{'gNoBackO'}{'ports'}{'udp'}{'gNoBackO'}++	; 
	$ports_ref->{'udp'}{'gNoBackO'}{'name'} = 'gNoBackO'		; 
	$srvcobjects_ref->{'gntp-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gntp-udp'}{'port'}{'udp'} = 'gntp-udp'	; 
	$srvcobjects_ref->{'gntp-udp'}{'ports'}{'udp'}{'gntp-udp'}++	; 
	$ports_ref->{'udp'}{'gntp-udp'}{'name'} = 'gntp-udp'		; 
	$srvcobjects_ref->{'gpcANYWHERE-stat'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gpcANYWHERE-stat'}{'port'}{'udp'} = 'gpcANYWHERE-stat'	; 
	$srvcobjects_ref->{'gpcANYWHERE-stat'}{'ports'}{'udp'}{'gpcANYWHERE-stat'}++	; 
	$ports_ref->{'udp'}{'gpcANYWHERE-stat'}{'name'} = 'gpcANYWHERE-stat'		; 
	$srvcobjects_ref->{'gRADIUS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRADIUS'}{'port'}{'udp'} = 'gRADIUS'	; 
	$srvcobjects_ref->{'gRADIUS'}{'ports'}{'udp'}{'gRADIUS'}++	; 
	$ports_ref->{'udp'}{'gRADIUS'}{'name'} = 'gRADIUS'		; 
	$srvcobjects_ref->{'gRADIUS-ACCOUNTING'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRADIUS-ACCOUNTING'}{'port'}{'udp'} = 'gRADIUS-ACCOUNTING'	; 
	$srvcobjects_ref->{'gRADIUS-ACCOUNTING'}{'ports'}{'udp'}{'gRADIUS-ACCOUNTING'}++	; 
	$ports_ref->{'udp'}{'gRADIUS-ACCOUNTING'}{'name'} = 'gRADIUS-ACCOUNTING'		; 
	$srvcobjects_ref->{'gRainWall_Daemon'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRainWall_Daemon'}{'port'}{'udp'} = 'gRainWall_Daemon'	; 
	$srvcobjects_ref->{'gRainWall_Daemon'}{'ports'}{'udp'}{'gRainWall_Daemon'}++	; 
	$ports_ref->{'udp'}{'gRainWall_Daemon'}{'name'} = 'gRainWall_Daemon'		; 
	$srvcobjects_ref->{'gRainWall_Status'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRainWall_Status'}{'port'}{'udp'} = 'gRainWall_Status'	; 
	$srvcobjects_ref->{'gRainWall_Status'}{'ports'}{'udp'}{'gRainWall_Status'}++	; 
	$ports_ref->{'udp'}{'gRainWall_Status'}{'name'} = 'gRainWall_Status'		; 
	$srvcobjects_ref->{'gRainWall_Stop'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRainWall_Stop'}{'port'}{'udp'} = 'gRainWall_Stop'	; 
	$srvcobjects_ref->{'gRainWall_Stop'}{'ports'}{'udp'}{'gRainWall_Stop'}++	; 
	$ports_ref->{'udp'}{'gRainWall_Stop'}{'name'} = 'gRainWall_Stop'		; 
	$srvcobjects_ref->{'gRDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRDP'}{'port'}{'udp'} = 'gRDP'	; 
	$srvcobjects_ref->{'gRDP'}{'ports'}{'udp'}{'gRDP'}++	; 
	$ports_ref->{'udp'}{'gRDP'}{'name'} = 'gRDP'		; 
	$srvcobjects_ref->{'gRexxRave'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRexxRave'}{'port'}{'udp'} = 'gRexxRave'	; 
	$srvcobjects_ref->{'gRexxRave'}{'ports'}{'udp'}{'gRexxRave'}++	; 
	$ports_ref->{'udp'}{'gRexxRave'}{'name'} = 'gRexxRave'		; 
	$srvcobjects_ref->{'grip'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'grip'}{'port'}{'udp'} = 'grip'	; 
	$srvcobjects_ref->{'grip'}{'ports'}{'udp'}{'grip'}++	; 
	$ports_ref->{'udp'}{'grip'}{'name'} = 'grip'		; 
	$srvcobjects_ref->{'gRIPng'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gRIPng'}{'port'}{'udp'} = 'gRIPng'	; 
	$srvcobjects_ref->{'gRIPng'}{'ports'}{'udp'}{'gRIPng'}++	; 
	$ports_ref->{'udp'}{'gRIPng'}{'name'} = 'gRIPng'		; 
	$srvcobjects_ref->{'gsecurid-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gsecurid-udp'}{'port'}{'udp'} = 'gsecurid-udp'	; 
	$srvcobjects_ref->{'gsecurid-udp'}{'ports'}{'udp'}{'gsecurid-udp'}++	; 
	$ports_ref->{'udp'}{'gsecurid-udp'}{'name'} = 'gsecurid-udp'		; 
	$srvcobjects_ref->{'gsip'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gsip'}{'port'}{'udp'} = 'gsip'	; 
	$srvcobjects_ref->{'gsip'}{'ports'}{'udp'}{'gsip'}++	; 
	$ports_ref->{'udp'}{'gsip'}{'name'} = 'gsip'		; 
	$srvcobjects_ref->{'gsip_any'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gsip_any'}{'port'}{'udp'} = 'gsip_any'	; 
	$srvcobjects_ref->{'gsip_any'}{'ports'}{'udp'}{'gsip_any'}++	; 
	$ports_ref->{'udp'}{'gsip_any'}{'name'} = 'gsip_any'		; 
	$srvcobjects_ref->{'gsnmp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gsnmp'}{'port'}{'udp'} = 'gsnmp'	; 
	$srvcobjects_ref->{'gsnmp'}{'ports'}{'udp'}{'gsnmp'}++	; 
	$ports_ref->{'udp'}{'gsnmp'}{'name'} = 'gsnmp'		; 
	$srvcobjects_ref->{'gsnmp-read'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gsnmp-read'}{'port'}{'udp'} = 'gsnmp-read'	; 
	$srvcobjects_ref->{'gsnmp-read'}{'ports'}{'udp'}{'gsnmp-read'}++	; 
	$ports_ref->{'udp'}{'gsnmp-read'}{'name'} = 'gsnmp-read'		; 
	$srvcobjects_ref->{'gsnmp-trap'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gsnmp-trap'}{'port'}{'udp'} = 'gsnmp-trap'	; 
	$srvcobjects_ref->{'gsnmp-trap'}{'ports'}{'udp'}{'gsnmp-trap'}++	; 
	$ports_ref->{'udp'}{'gsnmp-trap'}{'name'} = 'gsnmp-trap'		; 
	$srvcobjects_ref->{'gSWTP_Gateway'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gSWTP_Gateway'}{'port'}{'udp'} = 'gSWTP_Gateway'	; 
	$srvcobjects_ref->{'gSWTP_Gateway'}{'ports'}{'udp'}{'gSWTP_Gateway'}++	; 
	$ports_ref->{'udp'}{'gSWTP_Gateway'}{'name'} = 'gSWTP_Gateway'		; 
	$srvcobjects_ref->{'gSWTP_SMS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gSWTP_SMS'}{'port'}{'udp'} = 'gSWTP_SMS'	; 
	$srvcobjects_ref->{'gSWTP_SMS'}{'ports'}{'udp'}{'gSWTP_SMS'}++	; 
	$ports_ref->{'udp'}{'gSWTP_SMS'}{'name'} = 'gSWTP_SMS'		; 
	$srvcobjects_ref->{'gsyslog'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gsyslog'}{'port'}{'udp'} = 'gsyslog'	; 
	$srvcobjects_ref->{'gsyslog'}{'ports'}{'udp'}{'gsyslog'}++	; 
	$ports_ref->{'udp'}{'gsyslog'}{'name'} = 'gsyslog'		; 
	$srvcobjects_ref->{'gTACACS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gTACACS'}{'port'}{'udp'} = 'gTACACS'	; 
	$srvcobjects_ref->{'gTACACS'}{'ports'}{'udp'}{'gTACACS'}++	; 
	$ports_ref->{'udp'}{'gTACACS'}{'name'} = 'gTACACS'		; 
	$srvcobjects_ref->{'gtftp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gtftp'}{'port'}{'udp'} = 'gtftp'	; 
	$srvcobjects_ref->{'gtftp'}{'ports'}{'udp'}{'gtftp'}++	; 
	$ports_ref->{'udp'}{'gtftp'}{'name'} = 'gtftp'		; 
	$srvcobjects_ref->{'gtime-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gtime-udp'}{'port'}{'udp'} = 'gtime-udp'	; 
	$srvcobjects_ref->{'gtime-udp'}{'ports'}{'udp'}{'gtime-udp'}++	; 
	$ports_ref->{'udp'}{'gtime-udp'}{'name'} = 'gtime-udp'		; 
	$srvcobjects_ref->{'gtunnel_test'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gtunnel_test'}{'port'}{'udp'} = 'gtunnel_test'	; 
	$srvcobjects_ref->{'gtunnel_test'}{'ports'}{'udp'}{'gtunnel_test'}++	; 
	$ports_ref->{'udp'}{'gtunnel_test'}{'name'} = 'gtunnel_test'		; 
	$srvcobjects_ref->{'gudp-high-ports'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gudp-high-ports'}{'port'}{'udp'} = 'gudp-high-ports'	; 
	$srvcobjects_ref->{'gudp-high-ports'}{'ports'}{'udp'}{'gudp-high-ports'}++	; 
	$ports_ref->{'udp'}{'gudp-high-ports'}{'name'} = 'gudp-high-ports'		; 
	$srvcobjects_ref->{'udp-high-ports'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'udp-high-ports'}{'port'}{'udp'} = 'udp-high-ports'	; 
	$srvcobjects_ref->{'udp-high-ports'}{'ports'}{'udp'}{'udp-high-ports'}++	; 
	$ports_ref->{'udp'}{'udp-high-ports'}{'name'} = 'udp-high-ports'		; 
	$srvcobjects_ref->{'gVPN1_IPSEC_encapsulation'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gVPN1_IPSEC_encapsulation'}{'port'}{'udp'} = 'gVPN1_IPSEC_encapsulation'	; 
	$srvcobjects_ref->{'gVPN1_IPSEC_encapsulation'}{'ports'}{'udp'}{'gVPN1_IPSEC_encapsulation'}++	; 
	$ports_ref->{'udp'}{'gVPN1_IPSEC_encapsulation'}{'name'} = 'gVPN1_IPSEC_encapsulation'		; 
	$srvcobjects_ref->{'gwap_wdp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gwap_wdp'}{'port'}{'udp'} = 'gwap_wdp'	; 
	$srvcobjects_ref->{'gwap_wdp'}{'ports'}{'udp'}{'gwap_wdp'}++	; 
	$ports_ref->{'udp'}{'gwap_wdp'}{'name'} = 'gwap_wdp'		; 
	$srvcobjects_ref->{'gwap_wdp_enc'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gwap_wdp_enc'}{'port'}{'udp'} = 'gwap_wdp_enc'	; 
	$srvcobjects_ref->{'gwap_wdp_enc'}{'ports'}{'udp'}{'gwap_wdp_enc'}++	; 
	$ports_ref->{'udp'}{'gwap_wdp_enc'}{'name'} = 'gwap_wdp_enc'		; 
	$srvcobjects_ref->{'gwap_wtp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gwap_wtp'}{'port'}{'udp'} = 'gwap_wtp'	; 
	$srvcobjects_ref->{'gwap_wtp'}{'ports'}{'udp'}{'gwap_wtp'}++	; 
	$ports_ref->{'udp'}{'gwap_wtp'}{'name'} = 'gwap_wtp'		; 
	$srvcobjects_ref->{'gwap_wtp_enc'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gwap_wtp_enc'}{'port'}{'udp'} = 'gwap_wtp_enc'	; 
	$srvcobjects_ref->{'gwap_wtp_enc'}{'ports'}{'udp'}{'gwap_wtp_enc'}++	; 
	$ports_ref->{'udp'}{'gwap_wtp_enc'}{'name'} = 'gwap_wtp_enc'		; 
	$srvcobjects_ref->{'gwho'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gwho'}{'port'}{'udp'} = 'gwho'	; 
	$srvcobjects_ref->{'gwho'}{'ports'}{'udp'}{'gwho'}++	; 
	$ports_ref->{'udp'}{'gwho'}{'name'} = 'gwho'		; 
	$srvcobjects_ref->{'gWinMX'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gWinMX'}{'port'}{'udp'} = 'gWinMX'	; 
	$srvcobjects_ref->{'gWinMX'}{'ports'}{'udp'}{'gWinMX'}++	; 
	$ports_ref->{'udp'}{'gWinMX'}{'name'} = 'gWinMX'		; 
	$srvcobjects_ref->{'gYahoo_Messenger_Voice_Chat_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_Voice_Chat_UDP'}{'port'}{'udp'} = 'gYahoo_Messenger_Voice_Chat_UDP'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_Voice_Chat_UDP'}{'ports'}{'udp'}{'gYahoo_Messenger_Voice_Chat_UDP'}++	; 
	$ports_ref->{'udp'}{'gYahoo_Messenger_Voice_Chat_UDP'}{'name'} = 'gYahoo_Messenger_Voice_Chat_UDP'		; 
	$srvcobjects_ref->{'GNUtella_rtr_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'GNUtella_rtr_UDP'}{'port'}{'udp'} = 'GNUtella_rtr_UDP'	; 
	$srvcobjects_ref->{'GNUtella_rtr_UDP'}{'ports'}{'udp'}{'GNUtella_rtr_UDP'}++	; 
	$ports_ref->{'udp'}{'GNUtella_rtr_UDP'}{'name'} = 'GNUtella_rtr_UDP'		; 
	$srvcobjects_ref->{'GNUtella_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'GNUtella_UDP'}{'port'}{'udp'} = 'GNUtella_UDP'	; 
	$srvcobjects_ref->{'GNUtella_UDP'}{'ports'}{'udp'}{'GNUtella_UDP'}++	; 
	$ports_ref->{'udp'}{'GNUtella_UDP'}{'name'} = 'GNUtella_UDP'		; 
	$srvcobjects_ref->{'GTPv0'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'GTPv0'}{'port'}{'udp'} = 'GTPv0'	; 
	$srvcobjects_ref->{'GTPv0'}{'ports'}{'udp'}{'GTPv0'}++	; 
	$ports_ref->{'udp'}{'GTPv0'}{'name'} = 'GTPv0'		; 
	$srvcobjects_ref->{'GTPv1-C'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'GTPv1-C'}{'port'}{'udp'} = 'GTPv1-C'	; 
	$srvcobjects_ref->{'GTPv1-C'}{'ports'}{'udp'}{'GTPv1-C'}++	; 
	$ports_ref->{'udp'}{'GTPv1-C'}{'name'} = 'GTPv1-C'		; 
	$srvcobjects_ref->{'GTPv1-U'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'GTPv1-U'}{'port'}{'udp'} = 'GTPv1-U'	; 
	$srvcobjects_ref->{'GTPv1-U'}{'ports'}{'udp'}{'GTPv1-U'}++	; 
	$ports_ref->{'udp'}{'GTPv1-U'}{'name'} = 'GTPv1-U'		; 
	$srvcobjects_ref->{'H323_ras'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'H323_ras'}{'port'}{'udp'} = 'H323_ras'	; 
	$srvcobjects_ref->{'H323_ras'}{'ports'}{'udp'}{'H323_ras'}++	; 
	$ports_ref->{'udp'}{'H323_ras'}{'name'} = 'H323_ras'		; 
	$srvcobjects_ref->{'H323_ras_only'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'H323_ras_only'}{'port'}{'udp'} = 'H323_ras_only'	; 
	$srvcobjects_ref->{'H323_ras_only'}{'ports'}{'udp'}{'H323_ras_only'}++	; 
	$ports_ref->{'udp'}{'H323_ras_only'}{'name'} = 'H323_ras_only'		; 
	$srvcobjects_ref->{'HackaTack_31789'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'HackaTack_31789'}{'port'}{'udp'} = 'HackaTack_31789'	; 
	$srvcobjects_ref->{'HackaTack_31789'}{'ports'}{'udp'}{'HackaTack_31789'}++	; 
	$ports_ref->{'udp'}{'HackaTack_31789'}{'name'} = 'HackaTack_31789'		; 
	$srvcobjects_ref->{'HackaTack_31791'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'HackaTack_31791'}{'port'}{'udp'} = 'HackaTack_31791'	; 
	$srvcobjects_ref->{'HackaTack_31791'}{'ports'}{'udp'}{'HackaTack_31791'}++	; 
	$ports_ref->{'udp'}{'HackaTack_31791'}{'name'} = 'HackaTack_31791'		; 
	$srvcobjects_ref->{'Hotline_tracker'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Hotline_tracker'}{'port'}{'udp'} = 'Hotline_tracker'	; 
	$srvcobjects_ref->{'Hotline_tracker'}{'ports'}{'udp'}{'Hotline_tracker'}++	; 
	$ports_ref->{'udp'}{'Hotline_tracker'}{'name'} = 'Hotline_tracker'		; 
	$srvcobjects_ref->{'ICQ_locator'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'ICQ_locator'}{'port'}{'udp'} = 'ICQ_locator'	; 
	$srvcobjects_ref->{'ICQ_locator'}{'ports'}{'udp'}{'ICQ_locator'}++	; 
	$ports_ref->{'udp'}{'ICQ_locator'}{'name'} = 'ICQ_locator'		; 
	$srvcobjects_ref->{'Revision'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Revision'}{'port'}{'udp'} = 'Revision'	; 
	$srvcobjects_ref->{'Revision'}{'ports'}{'udp'}{'Revision'}++	; 
	$ports_ref->{'udp'}{'Revision'}{'name'} = 'Revision'		; 
	$srvcobjects_ref->{'IKE'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'IKE'}{'port'}{'udp'} = 'IKE'	; 
	$srvcobjects_ref->{'IKE'}{'ports'}{'udp'}{'IKE'}++	; 
	$ports_ref->{'udp'}{'IKE'}{'name'} = 'IKE'		; 
	$srvcobjects_ref->{'IKE_NAT_TRAVERSAL'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'IKE_NAT_TRAVERSAL'}{'port'}{'udp'} = 'IKE_NAT_TRAVERSAL'	; 
	$srvcobjects_ref->{'IKE_NAT_TRAVERSAL'}{'ports'}{'udp'}{'IKE_NAT_TRAVERSAL'}++	; 
	$ports_ref->{'udp'}{'IKE_NAT_TRAVERSAL'}{'name'} = 'IKE_NAT_TRAVERSAL'		; 
	$srvcobjects_ref->{'interphone'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'interphone'}{'port'}{'udp'} = 'interphone'	; 
	$srvcobjects_ref->{'interphone'}{'ports'}{'udp'}{'interphone'}++	; 
	$ports_ref->{'udp'}{'interphone'}{'name'} = 'interphone'		; 
	$srvcobjects_ref->{'Kerberos_v5_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Kerberos_v5_UDP'}{'port'}{'udp'} = 'Kerberos_v5_UDP'	; 
	$srvcobjects_ref->{'Kerberos_v5_UDP'}{'ports'}{'udp'}{'Kerberos_v5_UDP'}++	; 
	$ports_ref->{'udp'}{'Kerberos_v5_UDP'}{'name'} = 'Kerberos_v5_UDP'		; 
	$srvcobjects_ref->{'kerberos-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'kerberos-udp'}{'port'}{'udp'} = 'kerberos-udp'	; 
	$srvcobjects_ref->{'kerberos-udp'}{'ports'}{'udp'}{'kerberos-udp'}++	; 
	$ports_ref->{'udp'}{'kerberos-udp'}{'name'} = 'kerberos-udp'		; 
	$srvcobjects_ref->{'L2TP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'L2TP'}{'port'}{'udp'} = 'L2TP'	; 
	$srvcobjects_ref->{'L2TP'}{'ports'}{'udp'}{'L2TP'}++	; 
	$ports_ref->{'udp'}{'L2TP'}{'name'} = 'L2TP'		; 
	$srvcobjects_ref->{'MetaIP-UAT'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'MetaIP-UAT'}{'port'}{'udp'} = 'MetaIP-UAT'	; 
	$srvcobjects_ref->{'MetaIP-UAT'}{'ports'}{'udp'}{'MetaIP-UAT'}++	; 
	$ports_ref->{'udp'}{'MetaIP-UAT'}{'name'} = 'MetaIP-UAT'		; 
	$srvcobjects_ref->{'mgcp_MG'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'mgcp_MG'}{'port'}{'udp'} = 'mgcp_MG'	; 
	$srvcobjects_ref->{'mgcp_MG'}{'ports'}{'udp'}{'mgcp_MG'}++	; 
	$ports_ref->{'udp'}{'mgcp_MG'}{'name'} = 'mgcp_MG'		; 
	$srvcobjects_ref->{'mgcp_CA'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'mgcp_CA'}{'port'}{'udp'} = 'mgcp_CA'	; 
	$srvcobjects_ref->{'mgcp_CA'}{'ports'}{'udp'}{'mgcp_CA'}++	; 
	$ports_ref->{'udp'}{'mgcp_CA'}{'name'} = 'mgcp_CA'		; 
	$srvcobjects_ref->{'microsoft-ds-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'microsoft-ds-udp'}{'port'}{'udp'} = 'microsoft-ds-udp'	; 
	$srvcobjects_ref->{'microsoft-ds-udp'}{'ports'}{'udp'}{'microsoft-ds-udp'}++	; 
	$ports_ref->{'udp'}{'microsoft-ds-udp'}{'name'} = 'microsoft-ds-udp'		; 
	$srvcobjects_ref->{'MSN_Messenger_1863_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'MSN_Messenger_1863_UDP'}{'port'}{'udp'} = 'MSN_Messenger_1863_UDP'	; 
	$srvcobjects_ref->{'MSN_Messenger_1863_UDP'}{'ports'}{'udp'}{'MSN_Messenger_1863_UDP'}++	; 
	$ports_ref->{'udp'}{'MSN_Messenger_1863_UDP'}{'name'} = 'MSN_Messenger_1863_UDP'		; 
	$srvcobjects_ref->{'MSN_Messenger_5190'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'MSN_Messenger_5190'}{'port'}{'udp'} = 'MSN_Messenger_5190'	; 
	$srvcobjects_ref->{'MSN_Messenger_5190'}{'ports'}{'udp'}{'MSN_Messenger_5190'}++	; 
	$ports_ref->{'udp'}{'MSN_Messenger_5190'}{'name'} = 'MSN_Messenger_5190'		; 
	$srvcobjects_ref->{'MSN_Messenger_Voice'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'MSN_Messenger_Voice'}{'port'}{'udp'} = 'MSN_Messenger_Voice'	; 
	$srvcobjects_ref->{'MSN_Messenger_Voice'}{'ports'}{'udp'}{'MSN_Messenger_Voice'}++	; 
	$ports_ref->{'udp'}{'MSN_Messenger_Voice'}{'name'} = 'MSN_Messenger_Voice'		; 
	$srvcobjects_ref->{'MSSQL_resolver'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'MSSQL_resolver'}{'port'}{'udp'} = 'MSSQL_resolver'	; 
	$srvcobjects_ref->{'MSSQL_resolver'}{'ports'}{'udp'}{'MSSQL_resolver'}++	; 
	$ports_ref->{'udp'}{'MSSQL_resolver'}{'name'} = 'MSSQL_resolver'		; 
	$srvcobjects_ref->{'MS-SQL-Monitor_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor_UDP'}{'port'}{'udp'} = 'MS-SQL-Monitor_UDP'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor_UDP'}{'ports'}{'udp'}{'MS-SQL-Monitor_UDP'}++	; 
	$ports_ref->{'udp'}{'MS-SQL-Monitor_UDP'}{'name'} = 'MS-SQL-Monitor_UDP'		; 
	$srvcobjects_ref->{'MS-SQL-Server_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'MS-SQL-Server_UDP'}{'port'}{'udp'} = 'MS-SQL-Server_UDP'	; 
	$srvcobjects_ref->{'MS-SQL-Server_UDP'}{'ports'}{'udp'}{'MS-SQL-Server_UDP'}++	; 
	$ports_ref->{'udp'}{'MS-SQL-Server_UDP'}{'name'} = 'MS-SQL-Server_UDP'		; 
	$srvcobjects_ref->{'nbdatagram'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'nbdatagram'}{'port'}{'udp'} = 'nbdatagram'	; 
	$srvcobjects_ref->{'nbdatagram'}{'ports'}{'udp'}{'nbdatagram'}++	; 
	$ports_ref->{'udp'}{'nbdatagram'}{'name'} = 'nbdatagram'		; 
	$srvcobjects_ref->{'nbname'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'nbname'}{'port'}{'udp'} = 'nbname'	; 
	$srvcobjects_ref->{'nbname'}{'ports'}{'udp'}{'nbname'}++	; 
	$ports_ref->{'udp'}{'nbname'}{'name'} = 'nbname'		; 
	$srvcobjects_ref->{'NEW-RADIUS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'NEW-RADIUS'}{'port'}{'udp'} = 'NEW-RADIUS'	; 
	$srvcobjects_ref->{'NEW-RADIUS'}{'ports'}{'udp'}{'NEW-RADIUS'}++	; 
	$ports_ref->{'udp'}{'NEW-RADIUS'}{'name'} = 'NEW-RADIUS'		; 
	$srvcobjects_ref->{'NEW-RADIUS-ACCOUNTING'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'NEW-RADIUS-ACCOUNTING'}{'port'}{'udp'} = 'NEW-RADIUS-ACCOUNTING'	; 
	$srvcobjects_ref->{'NEW-RADIUS-ACCOUNTING'}{'ports'}{'udp'}{'NEW-RADIUS-ACCOUNTING'}++	; 
	$ports_ref->{'udp'}{'NEW-RADIUS-ACCOUNTING'}{'name'} = 'NEW-RADIUS-ACCOUNTING'		; 
	$srvcobjects_ref->{'NoBackO'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'NoBackO'}{'port'}{'udp'} = 'NoBackO'	; 
	$srvcobjects_ref->{'NoBackO'}{'ports'}{'udp'}{'NoBackO'}++	; 
	$ports_ref->{'udp'}{'NoBackO'}{'name'} = 'NoBackO'		; 
	$srvcobjects_ref->{'ntp-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'ntp-udp'}{'port'}{'udp'} = 'ntp-udp'	; 
	$srvcobjects_ref->{'ntp-udp'}{'ports'}{'udp'}{'ntp-udp'}++	; 
	$ports_ref->{'udp'}{'ntp-udp'}{'name'} = 'ntp-udp'		; 
	$srvcobjects_ref->{'RADIUS-ACCOUNTING'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RADIUS-ACCOUNTING'}{'port'}{'udp'} = 'RADIUS-ACCOUNTING'	; 
	$srvcobjects_ref->{'RADIUS-ACCOUNTING'}{'ports'}{'udp'}{'RADIUS-ACCOUNTING'}++	; 
	$ports_ref->{'udp'}{'RADIUS-ACCOUNTING'}{'name'} = 'RADIUS-ACCOUNTING'		; 
	$srvcobjects_ref->{'RainWall_Daemon'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RainWall_Daemon'}{'port'}{'udp'} = 'RainWall_Daemon'	; 
	$srvcobjects_ref->{'RainWall_Daemon'}{'ports'}{'udp'}{'RainWall_Daemon'}++	; 
	$ports_ref->{'udp'}{'RainWall_Daemon'}{'name'} = 'RainWall_Daemon'		; 
	$srvcobjects_ref->{'RainWall_Status'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RainWall_Status'}{'port'}{'udp'} = 'RainWall_Status'	; 
	$srvcobjects_ref->{'RainWall_Status'}{'ports'}{'udp'}{'RainWall_Status'}++	; 
	$ports_ref->{'udp'}{'RainWall_Status'}{'name'} = 'RainWall_Status'		; 
	$srvcobjects_ref->{'RainWall_Stop'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RainWall_Stop'}{'port'}{'udp'} = 'RainWall_Stop'	; 
	$srvcobjects_ref->{'RainWall_Stop'}{'ports'}{'udp'}{'RainWall_Stop'}++	; 
	$ports_ref->{'udp'}{'RainWall_Stop'}{'name'} = 'RainWall_Stop'		; 
	$srvcobjects_ref->{'RDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RDP'}{'port'}{'udp'} = 'RDP'	; 
	$srvcobjects_ref->{'RDP'}{'ports'}{'udp'}{'RDP'}++	; 
	$ports_ref->{'udp'}{'RDP'}{'name'} = 'RDP'		; 
	$srvcobjects_ref->{'RexxRave'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RexxRave'}{'port'}{'udp'} = 'RexxRave'	; 
	$srvcobjects_ref->{'RexxRave'}{'ports'}{'udp'}{'RexxRave'}++	; 
	$ports_ref->{'udp'}{'RexxRave'}{'name'} = 'RexxRave'		; 
	$srvcobjects_ref->{'rip'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'rip'}{'port'}{'udp'} = 'rip'	; 
	$srvcobjects_ref->{'rip'}{'ports'}{'udp'}{'rip'}++	; 
	$ports_ref->{'udp'}{'rip'}{'name'} = 'rip'		; 
	$srvcobjects_ref->{'securid-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'securid-udp'}{'port'}{'udp'} = 'securid-udp'	; 
	$srvcobjects_ref->{'securid-udp'}{'ports'}{'udp'}{'securid-udp'}++	; 
	$ports_ref->{'udp'}{'securid-udp'}{'name'} = 'securid-udp'		; 
	$srvcobjects_ref->{'sip_any'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'sip_any'}{'port'}{'udp'} = 'sip_any'	; 
	$srvcobjects_ref->{'sip_any'}{'ports'}{'udp'}{'sip_any'}++	; 
	$ports_ref->{'udp'}{'sip_any'}{'name'} = 'sip_any'		; 
	$srvcobjects_ref->{'snmp-read'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'snmp-read'}{'port'}{'udp'} = 'snmp-read'	; 
	$srvcobjects_ref->{'snmp-read'}{'ports'}{'udp'}{'snmp-read'}++	; 
	$ports_ref->{'udp'}{'snmp-read'}{'name'} = 'snmp-read'		; 
	$srvcobjects_ref->{'Streamworks'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Streamworks'}{'port'}{'udp'} = 'Streamworks'	; 
	$srvcobjects_ref->{'Streamworks'}{'ports'}{'udp'}{'Streamworks'}++	; 
	$ports_ref->{'udp'}{'Streamworks'}{'name'} = 'Streamworks'		; 
	$srvcobjects_ref->{'SWTP_Gateway'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'SWTP_Gateway'}{'port'}{'udp'} = 'SWTP_Gateway'	; 
	$srvcobjects_ref->{'SWTP_Gateway'}{'ports'}{'udp'}{'SWTP_Gateway'}++	; 
	$ports_ref->{'udp'}{'SWTP_Gateway'}{'name'} = 'SWTP_Gateway'		; 
	$srvcobjects_ref->{'SWTP_SMS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'SWTP_SMS'}{'port'}{'udp'} = 'SWTP_SMS'	; 
	$srvcobjects_ref->{'SWTP_SMS'}{'ports'}{'udp'}{'SWTP_SMS'}++	; 
	$ports_ref->{'udp'}{'SWTP_SMS'}{'name'} = 'SWTP_SMS'		; 
	$srvcobjects_ref->{'time-udp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'time-udp'}{'port'}{'udp'} = 'time-udp'	; 
	$srvcobjects_ref->{'time-udp'}{'ports'}{'udp'}{'time-udp'}++	; 
	$ports_ref->{'udp'}{'time-udp'}{'name'} = 'time-udp'		; 
	$srvcobjects_ref->{'tunnel_test'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'tunnel_test'}{'port'}{'udp'} = 'tunnel_test'	; 
	$srvcobjects_ref->{'tunnel_test'}{'ports'}{'udp'}{'tunnel_test'}++	; 
	$ports_ref->{'udp'}{'tunnel_test'}{'name'} = 'tunnel_test'		; 
	$srvcobjects_ref->{'vosaic-data'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'vosaic-data'}{'port'}{'udp'} = 'vosaic-data'	; 
	$srvcobjects_ref->{'vosaic-data'}{'ports'}{'udp'}{'vosaic-data'}++	; 
	$ports_ref->{'udp'}{'vosaic-data'}{'name'} = 'vosaic-data'		; 
	$srvcobjects_ref->{'vosaic-ctrl'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'vosaic-ctrl'}{'port'}{'udp'} = 'vosaic-ctrl'	; 
	$srvcobjects_ref->{'vosaic-ctrl'}{'ports'}{'udp'}{'vosaic-ctrl'}++	; 
	$ports_ref->{'udp'}{'vosaic-ctrl'}{'name'} = 'vosaic-ctrl'		; 
	$srvcobjects_ref->{'VPN1_IPSEC_encapsulation'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'VPN1_IPSEC_encapsulation'}{'port'}{'udp'} = 'VPN1_IPSEC_encapsulation'	; 
	$srvcobjects_ref->{'VPN1_IPSEC_encapsulation'}{'ports'}{'udp'}{'VPN1_IPSEC_encapsulation'}++	; 
	$ports_ref->{'udp'}{'VPN1_IPSEC_encapsulation'}{'name'} = 'VPN1_IPSEC_encapsulation'		; 
	$srvcobjects_ref->{'wap_wdp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'wap_wdp'}{'port'}{'udp'} = 'wap_wdp'	; 
	$srvcobjects_ref->{'wap_wdp'}{'ports'}{'udp'}{'wap_wdp'}++	; 
	$ports_ref->{'udp'}{'wap_wdp'}{'name'} = 'wap_wdp'		; 
	$srvcobjects_ref->{'wap_wdp_enc'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'wap_wdp_enc'}{'port'}{'udp'} = 'wap_wdp_enc'	; 
	$srvcobjects_ref->{'wap_wdp_enc'}{'ports'}{'udp'}{'wap_wdp_enc'}++	; 
	$ports_ref->{'udp'}{'wap_wdp_enc'}{'name'} = 'wap_wdp_enc'		; 
	$srvcobjects_ref->{'wap_wtp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'wap_wtp'}{'port'}{'udp'} = 'wap_wtp'	; 
	$srvcobjects_ref->{'wap_wtp'}{'ports'}{'udp'}{'wap_wtp'}++	; 
	$ports_ref->{'udp'}{'wap_wtp'}{'name'} = 'wap_wtp'		; 
	$srvcobjects_ref->{'wap_wtp_enc'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'wap_wtp_enc'}{'port'}{'udp'} = 'wap_wtp_enc'	; 
	$srvcobjects_ref->{'wap_wtp_enc'}{'ports'}{'udp'}{'wap_wtp_enc'}++	; 
	$ports_ref->{'udp'}{'wap_wtp_enc'}{'name'} = 'wap_wtp_enc'		; 
	$srvcobjects_ref->{'WebTheater'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'WebTheater'}{'port'}{'udp'} = 'WebTheater'	; 
	$srvcobjects_ref->{'WebTheater'}{'ports'}{'udp'}{'WebTheater'}++	; 
	$ports_ref->{'udp'}{'WebTheater'}{'name'} = 'WebTheater'		; 
	$srvcobjects_ref->{'WinMX'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'WinMX'}{'port'}{'udp'} = 'WinMX'	; 
	$srvcobjects_ref->{'WinMX'}{'ports'}{'udp'}{'WinMX'}++	; 
	$ports_ref->{'udp'}{'WinMX'}{'name'} = 'WinMX'		; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_UDP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_UDP'}{'port'}{'udp'} = 'Yahoo_Messenger_Voice_Chat_UDP'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_UDP'}{'ports'}{'udp'}{'Yahoo_Messenger_Voice_Chat_UDP'}++	; 
	$ports_ref->{'udp'}{'Yahoo_Messenger_Voice_Chat_UDP'}{'name'} = 'Yahoo_Messenger_Voice_Chat_UDP'		; 

# NOTE: Checkpoint Default UDP ports

	$srvcobjects_ref->{'ISAKMP'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'ISAKMP'}{'port'}{'udp'} = '500'	; 
	$srvcobjects_ref->{'ISAKMP'}{'ports'}{'udp'}{'500'}++	; 
	$ports_ref->{'udp'}{'500'}{'name'} = 'ISAKMP'		; 
	$srvcobjects_ref->{'name'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'name'}{'port'}{'udp'} = '42'	; 
	$srvcobjects_ref->{'name'}{'ports'}{'udp'}{'42'}++	; 
	$ports_ref->{'udp'}{'42'}{'name'} = 'name'		; 
	$srvcobjects_ref->{'nfsd'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'nfsd'}{'port'}{'udp'} = '2049'	; 
	$srvcobjects_ref->{'nfsd'}{'ports'}{'udp'}{'2049'}++	; 
	$ports_ref->{'udp'}{'2049'}{'name'} = 'nfsd'		; 
	$srvcobjects_ref->{'OnTime'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'OnTime'}{'port'}{'udp'} = '1622'	; 
	$srvcobjects_ref->{'OnTime'}{'ports'}{'udp'}{'1622'}++	; 
	$ports_ref->{'udp'}{'1622'}{'name'} = 'OnTime'		; 
	$srvcobjects_ref->{'pcANYWHERE-stat'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'pcANYWHERE-stat'}{'port'}{'udp'} = '5632'	; 
	$srvcobjects_ref->{'pcANYWHERE-stat'}{'ports'}{'udp'}{'5632'}++	; 
	$ports_ref->{'udp'}{'5632'}{'name'} = 'pcANYWHERE-stat'		; 
	$srvcobjects_ref->{'RADIUS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RADIUS'}{'port'}{'udp'} = '1812'	; 
	$srvcobjects_ref->{'RADIUS'}{'ports'}{'udp'}{'1812'}++	; 
	$ports_ref->{'udp'}{'1812'}{'name'} = 'RADIUS'		; 
	$srvcobjects_ref->{'RIPng'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'RIPng'}{'port'}{'udp'} = '521'	; 
	$srvcobjects_ref->{'RIPng'}{'ports'}{'udp'}{'521'}++	; 
	$ports_ref->{'udp'}{'521'}{'name'} = 'RIPng'		; 
	$srvcobjects_ref->{'sip'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'sip'}{'port'}{'udp'} = '5060'	; 
	$srvcobjects_ref->{'sip'}{'ports'}{'udp'}{'5060'}++	; 
	$ports_ref->{'udp'}{'5060'}{'name'} = 'sip'		; 
	$srvcobjects_ref->{'snmp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'snmp'}{'port'}{'udp'} = '161'	; 
	$srvcobjects_ref->{'snmp'}{'ports'}{'udp'}{'161'}++	; 
	$ports_ref->{'udp'}{'161'}{'name'} = 'snmp'		; 
	$srvcobjects_ref->{'snmp-trap'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'snmp-trap'}{'port'}{'udp'} = '162'	; 
	$srvcobjects_ref->{'snmp-trap'}{'ports'}{'udp'}{'162'}++	; 
	$ports_ref->{'udp'}{'162'}{'name'} = 'snmp-trap'		; 
	$srvcobjects_ref->{'syslog'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'syslog'}{'port'}{'udp'} = '514'	; 
	$srvcobjects_ref->{'syslog'}{'ports'}{'udp'}{'514'}++	; 
	$ports_ref->{'udp'}{'514'}{'name'} = 'syslog'		; 
	$srvcobjects_ref->{'TACACS'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'TACACS'}{'port'}{'udp'} = '49'	; 
	$srvcobjects_ref->{'TACACS'}{'ports'}{'udp'}{'49'}++	; 
	$ports_ref->{'udp'}{'49'}{'name'} = 'TACACS'		; 
	$srvcobjects_ref->{'tftp'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'tftp'}{'port'}{'udp'} = '69'	; 
	$srvcobjects_ref->{'tftp'}{'ports'}{'udp'}{'69'}++	; 
	$ports_ref->{'udp'}{'69'}{'name'} = 'tftp'		; 
	$srvcobjects_ref->{'who'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'who'}{'port'}{'udp'} = '513'	; 
	$srvcobjects_ref->{'who'}{'ports'}{'udp'}{'513'}++	; 
	$ports_ref->{'udp'}{'513'}{'name'} = 'who'		; 

# NOTE: Checkpoint Default ICMP ports

	$srvcobjects_ref->{'dest-unreach'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'dest-unreach'}{'port'}{'icmp'} = 'dest-unreach'	; 
	$srvcobjects_ref->{'dest-unreach'}{'ports'}{'icmp'}{'dest-unreach'}++	; 
	$ports_ref->{'icmp'}{'dest-unreach'}{'name'} = 'dest-unreach'		; 
	$srvcobjects_ref->{'echo-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'echo-reply'}{'port'}{'icmp'} = 'echo-reply'	; 
	$srvcobjects_ref->{'echo-reply'}{'ports'}{'icmp'}{'echo-reply'}++	; 
	$ports_ref->{'icmp'}{'echo-reply'}{'name'} = 'echo-reply'		; 
	$srvcobjects_ref->{'echo-request'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'echo-request'}{'port'}{'icmp'} = 'echo-request'	; 
	$srvcobjects_ref->{'echo-request'}{'ports'}{'icmp'}{'echo-request'}++	; 
	$ports_ref->{'icmp'}{'echo-request'}{'name'} = 'echo-request'		; 
	$srvcobjects_ref->{'gdest-unreach'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gdest-unreach'}{'port'}{'icmp'} = 'gdest-unreach'	; 
	$srvcobjects_ref->{'gdest-unreach'}{'ports'}{'icmp'}{'gdest-unreach'}++	; 
	$ports_ref->{'icmp'}{'gdest-unreach'}{'name'} = 'gdest-unreach'		; 
	$srvcobjects_ref->{'gecho-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gecho-reply'}{'port'}{'icmp'} = 'gecho-reply'	; 
	$srvcobjects_ref->{'gecho-reply'}{'ports'}{'icmp'}{'gecho-reply'}++	; 
	$ports_ref->{'icmp'}{'gecho-reply'}{'name'} = 'gecho-reply'		; 
	$srvcobjects_ref->{'gecho-request'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gecho-request'}{'port'}{'icmp'} = 'gecho-request'	; 
	$srvcobjects_ref->{'gecho-request'}{'ports'}{'icmp'}{'gecho-request'}++	; 
	$ports_ref->{'icmp'}{'gecho-request'}{'name'} = 'gecho-request'		; 
	$srvcobjects_ref->{'ginfo-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'ginfo-reply'}{'port'}{'icmp'} = 'ginfo-reply'	; 
	$srvcobjects_ref->{'ginfo-reply'}{'ports'}{'icmp'}{'ginfo-reply'}++	; 
	$ports_ref->{'icmp'}{'ginfo-reply'}{'name'} = 'ginfo-reply'		; 
	$srvcobjects_ref->{'ginfo-req'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'ginfo-req'}{'port'}{'icmp'} = 'ginfo-req'	; 
	$srvcobjects_ref->{'ginfo-req'}{'ports'}{'icmp'}{'ginfo-req'}++	; 
	$ports_ref->{'icmp'}{'ginfo-req'}{'name'} = 'ginfo-req'		; 
	$srvcobjects_ref->{'gmask-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gmask-reply'}{'port'}{'icmp'} = 'gmask-reply'	; 
	$srvcobjects_ref->{'gmask-reply'}{'ports'}{'icmp'}{'gmask-reply'}++	; 
	$ports_ref->{'icmp'}{'gmask-reply'}{'name'} = 'gmask-reply'		; 
	$srvcobjects_ref->{'gmask-request'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gmask-request'}{'port'}{'icmp'} = 'gmask-request'	; 
	$srvcobjects_ref->{'gmask-request'}{'ports'}{'icmp'}{'gmask-request'}++	; 
	$ports_ref->{'icmp'}{'gmask-request'}{'name'} = 'gmask-request'		; 
	$srvcobjects_ref->{'gparam-prblm'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gparam-prblm'}{'port'}{'icmp'} = 'gparam-prblm'	; 
	$srvcobjects_ref->{'gparam-prblm'}{'ports'}{'icmp'}{'gparam-prblm'}++	; 
	$ports_ref->{'icmp'}{'gparam-prblm'}{'name'} = 'gparam-prblm'		; 
	$srvcobjects_ref->{'gredirect'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gredirect'}{'port'}{'icmp'} = 'gredirect'	; 
	$srvcobjects_ref->{'gredirect'}{'ports'}{'icmp'}{'gredirect'}++	; 
	$ports_ref->{'icmp'}{'gredirect'}{'name'} = 'gredirect'		; 
	$srvcobjects_ref->{'gsource-quench'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gsource-quench'}{'port'}{'icmp'} = 'gsource-quench'	; 
	$srvcobjects_ref->{'gsource-quench'}{'ports'}{'icmp'}{'gsource-quench'}++	; 
	$ports_ref->{'icmp'}{'gsource-quench'}{'name'} = 'gsource-quench'		; 
	$srvcobjects_ref->{'gtime-exceeded'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gtime-exceeded'}{'port'}{'icmp'} = 'gtime-exceeded'	; 
	$srvcobjects_ref->{'gtime-exceeded'}{'ports'}{'icmp'}{'gtime-exceeded'}++	; 
	$ports_ref->{'icmp'}{'gtime-exceeded'}{'name'} = 'gtime-exceeded'		; 
	$srvcobjects_ref->{'gtimestamp'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gtimestamp'}{'port'}{'icmp'} = 'gtimestamp'	; 
	$srvcobjects_ref->{'gtimestamp'}{'ports'}{'icmp'}{'gtimestamp'}++	; 
	$ports_ref->{'icmp'}{'gtimestamp'}{'name'} = 'gtimestamp'		; 
	$srvcobjects_ref->{'gtimestamp-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'gtimestamp-reply'}{'port'}{'icmp'} = 'gtimestamp-reply'	; 
	$srvcobjects_ref->{'gtimestamp-reply'}{'ports'}{'icmp'}{'gtimestamp-reply'}++	; 
	$ports_ref->{'icmp'}{'gtimestamp-reply'}{'name'} = 'gtimestamp-reply'		; 
	$srvcobjects_ref->{'ICMP_frag_needed'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'ICMP_frag_needed'}{'port'}{'icmp'} = 'ICMP_frag_needed'	; 
	$srvcobjects_ref->{'ICMP_frag_needed'}{'ports'}{'icmp'}{'ICMP_frag_needed'}++	; 
	$ports_ref->{'icmp'}{'ICMP_frag_needed'}{'name'} = 'ICMP_frag_needed'		; 
	$srvcobjects_ref->{'info-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'info-reply'}{'port'}{'icmp'} = 'info-reply'	; 
	$srvcobjects_ref->{'info-reply'}{'ports'}{'icmp'}{'info-reply'}++	; 
	$ports_ref->{'icmp'}{'info-reply'}{'name'} = 'info-reply'		; 
	$srvcobjects_ref->{'info-req'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'info-req'}{'port'}{'icmp'} = 'info-req'	; 
	$srvcobjects_ref->{'info-req'}{'ports'}{'icmp'}{'info-req'}++	; 
	$ports_ref->{'icmp'}{'info-req'}{'name'} = 'info-req'		; 
	$srvcobjects_ref->{'mask-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'mask-reply'}{'port'}{'icmp'} = 'mask-reply'	; 
	$srvcobjects_ref->{'mask-reply'}{'ports'}{'icmp'}{'mask-reply'}++	; 
	$ports_ref->{'icmp'}{'mask-reply'}{'name'} = 'mask-reply'		; 
	$srvcobjects_ref->{'mask-request'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'mask-request'}{'port'}{'icmp'} = 'mask-request'	; 
	$srvcobjects_ref->{'mask-request'}{'ports'}{'icmp'}{'mask-request'}++	; 
	$ports_ref->{'icmp'}{'mask-request'}{'name'} = 'mask-request'		; 
	$srvcobjects_ref->{'param-prblm'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'param-prblm'}{'port'}{'icmp'} = 'param-prblm'	; 
	$srvcobjects_ref->{'param-prblm'}{'ports'}{'icmp'}{'param-prblm'}++	; 
	$ports_ref->{'icmp'}{'param-prblm'}{'name'} = 'param-prblm'		; 
	$srvcobjects_ref->{'redirect'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'redirect'}{'port'}{'icmp'} = 'redirect'	; 
	$srvcobjects_ref->{'redirect'}{'ports'}{'icmp'}{'redirect'}++	; 
	$ports_ref->{'icmp'}{'redirect'}{'name'} = 'redirect'		; 
	$srvcobjects_ref->{'source-quench'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'source-quench'}{'port'}{'icmp'} = 'source-quench'	; 
	$srvcobjects_ref->{'source-quench'}{'ports'}{'icmp'}{'source-quench'}++	; 
	$ports_ref->{'icmp'}{'source-quench'}{'name'} = 'source-quench'		; 
	$srvcobjects_ref->{'time-exceeded'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'time-exceeded'}{'port'}{'icmp'} = 'time-exceeded'	; 
	$srvcobjects_ref->{'time-exceeded'}{'ports'}{'icmp'}{'time-exceeded'}++	; 
	$ports_ref->{'icmp'}{'time-exceeded'}{'name'} = 'time-exceeded'		; 
	$srvcobjects_ref->{'timestamp'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'timestamp'}{'port'}{'icmp'} = 'timestamp'	; 
	$srvcobjects_ref->{'timestamp'}{'ports'}{'icmp'}{'timestamp'}++	; 
	$ports_ref->{'icmp'}{'timestamp'}{'name'} = 'timestamp'		; 
	$srvcobjects_ref->{'timestamp-reply'}{'type'} = 'icmp'	; 
	$srvcobjects_ref->{'timestamp-reply'}{'port'}{'icmp'} = 'timestamp-reply'	; 
	$srvcobjects_ref->{'timestamp-reply'}{'ports'}{'icmp'}{'timestamp-reply'}++	; 
	$ports_ref->{'icmp'}{'timestamp-reply'}{'name'} = 'timestamp-reply'		; 

# NOTE: Checkpoint Default OTHER ports

	$srvcobjects_ref->{'AH'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'AH'}{'port'}{'other'} = 'AH'	; 
	$srvcobjects_ref->{'AH'}{'ports'}{'other'}{'AH'}++	; 
	$ports_ref->{'other'}{'AH'}{'name'} = 'AH'		; 
	$srvcobjects_ref->{'backweb'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'backweb'}{'port'}{'other'} = 'backweb'	; 
	$srvcobjects_ref->{'backweb'}{'ports'}{'other'}{'backweb'}++	; 
	$ports_ref->{'other'}{'backweb'}{'name'} = 'backweb'		; 
	$srvcobjects_ref->{'cooltk'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'cooltk'}{'port'}{'other'} = 'cooltk'	; 
	$srvcobjects_ref->{'cooltk'}{'ports'}{'other'}{'cooltk'}++	; 
	$ports_ref->{'other'}{'cooltk'}{'name'} = 'cooltk'		; 
	$srvcobjects_ref->{'DCE-RPC'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'DCE-RPC'}{'port'}{'other'} = 'DCE-RPC'	; 
	$srvcobjects_ref->{'DCE-RPC'}{'ports'}{'other'}{'DCE-RPC'}++	; 
	$ports_ref->{'other'}{'DCE-RPC'}{'name'} = 'DCE-RPC'		; 
	$srvcobjects_ref->{'egp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'egp'}{'port'}{'other'} = 'egp'	; 
	$srvcobjects_ref->{'egp'}{'ports'}{'other'}{'egp'}++	; 
	$ports_ref->{'other'}{'egp'}{'name'} = 'egp'		; 
	$srvcobjects_ref->{'ESP'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ESP'}{'port'}{'other'} = 'ESP'	; 
	$srvcobjects_ref->{'ESP'}{'ports'}{'other'}{'ESP'}++	; 
	$ports_ref->{'other'}{'ESP'}{'name'} = 'ESP'		; 
	$srvcobjects_ref->{'FreeTel-incoming'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'FreeTel-incoming'}{'port'}{'other'} = 'FreeTel-incoming'	; 
	$srvcobjects_ref->{'FreeTel-incoming'}{'ports'}{'other'}{'FreeTel-incoming'}++	; 
	$ports_ref->{'other'}{'FreeTel-incoming'}{'name'} = 'FreeTel-incoming'		; 
	$srvcobjects_ref->{'Free-Tel-outgoing'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'Free-Tel-outgoing'}{'port'}{'other'} = 'Free-Tel-outgoing'	; 
	$srvcobjects_ref->{'Free-Tel-outgoing'}{'ports'}{'other'}{'Free-Tel-outgoing'}++	; 
	$ports_ref->{'other'}{'Free-Tel-outgoing'}{'name'} = 'Free-Tel-outgoing'		; 
	$srvcobjects_ref->{'Revision'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'Revision'}{'port'}{'other'} = 'Revision'	; 
	$srvcobjects_ref->{'Revision'}{'ports'}{'other'}{'Revision'}++	; 
	$ports_ref->{'other'}{'Revision'}{'name'} = 'Revision'		; 
	$srvcobjects_ref->{'FreeTel-outgoing-client'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'FreeTel-outgoing-client'}{'port'}{'other'} = 'FreeTel-outgoing-client'	; 
	$srvcobjects_ref->{'FreeTel-outgoing-client'}{'ports'}{'other'}{'FreeTel-outgoing-client'}++	; 
	$ports_ref->{'other'}{'FreeTel-outgoing-client'}{'name'} = 'FreeTel-outgoing-client'		; 
	$srvcobjects_ref->{'ftp_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ftp_mapped'}{'port'}{'other'} = 'ftp_mapped'	; 
	$srvcobjects_ref->{'ftp_mapped'}{'ports'}{'other'}{'ftp_mapped'}++	; 
	$ports_ref->{'other'}{'ftp_mapped'}{'name'} = 'ftp_mapped'		; 
	$srvcobjects_ref->{'FW1_Encapsulation'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'FW1_Encapsulation'}{'port'}{'other'} = 'FW1_Encapsulation'	; 
	$srvcobjects_ref->{'FW1_Encapsulation'}{'ports'}{'other'}{'FW1_Encapsulation'}++	; 
	$ports_ref->{'other'}{'FW1_Encapsulation'}{'name'} = 'FW1_Encapsulation'		; 
	$srvcobjects_ref->{'gAH'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gAH'}{'port'}{'other'} = 'gAH'	; 
	$srvcobjects_ref->{'gAH'}{'ports'}{'other'}{'gAH'}++	; 
	$ports_ref->{'other'}{'gAH'}{'name'} = 'gAH'		; 
	$srvcobjects_ref->{'gbackweb'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gbackweb'}{'port'}{'other'} = 'gbackweb'	; 
	$srvcobjects_ref->{'gbackweb'}{'ports'}{'other'}{'gbackweb'}++	; 
	$ports_ref->{'other'}{'gbackweb'}{'name'} = 'gbackweb'		; 
	$srvcobjects_ref->{'gegp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gegp'}{'port'}{'other'} = 'gegp'	; 
	$srvcobjects_ref->{'gegp'}{'ports'}{'other'}{'gegp'}++	; 
	$ports_ref->{'other'}{'gegp'}{'name'} = 'gegp'		; 
	$srvcobjects_ref->{'gESP'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gESP'}{'port'}{'other'} = 'gESP'	; 
	$srvcobjects_ref->{'gESP'}{'ports'}{'other'}{'gESP'}++	; 
	$ports_ref->{'other'}{'gESP'}{'name'} = 'gESP'		; 
	$srvcobjects_ref->{'gFreeTel-incoming'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gFreeTel-incoming'}{'port'}{'other'} = 'gFreeTel-incoming'	; 
	$srvcobjects_ref->{'gFreeTel-incoming'}{'ports'}{'other'}{'gFreeTel-incoming'}++	; 
	$ports_ref->{'other'}{'gFreeTel-incoming'}{'name'} = 'gFreeTel-incoming'		; 
	$srvcobjects_ref->{'gFreeTel-outgoing-client'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gFreeTel-outgoing-client'}{'port'}{'other'} = 'gFreeTel-outgoing-client'	; 
	$srvcobjects_ref->{'gFreeTel-outgoing-client'}{'ports'}{'other'}{'gFreeTel-outgoing-client'}++	; 
	$ports_ref->{'other'}{'gFreeTel-outgoing-client'}{'name'} = 'gFreeTel-outgoing-client'		; 
	$srvcobjects_ref->{'gftp_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gftp_mapped'}{'port'}{'other'} = 'gftp_mapped'	; 
	$srvcobjects_ref->{'gftp_mapped'}{'ports'}{'other'}{'gftp_mapped'}++	; 
	$ports_ref->{'other'}{'gftp_mapped'}{'name'} = 'gftp_mapped'		; 
	$srvcobjects_ref->{'gFW1_Encapsulation'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gFW1_Encapsulation'}{'port'}{'other'} = 'gFW1_Encapsulation'	; 
	$srvcobjects_ref->{'gFW1_Encapsulation'}{'ports'}{'other'}{'gFW1_Encapsulation'}++	; 
	$ports_ref->{'other'}{'gFW1_Encapsulation'}{'name'} = 'gFW1_Encapsulation'		; 
	$srvcobjects_ref->{'gggp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gggp'}{'port'}{'other'} = 'gggp'	; 
	$srvcobjects_ref->{'gggp'}{'ports'}{'other'}{'gggp'}++	; 
	$ports_ref->{'other'}{'gggp'}{'name'} = 'gggp'		; 
	$srvcobjects_ref->{'ggre'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ggre'}{'port'}{'other'} = 'ggre'	; 
	$srvcobjects_ref->{'ggre'}{'ports'}{'other'}{'ggre'}++	; 
	$ports_ref->{'other'}{'ggre'}{'name'} = 'ggre'		; 
	$srvcobjects_ref->{'ggtp_reverse'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ggtp_reverse'}{'port'}{'other'} = 'ggtp_reverse'	; 
	$srvcobjects_ref->{'ggtp_reverse'}{'ports'}{'other'}{'ggtp_reverse'}++	; 
	$ports_ref->{'other'}{'ggtp_reverse'}{'name'} = 'ggtp_reverse'		; 
	$srvcobjects_ref->{'ggtp_v0_path_mgmt'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ggtp_v0_path_mgmt'}{'port'}{'other'} = 'ggtp_v0_path_mgmt'	; 
	$srvcobjects_ref->{'ggtp_v0_path_mgmt'}{'ports'}{'other'}{'ggtp_v0_path_mgmt'}++	; 
	$ports_ref->{'other'}{'ggtp_v0_path_mgmt'}{'name'} = 'ggtp_v0_path_mgmt'		; 
	$srvcobjects_ref->{'ggtp_v1_path_mgmt'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ggtp_v1_path_mgmt'}{'port'}{'other'} = 'ggtp_v1_path_mgmt'	; 
	$srvcobjects_ref->{'ggtp_v1_path_mgmt'}{'ports'}{'other'}{'ggtp_v1_path_mgmt'}++	; 
	$ports_ref->{'other'}{'ggtp_v1_path_mgmt'}{'name'} = 'ggtp_v1_path_mgmt'		; 
	$srvcobjects_ref->{'ghttp_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ghttp_mapped'}{'port'}{'other'} = 'ghttp_mapped'	; 
	$srvcobjects_ref->{'ghttp_mapped'}{'ports'}{'other'}{'ghttp_mapped'}++	; 
	$ports_ref->{'other'}{'ghttp_mapped'}{'name'} = 'ghttp_mapped'		; 
	$srvcobjects_ref->{'gHTTP_wo_SCV'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gHTTP_wo_SCV'}{'port'}{'other'} = 'gHTTP_wo_SCV'	; 
	$srvcobjects_ref->{'gHTTP_wo_SCV'}{'ports'}{'other'}{'gHTTP_wo_SCV'}++	; 
	$ports_ref->{'other'}{'gHTTP_wo_SCV'}{'name'} = 'gHTTP_wo_SCV'		; 
	$srvcobjects_ref->{'gicmp-proto'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gicmp-proto'}{'port'}{'other'} = 'gicmp-proto'	; 
	$srvcobjects_ref->{'gicmp-proto'}{'ports'}{'other'}{'gicmp-proto'}++	; 
	$ports_ref->{'other'}{'gicmp-proto'}{'name'} = 'gicmp-proto'		; 
	$srvcobjects_ref->{'gigmp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gigmp'}{'port'}{'other'} = 'gigmp'	; 
	$srvcobjects_ref->{'gigmp'}{'ports'}{'other'}{'gigmp'}++	; 
	$ports_ref->{'other'}{'gigmp'}{'name'} = 'gigmp'		; 
	$srvcobjects_ref->{'gigrp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gigrp'}{'port'}{'other'} = 'gigrp'	; 
	$srvcobjects_ref->{'gigrp'}{'ports'}{'other'}{'gigrp'}++	; 
	$ports_ref->{'other'}{'gigrp'}{'name'} = 'gigrp'		; 
	$srvcobjects_ref->{'gospf'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gospf'}{'port'}{'other'} = 'gospf'	; 
	$srvcobjects_ref->{'gospf'}{'ports'}{'other'}{'gospf'}++	; 
	$ports_ref->{'other'}{'gospf'}{'name'} = 'gospf'		; 
	$srvcobjects_ref->{'gpim'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gpim'}{'port'}{'other'} = 'gpim'	; 
	$srvcobjects_ref->{'gpim'}{'ports'}{'other'}{'gpim'}++	; 
	$ports_ref->{'other'}{'gpim'}{'name'} = 'gpim'		; 
	$srvcobjects_ref->{'grip-response'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'grip-response'}{'port'}{'other'} = 'grip-response'	; 
	$srvcobjects_ref->{'grip-response'}{'ports'}{'other'}{'grip-response'}++	; 
	$ports_ref->{'other'}{'grip-response'}{'name'} = 'grip-response'		; 
	$srvcobjects_ref->{'gsip_dynamic_ports'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gsip_dynamic_ports'}{'port'}{'other'} = 'gsip_dynamic_ports'	; 
	$srvcobjects_ref->{'gsip_dynamic_ports'}{'ports'}{'other'}{'gsip_dynamic_ports'}++	; 
	$ports_ref->{'other'}{'gsip_dynamic_ports'}{'name'} = 'gsip_dynamic_ports'		; 
	$srvcobjects_ref->{'gSitara'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gSitara'}{'port'}{'other'} = 'gSitara'	; 
	$srvcobjects_ref->{'gSitara'}{'ports'}{'other'}{'gSitara'}++	; 
	$ports_ref->{'other'}{'gSitara'}{'name'} = 'gSitara'		; 
	$srvcobjects_ref->{'gSKIP'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gSKIP'}{'port'}{'other'} = 'gSKIP'	; 
	$srvcobjects_ref->{'gSKIP'}{'ports'}{'other'}{'gSKIP'}++	; 
	$ports_ref->{'other'}{'gSKIP'}{'name'} = 'gSKIP'		; 
	$srvcobjects_ref->{'gsmtp_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gsmtp_mapped'}{'port'}{'other'} = 'gsmtp_mapped'	; 
	$srvcobjects_ref->{'gsmtp_mapped'}{'ports'}{'other'}{'gsmtp_mapped'}++	; 
	$ports_ref->{'other'}{'gsmtp_mapped'}{'name'} = 'gsmtp_mapped'		; 
	$srvcobjects_ref->{'gSnmp-Read-Only'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gSnmp-Read-Only'}{'port'}{'other'} = 'gSnmp-Read-Only'	; 
	$srvcobjects_ref->{'gSnmp-Read-Only'}{'ports'}{'other'}{'gSnmp-Read-Only'}++	; 
	$ports_ref->{'other'}{'gSnmp-Read-Only'}{'name'} = 'gSnmp-Read-Only'		; 
	$srvcobjects_ref->{'gtraceroute'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gtraceroute'}{'port'}{'other'} = 'gtraceroute'	; 
	$srvcobjects_ref->{'gtraceroute'}{'ports'}{'other'}{'gtraceroute'}++	; 
	$ports_ref->{'other'}{'gtraceroute'}{'name'} = 'gtraceroute'		; 
	$srvcobjects_ref->{'gtunnel_test_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gtunnel_test_mapped'}{'port'}{'other'} = 'gtunnel_test_mapped'	; 
	$srvcobjects_ref->{'gtunnel_test_mapped'}{'ports'}{'other'}{'gtunnel_test_mapped'}++	; 
	$ports_ref->{'other'}{'gtunnel_test_mapped'}{'name'} = 'gtunnel_test_mapped'		; 
	$srvcobjects_ref->{'gvrrp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gvrrp'}{'port'}{'other'} = 'gvrrp'	; 
	$srvcobjects_ref->{'gvrrp'}{'ports'}{'other'}{'gvrrp'}++	; 
	$ports_ref->{'other'}{'gvrrp'}{'name'} = 'gvrrp'		; 
	$srvcobjects_ref->{'gX11-verify'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gX11-verify'}{'port'}{'other'} = 'gX11-verify'	; 
	$srvcobjects_ref->{'gX11-verify'}{'ports'}{'other'}{'gX11-verify'}++	; 
	$ports_ref->{'other'}{'gX11-verify'}{'name'} = 'gX11-verify'		; 
	$srvcobjects_ref->{'gZSP'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gZSP'}{'port'}{'other'} = 'gZSP'	; 
	$srvcobjects_ref->{'gZSP'}{'ports'}{'other'}{'gZSP'}++	; 
	$ports_ref->{'other'}{'gZSP'}{'name'} = 'gZSP'		; 
	$srvcobjects_ref->{'ggp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ggp'}{'port'}{'other'} = 'ggp'	; 
	$srvcobjects_ref->{'ggp'}{'ports'}{'other'}{'ggp'}++	; 
	$ports_ref->{'other'}{'ggp'}{'name'} = 'ggp'		; 
	$srvcobjects_ref->{'gre'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gre'}{'port'}{'other'} = 'gre'	; 
	$srvcobjects_ref->{'gre'}{'ports'}{'other'}{'gre'}++	; 
	$srvcobjects_ref->{'gre'}{'ports'}{'GRE'}{'GRE'}++	; 
	$srvcobjects_ref->{'gre'}{'ports'}{'47'}{'GRE'}++	; 
	$ports_ref->{'other'}{'gre'}{'name'} = 'gre'		; 
	$srvcobjects_ref->{'gtp_path_mgmt'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gtp_path_mgmt'}{'port'}{'other'} = 'gtp_path_mgmt'	; 
	$srvcobjects_ref->{'gtp_path_mgmt'}{'ports'}{'other'}{'gtp_path_mgmt'}++	; 
	$ports_ref->{'other'}{'gtp_path_mgmt'}{'name'} = 'gtp_path_mgmt'		; 
	$srvcobjects_ref->{'gtp_reverse'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gtp_reverse'}{'port'}{'other'} = 'gtp_reverse'	; 
	$srvcobjects_ref->{'gtp_reverse'}{'ports'}{'other'}{'gtp_reverse'}++	; 
	$ports_ref->{'other'}{'gtp_reverse'}{'name'} = 'gtp_reverse'		; 
	$srvcobjects_ref->{'gtp_v0_path_mgmt'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gtp_v0_path_mgmt'}{'port'}{'other'} = 'gtp_v0_path_mgmt'	; 
	$srvcobjects_ref->{'gtp_v0_path_mgmt'}{'ports'}{'other'}{'gtp_v0_path_mgmt'}++	; 
	$ports_ref->{'other'}{'gtp_v0_path_mgmt'}{'name'} = 'gtp_v0_path_mgmt'		; 
	$srvcobjects_ref->{'gtp_v1_path_mgmt'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'gtp_v1_path_mgmt'}{'port'}{'other'} = 'gtp_v1_path_mgmt'	; 
	$srvcobjects_ref->{'gtp_v1_path_mgmt'}{'ports'}{'other'}{'gtp_v1_path_mgmt'}++	; 
	$ports_ref->{'other'}{'gtp_v1_path_mgmt'}{'name'} = 'gtp_v1_path_mgmt'		; 
	$srvcobjects_ref->{'http_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'http_mapped'}{'port'}{'other'} = 'http_mapped'	; 
	$srvcobjects_ref->{'http_mapped'}{'ports'}{'other'}{'http_mapped'}++	; 
	$ports_ref->{'other'}{'http_mapped'}{'name'} = 'http_mapped'		; 
	$srvcobjects_ref->{'HTTP_wo_SCV'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'HTTP_wo_SCV'}{'port'}{'other'} = 'HTTP_wo_SCV'	; 
	$srvcobjects_ref->{'HTTP_wo_SCV'}{'ports'}{'other'}{'HTTP_wo_SCV'}++	; 
	$ports_ref->{'other'}{'HTTP_wo_SCV'}{'name'} = 'HTTP_wo_SCV'		; 
	$srvcobjects_ref->{'icmp-proto'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'icmp-proto'}{'port'}{'other'} = 'icmp-proto'	; 
	$srvcobjects_ref->{'icmp-proto'}{'ports'}{'other'}{'icmp-proto'}++	; 
	$ports_ref->{'other'}{'icmp-proto'}{'name'} = 'icmp-proto'		; 
	$srvcobjects_ref->{'igmp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'igmp'}{'port'}{'other'} = 'igmp'	; 
	$srvcobjects_ref->{'igmp'}{'ports'}{'other'}{'igmp'}++	; 
	$ports_ref->{'other'}{'igmp'}{'name'} = 'igmp'		; 
	$srvcobjects_ref->{'igrp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'igrp'}{'port'}{'other'} = 'igrp'	; 
	$srvcobjects_ref->{'igrp'}{'ports'}{'other'}{'igrp'}++	; 
	$ports_ref->{'other'}{'igrp'}{'name'} = 'igrp'		; 
	$srvcobjects_ref->{'IP_Mobility'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'IP_Mobility'}{'port'}{'other'} = 'IP_Mobility'	; 
	$srvcobjects_ref->{'IP_Mobility'}{'ports'}{'other'}{'IP_Mobility'}++	; 
	$ports_ref->{'other'}{'IP_Mobility'}{'name'} = 'IP_Mobility'		; 
	$srvcobjects_ref->{'MSExchange'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MSExchange'}{'port'}{'other'} = 'MSExchange'	; 
	$srvcobjects_ref->{'MSExchange'}{'ports'}{'other'}{'MSExchange'}++	; 
	$ports_ref->{'other'}{'MSExchange'}{'name'} = 'MSExchange'		; 
	$srvcobjects_ref->{'MSExchange-SiteConnector'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MSExchange-SiteConnector'}{'port'}{'other'} = 'MSExchange-SiteConnector'	; 
	$srvcobjects_ref->{'MSExchange-SiteConnector'}{'ports'}{'other'}{'MSExchange-SiteConnector'}++	; 
	$ports_ref->{'other'}{'MSExchange-SiteConnector'}{'name'} = 'MSExchange-SiteConnector'		; 
	$srvcobjects_ref->{'MSExchange-RemoteAdmin'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MSExchange-RemoteAdmin'}{'port'}{'other'} = 'MSExchange-RemoteAdmin'	; 
	$srvcobjects_ref->{'MSExchange-RemoteAdmin'}{'ports'}{'other'}{'MSExchange-RemoteAdmin'}++	; 
	$ports_ref->{'other'}{'MSExchange-RemoteAdmin'}{'name'} = 'MSExchange-RemoteAdmin'		; 
	$srvcobjects_ref->{'MS-SQL-Monitor_SD'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor_SD'}{'port'}{'other'} = 'MS-SQL-Monitor_SD'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor_SD'}{'ports'}{'other'}{'MS-SQL-Monitor_SD'}++	; 
	$ports_ref->{'other'}{'MS-SQL-Monitor_SD'}{'name'} = 'MS-SQL-Monitor_SD'		; 
	$srvcobjects_ref->{'MS-SQL-Server_SD'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MS-SQL-Server_SD'}{'port'}{'other'} = 'MS-SQL-Server_SD'	; 
	$srvcobjects_ref->{'MS-SQL-Server_SD'}{'ports'}{'other'}{'MS-SQL-Server_SD'}++	; 
	$ports_ref->{'other'}{'MS-SQL-Server_SD'}{'name'} = 'MS-SQL-Server_SD'		; 
	$srvcobjects_ref->{'MS-SQL-Server_SD_2433'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MS-SQL-Server_SD_2433'}{'port'}{'other'} = 'MS-SQL-Server_SD_2433'	; 
	$srvcobjects_ref->{'MS-SQL-Server_SD_2433'}{'ports'}{'other'}{'MS-SQL-Server_SD_2433'}++	; 
	$ports_ref->{'other'}{'MS-SQL-Server_SD_2433'}{'name'} = 'MS-SQL-Server_SD_2433'		; 
	$srvcobjects_ref->{'MS-WINS-Replication-TCP_SD'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MS-WINS-Replication-TCP_SD'}{'port'}{'other'} = 'MS-WINS-Replication-TCP_SD'	; 
	$srvcobjects_ref->{'MS-WINS-Replication-TCP_SD'}{'ports'}{'other'}{'MS-WINS-Replication-TCP_SD'}++	; 
	$ports_ref->{'other'}{'MS-WINS-Replication-TCP_SD'}{'name'} = 'MS-WINS-Replication-TCP_SD'		; 
	$srvcobjects_ref->{'MS-WINS-Replication-UDP_SD'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'MS-WINS-Replication-UDP_SD'}{'port'}{'other'} = 'MS-WINS-Replication-UDP_SD'	; 
	$srvcobjects_ref->{'MS-WINS-Replication-UDP_SD'}{'ports'}{'other'}{'MS-WINS-Replication-UDP_SD'}++	; 
	$ports_ref->{'other'}{'MS-WINS-Replication-UDP_SD'}{'name'} = 'MS-WINS-Replication-UDP_SD'		; 
	$srvcobjects_ref->{'ospf'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ospf'}{'port'}{'other'} = 'ospf'	; 
	$srvcobjects_ref->{'ospf'}{'ports'}{'other'}{'ospf'}++	; 
	$ports_ref->{'other'}{'ospf'}{'name'} = 'ospf'		; 
	$srvcobjects_ref->{'Partial-Destination-v6'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'Partial-Destination-v6'}{'port'}{'other'} = 'Partial-Destination-v6'	; 
	$srvcobjects_ref->{'Partial-Destination-v6'}{'ports'}{'other'}{'Partial-Destination-v6'}++	; 
	$ports_ref->{'other'}{'Partial-Destination-v6'}{'name'} = 'Partial-Destination-v6'		; 
	$srvcobjects_ref->{'Partial-Source-v6'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'Partial-Source-v6'}{'port'}{'other'} = 'Partial-Source-v6'	; 
	$srvcobjects_ref->{'Partial-Source-v6'}{'ports'}{'other'}{'Partial-Source-v6'}++	; 
	$ports_ref->{'other'}{'Partial-Source-v6'}{'name'} = 'Partial-Source-v6'		; 
	$srvcobjects_ref->{'PIM'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'PIM'}{'port'}{'other'} = 'PIM'	; 
	$srvcobjects_ref->{'PIM'}{'ports'}{'other'}{'PIM'}++	; 
	$ports_ref->{'other'}{'PIM'}{'name'} = 'PIM'		; 
	$srvcobjects_ref->{'PIM_CISCO_IOS'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'PIM_CISCO_IOS'}{'port'}{'other'} = 'PIM_CISCO_IOS'	; 
	$srvcobjects_ref->{'PIM_CISCO_IOS'}{'ports'}{'other'}{'PIM_CISCO_IOS'}++	; 
	$ports_ref->{'other'}{'PIM_CISCO_IOS'}{'name'} = 'PIM_CISCO_IOS'		; 
	$srvcobjects_ref->{'rip-response'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'rip-response'}{'port'}{'other'} = 'rip-response'	; 
	$srvcobjects_ref->{'rip-response'}{'ports'}{'other'}{'rip-response'}++	; 
	$ports_ref->{'other'}{'rip-response'}{'name'} = 'rip-response'		; 
	$srvcobjects_ref->{'sip_dynamic_ports'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'sip_dynamic_ports'}{'port'}{'other'} = 'sip_dynamic_ports'	; 
	$srvcobjects_ref->{'sip_dynamic_ports'}{'ports'}{'other'}{'sip_dynamic_ports'}++	; 
	$ports_ref->{'other'}{'sip_dynamic_ports'}{'name'} = 'sip_dynamic_ports'		; 
	$srvcobjects_ref->{'sasser-icmp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'sasser-icmp'}{'port'}{'other'} = 'sasser-icmp'	; 
	$srvcobjects_ref->{'sasser-icmp'}{'ports'}{'other'}{'sasser-icmp'}++	; 
	$ports_ref->{'other'}{'sasser-icmp'}{'name'} = 'sasser-icmp'		; 
	$srvcobjects_ref->{'SIT'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'SIT'}{'port'}{'other'} = 'SIT'	; 
	$srvcobjects_ref->{'SIT'}{'ports'}{'other'}{'SIT'}++	; 
	$ports_ref->{'other'}{'SIT'}{'name'} = 'SIT'		; 
	$srvcobjects_ref->{'SIT_with_Intra_Tunnel_Inspection'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'SIT_with_Intra_Tunnel_Inspection'}{'port'}{'other'} = 'SIT_with_Intra_Tunnel_Inspection'	; 
	$srvcobjects_ref->{'SIT_with_Intra_Tunnel_Inspection'}{'ports'}{'other'}{'SIT_with_Intra_Tunnel_Inspection'}++	; 
	$ports_ref->{'other'}{'SIT_with_Intra_Tunnel_Inspection'}{'name'} = 'SIT_with_Intra_Tunnel_Inspection'		; 
	$srvcobjects_ref->{'Sitara'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'Sitara'}{'port'}{'other'} = 'Sitara'	; 
	$srvcobjects_ref->{'Sitara'}{'ports'}{'other'}{'Sitara'}++	; 
	$ports_ref->{'other'}{'Sitara'}{'name'} = 'Sitara'		; 
	$srvcobjects_ref->{'SKIP'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'SKIP'}{'port'}{'other'} = 'SKIP'	; 
	$srvcobjects_ref->{'SKIP'}{'ports'}{'other'}{'SKIP'}++	; 
	$ports_ref->{'other'}{'SKIP'}{'name'} = 'SKIP'		; 
	$srvcobjects_ref->{'smtp_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'smtp_mapped'}{'port'}{'other'} = 'smtp_mapped'	; 
	$srvcobjects_ref->{'smtp_mapped'}{'ports'}{'other'}{'smtp_mapped'}++	; 
	$ports_ref->{'other'}{'smtp_mapped'}{'name'} = 'smtp_mapped'		; 
	$srvcobjects_ref->{'Snmp-Read-Only'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'Snmp-Read-Only'}{'port'}{'other'} = 'Snmp-Read-Only'	; 
	$srvcobjects_ref->{'Snmp-Read-Only'}{'ports'}{'other'}{'Snmp-Read-Only'}++	; 
	$ports_ref->{'other'}{'Snmp-Read-Only'}{'name'} = 'Snmp-Read-Only'		; 
	$srvcobjects_ref->{'sqlnet2'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'sqlnet2'}{'port'}{'other'} = 'sqlnet2'	; 
	$srvcobjects_ref->{'sqlnet2'}{'ports'}{'other'}{'sqlnet2'}++	; 
	$ports_ref->{'other'}{'sqlnet2'}{'name'} = 'sqlnet2'		; 
	$srvcobjects_ref->{'SSL_Null_Pointer'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'SSL_Null_Pointer'}{'port'}{'other'} = 'SSL_Null_Pointer'	; 
	$srvcobjects_ref->{'SSL_Null_Pointer'}{'ports'}{'other'}{'SSL_Null_Pointer'}++	; 
	$ports_ref->{'other'}{'SSL_Null_Pointer'}{'name'} = 'SSL_Null_Pointer'		; 
	$srvcobjects_ref->{'SUN_ND'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'SUN_ND'}{'port'}{'other'} = 'SUN_ND'	; 
	$srvcobjects_ref->{'SUN_ND'}{'ports'}{'other'}{'SUN_ND'}++	; 
	$ports_ref->{'other'}{'SUN_ND'}{'name'} = 'SUN_ND'		; 
	$srvcobjects_ref->{'SWIPE'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'SWIPE'}{'port'}{'other'} = 'SWIPE'	; 
	$srvcobjects_ref->{'SWIPE'}{'ports'}{'other'}{'SWIPE'}++	; 
	$ports_ref->{'other'}{'SWIPE'}{'name'} = 'SWIPE'		; 
	$srvcobjects_ref->{'traceroute'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'traceroute'}{'port'}{'other'} = '33434'	; 
	$srvcobjects_ref->{'traceroute'}{'ports'}{'other'}{'33434'}++	; 
	$ports_ref->{'other'}{'33434'}{'name'} = 'traceroute'		; 
	$srvcobjects_ref->{'tunnel_test_mapped'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'tunnel_test_mapped'}{'port'}{'other'} = 'tunnel_test_mapped'	; 
	$srvcobjects_ref->{'tunnel_test_mapped'}{'ports'}{'other'}{'tunnel_test_mapped'}++	; 
	$ports_ref->{'other'}{'tunnel_test_mapped'}{'name'} = 'tunnel_test_mapped'		; 
	$srvcobjects_ref->{'VDO-Live'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'VDO-Live'}{'port'}{'other'} = 'VDO-Live'	; 
	$srvcobjects_ref->{'VDO-Live'}{'ports'}{'other'}{'VDO-Live'}++	; 
	$ports_ref->{'other'}{'VDO-Live'}{'name'} = 'VDO-Live'		; 
	$srvcobjects_ref->{'vrrp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'vrrp'}{'port'}{'other'} = 'vrrp'	; 
	$srvcobjects_ref->{'vrrp'}{'ports'}{'other'}{'vrrp'}++	; 
	$ports_ref->{'other'}{'vrrp'}{'name'} = 'vrrp'		; 
	$srvcobjects_ref->{'welchia-icmp'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'welchia-icmp'}{'port'}{'other'} = 'welchia-icmp'	; 
	$srvcobjects_ref->{'welchia-icmp'}{'ports'}{'other'}{'welchia-icmp'}++	; 
	$ports_ref->{'other'}{'welchia-icmp'}{'name'} = 'welchia-icmp'		; 
	$srvcobjects_ref->{'Witty_Worm'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'Witty_Worm'}{'port'}{'other'} = 'Witty_Worm'	; 
	$srvcobjects_ref->{'Witty_Worm'}{'ports'}{'other'}{'Witty_Worm'}++	; 
	$ports_ref->{'other'}{'Witty_Worm'}{'name'} = 'Witty_Worm'		; 
	$srvcobjects_ref->{'X11-verify'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'X11-verify'}{'port'}{'other'} = 'X11-verify'	; 
	$srvcobjects_ref->{'X11-verify'}{'ports'}{'other'}{'X11-verify'}++	; 
	$ports_ref->{'other'}{'X11-verify'}{'name'} = 'X11-verify'		; 
	$srvcobjects_ref->{'ZSP'}{'type'} = 'other'	; 
	$srvcobjects_ref->{'ZSP'}{'port'}{'other'} = 'ZSP'	; 
	$srvcobjects_ref->{'ZSP'}{'ports'}{'other'}{'ZSP'}++	; 
	$ports_ref->{'other'}{'ZSP'}{'name'} = 'ZSP'		; 

# NOTE: Checkpoint Default RPC ports

	$srvcobjects_ref->{'cachefsd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'cachefsd'}{'port'}{'rpc'} = 'cachefsd'	; 
	$srvcobjects_ref->{'cachefsd'}{'ports'}{'rpc'}{'cachefsd'}++	; 
	$ports_ref->{'rpc'}{'cachefsd'}{'name'} = 'cachefsd'		; 
	$srvcobjects_ref->{'cmsd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'cmsd'}{'port'}{'rpc'} = 'cmsd'	; 
	$srvcobjects_ref->{'cmsd'}{'ports'}{'rpc'}{'cmsd'}++	; 
	$ports_ref->{'rpc'}{'cmsd'}{'name'} = 'cmsd'		; 
	$srvcobjects_ref->{'gcachefsd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gcachefsd'}{'port'}{'rpc'} = 'gcachefsd'	; 
	$srvcobjects_ref->{'gcachefsd'}{'ports'}{'rpc'}{'gcachefsd'}++	; 
	$ports_ref->{'rpc'}{'gcachefsd'}{'name'} = 'gcachefsd'		; 
	$srvcobjects_ref->{'gcmsd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gcmsd'}{'port'}{'rpc'} = 'gcmsd'	; 
	$srvcobjects_ref->{'gcmsd'}{'ports'}{'rpc'}{'gcmsd'}++	; 
	$ports_ref->{'rpc'}{'gcmsd'}{'name'} = 'gcmsd'		; 
	$srvcobjects_ref->{'gmountd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gmountd'}{'port'}{'rpc'} = 'gmountd'	; 
	$srvcobjects_ref->{'gmountd'}{'ports'}{'rpc'}{'gmountd'}++	; 
	$ports_ref->{'rpc'}{'gmountd'}{'name'} = 'gmountd'		; 
	$srvcobjects_ref->{'gnfsprog'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gnfsprog'}{'port'}{'rpc'} = 'gnfsprog'	; 
	$srvcobjects_ref->{'gnfsprog'}{'ports'}{'rpc'}{'gnfsprog'}++	; 
	$ports_ref->{'rpc'}{'gnfsprog'}{'name'} = 'gnfsprog'		; 
	$srvcobjects_ref->{'gnisplus'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gnisplus'}{'port'}{'rpc'} = 'gnisplus'	; 
	$srvcobjects_ref->{'gnisplus'}{'ports'}{'rpc'}{'gnisplus'}++	; 
	$ports_ref->{'rpc'}{'gnisplus'}{'name'} = 'gnisplus'		; 
	$srvcobjects_ref->{'gnlockmgr'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gnlockmgr'}{'port'}{'rpc'} = 'gnlockmgr'	; 
	$srvcobjects_ref->{'gnlockmgr'}{'ports'}{'rpc'}{'gnlockmgr'}++	; 
	$ports_ref->{'rpc'}{'gnlockmgr'}{'name'} = 'gnlockmgr'		; 
	$srvcobjects_ref->{'gpcnfsd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gpcnfsd'}{'port'}{'rpc'} = 'gpcnfsd'	; 
	$srvcobjects_ref->{'gpcnfsd'}{'ports'}{'rpc'}{'gpcnfsd'}++	; 
	$ports_ref->{'rpc'}{'gpcnfsd'}{'name'} = 'gpcnfsd'		; 
	$srvcobjects_ref->{'grstat'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'grstat'}{'port'}{'rpc'} = 'grstat'	; 
	$srvcobjects_ref->{'grstat'}{'ports'}{'rpc'}{'grstat'}++	; 
	$ports_ref->{'rpc'}{'grstat'}{'name'} = 'grstat'		; 
	$srvcobjects_ref->{'grwall'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'grwall'}{'port'}{'rpc'} = 'grwall'	; 
	$srvcobjects_ref->{'grwall'}{'ports'}{'rpc'}{'grwall'}++	; 
	$ports_ref->{'rpc'}{'grwall'}{'name'} = 'grwall'		; 
	$srvcobjects_ref->{'gsadmind'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gsadmind'}{'port'}{'rpc'} = 'gsadmind'	; 
	$srvcobjects_ref->{'gsadmind'}{'ports'}{'rpc'}{'gsadmind'}++	; 
	$ports_ref->{'rpc'}{'gsadmind'}{'name'} = 'gsadmind'		; 
	$srvcobjects_ref->{'gsnmpXdmid'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gsnmpXdmid'}{'port'}{'rpc'} = 'gsnmpXdmid'	; 
	$srvcobjects_ref->{'gsnmpXdmid'}{'ports'}{'rpc'}{'gsnmpXdmid'}++	; 
	$ports_ref->{'rpc'}{'gsnmpXdmid'}{'name'} = 'gsnmpXdmid'		; 
	$srvcobjects_ref->{'gstatd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gstatd'}{'port'}{'rpc'} = 'gstatd'	; 
	$srvcobjects_ref->{'gstatd'}{'ports'}{'rpc'}{'gstatd'}++	; 
	$ports_ref->{'rpc'}{'gstatd'}{'name'} = 'gstatd'		; 
	$srvcobjects_ref->{'gttdbserverd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gttdbserverd'}{'port'}{'rpc'} = 'gttdbserverd'	; 
	$srvcobjects_ref->{'gttdbserverd'}{'ports'}{'rpc'}{'gttdbserverd'}++	; 
	$ports_ref->{'rpc'}{'gttdbserverd'}{'name'} = 'gttdbserverd'		; 
	$srvcobjects_ref->{'gypbind'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gypbind'}{'port'}{'rpc'} = 'gypbind'	; 
	$srvcobjects_ref->{'gypbind'}{'ports'}{'rpc'}{'gypbind'}++	; 
	$ports_ref->{'rpc'}{'gypbind'}{'name'} = 'gypbind'		; 
	$srvcobjects_ref->{'gyppasswd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gyppasswd'}{'port'}{'rpc'} = 'gyppasswd'	; 
	$srvcobjects_ref->{'gyppasswd'}{'ports'}{'rpc'}{'gyppasswd'}++	; 
	$ports_ref->{'rpc'}{'gyppasswd'}{'name'} = 'gyppasswd'		; 
	$srvcobjects_ref->{'gypserv'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gypserv'}{'port'}{'rpc'} = 'gypserv'	; 
	$srvcobjects_ref->{'gypserv'}{'ports'}{'rpc'}{'gypserv'}++	; 
	$ports_ref->{'rpc'}{'gypserv'}{'name'} = 'gypserv'		; 
	$srvcobjects_ref->{'gypupdated'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gypupdated'}{'port'}{'rpc'} = 'gypupdated'	; 
	$srvcobjects_ref->{'gypupdated'}{'ports'}{'rpc'}{'gypupdated'}++	; 
	$ports_ref->{'rpc'}{'gypupdated'}{'name'} = 'gypupdated'		; 
	$srvcobjects_ref->{'gypxfrd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'gypxfrd'}{'port'}{'rpc'} = 'gypxfrd'	; 
	$srvcobjects_ref->{'gypxfrd'}{'ports'}{'rpc'}{'gypxfrd'}++	; 
	$ports_ref->{'rpc'}{'gypxfrd'}{'name'} = 'gypxfrd'		; 
	$srvcobjects_ref->{'mountd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'mountd'}{'port'}{'rpc'} = 'mountd'	; 
	$srvcobjects_ref->{'mountd'}{'ports'}{'rpc'}{'mountd'}++	; 
	$ports_ref->{'rpc'}{'mountd'}{'name'} = 'mountd'		; 
	$srvcobjects_ref->{'nfsprog'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'nfsprog'}{'port'}{'rpc'} = 'nfsprog'	; 
	$srvcobjects_ref->{'nfsprog'}{'ports'}{'rpc'}{'nfsprog'}++	; 
	$ports_ref->{'rpc'}{'nfsprog'}{'name'} = 'nfsprog'		; 
	$srvcobjects_ref->{'nisplus'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'nisplus'}{'port'}{'rpc'} = 'nisplus'	; 
	$srvcobjects_ref->{'nisplus'}{'ports'}{'rpc'}{'nisplus'}++	; 
	$ports_ref->{'rpc'}{'nisplus'}{'name'} = 'nisplus'		; 
	$srvcobjects_ref->{'nlockmgr'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'nlockmgr'}{'port'}{'rpc'} = 'nlockmgr'	; 
	$srvcobjects_ref->{'nlockmgr'}{'ports'}{'rpc'}{'nlockmgr'}++	; 
	$ports_ref->{'rpc'}{'nlockmgr'}{'name'} = 'nlockmgr'		; 
	$srvcobjects_ref->{'pcnfsd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'pcnfsd'}{'port'}{'rpc'} = 'pcnfsd'	; 
	$srvcobjects_ref->{'pcnfsd'}{'ports'}{'rpc'}{'pcnfsd'}++	; 
	$ports_ref->{'rpc'}{'pcnfsd'}{'name'} = 'pcnfsd'		; 
	$srvcobjects_ref->{'rstat'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'rstat'}{'port'}{'rpc'} = 'rstat'	; 
	$srvcobjects_ref->{'rstat'}{'ports'}{'rpc'}{'rstat'}++	; 
	$ports_ref->{'rpc'}{'rstat'}{'name'} = 'rstat'		; 
	$srvcobjects_ref->{'rwall'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'rwall'}{'port'}{'rpc'} = 'rwall'	; 
	$srvcobjects_ref->{'rwall'}{'ports'}{'rpc'}{'rwall'}++	; 
	$ports_ref->{'rpc'}{'rwall'}{'name'} = 'rwall'		; 
	$srvcobjects_ref->{'sadmind'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'sadmind'}{'port'}{'rpc'} = 'sadmind'	; 
	$srvcobjects_ref->{'sadmind'}{'ports'}{'rpc'}{'sadmind'}++	; 
	$ports_ref->{'rpc'}{'sadmind'}{'name'} = 'sadmind'		; 
	$srvcobjects_ref->{'snmpXdmid'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'snmpXdmid'}{'port'}{'rpc'} = 'snmpXdmid'	; 
	$srvcobjects_ref->{'snmpXdmid'}{'ports'}{'rpc'}{'snmpXdmid'}++	; 
	$ports_ref->{'rpc'}{'snmpXdmid'}{'name'} = 'snmpXdmid'		; 
	$srvcobjects_ref->{'statd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'statd'}{'port'}{'rpc'} = 'statd'	; 
	$srvcobjects_ref->{'statd'}{'ports'}{'rpc'}{'statd'}++	; 
	$ports_ref->{'rpc'}{'statd'}{'name'} = 'statd'		; 
	$srvcobjects_ref->{'ttdbserverd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'ttdbserverd'}{'port'}{'rpc'} = 'ttdbserverd'	; 
	$srvcobjects_ref->{'ttdbserverd'}{'ports'}{'rpc'}{'ttdbserverd'}++	; 
	$ports_ref->{'rpc'}{'ttdbserverd'}{'name'} = 'ttdbserverd'		; 
	$srvcobjects_ref->{'ypbind'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'ypbind'}{'port'}{'rpc'} = 'ypbind'	; 
	$srvcobjects_ref->{'ypbind'}{'ports'}{'rpc'}{'ypbind'}++	; 
	$ports_ref->{'rpc'}{'ypbind'}{'name'} = 'ypbind'		; 
	$srvcobjects_ref->{'yppasswd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'yppasswd'}{'port'}{'rpc'} = 'yppasswd'	; 
	$srvcobjects_ref->{'yppasswd'}{'ports'}{'rpc'}{'yppasswd'}++	; 
	$ports_ref->{'rpc'}{'yppasswd'}{'name'} = 'yppasswd'		; 
	$srvcobjects_ref->{'ypserv'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'ypserv'}{'port'}{'rpc'} = 'ypserv'	; 
	$srvcobjects_ref->{'ypserv'}{'ports'}{'rpc'}{'ypserv'}++	; 
	$ports_ref->{'rpc'}{'ypserv'}{'name'} = 'ypserv'		; 
	$srvcobjects_ref->{'ypupdated'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'ypupdated'}{'port'}{'rpc'} = 'ypupdated'	; 
	$srvcobjects_ref->{'ypupdated'}{'ports'}{'rpc'}{'ypupdated'}++	; 
	$ports_ref->{'rpc'}{'ypupdated'}{'name'} = 'ypupdated'		; 
	$srvcobjects_ref->{'ypxfrd'}{'type'} = 'rpc'	; 
	$srvcobjects_ref->{'ypxfrd'}{'port'}{'rpc'} = 'ypxfrd'	; 
	$srvcobjects_ref->{'ypxfrd'}{'ports'}{'rpc'}{'ypxfrd'}++	; 
	$ports_ref->{'rpc'}{'ypxfrd'}{'name'} = 'ypxfrd'		; 

# NOTE: Checkpoint Default TCP ports with non numeric port addresses that also do have numeric addresses later but are still needed for log matching

	$srvcobjects_ref->{'exec'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'exec'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'exec'}{'port'}{'tcp'} = 'exec'	; 
	$srvcobjects_ref->{'exec'}{'ports'}{'tcp'}{'exec'}++	; 
	$ports_ref->{'tcp'}{'exec'}{'name'} = 'exec'		; 
	$srvcobjects_ref->{'finger'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'finger'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'finger'}{'port'}{'tcp'} = 'finger'	; 
	$srvcobjects_ref->{'finger'}{'ports'}{'tcp'}{'finger'}++	; 
	$ports_ref->{'tcp'}{'finger'}{'name'} = 'finger'		; 
	$srvcobjects_ref->{'ftp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ftp'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'ftp'}{'port'}{'tcp'} = 'ftp'	; 
	$srvcobjects_ref->{'ftp'}{'ports'}{'tcp'}{'ftp'}++	; 
	$ports_ref->{'tcp'}{'ftp'}{'name'} = 'ftp'		; 
	$srvcobjects_ref->{'gopher'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gopher'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'gopher'}{'port'}{'tcp'} = 'gopher'	; 
	$srvcobjects_ref->{'gopher'}{'ports'}{'tcp'}{'gopher'}++	; 
	$ports_ref->{'tcp'}{'gopher'}{'name'} = 'gopher'		; 
	$srvcobjects_ref->{'http'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'http'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'http'}{'port'}{'tcp'} = 'http'	; 
	$srvcobjects_ref->{'http'}{'ports'}{'tcp'}{'http'}++	; 
	$ports_ref->{'tcp'}{'http'}{'name'} = 'http'		; 
	$srvcobjects_ref->{'https'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'https'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'https'}{'port'}{'tcp'} = 'https'	; 
	$srvcobjects_ref->{'https'}{'ports'}{'tcp'}{'https'}++	; 
	$ports_ref->{'tcp'}{'https'}{'name'} = 'https'		; 
	$srvcobjects_ref->{'ident'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ident'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'ident'}{'port'}{'tcp'} = 'ident'	; 
	$srvcobjects_ref->{'ident'}{'ports'}{'tcp'}{'ident'}++	; 
	$ports_ref->{'tcp'}{'ident'}{'name'} = 'ident'		; 
	$srvcobjects_ref->{'imap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'imap'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'imap'}{'port'}{'tcp'} = 'imap'	; 
	$srvcobjects_ref->{'imap'}{'ports'}{'tcp'}{'imap'}++	; 
	$ports_ref->{'tcp'}{'imap'}{'name'} = 'imap'		; 
	$srvcobjects_ref->{'ldap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ldap'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'ldap'}{'port'}{'tcp'} = 'ldap'	; 
	$srvcobjects_ref->{'ldap'}{'ports'}{'tcp'}{'ldap'}++	; 
	$ports_ref->{'tcp'}{'ldap'}{'name'} = 'ldap'		; 
	$srvcobjects_ref->{'login'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'login'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'login'}{'port'}{'tcp'} = 'login'	; 
	$srvcobjects_ref->{'login'}{'ports'}{'tcp'}{'login'}++	; 
	$ports_ref->{'tcp'}{'login'}{'name'} = 'login'		; 
	$srvcobjects_ref->{'nntp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'nntp'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'nntp'}{'port'}{'tcp'} = 'nntp'	; 
	$srvcobjects_ref->{'nntp'}{'ports'}{'tcp'}{'nntp'}++	; 
	$ports_ref->{'tcp'}{'nntp'}{'name'} = 'nntp'		; 
	$srvcobjects_ref->{'rtsp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'rtsp'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'rtsp'}{'port'}{'tcp'} = 'rtsp'	; 
	$srvcobjects_ref->{'rtsp'}{'ports'}{'tcp'}{'rtsp'}++	; 
	$ports_ref->{'tcp'}{'rtsp'}{'name'} = 'rtsp'		; 
	$srvcobjects_ref->{'shell'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'shell'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'shell'}{'port'}{'tcp'} = 'shell'	; 
	$srvcobjects_ref->{'shell'}{'ports'}{'tcp'}{'shell'}++	; 
	$ports_ref->{'tcp'}{'shell'}{'name'} = 'shell'		; 
	$srvcobjects_ref->{'smtp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'smtp'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'smtp'}{'port'}{'tcp'} = 'smtp'	; 
	$srvcobjects_ref->{'smtp'}{'ports'}{'tcp'}{'smtp'}++	; 
	$ports_ref->{'tcp'}{'smtp'}{'name'} = 'smtp'		; 
	$srvcobjects_ref->{'ssh'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ssh'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'ssh'}{'port'}{'tcp'} = 'ssh'	; 
	$srvcobjects_ref->{'ssh'}{'ports'}{'tcp'}{'ssh'}++	; 
	$ports_ref->{'tcp'}{'ssh'}{'name'} = 'ssh'		; 
	$srvcobjects_ref->{'telnet'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'telnet'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'telnet'}{'port'}{'tcp'} = 'telnet'	; 
	$srvcobjects_ref->{'telnet'}{'ports'}{'tcp'}{'telnet'}++	; 
	$ports_ref->{'tcp'}{'telnet'}{'name'} = 'telnet'		; 
	$srvcobjects_ref->{'uucp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'uucp'}{'default'} = 'yes'	; 
	$srvcobjects_ref->{'uucp'}{'port'}{'tcp'} = 'uucp'	; 
	$srvcobjects_ref->{'uucp'}{'ports'}{'tcp'}{'uucp'}++	; 
	$ports_ref->{'tcp'}{'uucp'}{'name'} = 'uucp'		; 

# NOTE: Checkpoint Default TCP ports with non numeric port addresses

	$srvcobjects_ref->{'vosaic-ctrl'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'vosaic-ctrl'}{'port'}{'tcp'} = 'vosaic-ctrl'	; 
	$srvcobjects_ref->{'vosaic-ctrl'}{'ports'}{'tcp'}{'vosaic-ctrl'}++	; 
	$ports_ref->{'tcp'}{'vosaic-ctrl'}{'name'} = 'vosaic-ctrl'		; 
#	$srvcobjects_ref->{'tcp-8080-proxy_service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcp-8080-proxy_service'}{'port'}{'tcp'} = 'tcp-8080-proxy_service'	; 
#	$srvcobjects_ref->{'tcp-8080-proxy_service'}{'ports'}{'tcp'}{'tcp-8080-proxy_service'}++	; 
#	$ports_ref->{'tcp'}{'tcp-8080-proxy_service'}{'name'} = 'tcp-8080-proxy_service'		; 
	$srvcobjects_ref->{'AOL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'AOL'}{'port'}{'tcp'} = 'AOL'	; 
	$srvcobjects_ref->{'AOL'}{'ports'}{'tcp'}{'AOL'}++	; 
	$ports_ref->{'tcp'}{'AOL'}{'name'} = 'AOL'		; 
	$srvcobjects_ref->{'Objects'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Objects'}{'port'}{'tcp'} = 'Objects'	; 
	$srvcobjects_ref->{'Objects'}{'ports'}{'tcp'}{'Objects'}++	; 
	$ports_ref->{'tcp'}{'Objects'}{'name'} = 'Objects'		; 
	$srvcobjects_ref->{'Back_Door_Setup'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Back_Door_Setup'}{'port'}{'tcp'} = 'Back_Door_Setup'	; 
	$srvcobjects_ref->{'Back_Door_Setup'}{'ports'}{'tcp'}{'Back_Door_Setup'}++	; 
	$ports_ref->{'tcp'}{'Back_Door_Setup'}{'name'} = 'Back_Door_Setup'		; 
	$srvcobjects_ref->{'Backage'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Backage'}{'port'}{'tcp'} = 'Backage'	; 
	$srvcobjects_ref->{'Backage'}{'ports'}{'tcp'}{'Backage'}++	; 
	$ports_ref->{'tcp'}{'Backage'}{'name'} = 'Backage'		; 
	$srvcobjects_ref->{'BackDoor-G'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'BackDoor-G'}{'port'}{'tcp'} = 'BackDoor-G'	; 
	$srvcobjects_ref->{'BackDoor-G'}{'ports'}{'tcp'}{'BackDoor-G'}++	; 
	$ports_ref->{'tcp'}{'BackDoor-G'}{'name'} = 'BackDoor-G'		; 
	$srvcobjects_ref->{'BGP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'BGP'}{'port'}{'tcp'} = 'BGP'	; 
	$srvcobjects_ref->{'BGP'}{'ports'}{'tcp'}{'BGP'}++	; 
	$ports_ref->{'tcp'}{'BGP'}{'name'} = 'BGP'		; 
	$srvcobjects_ref->{'Bionet-Setup'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Bionet-Setup'}{'port'}{'tcp'} = 'Bionet-Setup'	; 
	$srvcobjects_ref->{'Bionet-Setup'}{'ports'}{'tcp'}{'Bionet-Setup'}++	; 
	$ports_ref->{'tcp'}{'Bionet-Setup'}{'name'} = 'Bionet-Setup'		; 
	$srvcobjects_ref->{'Citrix_ICA'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Citrix_ICA'}{'port'}{'tcp'} = 'Citrix_ICA'	; 
	$srvcobjects_ref->{'Citrix_ICA'}{'ports'}{'tcp'}{'Citrix_ICA'}++	; 
	$ports_ref->{'tcp'}{'Citrix_ICA'}{'name'} = 'Citrix_ICA'		; 
	$srvcobjects_ref->{'Services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Services'}{'port'}{'tcp'} = 'Services'	; 
	$srvcobjects_ref->{'Services'}{'ports'}{'tcp'}{'Services'}++	; 
	$ports_ref->{'tcp'}{'Services'}{'name'} = 'Services'		; 
	$srvcobjects_ref->{'CP_Exnet_PK'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CP_Exnet_PK'}{'port'}{'tcp'} = 'CP_Exnet_PK'	; 
	$srvcobjects_ref->{'FW1_mgmt'}{'ports'}{'tcp'}{'FW1_mgmt'}++	; 
	$ports_ref->{'tcp'}{'FW1_mgmt'}{'name'} = 'FW1_mgmt'		; 
	$srvcobjects_ref->{'FW1_netso'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_netso'}{'port'}{'tcp'} = 'FW1_netso'	; 
	$srvcobjects_ref->{'FW1_netso'}{'ports'}{'tcp'}{'FW1_netso'}++	; 
	$ports_ref->{'tcp'}{'FW1_netso'}{'name'} = 'FW1_netso'		; 
	$srvcobjects_ref->{'FW1_omi'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_omi'}{'port'}{'tcp'} = 'FW1_omi'	; 
	$srvcobjects_ref->{'FW1_omi'}{'ports'}{'tcp'}{'FW1_omi'}++	; 
	$ports_ref->{'tcp'}{'FW1_omi'}{'name'} = 'FW1_omi'		; 
	$srvcobjects_ref->{'FW1_omi-sic'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_omi-sic'}{'port'}{'tcp'} = 'FW1_omi-sic'	; 
	$srvcobjects_ref->{'FW1_omi-sic'}{'ports'}{'tcp'}{'FW1_omi-sic'}++	; 
	$ports_ref->{'tcp'}{'FW1_omi-sic'}{'name'} = 'FW1_omi-sic'		; 
	$srvcobjects_ref->{'FW1_pslogon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_pslogon'}{'port'}{'tcp'} = 'FW1_pslogon'	; 
	$srvcobjects_ref->{'FW1_pslogon'}{'ports'}{'tcp'}{'FW1_pslogon'}++	; 
	$ports_ref->{'tcp'}{'FW1_pslogon'}{'name'} = 'FW1_pslogon'		; 
	$srvcobjects_ref->{'FW1_pslogon_NG'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_pslogon_NG'}{'port'}{'tcp'} = 'FW1_pslogon_NG'	; 
	$srvcobjects_ref->{'FW1_pslogon_NG'}{'ports'}{'tcp'}{'FW1_pslogon_NG'}++	; 
	$ports_ref->{'tcp'}{'FW1_pslogon_NG'}{'name'} = 'FW1_pslogon_NG'		; 
	$srvcobjects_ref->{'FW1_sam'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_sam'}{'port'}{'tcp'} = 'FW1_sam'	; 
	$srvcobjects_ref->{'FW1_sam'}{'ports'}{'tcp'}{'FW1_sam'}++	; 
	$ports_ref->{'tcp'}{'FW1_sam'}{'name'} = 'FW1_sam'		; 
	$srvcobjects_ref->{'FW1_sds_logon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_sds_logon'}{'port'}{'tcp'} = 'FW1_sds_logon'	; 
	$srvcobjects_ref->{'FW1_sds_logon'}{'ports'}{'tcp'}{'FW1_sds_logon'}++	; 
	$ports_ref->{'tcp'}{'FW1_sds_logon'}{'name'} = 'FW1_sds_logon'		; 
	$srvcobjects_ref->{'FW1_sds_logon_NG'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_sds_logon_NG'}{'port'}{'tcp'} = 'FW1_sds_logon_NG'	; 
	$srvcobjects_ref->{'FW1_sds_logon_NG'}{'ports'}{'tcp'}{'FW1_sds_logon_NG'}++	; 
	$ports_ref->{'tcp'}{'FW1_sds_logon_NG'}{'name'} = 'FW1_sds_logon_NG'		; 
	$srvcobjects_ref->{'FW1_snauth'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_snauth'}{'port'}{'tcp'} = 'FW1_snauth'	; 
	$srvcobjects_ref->{'FW1_snauth'}{'ports'}{'tcp'}{'FW1_snauth'}++	; 
	$ports_ref->{'tcp'}{'FW1_snauth'}{'name'} = 'FW1_snauth'		; 
	$srvcobjects_ref->{'FW1_topo'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_topo'}{'port'}{'tcp'} = 'FW1_topo'	; 
	$srvcobjects_ref->{'FW1_topo'}{'ports'}{'tcp'}{'FW1_topo'}++	; 
	$ports_ref->{'tcp'}{'FW1_topo'}{'name'} = 'FW1_topo'		; 
	$srvcobjects_ref->{'FW1_uaa'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_uaa'}{'port'}{'tcp'} = 'FW1_uaa'	; 
	$srvcobjects_ref->{'FW1_uaa'}{'ports'}{'tcp'}{'FW1_uaa'}++	; 
	$ports_ref->{'tcp'}{'FW1_uaa'}{'name'} = 'FW1_uaa'		; 
	$srvcobjects_ref->{'FW1_ufp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_ufp'}{'port'}{'tcp'} = 'FW1_ufp'	; 
	$srvcobjects_ref->{'FW1_ufp'}{'ports'}{'tcp'}{'FW1_ufp'}++	; 
	$ports_ref->{'tcp'}{'FW1_ufp'}{'name'} = 'FW1_ufp'		; 
	$srvcobjects_ref->{'AOL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'AOL'}{'port'}{'tcp'} = 'AOL'	; 
	$srvcobjects_ref->{'AOL'}{'ports'}{'tcp'}{'AOL'}++	; 
	$ports_ref->{'tcp'}{'AOL'}{'name'} = 'AOL'		; 
	$srvcobjects_ref->{'AP-Defender'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'AP-Defender'}{'port'}{'tcp'} = 'AP-Defender'	; 
	$srvcobjects_ref->{'AP-Defender'}{'ports'}{'tcp'}{'AP-Defender'}++	; 
	$ports_ref->{'tcp'}{'AP-Defender'}{'name'} = 'AP-Defender'		; 
	$srvcobjects_ref->{'AT-Defender'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'AT-Defender'}{'port'}{'tcp'} = 'AT-Defender'	; 
	$srvcobjects_ref->{'AT-Defender'}{'ports'}{'tcp'}{'AT-Defender'}++	; 
	$ports_ref->{'tcp'}{'AT-Defender'}{'name'} = 'AT-Defender'		; 
	$srvcobjects_ref->{'Backage'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Backage'}{'port'}{'tcp'} = 'Backage'	; 
	$srvcobjects_ref->{'Backage'}{'ports'}{'tcp'}{'Backage'}++	; 
	$ports_ref->{'tcp'}{'Backage'}{'name'} = 'Backage'		; 
	$srvcobjects_ref->{'Bionet-Setup'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Bionet-Setup'}{'port'}{'tcp'} = 'Bionet-Setup'	; 
	$srvcobjects_ref->{'Bionet-Setup'}{'ports'}{'tcp'}{'Bionet-Setup'}++	; 
	$ports_ref->{'tcp'}{'Bionet-Setup'}{'name'} = 'Bionet-Setup'		; 
	$srvcobjects_ref->{'Citrix_ICA'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Citrix_ICA'}{'port'}{'tcp'} = 'Citrix_ICA'	; 
	$srvcobjects_ref->{'Citrix_ICA'}{'ports'}{'tcp'}{'Citrix_ICA'}++	; 
	$ports_ref->{'tcp'}{'Citrix_ICA'}{'name'} = 'Citrix_ICA'		; 
	$srvcobjects_ref->{'ConnectedOnLine'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ConnectedOnLine'}{'port'}{'tcp'} = 'ConnectedOnLine'	; 
	$srvcobjects_ref->{'ConnectedOnLine'}{'ports'}{'tcp'}{'ConnectedOnLine'}++	; 
	$ports_ref->{'tcp'}{'ConnectedOnLine'}{'name'} = 'ConnectedOnLine'		; 
	$srvcobjects_ref->{'CP_Exnet_PK'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CP_Exnet_PK'}{'port'}{'tcp'} = 'CP_Exnet_PK'	; 
	$srvcobjects_ref->{'CP_Exnet_PK'}{'ports'}{'tcp'}{'CP_Exnet_PK'}++	; 
	$ports_ref->{'tcp'}{'CP_Exnet_PK'}{'name'} = 'CP_Exnet_PK'		; 
	$srvcobjects_ref->{'CP_Exnet_resolve'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CP_Exnet_resolve'}{'port'}{'tcp'} = 'CP_Exnet_resolve'	; 
	$srvcobjects_ref->{'CP_Exnet_resolve'}{'ports'}{'tcp'}{'CP_Exnet_resolve'}++	; 
	$ports_ref->{'tcp'}{'CP_Exnet_resolve'}{'name'} = 'CP_Exnet_resolve'		; 
	$srvcobjects_ref->{'CP_redundant'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CP_redundant'}{'port'}{'tcp'} = 'CP_redundant'	; 
	$srvcobjects_ref->{'CP_redundant'}{'ports'}{'tcp'}{'CP_redundant'}++	; 
	$ports_ref->{'tcp'}{'CP_redundant'}{'name'} = 'CP_redundant'		; 
	$srvcobjects_ref->{'CP_reporting'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CP_reporting'}{'port'}{'tcp'} = 'CP_reporting'	; 
	$srvcobjects_ref->{'CP_reporting'}{'ports'}{'tcp'}{'CP_reporting'}++	; 
	$ports_ref->{'tcp'}{'CP_reporting'}{'name'} = 'CP_reporting'		; 
	$srvcobjects_ref->{'CP_rtm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CP_rtm'}{'port'}{'tcp'} = 'CP_rtm'	; 
	$srvcobjects_ref->{'CP_rtm'}{'ports'}{'tcp'}{'CP_rtm'}++	; 
	$ports_ref->{'tcp'}{'CP_rtm'}{'name'} = 'CP_rtm'		; 
	$srvcobjects_ref->{'CP_seam'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CP_seam'}{'port'}{'tcp'} = 'CP_seam'	; 
	$srvcobjects_ref->{'CP_seam'}{'ports'}{'tcp'}{'CP_seam'}++	; 
	$ports_ref->{'tcp'}{'CP_seam'}{'name'} = 'CP_seam'		; 
	$srvcobjects_ref->{'CPD'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CPD'}{'port'}{'tcp'} = 'CPD'	; 
	$srvcobjects_ref->{'CPD'}{'ports'}{'tcp'}{'CPD'}++	; 
	$ports_ref->{'tcp'}{'CPD'}{'name'} = 'CPD'		; 
	$srvcobjects_ref->{'CPD_amon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CPD_amon'}{'port'}{'tcp'} = 'CPD_amon'	; 
	$srvcobjects_ref->{'CPD_amon'}{'ports'}{'tcp'}{'CPD_amon'}++	; 
	$ports_ref->{'tcp'}{'CPD_amon'}{'name'} = 'CPD_amon'		; 
	$srvcobjects_ref->{'CPMI'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CPMI'}{'port'}{'tcp'} = 'CPMI'	; 
	$srvcobjects_ref->{'CPMI'}{'ports'}{'tcp'}{'CPMI'}++	; 
	$ports_ref->{'tcp'}{'CPMI'}{'name'} = 'CPMI'		; 
	$srvcobjects_ref->{'CrackDown'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CrackDown'}{'port'}{'tcp'} = 'CrackDown'	; 
	$srvcobjects_ref->{'CrackDown'}{'ports'}{'tcp'}{'CrackDown'}++	; 
	$ports_ref->{'tcp'}{'CrackDown'}{'name'} = 'CrackDown'		; 
	$srvcobjects_ref->{'CreativePartnerClnt'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CreativePartnerClnt'}{'port'}{'tcp'} = 'CreativePartnerClnt'	; 
	$srvcobjects_ref->{'CreativePartnerClnt'}{'ports'}{'tcp'}{'CreativePartnerClnt'}++	; 
	$ports_ref->{'tcp'}{'CreativePartnerClnt'}{'name'} = 'CreativePartnerClnt'		; 
	$srvcobjects_ref->{'CreativePartnerSrvr'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'CreativePartnerSrvr'}{'port'}{'tcp'} = 'CreativePartnerSrvr'	; 
	$srvcobjects_ref->{'CreativePartnerSrvr'}{'ports'}{'tcp'}{'CreativePartnerSrvr'}++	; 
	$ports_ref->{'tcp'}{'CreativePartnerSrvr'}{'name'} = 'CreativePartnerSrvr'		; 
	$srvcobjects_ref->{'DaCryptic'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'DaCryptic'}{'port'}{'tcp'} = 'DaCryptic'	; 
	$srvcobjects_ref->{'DaCryptic'}{'ports'}{'tcp'}{'DaCryptic'}++	; 
	$ports_ref->{'tcp'}{'DaCryptic'}{'name'} = 'DaCryptic'		; 
	$srvcobjects_ref->{'DameWare'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'DameWare'}{'port'}{'tcp'} = 'DameWare'	; 
	$srvcobjects_ref->{'DameWare'}{'ports'}{'tcp'}{'DameWare'}++	; 
	$ports_ref->{'tcp'}{'DameWare'}{'name'} = 'DameWare'		; 
	$srvcobjects_ref->{'daytime-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'daytime-tcp'}{'port'}{'tcp'} = 'daytime-tcp'	; 
	$srvcobjects_ref->{'daytime-tcp'}{'ports'}{'tcp'}{'daytime-tcp'}++	; 
	$ports_ref->{'tcp'}{'daytime-tcp'}{'name'} = 'daytime-tcp'		; 
	$srvcobjects_ref->{'DerSphere'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'DerSphere'}{'port'}{'tcp'} = 'DerSphere'	; 
	$srvcobjects_ref->{'DerSphere'}{'ports'}{'tcp'}{'DerSphere'}++	; 
	$ports_ref->{'tcp'}{'DerSphere'}{'name'} = 'DerSphere'		; 
	$srvcobjects_ref->{'DerSphere_II'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'DerSphere_II'}{'port'}{'tcp'} = 'DerSphere_II'	; 
	$srvcobjects_ref->{'DerSphere_II'}{'ports'}{'tcp'}{'DerSphere_II'}++	; 
	$ports_ref->{'tcp'}{'DerSphere_II'}{'name'} = 'DerSphere_II'		; 
	$srvcobjects_ref->{'Direct_Connect_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Direct_Connect_TCP'}{'port'}{'tcp'} = 'Direct_Connect_TCP'	; 
	$srvcobjects_ref->{'Direct_Connect_TCP'}{'ports'}{'tcp'}{'Direct_Connect_TCP'}++	; 
	$ports_ref->{'tcp'}{'Direct_Connect_TCP'}{'name'} = 'Direct_Connect_TCP'		; 
	$srvcobjects_ref->{'discard-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'discard-tcp'}{'port'}{'tcp'} = 'discard-tcp'	; 
	$srvcobjects_ref->{'discard-tcp'}{'ports'}{'tcp'}{'discard-tcp'}++	; 
	$ports_ref->{'tcp'}{'discard-tcp'}{'name'} = 'discard-tcp'		; 
	$srvcobjects_ref->{'domain-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'domain-tcp'}{'port'}{'tcp'} = 'domain-tcp'	; 
	$srvcobjects_ref->{'domain-tcp'}{'ports'}{'tcp'}{'domain-tcp'}++	; 
	$ports_ref->{'tcp'}{'domain-tcp'}{'name'} = 'domain-tcp'		; 
	$srvcobjects_ref->{'domain-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'domain-tcp'}{'port'}{'tcp'} = 'domain-tcp'	; 
	$srvcobjects_ref->{'domain-tcp'}{'ports'}{'tcp'}{'domain-tcp'}++	; 
	$ports_ref->{'tcp'}{'domain-tcp'}{'name'} = 'domain-tcp'		; 
	$srvcobjects_ref->{'echo-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'echo-tcp'}{'port'}{'tcp'} = 'echo-tcp'	; 
	$srvcobjects_ref->{'echo-tcp'}{'ports'}{'tcp'}{'echo-tcp'}++	; 
	$ports_ref->{'tcp'}{'echo-tcp'}{'name'} = 'echo-tcp'		; 
	$srvcobjects_ref->{'eDonkey_4661'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'eDonkey_4661'}{'port'}{'tcp'} = 'eDonkey_4661'	; 
	$srvcobjects_ref->{'eDonkey_4661'}{'ports'}{'tcp'}{'eDonkey_4661'}++	; 
	$ports_ref->{'tcp'}{'eDonkey_4661'}{'name'} = 'eDonkey_4661'		; 
	$srvcobjects_ref->{'eDonkey_4662'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'eDonkey_4662'}{'port'}{'tcp'} = 'eDonkey_4662'	; 
	$srvcobjects_ref->{'eDonkey_4662'}{'ports'}{'tcp'}{'eDonkey_4662'}++	; 
	$ports_ref->{'tcp'}{'eDonkey_4662'}{'name'} = 'eDonkey_4662'		; 
	$srvcobjects_ref->{'Entrust-Admin'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Entrust-Admin'}{'port'}{'tcp'} = 'Entrust-Admin'	; 
	$srvcobjects_ref->{'Entrust-Admin'}{'ports'}{'tcp'}{'Entrust-Admin'}++	; 
	$ports_ref->{'tcp'}{'Entrust-Admin'}{'name'} = 'Entrust-Admin'		; 
	$srvcobjects_ref->{'Entrust-KeyMgmt'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Entrust-KeyMgmt'}{'port'}{'tcp'} = 'Entrust-KeyMgmt'	; 
	$srvcobjects_ref->{'Entrust-KeyMgmt'}{'ports'}{'tcp'}{'Entrust-KeyMgmt'}++	; 
	$ports_ref->{'tcp'}{'Entrust-KeyMgmt'}{'name'} = 'Entrust-KeyMgmt'		; 
	$srvcobjects_ref->{'exec'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'exec'}{'port'}{'tcp'} = 'exec'	; 
	$srvcobjects_ref->{'exec'}{'ports'}{'tcp'}{'exec'}++	; 
	$ports_ref->{'tcp'}{'exec'}{'name'} = 'exec'		; 
	$srvcobjects_ref->{'FIBMGR'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FIBMGR'}{'port'}{'tcp'} = 'FIBMGR'	; 
	$srvcobjects_ref->{'FIBMGR'}{'ports'}{'tcp'}{'FIBMGR'}++	; 
	$ports_ref->{'tcp'}{'FIBMGR'}{'name'} = 'FIBMGR'		; 
	$srvcobjects_ref->{'finger'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'finger'}{'port'}{'tcp'} = 'finger'	; 
	$srvcobjects_ref->{'finger'}{'ports'}{'tcp'}{'finger'}++	; 
	$ports_ref->{'tcp'}{'finger'}{'name'} = 'finger'		; 
	$srvcobjects_ref->{'Freak2k'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Freak2k'}{'port'}{'tcp'} = 'Freak2k'	; 
	$srvcobjects_ref->{'Freak2k'}{'ports'}{'tcp'}{'Freak2k'}++	; 
	$ports_ref->{'tcp'}{'Freak2k'}{'name'} = 'Freak2k'		; 
	$srvcobjects_ref->{'ftp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ftp'}{'port'}{'tcp'} = 'ftp'	; 
	$srvcobjects_ref->{'ftp'}{'ports'}{'tcp'}{'ftp'}++	; 
	$ports_ref->{'tcp'}{'ftp'}{'name'} = 'ftp'		; 
	$srvcobjects_ref->{'ftp-bidir'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ftp-bidir'}{'port'}{'tcp'} = 'ftp-bidir'	; 
	$srvcobjects_ref->{'ftp-bidir'}{'ports'}{'tcp'}{'ftp-bidir'}++	; 
	$ports_ref->{'tcp'}{'ftp-bidir'}{'name'} = 'ftp-bidir'		; 
	$srvcobjects_ref->{'ftp-pasv'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ftp-pasv'}{'port'}{'tcp'} = 'ftp-pasv'	; 
	$srvcobjects_ref->{'ftp-pasv'}{'ports'}{'tcp'}{'ftp-pasv'}++	; 
	$ports_ref->{'tcp'}{'ftp-pasv'}{'name'} = 'ftp-pasv'		; 
	$srvcobjects_ref->{'ftp-port'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ftp-port'}{'port'}{'tcp'} = 'ftp-port'	; 
	$srvcobjects_ref->{'ftp-port'}{'ports'}{'tcp'}{'ftp-port'}++	; 
	$ports_ref->{'tcp'}{'ftp-port'}{'name'} = 'ftp-port'		; 
	$srvcobjects_ref->{'FW1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1'}{'port'}{'tcp'} = 'FW1'	; 
	$srvcobjects_ref->{'FW1'}{'ports'}{'tcp'}{'FW1'}++	; 
	$ports_ref->{'tcp'}{'FW1'}{'name'} = 'FW1'		; 
	$srvcobjects_ref->{'FW1_amon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_amon'}{'port'}{'tcp'} = 'FW1_amon'	; 
	$srvcobjects_ref->{'FW1_amon'}{'ports'}{'tcp'}{'FW1_amon'}++	; 
	$ports_ref->{'tcp'}{'FW1_amon'}{'name'} = 'FW1_amon'		; 
	$srvcobjects_ref->{'FW1_clntauth_http'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_clntauth_http'}{'port'}{'tcp'} = 'FW1_clntauth_http'	; 
	$srvcobjects_ref->{'FW1_clntauth_http'}{'ports'}{'tcp'}{'FW1_clntauth_http'}++	; 
	$ports_ref->{'tcp'}{'FW1_clntauth_http'}{'name'} = 'FW1_clntauth_http'		; 
	$srvcobjects_ref->{'FW1_clntauth_telnet'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_clntauth_telnet'}{'port'}{'tcp'} = 'FW1_clntauth_telnet'	; 
	$srvcobjects_ref->{'FW1_clntauth_telnet'}{'ports'}{'tcp'}{'FW1_clntauth_telnet'}++	; 
	$ports_ref->{'tcp'}{'FW1_clntauth_telnet'}{'name'} = 'FW1_clntauth_telnet'		; 
	$srvcobjects_ref->{'FW1_CPRID'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_CPRID'}{'port'}{'tcp'} = 'FW1_CPRID'	; 
	$srvcobjects_ref->{'FW1_CPRID'}{'ports'}{'tcp'}{'FW1_CPRID'}++	; 
	$ports_ref->{'tcp'}{'FW1_CPRID'}{'name'} = 'FW1_CPRID'		; 
	$srvcobjects_ref->{'FW1_cvp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_cvp'}{'port'}{'tcp'} = 'FW1_cvp'	; 
	$srvcobjects_ref->{'FW1_cvp'}{'ports'}{'tcp'}{'FW1_cvp'}++	; 
	$ports_ref->{'tcp'}{'FW1_cvp'}{'name'} = 'FW1_cvp'		; 
	$srvcobjects_ref->{'FW1_ela'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_ela'}{'port'}{'tcp'} = 'FW1_ela'	; 
	$srvcobjects_ref->{'FW1_ela'}{'ports'}{'tcp'}{'FW1_ela'}++	; 
	$ports_ref->{'tcp'}{'FW1_ela'}{'name'} = 'FW1_ela'		; 
	$srvcobjects_ref->{'FW1_ica_mgmt_tools'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_ica_mgmt_tools'}{'port'}{'tcp'} = 'FW1_ica_mgmt_tools'	; 
	$srvcobjects_ref->{'FW1_ica_mgmt_tools'}{'ports'}{'tcp'}{'FW1_ica_mgmt_tools'}++	; 
	$ports_ref->{'tcp'}{'FW1_ica_mgmt_tools'}{'name'} = 'FW1_ica_mgmt_tools'		; 
	$srvcobjects_ref->{'FW1_ica_pull'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_ica_pull'}{'port'}{'tcp'} = 'FW1_ica_pull'	; 
	$srvcobjects_ref->{'FW1_ica_pull'}{'ports'}{'tcp'}{'FW1_ica_pull'}++	; 
	$ports_ref->{'tcp'}{'FW1_ica_pull'}{'name'} = 'FW1_ica_pull'		; 
	$srvcobjects_ref->{'FW1_ica_push'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_ica_push'}{'port'}{'tcp'} = 'FW1_ica_push'	; 
	$srvcobjects_ref->{'FW1_ica_push'}{'ports'}{'tcp'}{'FW1_ica_push'}++	; 
	$ports_ref->{'tcp'}{'FW1_ica_push'}{'name'} = 'FW1_ica_push'		; 
	$srvcobjects_ref->{'FW1_ica_services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_ica_services'}{'port'}{'tcp'} = 'FW1_ica_services'	; 
	$srvcobjects_ref->{'FW1_ica_services'}{'ports'}{'tcp'}{'FW1_ica_services'}++	; 
	$ports_ref->{'tcp'}{'FW1_ica_services'}{'name'} = 'FW1_ica_services'		; 
	$srvcobjects_ref->{'FW1_key'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_key'}{'port'}{'tcp'} = 'FW1_key'	; 
	$srvcobjects_ref->{'FW1_key'}{'ports'}{'tcp'}{'FW1_key'}++	; 
	$ports_ref->{'tcp'}{'FW1_key'}{'name'} = 'FW1_key'		; 
	$srvcobjects_ref->{'FW1_lea'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_lea'}{'port'}{'tcp'} = 'FW1_lea'	; 
	$srvcobjects_ref->{'FW1_lea'}{'ports'}{'tcp'}{'FW1_lea'}++	; 
	$ports_ref->{'tcp'}{'FW1_lea'}{'name'} = 'FW1_lea'		; 
	$srvcobjects_ref->{'FW1_log'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_log'}{'port'}{'tcp'} = 'FW1_log'	; 
	$srvcobjects_ref->{'FW1_log'}{'ports'}{'tcp'}{'FW1_log'}++	; 
	$ports_ref->{'tcp'}{'FW1_log'}{'name'} = 'FW1_log'		; 
	$srvcobjects_ref->{'FW1_mgmt'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_mgmt'}{'port'}{'tcp'} = 'FW1_mgmt'	; 
	$srvcobjects_ref->{'FW1_mgmt'}{'ports'}{'tcp'}{'FW1_mgmt'}++	; 
	$ports_ref->{'tcp'}{'FW1_mgmt'}{'name'} = 'FW1_mgmt'		; 
	$srvcobjects_ref->{'FW1_netso'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_netso'}{'port'}{'tcp'} = 'FW1_netso'	; 
	$srvcobjects_ref->{'FW1_netso'}{'ports'}{'tcp'}{'FW1_netso'}++	; 
	$ports_ref->{'tcp'}{'FW1_netso'}{'name'} = 'FW1_netso'		; 
	$srvcobjects_ref->{'FW1_omi'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_omi'}{'port'}{'tcp'} = 'FW1_omi'	; 
	$srvcobjects_ref->{'FW1_omi'}{'ports'}{'tcp'}{'FW1_omi'}++	; 
	$ports_ref->{'tcp'}{'FW1_omi'}{'name'} = 'FW1_omi'		; 
	$srvcobjects_ref->{'FW1_omi-sic'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_omi-sic'}{'port'}{'tcp'} = 'FW1_omi-sic'	; 
	$srvcobjects_ref->{'FW1_omi-sic'}{'ports'}{'tcp'}{'FW1_omi-sic'}++	; 
	$ports_ref->{'tcp'}{'FW1_omi-sic'}{'name'} = 'FW1_omi-sic'		; 
	$srvcobjects_ref->{'FW1_pslogon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_pslogon'}{'port'}{'tcp'} = 'FW1_pslogon'	; 
	$srvcobjects_ref->{'FW1_pslogon'}{'ports'}{'tcp'}{'FW1_pslogon'}++	; 
	$ports_ref->{'tcp'}{'FW1_pslogon'}{'name'} = 'FW1_pslogon'		; 
	$srvcobjects_ref->{'20061229'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'20061229'}{'port'}{'tcp'} = '20061229'	; 
	$srvcobjects_ref->{'20061229'}{'ports'}{'tcp'}{'20061229'}++	; 
	$ports_ref->{'tcp'}{'20061229'}{'name'} = '20061229'		; 
	$srvcobjects_ref->{'FW1_pslogon_NG'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_pslogon_NG'}{'port'}{'tcp'} = 'FW1_pslogon_NG'	; 
	$srvcobjects_ref->{'FW1_pslogon_NG'}{'ports'}{'tcp'}{'FW1_pslogon_NG'}++	; 
	$ports_ref->{'tcp'}{'FW1_pslogon_NG'}{'name'} = 'FW1_pslogon_NG'		; 
	$srvcobjects_ref->{'FW1_sam'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_sam'}{'port'}{'tcp'} = 'FW1_sam'	; 
	$srvcobjects_ref->{'FW1_sam'}{'ports'}{'tcp'}{'FW1_sam'}++	; 
	$ports_ref->{'tcp'}{'FW1_sam'}{'name'} = 'FW1_sam'		; 
	$srvcobjects_ref->{'FW1_sds_logon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_sds_logon'}{'port'}{'tcp'} = 'FW1_sds_logon'	; 
	$srvcobjects_ref->{'FW1_sds_logon'}{'ports'}{'tcp'}{'FW1_sds_logon'}++	; 
	$ports_ref->{'tcp'}{'FW1_sds_logon'}{'name'} = 'FW1_sds_logon'		; 
	$srvcobjects_ref->{'FW1_sds_logon_NG'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_sds_logon_NG'}{'port'}{'tcp'} = 'FW1_sds_logon_NG'	; 
	$srvcobjects_ref->{'FW1_sds_logon_NG'}{'ports'}{'tcp'}{'FW1_sds_logon_NG'}++	; 
	$ports_ref->{'tcp'}{'FW1_sds_logon_NG'}{'name'} = 'FW1_sds_logon_NG'		; 
	$srvcobjects_ref->{'FW1_snauth'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_snauth'}{'port'}{'tcp'} = 'FW1_snauth'	; 
	$srvcobjects_ref->{'FW1_snauth'}{'ports'}{'tcp'}{'FW1_snauth'}++	; 
	$ports_ref->{'tcp'}{'FW1_snauth'}{'name'} = 'FW1_snauth'		; 
	$srvcobjects_ref->{'FW1_topo'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_topo'}{'port'}{'tcp'} = 'FW1_topo'	; 
	$srvcobjects_ref->{'FW1_topo'}{'ports'}{'tcp'}{'FW1_topo'}++	; 
	$ports_ref->{'tcp'}{'FW1_topo'}{'name'} = 'FW1_topo'		; 
	$srvcobjects_ref->{'FW1_uaa'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_uaa'}{'port'}{'tcp'} = 'FW1_uaa'	; 
	$srvcobjects_ref->{'FW1_uaa'}{'ports'}{'tcp'}{'FW1_uaa'}++	; 
	$ports_ref->{'tcp'}{'FW1_uaa'}{'name'} = 'FW1_uaa'		; 
	$srvcobjects_ref->{'FW1_ufp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'FW1_ufp'}{'port'}{'tcp'} = 'FW1_ufp'	; 
	$srvcobjects_ref->{'FW1_ufp'}{'ports'}{'tcp'}{'FW1_ufp'}++	; 
	$ports_ref->{'tcp'}{'FW1_ufp'}{'name'} = 'FW1_ufp'		; 
	$srvcobjects_ref->{'GateCrasher'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GateCrasher'}{'port'}{'tcp'} = 'GateCrasher'	; 
	$srvcobjects_ref->{'GateCrasher'}{'ports'}{'tcp'}{'GateCrasher'}++	; 
	$ports_ref->{'tcp'}{'GateCrasher'}{'name'} = 'GateCrasher'		; 
	$srvcobjects_ref->{'GNUtella_rtr_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GNUtella_rtr_TCP'}{'port'}{'tcp'} = 'GNUtella_rtr_TCP'	; 
	$srvcobjects_ref->{'GNUtella_rtr_TCP'}{'ports'}{'tcp'}{'GNUtella_rtr_TCP'}++	; 
	$ports_ref->{'tcp'}{'GNUtella_rtr_TCP'}{'name'} = 'GNUtella_rtr_TCP'		; 
	$srvcobjects_ref->{'GNUtella_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GNUtella_TCP'}{'port'}{'tcp'} = 'GNUtella_TCP'	; 
	$srvcobjects_ref->{'GNUtella_TCP'}{'ports'}{'tcp'}{'GNUtella_TCP'}++	; 
	$ports_ref->{'tcp'}{'GNUtella_TCP'}{'name'} = 'GNUtella_TCP'		; 
	$srvcobjects_ref->{'opher'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'opher'}{'port'}{'tcp'} = 'opher'	; 
	$srvcobjects_ref->{'opher'}{'ports'}{'tcp'}{'opher'}++	; 
	$ports_ref->{'tcp'}{'opher'}{'name'} = 'opher'		; 
	$srvcobjects_ref->{'GoToMyPC'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GoToMyPC'}{'port'}{'tcp'} = 'GoToMyPC'	; 
	$srvcobjects_ref->{'GoToMyPC'}{'ports'}{'tcp'}{'GoToMyPC'}++	; 
	$ports_ref->{'tcp'}{'GoToMyPC'}{'name'} = 'GoToMyPC'		; 
	$srvcobjects_ref->{'H323'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'H323'}{'port'}{'tcp'} = 'H323'	; 
	$srvcobjects_ref->{'H323'}{'ports'}{'tcp'}{'H323'}++	; 
	$ports_ref->{'tcp'}{'H323'}{'name'} = 'H323'		; 
	$srvcobjects_ref->{'H323_any'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'H323_any'}{'port'}{'tcp'} = 'H323_any'	; 
	$srvcobjects_ref->{'H323_any'}{'ports'}{'tcp'}{'H323_any'}++	; 
	$ports_ref->{'tcp'}{'H323_any'}{'name'} = 'H323_any'		; 
	$srvcobjects_ref->{'HackaTack_31785'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31785'}{'port'}{'tcp'} = 'HackaTack_31785'	; 
	$srvcobjects_ref->{'HackaTack_31785'}{'ports'}{'tcp'}{'HackaTack_31785'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31785'}{'name'} = 'HackaTack_31785'		; 
	$srvcobjects_ref->{'HackaTack_31787'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31787'}{'port'}{'tcp'} = 'HackaTack_31787'	; 
	$srvcobjects_ref->{'HackaTack_31787'}{'ports'}{'tcp'}{'HackaTack_31787'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31787'}{'name'} = 'HackaTack_31787'		; 
	$srvcobjects_ref->{'HackaTack_31788'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31788'}{'port'}{'tcp'} = 'HackaTack_31788'	; 
	$srvcobjects_ref->{'HackaTack_31788'}{'ports'}{'tcp'}{'HackaTack_31788'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31788'}{'name'} = 'HackaTack_31788'		; 
	$srvcobjects_ref->{'HackaTack_31790'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31790'}{'port'}{'tcp'} = 'HackaTack_31790'	; 
	$srvcobjects_ref->{'HackaTack_31790'}{'ports'}{'tcp'}{'HackaTack_31790'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31790'}{'name'} = 'HackaTack_31790'		; 
	$srvcobjects_ref->{'HackaTack_31792'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31792'}{'port'}{'tcp'} = 'HackaTack_31792'	; 
	$srvcobjects_ref->{'HackaTack_31792'}{'ports'}{'tcp'}{'HackaTack_31792'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31792'}{'name'} = 'HackaTack_31792'		; 
	$srvcobjects_ref->{'Hotline_client'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Hotline_client'}{'port'}{'tcp'} = 'Hotline_client'	; 
	$srvcobjects_ref->{'Hotline_client'}{'ports'}{'tcp'}{'Hotline_client'}++	; 
	$ports_ref->{'tcp'}{'Hotline_client'}{'name'} = 'Hotline_client'		; 
	$srvcobjects_ref->{'http'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'http'}{'port'}{'tcp'} = 'http'	; 
	$srvcobjects_ref->{'http'}{'ports'}{'tcp'}{'http'}++	; 
	$ports_ref->{'tcp'}{'http'}{'name'} = 'http'		; 
	$srvcobjects_ref->{'https'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'https'}{'port'}{'tcp'} = 'https'	; 
	$srvcobjects_ref->{'https'}{'ports'}{'tcp'}{'https'}++	; 
	$ports_ref->{'tcp'}{'https'}{'name'} = 'https'		; 
	$srvcobjects_ref->{'ICKiller'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ICKiller'}{'port'}{'tcp'} = 'ICKiller'	; 
	$srvcobjects_ref->{'ICKiller'}{'ports'}{'tcp'}{'ICKiller'}++	; 
	$ports_ref->{'tcp'}{'ICKiller'}{'name'} = 'ICKiller'		; 
	$srvcobjects_ref->{'ident'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ident'}{'port'}{'tcp'} = 'ident'	; 
	$srvcobjects_ref->{'ident'}{'ports'}{'tcp'}{'ident'}++	; 
	$ports_ref->{'tcp'}{'ident'}{'name'} = 'ident'		; 
	$srvcobjects_ref->{'IKE_tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'IKE_tcp'}{'port'}{'tcp'} = 'IKE_tcp'	; 
	$srvcobjects_ref->{'IKE_tcp'}{'ports'}{'tcp'}{'IKE_tcp'}++	; 
	$ports_ref->{'tcp'}{'IKE_tcp'}{'name'} = 'IKE_tcp'		; 
	$srvcobjects_ref->{'imap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'imap'}{'port'}{'tcp'} = 'imap'	; 
	$srvcobjects_ref->{'imap'}{'ports'}{'tcp'}{'imap'}++	; 
	$ports_ref->{'tcp'}{'imap'}{'name'} = 'imap'		; 
	$srvcobjects_ref->{'iMesh'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'iMesh'}{'port'}{'tcp'} = 'iMesh'	; 
	$srvcobjects_ref->{'iMesh'}{'ports'}{'tcp'}{'iMesh'}++	; 
	$ports_ref->{'tcp'}{'iMesh'}{'name'} = 'iMesh'		; 
	$srvcobjects_ref->{'InCommand'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'InCommand'}{'port'}{'tcp'} = 'InCommand'	; 
	$srvcobjects_ref->{'InCommand'}{'ports'}{'tcp'}{'InCommand'}++	; 
	$ports_ref->{'tcp'}{'InCommand'}{'name'} = 'InCommand'		; 
	$srvcobjects_ref->{'IPSO_Clustering_Mgmt_Protocol'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'IPSO_Clustering_Mgmt_Protocol'}{'port'}{'tcp'} = 'IPSO_Clustering_Mgmt_Protocol'	; 
	$srvcobjects_ref->{'IPSO_Clustering_Mgmt_Protocol'}{'ports'}{'tcp'}{'IPSO_Clustering_Mgmt_Protocol'}++	; 
	$ports_ref->{'tcp'}{'IPSO_Clustering_Mgmt_Protocol'}{'name'} = 'IPSO_Clustering_Mgmt_Protocol'		; 
	$srvcobjects_ref->{'irc1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'irc1'}{'port'}{'tcp'} = 'irc1'	; 
	$srvcobjects_ref->{'irc1'}{'ports'}{'tcp'}{'irc1'}++	; 
	$ports_ref->{'tcp'}{'irc1'}{'name'} = 'irc1'		; 
	$srvcobjects_ref->{'irc2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'irc2'}{'port'}{'tcp'} = 'irc2'	; 
	$srvcobjects_ref->{'irc2'}{'ports'}{'tcp'}{'irc2'}++	; 
	$ports_ref->{'tcp'}{'irc2'}{'name'} = 'irc2'		; 
	$srvcobjects_ref->{'Jade'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Jade'}{'port'}{'tcp'} = 'Jade'	; 
	$srvcobjects_ref->{'Jade'}{'ports'}{'tcp'}{'Jade'}++	; 
	$ports_ref->{'tcp'}{'Jade'}{'name'} = 'Jade'		; 
	$srvcobjects_ref->{'Kaos'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Kaos'}{'port'}{'tcp'} = 'Kaos'	; 
	$srvcobjects_ref->{'Kaos'}{'ports'}{'tcp'}{'Kaos'}++	; 
	$ports_ref->{'tcp'}{'Kaos'}{'name'} = 'Kaos'		; 
	$srvcobjects_ref->{'KaZaA'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'KaZaA'}{'port'}{'tcp'} = 'KaZaA'	; 
	$srvcobjects_ref->{'KaZaA'}{'ports'}{'tcp'}{'KaZaA'}++	; 
	$ports_ref->{'tcp'}{'KaZaA'}{'name'} = 'KaZaA'		; 
	$srvcobjects_ref->{'Kerberos_v5_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Kerberos_v5_TCP'}{'port'}{'tcp'} = 'Kerberos_v5_TCP'	; 
	$srvcobjects_ref->{'Kerberos_v5_TCP'}{'ports'}{'tcp'}{'Kerberos_v5_TCP'}++	; 
	$ports_ref->{'tcp'}{'Kerberos_v5_TCP'}{'name'} = 'Kerberos_v5_TCP'		; 
	$srvcobjects_ref->{'Kuang2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Kuang2'}{'port'}{'tcp'} = 'Kuang2'	; 
	$srvcobjects_ref->{'Kuang2'}{'ports'}{'tcp'}{'Kuang2'}++	; 
	$ports_ref->{'tcp'}{'Kuang2'}{'name'} = 'Kuang2'		; 
	$srvcobjects_ref->{'ldap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ldap'}{'port'}{'tcp'} = 'ldap'	; 
	$srvcobjects_ref->{'ldap'}{'ports'}{'tcp'}{'ldap'}++	; 
	$ports_ref->{'tcp'}{'ldap'}{'name'} = 'ldap'		; 
	$srvcobjects_ref->{'ldap-ssl'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ldap-ssl'}{'port'}{'tcp'} = 'ldap-ssl'	; 
	$srvcobjects_ref->{'ldap-ssl'}{'ports'}{'tcp'}{'ldap-ssl'}++	; 
	$ports_ref->{'tcp'}{'ldap-ssl'}{'name'} = 'ldap-ssl'		; 
	$srvcobjects_ref->{'login'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'login'}{'port'}{'tcp'} = 'login'	; 
	$srvcobjects_ref->{'login'}{'ports'}{'tcp'}{'login'}++	; 
	$ports_ref->{'tcp'}{'login'}{'name'} = 'login'		; 
	$srvcobjects_ref->{'lotus'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'lotus'}{'port'}{'tcp'} = 'lotus'	; 
	$srvcobjects_ref->{'lotus'}{'ports'}{'tcp'}{'lotus'}++	; 
	$ports_ref->{'tcp'}{'lotus'}{'name'} = 'lotus'		; 
	$srvcobjects_ref->{'lpdw0rm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'lpdw0rm'}{'port'}{'tcp'} = 'lpdw0rm'	; 
	$srvcobjects_ref->{'lpdw0rm'}{'ports'}{'tcp'}{'lpdw0rm'}++	; 
	$ports_ref->{'tcp'}{'lpdw0rm'}{'name'} = 'lpdw0rm'		; 
	$srvcobjects_ref->{'Madster'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Madster'}{'port'}{'tcp'} = 'Madster'	; 
	$srvcobjects_ref->{'Madster'}{'ports'}{'tcp'}{'Madster'}++	; 
	$ports_ref->{'tcp'}{'Madster'}{'name'} = 'Madster'		; 
	$srvcobjects_ref->{'microsoft-ds'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'microsoft-ds'}{'port'}{'tcp'} = 'microsoft-ds'	; 
	$srvcobjects_ref->{'microsoft-ds'}{'ports'}{'tcp'}{'microsoft-ds'}++	; 
	$ports_ref->{'tcp'}{'microsoft-ds'}{'name'} = 'microsoft-ds'		; 
	$srvcobjects_ref->{'Mneah'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Mneah'}{'port'}{'tcp'} = 'Mneah'	; 
	$srvcobjects_ref->{'Mneah'}{'ports'}{'tcp'}{'Mneah'}++	; 
	$ports_ref->{'tcp'}{'Mneah'}{'name'} = 'Mneah'		; 
	$srvcobjects_ref->{'MSN_Messenger_File_Transfer'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MSN_Messenger_File_Transfer'}{'port'}{'tcp'} = 'MSN_Messenger_File_Transfer'	; 
	$srvcobjects_ref->{'MSN_Messenger_File_Transfer'}{'ports'}{'tcp'}{'MSN_Messenger_File_Transfer'}++	; 
	$ports_ref->{'tcp'}{'MSN_Messenger_File_Transfer'}{'name'} = 'MSN_Messenger_File_Transfer'		; 
	$srvcobjects_ref->{'MSNMS'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MSNMS'}{'port'}{'tcp'} = 'MSNMS'	; 
	$srvcobjects_ref->{'MSNMS'}{'ports'}{'tcp'}{'MSNMS'}++	; 
	$ports_ref->{'tcp'}{'MSNMS'}{'name'} = 'MSNMS'		; 
	$srvcobjects_ref->{'MSNP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MSNP'}{'port'}{'tcp'} = 'MSNP'	; 
	$srvcobjects_ref->{'MSNP'}{'ports'}{'tcp'}{'MSNP'}++	; 
	$ports_ref->{'tcp'}{'MSNP'}{'name'} = 'MSNP'		; 
	$srvcobjects_ref->{'MS-SQL-Monitor'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor'}{'port'}{'tcp'} = 'MS-SQL-Monitor'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor'}{'ports'}{'tcp'}{'MS-SQL-Monitor'}++	; 
	$ports_ref->{'tcp'}{'MS-SQL-Monitor'}{'name'} = 'MS-SQL-Monitor'		; 
	$srvcobjects_ref->{'MS-SQL-Server'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MS-SQL-Server'}{'port'}{'tcp'} = 'MS-SQL-Server'	; 
	$srvcobjects_ref->{'MS-SQL-Server'}{'ports'}{'tcp'}{'MS-SQL-Server'}++	; 
	$ports_ref->{'tcp'}{'MS-SQL-Server'}{'name'} = 'MS-SQL-Server'		; 
	$srvcobjects_ref->{'Multidropper'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Multidropper'}{'port'}{'tcp'} = 'Multidropper'	; 
	$srvcobjects_ref->{'Multidropper'}{'ports'}{'tcp'}{'Multidropper'}++	; 
	$ports_ref->{'tcp'}{'Multidropper'}{'name'} = 'Multidropper'		; 
	$srvcobjects_ref->{'MySQL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MySQL'}{'port'}{'tcp'} = 'MySQL'	; 
	$srvcobjects_ref->{'MySQL'}{'ports'}{'tcp'}{'MySQL'}++	; 
	$ports_ref->{'tcp'}{'MySQL'}{'name'} = 'MySQL'		; 
	$srvcobjects_ref->{'Napster_Client_6600-6699'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_Client_6600-6699'}{'port'}{'tcp'} = 'Napster_Client_6600-6699'	; 
	$srvcobjects_ref->{'Napster_Client_6600-6699'}{'ports'}{'tcp'}{'Napster_Client_6600-6699'}++	; 
	$ports_ref->{'tcp'}{'Napster_Client_6600-6699'}{'name'} = 'Napster_Client_6600-6699'		; 
	$srvcobjects_ref->{'Napster_directory_4444'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_4444'}{'port'}{'tcp'} = 'Napster_directory_4444'	; 
	$srvcobjects_ref->{'Napster_directory_4444'}{'ports'}{'tcp'}{'Napster_directory_4444'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_4444'}{'name'} = 'Napster_directory_4444'		; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'port'}{'tcp'} = 'Napster_directory_5555'	; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'ports'}{'tcp'}{'Napster_directory_5555'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_5555'}{'name'} = 'Napster_directory_5555'		; 
	$srvcobjects_ref->{'Napster_directory_6666'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_6666'}{'port'}{'tcp'} = 'Napster_directory_6666'	; 
	$srvcobjects_ref->{'Napster_directory_6666'}{'ports'}{'tcp'}{'Napster_directory_6666'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_6666'}{'name'} = 'Napster_directory_6666'		; 
	$srvcobjects_ref->{'Napster_directory_7777'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_7777'}{'port'}{'tcp'} = 'Napster_directory_7777'	; 
	$srvcobjects_ref->{'Napster_directory_7777'}{'ports'}{'tcp'}{'Napster_directory_7777'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_7777'}{'name'} = 'Napster_directory_7777'		; 
	$srvcobjects_ref->{'Napster_directory_8888_primary'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_8888_primary'}{'port'}{'tcp'} = 'Napster_directory_8888_primary'	; 
	$srvcobjects_ref->{'Napster_directory_8888_primary'}{'ports'}{'tcp'}{'Napster_directory_8888_primary'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_8888_primary'}{'name'} = 'Napster_directory_8888_primary'		; 
	$srvcobjects_ref->{'Napster_redirector'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_redirector'}{'port'}{'tcp'} = 'Napster_redirector'	; 
	$srvcobjects_ref->{'Napster_redirector'}{'ports'}{'tcp'}{'Napster_redirector'}++	; 
	$ports_ref->{'tcp'}{'Napster_redirector'}{'name'} = 'Napster_redirector'		; 
	$srvcobjects_ref->{'nbsession'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'nbsession'}{'port'}{'tcp'} = 'nbsession'	; 
	$srvcobjects_ref->{'nbsession'}{'ports'}{'tcp'}{'nbsession'}++	; 
	$ports_ref->{'tcp'}{'nbsession'}{'name'} = 'nbsession'		; 
	$srvcobjects_ref->{'NCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'NCP'}{'port'}{'tcp'} = 'NCP'	; 
	$srvcobjects_ref->{'NCP'}{'ports'}{'tcp'}{'NCP'}++	; 
	$ports_ref->{'tcp'}{'NCP'}{'name'} = 'NCP'		; 
	$srvcobjects_ref->{'netshow'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'netshow'}{'port'}{'tcp'} = 'netshow'	; 
	$srvcobjects_ref->{'netshow'}{'ports'}{'tcp'}{'netshow'}++	; 
	$ports_ref->{'tcp'}{'netshow'}{'name'} = 'netshow'		; 
	$srvcobjects_ref->{'Services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Services'}{'port'}{'tcp'} = 'Services'	; 
	$srvcobjects_ref->{'Services'}{'ports'}{'tcp'}{'Services'}++	; 
	$ports_ref->{'tcp'}{'Services'}{'name'} = 'Services'		; 
	$srvcobjects_ref->{'nntp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'nntp'}{'port'}{'tcp'} = 'nntp'	; 
	$srvcobjects_ref->{'nntp'}{'ports'}{'tcp'}{'nntp'}++	; 
	$ports_ref->{'tcp'}{'nntp'}{'name'} = 'nntp'		; 
	$srvcobjects_ref->{'ntp-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ntp-tcp'}{'port'}{'tcp'} = 'ntp-tcp'	; 
	$srvcobjects_ref->{'ntp-tcp'}{'ports'}{'tcp'}{'ntp-tcp'}++	; 
	$ports_ref->{'tcp'}{'ntp-tcp'}{'name'} = 'ntp-tcp'		; 
	$srvcobjects_ref->{'OAS-NameServer'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'OAS-NameServer'}{'port'}{'tcp'} = 'OAS-NameServer'	; 
	$srvcobjects_ref->{'OAS-NameServer'}{'ports'}{'tcp'}{'OAS-NameServer'}++	; 
	$ports_ref->{'tcp'}{'OAS-NameServer'}{'name'} = 'OAS-NameServer'		; 
	$srvcobjects_ref->{'OAS-ORB'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'OAS-ORB'}{'port'}{'tcp'} = 'OAS-ORB'	; 
	$srvcobjects_ref->{'OAS-ORB'}{'ports'}{'tcp'}{'OAS-ORB'}++	; 
	$ports_ref->{'tcp'}{'OAS-ORB'}{'name'} = 'OAS-ORB'		; 
	$srvcobjects_ref->{'OpenWindows'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'OpenWindows'}{'port'}{'tcp'} = 'OpenWindows'	; 
	$srvcobjects_ref->{'OpenWindows'}{'ports'}{'tcp'}{'OpenWindows'}++	; 
	$ports_ref->{'tcp'}{'OpenWindows'}{'name'} = 'OpenWindows'		; 
	$srvcobjects_ref->{'Orbix-1570'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Orbix-1570'}{'port'}{'tcp'} = 'Orbix-1570'	; 
	$srvcobjects_ref->{'Orbix-1570'}{'ports'}{'tcp'}{'Orbix-1570'}++	; 
	$ports_ref->{'tcp'}{'Orbix-1570'}{'name'} = 'Orbix-1570'		; 
	$srvcobjects_ref->{'Orbix-1571'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Orbix-1571'}{'port'}{'tcp'} = 'Orbix-1571'	; 
	$srvcobjects_ref->{'Orbix-1571'}{'ports'}{'tcp'}{'Orbix-1571'}++	; 
	$ports_ref->{'tcp'}{'Orbix-1571'}{'name'} = 'Orbix-1571'		; 
	$srvcobjects_ref->{'pcANYWHERE-data'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pcANYWHERE-data'}{'port'}{'tcp'} = 'pcANYWHERE-data'	; 
	$srvcobjects_ref->{'pcANYWHERE-data'}{'ports'}{'tcp'}{'pcANYWHERE-data'}++	; 
	$ports_ref->{'tcp'}{'pcANYWHERE-data'}{'name'} = 'pcANYWHERE-data'		; 
	$srvcobjects_ref->{'pcTELECOMMUTE-FileSync'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pcTELECOMMUTE-FileSync'}{'port'}{'tcp'} = 'pcTELECOMMUTE-FileSync'	; 
	$srvcobjects_ref->{'pcTELECOMMUTE-FileSync'}{'ports'}{'tcp'}{'pcTELECOMMUTE-FileSync'}++	; 
	$ports_ref->{'tcp'}{'pcTELECOMMUTE-FileSync'}{'name'} = 'pcTELECOMMUTE-FileSync'		; 
	$srvcobjects_ref->{'pop-2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pop-2'}{'port'}{'tcp'} = 'pop-2'	; 
	$srvcobjects_ref->{'pop-2'}{'ports'}{'tcp'}{'pop-2'}++	; 
	$ports_ref->{'tcp'}{'pop-2'}{'name'} = 'pop-2'		; 
	$srvcobjects_ref->{'pop-3'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pop-3'}{'port'}{'tcp'} = 'pop-3'	; 
	$srvcobjects_ref->{'pop-3'}{'ports'}{'tcp'}{'pop-3'}++	; 
	$ports_ref->{'tcp'}{'pop-3'}{'name'} = 'pop-3'		; 
	$srvcobjects_ref->{'Port_6667_trojans'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Port_6667_trojans'}{'port'}{'tcp'} = 'Port_6667_trojans'	; 
	$srvcobjects_ref->{'Port_6667_trojans'}{'ports'}{'tcp'}{'Port_6667_trojans'}++	; 
	$ports_ref->{'tcp'}{'Port_6667_trojans'}{'name'} = 'Port_6667_trojans'		; 
	$srvcobjects_ref->{'PostgreSQL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'PostgreSQL'}{'port'}{'tcp'} = 'PostgreSQL'	; 
	$srvcobjects_ref->{'PostgreSQL'}{'ports'}{'tcp'}{'PostgreSQL'}++	; 
	$ports_ref->{'tcp'}{'PostgreSQL'}{'name'} = 'PostgreSQL'		; 
	$srvcobjects_ref->{'pptp-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pptp-tcp'}{'port'}{'tcp'} = 'pptp-tcp'	; 
	$srvcobjects_ref->{'pptp-tcp'}{'ports'}{'tcp'}{'pptp-tcp'}++	; 
	$ports_ref->{'tcp'}{'pptp-tcp'}{'name'} = 'pptp-tcp'		; 
	$srvcobjects_ref->{'RainWall_Command'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'RainWall_Command'}{'port'}{'tcp'} = 'RainWall_Command'	; 
	$srvcobjects_ref->{'RainWall_Command'}{'ports'}{'tcp'}{'RainWall_Command'}++	; 
	$ports_ref->{'tcp'}{'RainWall_Command'}{'name'} = 'RainWall_Command'		; 
	$srvcobjects_ref->{'RAT'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'RAT'}{'port'}{'tcp'} = 'RAT'	; 
	$srvcobjects_ref->{'RAT'}{'ports'}{'tcp'}{'RAT'}++	; 
	$ports_ref->{'tcp'}{'RAT'}{'name'} = 'RAT'		; 
	$srvcobjects_ref->{'Real-Audio'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Real-Audio'}{'port'}{'tcp'} = 'Real-Audio'	; 
	$srvcobjects_ref->{'Real-Audio'}{'ports'}{'tcp'}{'Real-Audio'}++	; 
	$ports_ref->{'tcp'}{'Real-Audio'}{'name'} = 'Real-Audio'		; 
	$srvcobjects_ref->{'RealSecure'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'RealSecure'}{'port'}{'tcp'} = 'RealSecure'	; 
	$srvcobjects_ref->{'RealSecure'}{'ports'}{'tcp'}{'RealSecure'}++	; 
	$ports_ref->{'tcp'}{'RealSecure'}{'name'} = 'RealSecure'		; 
	$srvcobjects_ref->{'Remote_Storm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Remote_Storm'}{'port'}{'tcp'} = 'Remote_Storm'	; 
	$srvcobjects_ref->{'Remote_Storm'}{'ports'}{'tcp'}{'Remote_Storm'}++	; 
	$ports_ref->{'tcp'}{'Remote_Storm'}{'name'} = 'Remote_Storm'		; 
	$srvcobjects_ref->{'rtsp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'rtsp'}{'port'}{'tcp'} = 'rtsp'	; 
	$srvcobjects_ref->{'rtsp'}{'ports'}{'tcp'}{'rtsp'}++	; 
	$ports_ref->{'tcp'}{'rtsp'}{'name'} = 'rtsp'		; 
	$srvcobjects_ref->{'SCCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SCCP'}{'port'}{'tcp'} = 'SCCP'	; 
	$srvcobjects_ref->{'SCCP'}{'ports'}{'tcp'}{'SCCP'}++	; 
	$ports_ref->{'tcp'}{'SCCP'}{'name'} = 'SCCP'		; 
	$srvcobjects_ref->{'securidprop'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'securidprop'}{'port'}{'tcp'} = 'securidprop'	; 
	$srvcobjects_ref->{'securidprop'}{'ports'}{'tcp'}{'securidprop'}++	; 
	$ports_ref->{'tcp'}{'securidprop'}{'name'} = 'securidprop'		; 
	$srvcobjects_ref->{'Shadyshell'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Shadyshell'}{'port'}{'tcp'} = 'Shadyshell'	; 
	$srvcobjects_ref->{'Shadyshell'}{'ports'}{'tcp'}{'Shadyshell'}++	; 
	$ports_ref->{'tcp'}{'Shadyshell'}{'name'} = 'Shadyshell'		; 
	$srvcobjects_ref->{'shell'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'shell'}{'port'}{'tcp'} = 'shell'	; 
	$srvcobjects_ref->{'shell'}{'ports'}{'tcp'}{'shell'}++	; 
	$ports_ref->{'tcp'}{'shell'}{'name'} = 'shell'		; 
	$srvcobjects_ref->{'sip_any-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sip_any-tcp'}{'port'}{'tcp'} = 'sip_any-tcp'	; 
	$srvcobjects_ref->{'sip_any-tcp'}{'ports'}{'tcp'}{'sip_any-tcp'}++	; 
	$ports_ref->{'tcp'}{'sip_any-tcp'}{'name'} = 'sip_any-tcp'		; 
	$srvcobjects_ref->{'sip-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sip-tcp'}{'port'}{'tcp'} = 'sip-tcp'	; 
	$srvcobjects_ref->{'sip-tcp'}{'ports'}{'tcp'}{'sip-tcp'}++	; 
	$ports_ref->{'tcp'}{'sip-tcp'}{'name'} = 'sip-tcp'		; 
	$srvcobjects_ref->{'SkyDance-T'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SkyDance-T'}{'port'}{'tcp'} = 'SkyDance-T'	; 
	$srvcobjects_ref->{'SkyDance-T'}{'ports'}{'tcp'}{'SkyDance-T'}++	; 
	$ports_ref->{'tcp'}{'SkyDance-T'}{'name'} = 'SkyDance-T'		; 
	$srvcobjects_ref->{'smtp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'smtp'}{'port'}{'tcp'} = 'smtp'	; 
	$srvcobjects_ref->{'smtp'}{'ports'}{'tcp'}{'smtp'}++	; 
	$ports_ref->{'tcp'}{'smtp'}{'name'} = 'smtp'		; 
	$srvcobjects_ref->{'Services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Services'}{'port'}{'tcp'} = 'Services'	; 
	$srvcobjects_ref->{'Services'}{'ports'}{'tcp'}{'Services'}++	; 
	$ports_ref->{'tcp'}{'Services'}{'name'} = 'Services'		; 
	$srvcobjects_ref->{'sqlnet1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet1'}{'port'}{'tcp'} = 'sqlnet1'	; 
	$srvcobjects_ref->{'sqlnet1'}{'ports'}{'tcp'}{'sqlnet1'}++	; 
	$ports_ref->{'tcp'}{'sqlnet1'}{'name'} = 'sqlnet1'		; 
	$srvcobjects_ref->{'sqlnet2-1521'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet2-1521'}{'port'}{'tcp'} = 'sqlnet2-1521'	; 
	$srvcobjects_ref->{'sqlnet2-1521'}{'ports'}{'tcp'}{'sqlnet2-1521'}++	; 
	$ports_ref->{'tcp'}{'sqlnet2-1521'}{'name'} = 'sqlnet2-1521'		; 
	$srvcobjects_ref->{'sqlnet2-1525'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet2-1525'}{'port'}{'tcp'} = 'sqlnet2-1525'	; 
	$srvcobjects_ref->{'sqlnet2-1525'}{'ports'}{'tcp'}{'sqlnet2-1525'}++	; 
	$ports_ref->{'tcp'}{'sqlnet2-1525'}{'name'} = 'sqlnet2-1525'		; 
	$srvcobjects_ref->{'sqlnet2-1526'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet2-1526'}{'port'}{'tcp'} = 'sqlnet2-1526'	; 
	$srvcobjects_ref->{'sqlnet2-1526'}{'ports'}{'tcp'}{'sqlnet2-1526'}++	; 
	$ports_ref->{'tcp'}{'sqlnet2-1526'}{'name'} = 'sqlnet2-1526'		; 
	$srvcobjects_ref->{'ssh'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ssh'}{'port'}{'tcp'} = 'ssh'	; 
	$srvcobjects_ref->{'ssh'}{'ports'}{'tcp'}{'ssh'}++	; 
	$ports_ref->{'tcp'}{'ssh'}{'name'} = 'ssh'		; 
	$srvcobjects_ref->{'ssh_version_2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ssh_version_2'}{'port'}{'tcp'} = 'ssh_version_2'	; 
	$srvcobjects_ref->{'ssh_version_2'}{'ports'}{'tcp'}{'ssh_version_2'}++	; 
	$ports_ref->{'tcp'}{'ssh_version_2'}{'name'} = 'ssh_version_2'		; 
	$srvcobjects_ref->{'ssl_v3'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ssl_v3'}{'port'}{'tcp'} = 'ssl_v3'	; 
	$srvcobjects_ref->{'ssl_v3'}{'ports'}{'tcp'}{'ssl_v3'}++	; 
	$ports_ref->{'tcp'}{'ssl_v3'}{'name'} = 'ssl_v3'		; 
	$srvcobjects_ref->{'StoneBeat-Control'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'StoneBeat-Control'}{'port'}{'tcp'} = 'StoneBeat-Control'	; 
	$srvcobjects_ref->{'StoneBeat-Control'}{'ports'}{'tcp'}{'StoneBeat-Control'}++	; 
	$ports_ref->{'tcp'}{'StoneBeat-Control'}{'name'} = 'StoneBeat-Control'		; 
	$srvcobjects_ref->{'20061229'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'20061229'}{'port'}{'tcp'} = '20061229'	; 
	$srvcobjects_ref->{'20061229'}{'ports'}{'tcp'}{'20061229'}++	; 
	$ports_ref->{'tcp'}{'20061229'}{'name'} = '20061229'		; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'port'}{'tcp'} = 'StoneBeat-Daemon'	; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'ports'}{'tcp'}{'StoneBeat-Daemon'}++	; 
	$ports_ref->{'tcp'}{'StoneBeat-Daemon'}{'name'} = 'StoneBeat-Daemon'		; 
	$srvcobjects_ref->{'SubSeven'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SubSeven'}{'port'}{'tcp'} = 'SubSeven'	; 
	$srvcobjects_ref->{'SubSeven'}{'ports'}{'tcp'}{'SubSeven'}++	; 
	$ports_ref->{'tcp'}{'SubSeven'}{'name'} = 'SubSeven'		; 
	$srvcobjects_ref->{'SubSeven-G'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SubSeven-G'}{'port'}{'tcp'} = 'SubSeven-G'	; 
	$srvcobjects_ref->{'SubSeven-G'}{'ports'}{'tcp'}{'SubSeven-G'}++	; 
	$ports_ref->{'tcp'}{'SubSeven-G'}{'name'} = 'SubSeven-G'		; 
	$srvcobjects_ref->{'T.120'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'T.120'}{'port'}{'tcp'} = 'T.120'	; 
	$srvcobjects_ref->{'T.120'}{'ports'}{'tcp'}{'T.120'}++	; 
	$ports_ref->{'tcp'}{'T.120'}{'name'} = 'T.120'		; 
	$srvcobjects_ref->{'TACACSplus'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'TACACSplus'}{'port'}{'tcp'} = 'TACACSplus'	; 
	$srvcobjects_ref->{'TACACSplus'}{'ports'}{'tcp'}{'TACACSplus'}++	; 
	$ports_ref->{'tcp'}{'TACACSplus'}{'name'} = 'TACACSplus'		; 
	$srvcobjects_ref->{'tcp-high-ports'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'port'}{'tcp'} = 'tcp-high-ports'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'ports'}{'tcp'}{'tcp-high-ports'}++	; 
	$ports_ref->{'tcp'}{'tcp-high-ports'}{'name'} = 'tcp-high-ports'		; 
	$srvcobjects_ref->{'tcp-high-ports'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'port'}{'tcp'} = 'tcp-high-ports'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'ports'}{'tcp'}{'tcp-high-ports'}++	; 
	$ports_ref->{'tcp'}{'tcp-high-ports'}{'name'} = 'tcp-high-ports'		; 
	$srvcobjects_ref->{'telnet'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'telnet'}{'port'}{'tcp'} = 'telnet'	; 
	$srvcobjects_ref->{'telnet'}{'ports'}{'tcp'}{'telnet'}++	; 
	$ports_ref->{'tcp'}{'telnet'}{'name'} = 'telnet'		; 
	$srvcobjects_ref->{'Terrortrojan'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Terrortrojan'}{'port'}{'tcp'} = 'Terrortrojan'	; 
	$srvcobjects_ref->{'Terrortrojan'}{'ports'}{'tcp'}{'Terrortrojan'}++	; 
	$ports_ref->{'tcp'}{'Terrortrojan'}{'name'} = 'Terrortrojan'		; 
	$srvcobjects_ref->{'TheFlu'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'TheFlu'}{'port'}{'tcp'} = 'TheFlu'	; 
	$srvcobjects_ref->{'TheFlu'}{'ports'}{'tcp'}{'TheFlu'}++	; 
	$ports_ref->{'tcp'}{'TheFlu'}{'name'} = 'TheFlu'		; 
	$srvcobjects_ref->{'time-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'time-tcp'}{'port'}{'tcp'} = 'time-tcp'	; 
	$srvcobjects_ref->{'time-tcp'}{'ports'}{'tcp'}{'time-tcp'}++	; 
	$ports_ref->{'tcp'}{'time-tcp'}{'name'} = 'time-tcp'		; 
	$srvcobjects_ref->{'TransScout'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'TransScout'}{'port'}{'tcp'} = 'TransScout'	; 
	$srvcobjects_ref->{'TransScout'}{'ports'}{'tcp'}{'TransScout'}++	; 
	$ports_ref->{'tcp'}{'TransScout'}{'name'} = 'TransScout'		; 
	$srvcobjects_ref->{'Trinoo'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Trinoo'}{'port'}{'tcp'} = 'Trinoo'	; 
	$srvcobjects_ref->{'Trinoo'}{'ports'}{'tcp'}{'Trinoo'}++	; 
	$ports_ref->{'tcp'}{'Trinoo'}{'name'} = 'Trinoo'		; 
	$srvcobjects_ref->{'UltorsTrojan'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'UltorsTrojan'}{'port'}{'tcp'} = 'UltorsTrojan'	; 
	$srvcobjects_ref->{'UltorsTrojan'}{'ports'}{'tcp'}{'UltorsTrojan'}++	; 
	$ports_ref->{'tcp'}{'UltorsTrojan'}{'name'} = 'UltorsTrojan'		; 
	$srvcobjects_ref->{'uucp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'uucp'}{'port'}{'tcp'} = 'uucp'	; 
	$srvcobjects_ref->{'uucp'}{'ports'}{'tcp'}{'uucp'}++	; 
	$ports_ref->{'tcp'}{'uucp'}{'name'} = 'uucp'		; 
	$srvcobjects_ref->{'wais'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'wais'}{'port'}{'tcp'} = 'wais'	; 
	$srvcobjects_ref->{'wais'}{'ports'}{'tcp'}{'wais'}++	; 
	$ports_ref->{'tcp'}{'wais'}{'name'} = 'wais'		; 
	$srvcobjects_ref->{'winframe'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'winframe'}{'port'}{'tcp'} = 'winframe'	; 
	$srvcobjects_ref->{'winframe'}{'ports'}{'tcp'}{'winframe'}++	; 
	$ports_ref->{'tcp'}{'winframe'}{'name'} = 'winframe'		; 
	$srvcobjects_ref->{'WinHole'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'WinHole'}{'port'}{'tcp'} = 'WinHole'	; 
	$srvcobjects_ref->{'WinHole'}{'ports'}{'tcp'}{'WinHole'}++	; 
	$ports_ref->{'tcp'}{'WinHole'}{'name'} = 'WinHole'		; 
	$srvcobjects_ref->{'X11'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'X11'}{'port'}{'tcp'} = 'X11'	; 
	$srvcobjects_ref->{'X11'}{'ports'}{'tcp'}{'X11'}++	; 
	$ports_ref->{'tcp'}{'X11'}{'name'} = 'X11'		; 
	$srvcobjects_ref->{'Xanadu'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Xanadu'}{'port'}{'tcp'} = 'Xanadu'	; 
	$srvcobjects_ref->{'Xanadu'}{'ports'}{'tcp'}{'Xanadu'}++	; 
	$ports_ref->{'tcp'}{'Xanadu'}{'name'} = 'Xanadu'		; 
	$srvcobjects_ref->{'Yahoo_Messenger_messages'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_messages'}{'port'}{'tcp'} = 'Yahoo_Messenger_messages'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_messages'}{'ports'}{'tcp'}{'Yahoo_Messenger_messages'}++	; 
	$ports_ref->{'tcp'}{'Yahoo_Messenger_messages'}{'name'} = 'Yahoo_Messenger_messages'		; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_TCP'}{'port'}{'tcp'} = 'Yahoo_Messenger_Voice_Chat_TCP'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_TCP'}{'ports'}{'tcp'}{'Yahoo_Messenger_Voice_Chat_TCP'}++	; 
	$ports_ref->{'tcp'}{'Yahoo_Messenger_Voice_Chat_TCP'}{'name'} = 'Yahoo_Messenger_Voice_Chat_TCP'		; 
	$srvcobjects_ref->{'Yahoo_Messenger_Webcams'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Webcams'}{'port'}{'tcp'} = 'Yahoo_Messenger_Webcams'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Webcams'}{'ports'}{'tcp'}{'Yahoo_Messenger_Webcams'}++	; 
	$ports_ref->{'tcp'}{'Yahoo_Messenger_Webcams'}{'name'} = 'Yahoo_Messenger_Webcams'		; 
	$srvcobjects_ref->{'gAOL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gAOL'}{'port'}{'tcp'} = 'gAOL'	; 
	$srvcobjects_ref->{'gAOL'}{'ports'}{'tcp'}{'gAOL'}++	; 
	$ports_ref->{'tcp'}{'gAOL'}{'name'} = 'gAOL'		; 
	$srvcobjects_ref->{'gAP-Defender'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gAP-Defender'}{'port'}{'tcp'} = 'gAP-Defender'	; 
	$srvcobjects_ref->{'gAP-Defender'}{'ports'}{'tcp'}{'gAP-Defender'}++	; 
	$ports_ref->{'tcp'}{'gAP-Defender'}{'name'} = 'gAP-Defender'		; 
	$srvcobjects_ref->{'gAT-Defender'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gAT-Defender'}{'port'}{'tcp'} = 'gAT-Defender'	; 
	$srvcobjects_ref->{'gAT-Defender'}{'ports'}{'tcp'}{'gAT-Defender'}++	; 
	$ports_ref->{'tcp'}{'gAT-Defender'}{'name'} = 'gAT-Defender'		; 
	$srvcobjects_ref->{'gBackage'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gBackage'}{'port'}{'tcp'} = 'gBackage'	; 
	$srvcobjects_ref->{'gBackage'}{'ports'}{'tcp'}{'gBackage'}++	; 
	$ports_ref->{'tcp'}{'gBackage'}{'name'} = 'gBackage'		; 
	$srvcobjects_ref->{'gBionet-Setup'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gBionet-Setup'}{'port'}{'tcp'} = 'gBionet-Setup'	; 
	$srvcobjects_ref->{'gBionet-Setup'}{'ports'}{'tcp'}{'gBionet-Setup'}++	; 
	$ports_ref->{'tcp'}{'gBionet-Setup'}{'name'} = 'gBionet-Setup'		; 
	$srvcobjects_ref->{'gCitrix_ICA'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCitrix_ICA'}{'port'}{'tcp'} = 'gCitrix_ICA'	; 
	$srvcobjects_ref->{'gCitrix_ICA'}{'ports'}{'tcp'}{'gCitrix_ICA'}++	; 
	$ports_ref->{'tcp'}{'gCitrix_ICA'}{'name'} = 'gCitrix_ICA'		; 
	$srvcobjects_ref->{'gConnectedOnLine'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gConnectedOnLine'}{'port'}{'tcp'} = 'gConnectedOnLine'	; 
	$srvcobjects_ref->{'gConnectedOnLine'}{'ports'}{'tcp'}{'gConnectedOnLine'}++	; 
	$ports_ref->{'tcp'}{'gConnectedOnLine'}{'name'} = 'gConnectedOnLine'		; 
	$srvcobjects_ref->{'gCP_Exnet_PK'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCP_Exnet_PK'}{'port'}{'tcp'} = 'gCP_Exnet_PK'	; 
	$srvcobjects_ref->{'gCP_Exnet_PK'}{'ports'}{'tcp'}{'gCP_Exnet_PK'}++	; 
	$ports_ref->{'tcp'}{'gCP_Exnet_PK'}{'name'} = 'gCP_Exnet_PK'		; 
	$srvcobjects_ref->{'gCP_Exnet_resolve'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCP_Exnet_resolve'}{'port'}{'tcp'} = 'gCP_Exnet_resolve'	; 
	$srvcobjects_ref->{'gCP_Exnet_resolve'}{'ports'}{'tcp'}{'gCP_Exnet_resolve'}++	; 
	$ports_ref->{'tcp'}{'gCP_Exnet_resolve'}{'name'} = 'gCP_Exnet_resolve'		; 
	$srvcobjects_ref->{'gCP_redundant'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCP_redundant'}{'port'}{'tcp'} = 'gCP_redundant'	; 
	$srvcobjects_ref->{'gCP_redundant'}{'ports'}{'tcp'}{'gCP_redundant'}++	; 
	$ports_ref->{'tcp'}{'gCP_redundant'}{'name'} = 'gCP_redundant'		; 
	$srvcobjects_ref->{'gCP_reporting'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCP_reporting'}{'port'}{'tcp'} = 'gCP_reporting'	; 
	$srvcobjects_ref->{'gCP_reporting'}{'ports'}{'tcp'}{'gCP_reporting'}++	; 
	$ports_ref->{'tcp'}{'gCP_reporting'}{'name'} = 'gCP_reporting'		; 
	$srvcobjects_ref->{'gCP_rtm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCP_rtm'}{'port'}{'tcp'} = 'gCP_rtm'	; 
	$srvcobjects_ref->{'gCP_rtm'}{'ports'}{'tcp'}{'gCP_rtm'}++	; 
	$ports_ref->{'tcp'}{'gCP_rtm'}{'name'} = 'gCP_rtm'		; 
	$srvcobjects_ref->{'gCP_seam'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCP_seam'}{'port'}{'tcp'} = 'gCP_seam'	; 
	$srvcobjects_ref->{'gCP_seam'}{'ports'}{'tcp'}{'gCP_seam'}++	; 
	$ports_ref->{'tcp'}{'gCP_seam'}{'name'} = 'gCP_seam'		; 
	$srvcobjects_ref->{'gCPD'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCPD'}{'port'}{'tcp'} = 'gCPD'	; 
	$srvcobjects_ref->{'gCPD'}{'ports'}{'tcp'}{'gCPD'}++	; 
	$ports_ref->{'tcp'}{'gCPD'}{'name'} = 'gCPD'		; 
	$srvcobjects_ref->{'gCPD_amon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCPD_amon'}{'port'}{'tcp'} = 'gCPD_amon'	; 
	$srvcobjects_ref->{'gCPD_amon'}{'ports'}{'tcp'}{'gCPD_amon'}++	; 
	$ports_ref->{'tcp'}{'gCPD_amon'}{'name'} = 'gCPD_amon'		; 
	$srvcobjects_ref->{'gCPMI'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCPMI'}{'port'}{'tcp'} = 'gCPMI'	; 
	$srvcobjects_ref->{'gCPMI'}{'ports'}{'tcp'}{'gCPMI'}++	; 
	$ports_ref->{'tcp'}{'gCPMI'}{'name'} = 'gCPMI'		; 
	$srvcobjects_ref->{'gCrackDown'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCrackDown'}{'port'}{'tcp'} = 'gCrackDown'	; 
	$srvcobjects_ref->{'gCrackDown'}{'ports'}{'tcp'}{'gCrackDown'}++	; 
	$ports_ref->{'tcp'}{'gCrackDown'}{'name'} = 'gCrackDown'		; 
	$srvcobjects_ref->{'gCreativePartnerClnt'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCreativePartnerClnt'}{'port'}{'tcp'} = 'gCreativePartnerClnt'	; 
	$srvcobjects_ref->{'gCreativePartnerClnt'}{'ports'}{'tcp'}{'gCreativePartnerClnt'}++	; 
	$ports_ref->{'tcp'}{'gCreativePartnerClnt'}{'name'} = 'gCreativePartnerClnt'		; 
	$srvcobjects_ref->{'gCreativePartnerSrvr'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gCreativePartnerSrvr'}{'port'}{'tcp'} = 'gCreativePartnerSrvr'	; 
	$srvcobjects_ref->{'gCreativePartnerSrvr'}{'ports'}{'tcp'}{'gCreativePartnerSrvr'}++	; 
	$ports_ref->{'tcp'}{'gCreativePartnerSrvr'}{'name'} = 'gCreativePartnerSrvr'		; 
	$srvcobjects_ref->{'gDaCryptic'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gDaCryptic'}{'port'}{'tcp'} = 'gDaCryptic'	; 
	$srvcobjects_ref->{'gDaCryptic'}{'ports'}{'tcp'}{'gDaCryptic'}++	; 
	$ports_ref->{'tcp'}{'gDaCryptic'}{'name'} = 'gDaCryptic'		; 
	$srvcobjects_ref->{'gDameWare'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gDameWare'}{'port'}{'tcp'} = 'gDameWare'	; 
	$srvcobjects_ref->{'gDameWare'}{'ports'}{'tcp'}{'gDameWare'}++	; 
	$ports_ref->{'tcp'}{'gDameWare'}{'name'} = 'gDameWare'		; 
	$srvcobjects_ref->{'gdaytime-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gdaytime-tcp'}{'port'}{'tcp'} = 'gdaytime-tcp'	; 
	$srvcobjects_ref->{'gdaytime-tcp'}{'ports'}{'tcp'}{'gdaytime-tcp'}++	; 
	$ports_ref->{'tcp'}{'gdaytime-tcp'}{'name'} = 'gdaytime-tcp'		; 
	$srvcobjects_ref->{'gDerSphere'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gDerSphere'}{'port'}{'tcp'} = 'gDerSphere'	; 
	$srvcobjects_ref->{'gDerSphere'}{'ports'}{'tcp'}{'gDerSphere'}++	; 
	$ports_ref->{'tcp'}{'gDerSphere'}{'name'} = 'gDerSphere'		; 
	$srvcobjects_ref->{'gDerSphere_II'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gDerSphere_II'}{'port'}{'tcp'} = 'gDerSphere_II'	; 
	$srvcobjects_ref->{'gDerSphere_II'}{'ports'}{'tcp'}{'gDerSphere_II'}++	; 
	$ports_ref->{'tcp'}{'gDerSphere_II'}{'name'} = 'gDerSphere_II'		; 
	$srvcobjects_ref->{'gDirect_Connect_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gDirect_Connect_TCP'}{'port'}{'tcp'} = 'gDirect_Connect_TCP'	; 
	$srvcobjects_ref->{'gDirect_Connect_TCP'}{'ports'}{'tcp'}{'gDirect_Connect_TCP'}++	; 
	$ports_ref->{'tcp'}{'gDirect_Connect_TCP'}{'name'} = 'gDirect_Connect_TCP'		; 
	$srvcobjects_ref->{'gdiscard-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gdiscard-tcp'}{'port'}{'tcp'} = 'gdiscard-tcp'	; 
	$srvcobjects_ref->{'gdiscard-tcp'}{'ports'}{'tcp'}{'gdiscard-tcp'}++	; 
	$ports_ref->{'tcp'}{'gdiscard-tcp'}{'name'} = 'gdiscard-tcp'		; 
	$srvcobjects_ref->{'domain-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'domain-tcp'}{'port'}{'tcp'} = 'domain-tcp'	; 
	$srvcobjects_ref->{'domain-tcp'}{'ports'}{'tcp'}{'domain-tcp'}++	; 
	$ports_ref->{'tcp'}{'domain-tcp'}{'name'} = 'domain-tcp'		; 
	$srvcobjects_ref->{'gdomain-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gdomain-tcp'}{'port'}{'tcp'} = 'gdomain-tcp'	; 
	$srvcobjects_ref->{'gdomain-tcp'}{'ports'}{'tcp'}{'gdomain-tcp'}++	; 
	$ports_ref->{'tcp'}{'gdomain-tcp'}{'name'} = 'gdomain-tcp'		; 
	$srvcobjects_ref->{'gecho-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gecho-tcp'}{'port'}{'tcp'} = 'gecho-tcp'	; 
	$srvcobjects_ref->{'gecho-tcp'}{'ports'}{'tcp'}{'gecho-tcp'}++	; 
	$ports_ref->{'tcp'}{'gecho-tcp'}{'name'} = 'gecho-tcp'		; 
	$srvcobjects_ref->{'geDonkey_4661'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'geDonkey_4661'}{'port'}{'tcp'} = 'geDonkey_4661'	; 
	$srvcobjects_ref->{'geDonkey_4661'}{'ports'}{'tcp'}{'geDonkey_4661'}++	; 
	$ports_ref->{'tcp'}{'geDonkey_4661'}{'name'} = 'geDonkey_4661'		; 
	$srvcobjects_ref->{'geDonkey_4662'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'geDonkey_4662'}{'port'}{'tcp'} = 'geDonkey_4662'	; 
	$srvcobjects_ref->{'geDonkey_4662'}{'ports'}{'tcp'}{'geDonkey_4662'}++	; 
	$ports_ref->{'tcp'}{'geDonkey_4662'}{'name'} = 'geDonkey_4662'		; 
	$srvcobjects_ref->{'gEntrust-Admin'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gEntrust-Admin'}{'port'}{'tcp'} = 'gEntrust-Admin'	; 
	$srvcobjects_ref->{'gEntrust-Admin'}{'ports'}{'tcp'}{'gEntrust-Admin'}++	; 
	$ports_ref->{'tcp'}{'gEntrust-Admin'}{'name'} = 'gEntrust-Admin'		; 
	$srvcobjects_ref->{'gEntrust-KeyMgmt'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gEntrust-KeyMgmt'}{'port'}{'tcp'} = 'gEntrust-KeyMgmt'	; 
	$srvcobjects_ref->{'gEntrust-KeyMgmt'}{'ports'}{'tcp'}{'gEntrust-KeyMgmt'}++	; 
	$ports_ref->{'tcp'}{'gEntrust-KeyMgmt'}{'name'} = 'gEntrust-KeyMgmt'		; 
	$srvcobjects_ref->{'gexec'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gexec'}{'port'}{'tcp'} = 'gexec'	; 
	$srvcobjects_ref->{'gexec'}{'ports'}{'tcp'}{'gexec'}++	; 
	$ports_ref->{'tcp'}{'gexec'}{'name'} = 'gexec'		; 
	$srvcobjects_ref->{'gFIBMGR'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFIBMGR'}{'port'}{'tcp'} = 'gFIBMGR'	; 
	$srvcobjects_ref->{'gFIBMGR'}{'ports'}{'tcp'}{'gFIBMGR'}++	; 
	$ports_ref->{'tcp'}{'gFIBMGR'}{'name'} = 'gFIBMGR'		; 
	$srvcobjects_ref->{'gfinger'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gfinger'}{'port'}{'tcp'} = 'gfinger'	; 
	$srvcobjects_ref->{'gfinger'}{'ports'}{'tcp'}{'gfinger'}++	; 
	$ports_ref->{'tcp'}{'gfinger'}{'name'} = 'gfinger'		; 
	$srvcobjects_ref->{'gFreak2k'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFreak2k'}{'port'}{'tcp'} = 'gFreak2k'	; 
	$srvcobjects_ref->{'gFreak2k'}{'ports'}{'tcp'}{'gFreak2k'}++	; 
	$ports_ref->{'tcp'}{'gFreak2k'}{'name'} = 'gFreak2k'		; 
	$srvcobjects_ref->{'gftp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gftp'}{'port'}{'tcp'} = 'gftp'	; 
	$srvcobjects_ref->{'gftp'}{'ports'}{'tcp'}{'gftp'}++	; 
	$ports_ref->{'tcp'}{'gftp'}{'name'} = 'gftp'		; 
	$srvcobjects_ref->{'gftp-bidir'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gftp-bidir'}{'port'}{'tcp'} = 'gftp-bidir'	; 
	$srvcobjects_ref->{'gftp-bidir'}{'ports'}{'tcp'}{'gftp-bidir'}++	; 
	$ports_ref->{'tcp'}{'gftp-bidir'}{'name'} = 'gftp-bidir'		; 
	$srvcobjects_ref->{'gftp-pasv'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gftp-pasv'}{'port'}{'tcp'} = 'gftp-pasv'	; 
	$srvcobjects_ref->{'gftp-pasv'}{'ports'}{'tcp'}{'gftp-pasv'}++	; 
	$ports_ref->{'tcp'}{'gftp-pasv'}{'name'} = 'gftp-pasv'		; 
	$srvcobjects_ref->{'gftp-port'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gftp-port'}{'port'}{'tcp'} = 'gftp-port'	; 
	$srvcobjects_ref->{'gftp-port'}{'ports'}{'tcp'}{'gftp-port'}++	; 
	$ports_ref->{'tcp'}{'gftp-port'}{'name'} = 'gftp-port'		; 
	$srvcobjects_ref->{'gFW1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1'}{'port'}{'tcp'} = 'gFW1'	; 
	$srvcobjects_ref->{'gFW1'}{'ports'}{'tcp'}{'gFW1'}++	; 
	$ports_ref->{'tcp'}{'gFW1'}{'name'} = 'gFW1'		; 
	$srvcobjects_ref->{'gFW1_amon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_amon'}{'port'}{'tcp'} = 'gFW1_amon'	; 
	$srvcobjects_ref->{'gFW1_amon'}{'ports'}{'tcp'}{'gFW1_amon'}++	; 
	$ports_ref->{'tcp'}{'gFW1_amon'}{'name'} = 'gFW1_amon'		; 
	$srvcobjects_ref->{'gFW1_clntauth_http'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_clntauth_http'}{'port'}{'tcp'} = 'gFW1_clntauth_http'	; 
	$srvcobjects_ref->{'gFW1_clntauth_http'}{'ports'}{'tcp'}{'gFW1_clntauth_http'}++	; 
	$ports_ref->{'tcp'}{'gFW1_clntauth_http'}{'name'} = 'gFW1_clntauth_http'		; 
	$srvcobjects_ref->{'gFW1_clntauth_telnet'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_clntauth_telnet'}{'port'}{'tcp'} = 'gFW1_clntauth_telnet'	; 
	$srvcobjects_ref->{'gFW1_clntauth_telnet'}{'ports'}{'tcp'}{'gFW1_clntauth_telnet'}++	; 
	$ports_ref->{'tcp'}{'gFW1_clntauth_telnet'}{'name'} = 'gFW1_clntauth_telnet'		; 
	$srvcobjects_ref->{'gFW1_CPRID'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_CPRID'}{'port'}{'tcp'} = 'gFW1_CPRID'	; 
	$srvcobjects_ref->{'gFW1_CPRID'}{'ports'}{'tcp'}{'gFW1_CPRID'}++	; 
	$ports_ref->{'tcp'}{'gFW1_CPRID'}{'name'} = 'gFW1_CPRID'		; 
	$srvcobjects_ref->{'gFW1_cvp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_cvp'}{'port'}{'tcp'} = 'gFW1_cvp'	; 
	$srvcobjects_ref->{'gFW1_cvp'}{'ports'}{'tcp'}{'gFW1_cvp'}++	; 
	$ports_ref->{'tcp'}{'gFW1_cvp'}{'name'} = 'gFW1_cvp'		; 
	$srvcobjects_ref->{'gFW1_ela'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_ela'}{'port'}{'tcp'} = 'gFW1_ela'	; 
	$srvcobjects_ref->{'gFW1_ela'}{'ports'}{'tcp'}{'gFW1_ela'}++	; 
	$ports_ref->{'tcp'}{'gFW1_ela'}{'name'} = 'gFW1_ela'		; 
	$srvcobjects_ref->{'gFW1_ica_mgmt_tools'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_ica_mgmt_tools'}{'port'}{'tcp'} = 'gFW1_ica_mgmt_tools'	; 
	$srvcobjects_ref->{'gFW1_ica_mgmt_tools'}{'ports'}{'tcp'}{'gFW1_ica_mgmt_tools'}++	; 
	$ports_ref->{'tcp'}{'gFW1_ica_mgmt_tools'}{'name'} = 'gFW1_ica_mgmt_tools'		; 
	$srvcobjects_ref->{'gFW1_ica_pull'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_ica_pull'}{'port'}{'tcp'} = 'gFW1_ica_pull'	; 
	$srvcobjects_ref->{'gFW1_ica_pull'}{'ports'}{'tcp'}{'gFW1_ica_pull'}++	; 
	$ports_ref->{'tcp'}{'gFW1_ica_pull'}{'name'} = 'gFW1_ica_pull'		; 
	$srvcobjects_ref->{'gFW1_ica_push'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_ica_push'}{'port'}{'tcp'} = 'gFW1_ica_push'	; 
	$srvcobjects_ref->{'gFW1_ica_push'}{'ports'}{'tcp'}{'gFW1_ica_push'}++	; 
	$ports_ref->{'tcp'}{'gFW1_ica_push'}{'name'} = 'gFW1_ica_push'		; 
	$srvcobjects_ref->{'gFW1_ica_services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_ica_services'}{'port'}{'tcp'} = 'gFW1_ica_services'	; 
	$srvcobjects_ref->{'gFW1_ica_services'}{'ports'}{'tcp'}{'gFW1_ica_services'}++	; 
	$ports_ref->{'tcp'}{'gFW1_ica_services'}{'name'} = 'gFW1_ica_services'		; 
	$srvcobjects_ref->{'gFW1_key'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_key'}{'port'}{'tcp'} = 'gFW1_key'	; 
	$srvcobjects_ref->{'gFW1_key'}{'ports'}{'tcp'}{'gFW1_key'}++	; 
	$ports_ref->{'tcp'}{'gFW1_key'}{'name'} = 'gFW1_key'		; 
	$srvcobjects_ref->{'gFW1_lea'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_lea'}{'port'}{'tcp'} = 'gFW1_lea'	; 
	$srvcobjects_ref->{'gFW1_lea'}{'ports'}{'tcp'}{'gFW1_lea'}++	; 
	$ports_ref->{'tcp'}{'gFW1_lea'}{'name'} = 'gFW1_lea'		; 
	$srvcobjects_ref->{'gFW1_log'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_log'}{'port'}{'tcp'} = 'gFW1_log'	; 
	$srvcobjects_ref->{'gFW1_log'}{'ports'}{'tcp'}{'gFW1_log'}++	; 
	$ports_ref->{'tcp'}{'gFW1_log'}{'name'} = 'gFW1_log'		; 
	$srvcobjects_ref->{'gFW1_mgmt'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_mgmt'}{'port'}{'tcp'} = 'gFW1_mgmt'	; 
	$srvcobjects_ref->{'gFW1_mgmt'}{'ports'}{'tcp'}{'gFW1_mgmt'}++	; 
	$ports_ref->{'tcp'}{'gFW1_mgmt'}{'name'} = 'gFW1_mgmt'		; 
	$srvcobjects_ref->{'gFW1_netso'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_netso'}{'port'}{'tcp'} = 'gFW1_netso'	; 
	$srvcobjects_ref->{'gFW1_netso'}{'ports'}{'tcp'}{'gFW1_netso'}++	; 
	$ports_ref->{'tcp'}{'gFW1_netso'}{'name'} = 'gFW1_netso'		; 
	$srvcobjects_ref->{'gFW1_omi'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_omi'}{'port'}{'tcp'} = 'gFW1_omi'	; 
	$srvcobjects_ref->{'gFW1_omi'}{'ports'}{'tcp'}{'gFW1_omi'}++	; 
	$ports_ref->{'tcp'}{'gFW1_omi'}{'name'} = 'gFW1_omi'		; 
	$srvcobjects_ref->{'gFW1_omi-sic'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_omi-sic'}{'port'}{'tcp'} = 'gFW1_omi-sic'	; 
	$srvcobjects_ref->{'gFW1_omi-sic'}{'ports'}{'tcp'}{'gFW1_omi-sic'}++	; 
	$ports_ref->{'tcp'}{'gFW1_omi-sic'}{'name'} = 'gFW1_omi-sic'		; 
	$srvcobjects_ref->{'gFW1_pslogon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_pslogon'}{'port'}{'tcp'} = 'gFW1_pslogon'	; 
	$srvcobjects_ref->{'gFW1_pslogon'}{'ports'}{'tcp'}{'gFW1_pslogon'}++	; 
	$ports_ref->{'tcp'}{'gFW1_pslogon'}{'name'} = 'gFW1_pslogon'		; 
	$srvcobjects_ref->{'20061229'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'20061229'}{'port'}{'tcp'} = '20061229'	; 
	$srvcobjects_ref->{'20061229'}{'ports'}{'tcp'}{'20061229'}++	; 
	$ports_ref->{'tcp'}{'20061229'}{'name'} = '20061229'		; 
	$srvcobjects_ref->{'gFW1_pslogon_NG'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_pslogon_NG'}{'port'}{'tcp'} = 'gFW1_pslogon_NG'	; 
	$srvcobjects_ref->{'gFW1_pslogon_NG'}{'ports'}{'tcp'}{'gFW1_pslogon_NG'}++	; 
	$ports_ref->{'tcp'}{'gFW1_pslogon_NG'}{'name'} = 'gFW1_pslogon_NG'		; 
	$srvcobjects_ref->{'gFW1_sam'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_sam'}{'port'}{'tcp'} = 'gFW1_sam'	; 
	$srvcobjects_ref->{'gFW1_sam'}{'ports'}{'tcp'}{'gFW1_sam'}++	; 
	$ports_ref->{'tcp'}{'gFW1_sam'}{'name'} = 'gFW1_sam'		; 
	$srvcobjects_ref->{'gFW1_sds_logon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_sds_logon'}{'port'}{'tcp'} = 'gFW1_sds_logon'	; 
	$srvcobjects_ref->{'gFW1_sds_logon'}{'ports'}{'tcp'}{'gFW1_sds_logon'}++	; 
	$ports_ref->{'tcp'}{'gFW1_sds_logon'}{'name'} = 'gFW1_sds_logon'		; 
	$srvcobjects_ref->{'gFW1_sds_logon_NG'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_sds_logon_NG'}{'port'}{'tcp'} = 'gFW1_sds_logon_NG'	; 
	$srvcobjects_ref->{'gFW1_sds_logon_NG'}{'ports'}{'tcp'}{'gFW1_sds_logon_NG'}++	; 
	$ports_ref->{'tcp'}{'gFW1_sds_logon_NG'}{'name'} = 'gFW1_sds_logon_NG'		; 
	$srvcobjects_ref->{'gFW1_snauth'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_snauth'}{'port'}{'tcp'} = 'gFW1_snauth'	; 
	$srvcobjects_ref->{'gFW1_snauth'}{'ports'}{'tcp'}{'gFW1_snauth'}++	; 
	$ports_ref->{'tcp'}{'gFW1_snauth'}{'name'} = 'gFW1_snauth'		; 
	$srvcobjects_ref->{'gFW1_topo'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_topo'}{'port'}{'tcp'} = 'gFW1_topo'	; 
	$srvcobjects_ref->{'gFW1_topo'}{'ports'}{'tcp'}{'gFW1_topo'}++	; 
	$ports_ref->{'tcp'}{'gFW1_topo'}{'name'} = 'gFW1_topo'		; 
	$srvcobjects_ref->{'gFW1_uaa'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_uaa'}{'port'}{'tcp'} = 'gFW1_uaa'	; 
	$srvcobjects_ref->{'gFW1_uaa'}{'ports'}{'tcp'}{'gFW1_uaa'}++	; 
	$ports_ref->{'tcp'}{'gFW1_uaa'}{'name'} = 'gFW1_uaa'		; 
	$srvcobjects_ref->{'gFW1_ufp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gFW1_ufp'}{'port'}{'tcp'} = 'gFW1_ufp'	; 
	$srvcobjects_ref->{'gFW1_ufp'}{'ports'}{'tcp'}{'gFW1_ufp'}++	; 
	$ports_ref->{'tcp'}{'gFW1_ufp'}{'name'} = 'gFW1_ufp'		; 
	$srvcobjects_ref->{'gGateCrasher'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gGateCrasher'}{'port'}{'tcp'} = 'gGateCrasher'	; 
	$srvcobjects_ref->{'gGateCrasher'}{'ports'}{'tcp'}{'gGateCrasher'}++	; 
	$ports_ref->{'tcp'}{'gGateCrasher'}{'name'} = 'gGateCrasher'		; 
	$srvcobjects_ref->{'gGNUtella_rtr_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gGNUtella_rtr_TCP'}{'port'}{'tcp'} = 'gGNUtella_rtr_TCP'	; 
	$srvcobjects_ref->{'gGNUtella_rtr_TCP'}{'ports'}{'tcp'}{'gGNUtella_rtr_TCP'}++	; 
	$ports_ref->{'tcp'}{'gGNUtella_rtr_TCP'}{'name'} = 'gGNUtella_rtr_TCP'		; 
	$srvcobjects_ref->{'gGNUtella_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gGNUtella_TCP'}{'port'}{'tcp'} = 'gGNUtella_TCP'	; 
	$srvcobjects_ref->{'gGNUtella_TCP'}{'ports'}{'tcp'}{'gGNUtella_TCP'}++	; 
	$ports_ref->{'tcp'}{'gGNUtella_TCP'}{'name'} = 'gGNUtella_TCP'		; 
	$srvcobjects_ref->{'ggopher'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ggopher'}{'port'}{'tcp'} = 'ggopher'	; 
	$srvcobjects_ref->{'ggopher'}{'ports'}{'tcp'}{'ggopher'}++	; 
	$ports_ref->{'tcp'}{'ggopher'}{'name'} = 'ggopher'		; 
	$srvcobjects_ref->{'gGoToMyPC'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gGoToMyPC'}{'port'}{'tcp'} = 'gGoToMyPC'	; 
	$srvcobjects_ref->{'gGoToMyPC'}{'ports'}{'tcp'}{'gGoToMyPC'}++	; 
	$ports_ref->{'tcp'}{'gGoToMyPC'}{'name'} = 'gGoToMyPC'		; 
	$srvcobjects_ref->{'gH323'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gH323'}{'port'}{'tcp'} = 'gH323'	; 
	$srvcobjects_ref->{'gH323'}{'ports'}{'tcp'}{'gH323'}++	; 
	$ports_ref->{'tcp'}{'gH323'}{'name'} = 'gH323'		; 
	$srvcobjects_ref->{'gH323_any'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gH323_any'}{'port'}{'tcp'} = 'gH323_any'	; 
	$srvcobjects_ref->{'gH323_any'}{'ports'}{'tcp'}{'gH323_any'}++	; 
	$ports_ref->{'tcp'}{'gH323_any'}{'name'} = 'gH323_any'		; 
	$srvcobjects_ref->{'gHackaTack_31785'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gHackaTack_31785'}{'port'}{'tcp'} = 'gHackaTack_31785'	; 
	$srvcobjects_ref->{'gHackaTack_31785'}{'ports'}{'tcp'}{'gHackaTack_31785'}++	; 
	$ports_ref->{'tcp'}{'gHackaTack_31785'}{'name'} = 'gHackaTack_31785'		; 
	$srvcobjects_ref->{'gHackaTack_31787'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gHackaTack_31787'}{'port'}{'tcp'} = 'gHackaTack_31787'	; 
	$srvcobjects_ref->{'gHackaTack_31787'}{'ports'}{'tcp'}{'gHackaTack_31787'}++	; 
	$ports_ref->{'tcp'}{'gHackaTack_31787'}{'name'} = 'gHackaTack_31787'		; 
	$srvcobjects_ref->{'gHackaTack_31788'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gHackaTack_31788'}{'port'}{'tcp'} = 'gHackaTack_31788'	; 
	$srvcobjects_ref->{'gHackaTack_31788'}{'ports'}{'tcp'}{'gHackaTack_31788'}++	; 
	$ports_ref->{'tcp'}{'gHackaTack_31788'}{'name'} = 'gHackaTack_31788'		; 
	$srvcobjects_ref->{'gHackaTack_31790'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gHackaTack_31790'}{'port'}{'tcp'} = 'gHackaTack_31790'	; 
	$srvcobjects_ref->{'gHackaTack_31790'}{'ports'}{'tcp'}{'gHackaTack_31790'}++	; 
	$ports_ref->{'tcp'}{'gHackaTack_31790'}{'name'} = 'gHackaTack_31790'		; 
	$srvcobjects_ref->{'gHackaTack_31792'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gHackaTack_31792'}{'port'}{'tcp'} = 'gHackaTack_31792'	; 
	$srvcobjects_ref->{'gHackaTack_31792'}{'ports'}{'tcp'}{'gHackaTack_31792'}++	; 
	$ports_ref->{'tcp'}{'gHackaTack_31792'}{'name'} = 'gHackaTack_31792'		; 
	$srvcobjects_ref->{'gHotline_client'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gHotline_client'}{'port'}{'tcp'} = 'gHotline_client'	; 
	$srvcobjects_ref->{'gHotline_client'}{'ports'}{'tcp'}{'gHotline_client'}++	; 
	$ports_ref->{'tcp'}{'gHotline_client'}{'name'} = 'gHotline_client'		; 
	$srvcobjects_ref->{'ghttp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ghttp'}{'port'}{'tcp'} = 'ghttp'	; 
	$srvcobjects_ref->{'ghttp'}{'ports'}{'tcp'}{'ghttp'}++	; 
	$ports_ref->{'tcp'}{'ghttp'}{'name'} = 'ghttp'		; 
	$srvcobjects_ref->{'ghttps'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ghttps'}{'port'}{'tcp'} = 'ghttps'	; 
	$srvcobjects_ref->{'ghttps'}{'ports'}{'tcp'}{'ghttps'}++	; 
	$ports_ref->{'tcp'}{'ghttps'}{'name'} = 'ghttps'		; 
	$srvcobjects_ref->{'gICKiller'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gICKiller'}{'port'}{'tcp'} = 'gICKiller'	; 
	$srvcobjects_ref->{'gICKiller'}{'ports'}{'tcp'}{'gICKiller'}++	; 
	$ports_ref->{'tcp'}{'gICKiller'}{'name'} = 'gICKiller'		; 
	$srvcobjects_ref->{'gident'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gident'}{'port'}{'tcp'} = 'gident'	; 
	$srvcobjects_ref->{'gident'}{'ports'}{'tcp'}{'gident'}++	; 
	$ports_ref->{'tcp'}{'gident'}{'name'} = 'gident'		; 
	$srvcobjects_ref->{'gIKE_tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gIKE_tcp'}{'port'}{'tcp'} = 'gIKE_tcp'	; 
	$srvcobjects_ref->{'gIKE_tcp'}{'ports'}{'tcp'}{'gIKE_tcp'}++	; 
	$ports_ref->{'tcp'}{'gIKE_tcp'}{'name'} = 'gIKE_tcp'		; 
	$srvcobjects_ref->{'gimap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gimap'}{'port'}{'tcp'} = 'gimap'	; 
	$srvcobjects_ref->{'gimap'}{'ports'}{'tcp'}{'gimap'}++	; 
	$ports_ref->{'tcp'}{'gimap'}{'name'} = 'gimap'		; 
	$srvcobjects_ref->{'giMesh'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'giMesh'}{'port'}{'tcp'} = 'giMesh'	; 
	$srvcobjects_ref->{'giMesh'}{'ports'}{'tcp'}{'giMesh'}++	; 
	$ports_ref->{'tcp'}{'giMesh'}{'name'} = 'giMesh'		; 
	$srvcobjects_ref->{'gInCommand'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gInCommand'}{'port'}{'tcp'} = 'gInCommand'	; 
	$srvcobjects_ref->{'gInCommand'}{'ports'}{'tcp'}{'gInCommand'}++	; 
	$ports_ref->{'tcp'}{'gInCommand'}{'name'} = 'gInCommand'		; 
	$srvcobjects_ref->{'gIPSO_Clustering_Mgmt_Protocol'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gIPSO_Clustering_Mgmt_Protocol'}{'port'}{'tcp'} = 'gIPSO_Clustering_Mgmt_Protocol'	; 
	$srvcobjects_ref->{'gIPSO_Clustering_Mgmt_Protocol'}{'ports'}{'tcp'}{'gIPSO_Clustering_Mgmt_Protocol'}++	; 
	$ports_ref->{'tcp'}{'gIPSO_Clustering_Mgmt_Protocol'}{'name'} = 'gIPSO_Clustering_Mgmt_Protocol'		; 
	$srvcobjects_ref->{'girc1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'girc1'}{'port'}{'tcp'} = 'girc1'	; 
	$srvcobjects_ref->{'girc1'}{'ports'}{'tcp'}{'girc1'}++	; 
	$ports_ref->{'tcp'}{'girc1'}{'name'} = 'girc1'		; 
	$srvcobjects_ref->{'girc2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'girc2'}{'port'}{'tcp'} = 'girc2'	; 
	$srvcobjects_ref->{'girc2'}{'ports'}{'tcp'}{'girc2'}++	; 
	$ports_ref->{'tcp'}{'girc2'}{'name'} = 'girc2'		; 
	$srvcobjects_ref->{'gJade'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gJade'}{'port'}{'tcp'} = 'gJade'	; 
	$srvcobjects_ref->{'gJade'}{'ports'}{'tcp'}{'gJade'}++	; 
	$ports_ref->{'tcp'}{'gJade'}{'name'} = 'gJade'		; 
	$srvcobjects_ref->{'gKaos'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gKaos'}{'port'}{'tcp'} = 'gKaos'	; 
	$srvcobjects_ref->{'gKaos'}{'ports'}{'tcp'}{'gKaos'}++	; 
	$ports_ref->{'tcp'}{'gKaos'}{'name'} = 'gKaos'		; 
	$srvcobjects_ref->{'gKaZaA'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gKaZaA'}{'port'}{'tcp'} = 'gKaZaA'	; 
	$srvcobjects_ref->{'gKaZaA'}{'ports'}{'tcp'}{'gKaZaA'}++	; 
	$ports_ref->{'tcp'}{'gKaZaA'}{'name'} = 'gKaZaA'		; 
	$srvcobjects_ref->{'gKerberos_v5_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gKerberos_v5_TCP'}{'port'}{'tcp'} = 'gKerberos_v5_TCP'	; 
	$srvcobjects_ref->{'gKerberos_v5_TCP'}{'ports'}{'tcp'}{'gKerberos_v5_TCP'}++	; 
	$ports_ref->{'tcp'}{'gKerberos_v5_TCP'}{'name'} = 'gKerberos_v5_TCP'		; 
	$srvcobjects_ref->{'gKuang2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gKuang2'}{'port'}{'tcp'} = 'gKuang2'	; 
	$srvcobjects_ref->{'gKuang2'}{'ports'}{'tcp'}{'gKuang2'}++	; 
	$ports_ref->{'tcp'}{'gKuang2'}{'name'} = 'gKuang2'		; 
	$srvcobjects_ref->{'gldap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gldap'}{'port'}{'tcp'} = 'gldap'	; 
	$srvcobjects_ref->{'gldap'}{'ports'}{'tcp'}{'gldap'}++	; 
	$ports_ref->{'tcp'}{'gldap'}{'name'} = 'gldap'		; 
	$srvcobjects_ref->{'gldap-ssl'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gldap-ssl'}{'port'}{'tcp'} = 'gldap-ssl'	; 
	$srvcobjects_ref->{'gldap-ssl'}{'ports'}{'tcp'}{'gldap-ssl'}++	; 
	$ports_ref->{'tcp'}{'gldap-ssl'}{'name'} = 'gldap-ssl'		; 
	$srvcobjects_ref->{'glogin'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'glogin'}{'port'}{'tcp'} = 'glogin'	; 
	$srvcobjects_ref->{'glogin'}{'ports'}{'tcp'}{'glogin'}++	; 
	$ports_ref->{'tcp'}{'glogin'}{'name'} = 'glogin'		; 
	$srvcobjects_ref->{'glotus'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'glotus'}{'port'}{'tcp'} = 'glotus'	; 
	$srvcobjects_ref->{'glotus'}{'ports'}{'tcp'}{'glotus'}++	; 
	$ports_ref->{'tcp'}{'glotus'}{'name'} = 'glotus'		; 
	$srvcobjects_ref->{'glpdw0rm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'glpdw0rm'}{'port'}{'tcp'} = 'glpdw0rm'	; 
	$srvcobjects_ref->{'glpdw0rm'}{'ports'}{'tcp'}{'glpdw0rm'}++	; 
	$ports_ref->{'tcp'}{'glpdw0rm'}{'name'} = 'glpdw0rm'		; 
	$srvcobjects_ref->{'gMadster'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMadster'}{'port'}{'tcp'} = 'gMadster'	; 
	$srvcobjects_ref->{'gMadster'}{'ports'}{'tcp'}{'gMadster'}++	; 
	$ports_ref->{'tcp'}{'gMadster'}{'name'} = 'gMadster'		; 
	$srvcobjects_ref->{'gmicrosoft-ds'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gmicrosoft-ds'}{'port'}{'tcp'} = 'gmicrosoft-ds'	; 
	$srvcobjects_ref->{'gmicrosoft-ds'}{'ports'}{'tcp'}{'gmicrosoft-ds'}++	; 
	$ports_ref->{'tcp'}{'gmicrosoft-ds'}{'name'} = 'gmicrosoft-ds'		; 
	$srvcobjects_ref->{'gMneah'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMneah'}{'port'}{'tcp'} = 'gMneah'	; 
	$srvcobjects_ref->{'gMneah'}{'ports'}{'tcp'}{'gMneah'}++	; 
	$ports_ref->{'tcp'}{'gMneah'}{'name'} = 'gMneah'		; 
	$srvcobjects_ref->{'gMSN_Messenger_File_Transfer'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMSN_Messenger_File_Transfer'}{'port'}{'tcp'} = 'gMSN_Messenger_File_Transfer'	; 
	$srvcobjects_ref->{'gMSN_Messenger_File_Transfer'}{'ports'}{'tcp'}{'gMSN_Messenger_File_Transfer'}++	; 
	$ports_ref->{'tcp'}{'gMSN_Messenger_File_Transfer'}{'name'} = 'gMSN_Messenger_File_Transfer'		; 
	$srvcobjects_ref->{'gMSNMS'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMSNMS'}{'port'}{'tcp'} = 'gMSNMS'	; 
	$srvcobjects_ref->{'gMSNMS'}{'ports'}{'tcp'}{'gMSNMS'}++	; 
	$ports_ref->{'tcp'}{'gMSNMS'}{'name'} = 'gMSNMS'		; 
	$srvcobjects_ref->{'gMSNP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMSNP'}{'port'}{'tcp'} = 'gMSNP'	; 
	$srvcobjects_ref->{'gMSNP'}{'ports'}{'tcp'}{'gMSNP'}++	; 
	$ports_ref->{'tcp'}{'gMSNP'}{'name'} = 'gMSNP'		; 
	$srvcobjects_ref->{'gMS-SQL-Monitor'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMS-SQL-Monitor'}{'port'}{'tcp'} = 'gMS-SQL-Monitor'	; 
	$srvcobjects_ref->{'gMS-SQL-Monitor'}{'ports'}{'tcp'}{'gMS-SQL-Monitor'}++	; 
	$ports_ref->{'tcp'}{'gMS-SQL-Monitor'}{'name'} = 'gMS-SQL-Monitor'		; 
	$srvcobjects_ref->{'gMS-SQL-Server'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMS-SQL-Server'}{'port'}{'tcp'} = 'gMS-SQL-Server'	; 
	$srvcobjects_ref->{'gMS-SQL-Server'}{'ports'}{'tcp'}{'gMS-SQL-Server'}++	; 
	$ports_ref->{'tcp'}{'gMS-SQL-Server'}{'name'} = 'gMS-SQL-Server'		; 
	$srvcobjects_ref->{'gMultidropper'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMultidropper'}{'port'}{'tcp'} = 'gMultidropper'	; 
	$srvcobjects_ref->{'gMultidropper'}{'ports'}{'tcp'}{'gMultidropper'}++	; 
	$ports_ref->{'tcp'}{'gMultidropper'}{'name'} = 'gMultidropper'		; 
	$srvcobjects_ref->{'gMySQL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gMySQL'}{'port'}{'tcp'} = 'gMySQL'	; 
	$srvcobjects_ref->{'gMySQL'}{'ports'}{'tcp'}{'gMySQL'}++	; 
	$ports_ref->{'tcp'}{'gMySQL'}{'name'} = 'gMySQL'		; 
	$srvcobjects_ref->{'gNapster_Client_6600-6699'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNapster_Client_6600-6699'}{'port'}{'tcp'} = 'gNapster_Client_6600-6699'	; 
	$srvcobjects_ref->{'gNapster_Client_6600-6699'}{'ports'}{'tcp'}{'gNapster_Client_6600-6699'}++	; 
	$ports_ref->{'tcp'}{'gNapster_Client_6600-6699'}{'name'} = 'gNapster_Client_6600-6699'		; 
	$srvcobjects_ref->{'gNapster_directory_4444'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNapster_directory_4444'}{'port'}{'tcp'} = 'gNapster_directory_4444'	; 
	$srvcobjects_ref->{'gNapster_directory_4444'}{'ports'}{'tcp'}{'gNapster_directory_4444'}++	; 
	$ports_ref->{'tcp'}{'gNapster_directory_4444'}{'name'} = 'gNapster_directory_4444'		; 
	$srvcobjects_ref->{'gNapster_directory_5555'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNapster_directory_5555'}{'port'}{'tcp'} = 'gNapster_directory_5555'	; 
	$srvcobjects_ref->{'gNapster_directory_5555'}{'ports'}{'tcp'}{'gNapster_directory_5555'}++	; 
	$ports_ref->{'tcp'}{'gNapster_directory_5555'}{'name'} = 'gNapster_directory_5555'		; 
	$srvcobjects_ref->{'gNapster_directory_6666'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNapster_directory_6666'}{'port'}{'tcp'} = 'gNapster_directory_6666'	; 
	$srvcobjects_ref->{'gNapster_directory_6666'}{'ports'}{'tcp'}{'gNapster_directory_6666'}++	; 
	$ports_ref->{'tcp'}{'gNapster_directory_6666'}{'name'} = 'gNapster_directory_6666'		; 
	$srvcobjects_ref->{'gNapster_directory_7777'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNapster_directory_7777'}{'port'}{'tcp'} = 'gNapster_directory_7777'	; 
	$srvcobjects_ref->{'gNapster_directory_7777'}{'ports'}{'tcp'}{'gNapster_directory_7777'}++	; 
	$ports_ref->{'tcp'}{'gNapster_directory_7777'}{'name'} = 'gNapster_directory_7777'		; 
	$srvcobjects_ref->{'gNapster_directory_8888_primary'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNapster_directory_8888_primary'}{'port'}{'tcp'} = 'gNapster_directory_8888_primary'	; 
	$srvcobjects_ref->{'gNapster_directory_8888_primary'}{'ports'}{'tcp'}{'gNapster_directory_8888_primary'}++	; 
	$ports_ref->{'tcp'}{'gNapster_directory_8888_primary'}{'name'} = 'gNapster_directory_8888_primary'		; 
	$srvcobjects_ref->{'gNapster_redirector'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNapster_redirector'}{'port'}{'tcp'} = 'gNapster_redirector'	; 
	$srvcobjects_ref->{'gNapster_redirector'}{'ports'}{'tcp'}{'gNapster_redirector'}++	; 
	$ports_ref->{'tcp'}{'gNapster_redirector'}{'name'} = 'gNapster_redirector'		; 
	$srvcobjects_ref->{'gnbsession'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gnbsession'}{'port'}{'tcp'} = 'gnbsession'	; 
	$srvcobjects_ref->{'gnbsession'}{'ports'}{'tcp'}{'gnbsession'}++	; 
	$ports_ref->{'tcp'}{'gnbsession'}{'name'} = 'gnbsession'		; 
	$srvcobjects_ref->{'gNCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gNCP'}{'port'}{'tcp'} = 'gNCP'	; 
	$srvcobjects_ref->{'gNCP'}{'ports'}{'tcp'}{'gNCP'}++	; 
	$ports_ref->{'tcp'}{'gNCP'}{'name'} = 'gNCP'		; 
	$srvcobjects_ref->{'gnetshow'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gnetshow'}{'port'}{'tcp'} = 'gnetshow'	; 
	$srvcobjects_ref->{'gnetshow'}{'ports'}{'tcp'}{'gnetshow'}++	; 
	$ports_ref->{'tcp'}{'gnetshow'}{'name'} = 'gnetshow'		; 
	$srvcobjects_ref->{'Services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Services'}{'port'}{'tcp'} = 'Services'	; 
	$srvcobjects_ref->{'Services'}{'ports'}{'tcp'}{'Services'}++	; 
	$ports_ref->{'tcp'}{'Services'}{'name'} = 'Services'		; 
	$srvcobjects_ref->{'gnntp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gnntp'}{'port'}{'tcp'} = 'gnntp'	; 
	$srvcobjects_ref->{'gnntp'}{'ports'}{'tcp'}{'gnntp'}++	; 
	$ports_ref->{'tcp'}{'gnntp'}{'name'} = 'gnntp'		; 
	$srvcobjects_ref->{'gntp-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gntp-tcp'}{'port'}{'tcp'} = 'gntp-tcp'	; 
	$srvcobjects_ref->{'gntp-tcp'}{'ports'}{'tcp'}{'gntp-tcp'}++	; 
	$ports_ref->{'tcp'}{'gntp-tcp'}{'name'} = 'gntp-tcp'		; 
	$srvcobjects_ref->{'gOAS-NameServer'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gOAS-NameServer'}{'port'}{'tcp'} = 'gOAS-NameServer'	; 
	$srvcobjects_ref->{'gOAS-NameServer'}{'ports'}{'tcp'}{'gOAS-NameServer'}++	; 
	$ports_ref->{'tcp'}{'gOAS-NameServer'}{'name'} = 'gOAS-NameServer'		; 
	$srvcobjects_ref->{'gOAS-ORB'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gOAS-ORB'}{'port'}{'tcp'} = 'gOAS-ORB'	; 
	$srvcobjects_ref->{'gOAS-ORB'}{'ports'}{'tcp'}{'gOAS-ORB'}++	; 
	$ports_ref->{'tcp'}{'gOAS-ORB'}{'name'} = 'gOAS-ORB'		; 
	$srvcobjects_ref->{'gOpenWindows'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gOpenWindows'}{'port'}{'tcp'} = 'gOpenWindows'	; 
	$srvcobjects_ref->{'gOpenWindows'}{'ports'}{'tcp'}{'gOpenWindows'}++	; 
	$ports_ref->{'tcp'}{'gOpenWindows'}{'name'} = 'gOpenWindows'		; 
	$srvcobjects_ref->{'gOrbix-1570'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gOrbix-1570'}{'port'}{'tcp'} = 'gOrbix-1570'	; 
	$srvcobjects_ref->{'gOrbix-1570'}{'ports'}{'tcp'}{'gOrbix-1570'}++	; 
	$ports_ref->{'tcp'}{'gOrbix-1570'}{'name'} = 'gOrbix-1570'		; 
	$srvcobjects_ref->{'gOrbix-1571'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gOrbix-1571'}{'port'}{'tcp'} = 'gOrbix-1571'	; 
	$srvcobjects_ref->{'gOrbix-1571'}{'ports'}{'tcp'}{'gOrbix-1571'}++	; 
	$ports_ref->{'tcp'}{'gOrbix-1571'}{'name'} = 'gOrbix-1571'		; 
	$srvcobjects_ref->{'gpcANYWHERE-data'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gpcANYWHERE-data'}{'port'}{'tcp'} = 'gpcANYWHERE-data'	; 
	$srvcobjects_ref->{'gpcANYWHERE-data'}{'ports'}{'tcp'}{'gpcANYWHERE-data'}++	; 
	$ports_ref->{'tcp'}{'gpcANYWHERE-data'}{'name'} = 'gpcANYWHERE-data'		; 
	$srvcobjects_ref->{'gpcTELECOMMUTE-FileSync'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gpcTELECOMMUTE-FileSync'}{'port'}{'tcp'} = 'gpcTELECOMMUTE-FileSync'	; 
	$srvcobjects_ref->{'gpcTELECOMMUTE-FileSync'}{'ports'}{'tcp'}{'gpcTELECOMMUTE-FileSync'}++	; 
	$ports_ref->{'tcp'}{'gpcTELECOMMUTE-FileSync'}{'name'} = 'gpcTELECOMMUTE-FileSync'		; 
	$srvcobjects_ref->{'gpop-2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gpop-2'}{'port'}{'tcp'} = 'gpop-2'	; 
	$srvcobjects_ref->{'gpop-2'}{'ports'}{'tcp'}{'gpop-2'}++	; 
	$ports_ref->{'tcp'}{'gpop-2'}{'name'} = 'gpop-2'		; 
	$srvcobjects_ref->{'gpop-3'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gpop-3'}{'port'}{'tcp'} = 'gpop-3'	; 
	$srvcobjects_ref->{'gpop-3'}{'ports'}{'tcp'}{'gpop-3'}++	; 
	$ports_ref->{'tcp'}{'gpop-3'}{'name'} = 'gpop-3'		; 
	$srvcobjects_ref->{'gPort_6667_trojans'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gPort_6667_trojans'}{'port'}{'tcp'} = 'gPort_6667_trojans'	; 
	$srvcobjects_ref->{'gPort_6667_trojans'}{'ports'}{'tcp'}{'gPort_6667_trojans'}++	; 
	$ports_ref->{'tcp'}{'gPort_6667_trojans'}{'name'} = 'gPort_6667_trojans'		; 
	$srvcobjects_ref->{'gPostgreSQL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gPostgreSQL'}{'port'}{'tcp'} = 'gPostgreSQL'	; 
	$srvcobjects_ref->{'gPostgreSQL'}{'ports'}{'tcp'}{'gPostgreSQL'}++	; 
	$ports_ref->{'tcp'}{'gPostgreSQL'}{'name'} = 'gPostgreSQL'		; 
	$srvcobjects_ref->{'gpptp-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gpptp-tcp'}{'port'}{'tcp'} = 'gpptp-tcp'	; 
	$srvcobjects_ref->{'gpptp-tcp'}{'ports'}{'tcp'}{'gpptp-tcp'}++	; 
	$ports_ref->{'tcp'}{'gpptp-tcp'}{'name'} = 'gpptp-tcp'		; 
	$srvcobjects_ref->{'gRainWall_Command'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gRainWall_Command'}{'port'}{'tcp'} = 'gRainWall_Command'	; 
	$srvcobjects_ref->{'gRainWall_Command'}{'ports'}{'tcp'}{'gRainWall_Command'}++	; 
	$ports_ref->{'tcp'}{'gRainWall_Command'}{'name'} = 'gRainWall_Command'		; 
	$srvcobjects_ref->{'gRAT'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gRAT'}{'port'}{'tcp'} = 'gRAT'	; 
	$srvcobjects_ref->{'gRAT'}{'ports'}{'tcp'}{'gRAT'}++	; 
	$ports_ref->{'tcp'}{'gRAT'}{'name'} = 'gRAT'		; 
	$srvcobjects_ref->{'gReal-Audio'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gReal-Audio'}{'port'}{'tcp'} = 'gReal-Audio'	; 
	$srvcobjects_ref->{'gReal-Audio'}{'ports'}{'tcp'}{'gReal-Audio'}++	; 
	$ports_ref->{'tcp'}{'gReal-Audio'}{'name'} = 'gReal-Audio'		; 
	$srvcobjects_ref->{'gRealSecure'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gRealSecure'}{'port'}{'tcp'} = 'gRealSecure'	; 
	$srvcobjects_ref->{'gRealSecure'}{'ports'}{'tcp'}{'gRealSecure'}++	; 
	$ports_ref->{'tcp'}{'gRealSecure'}{'name'} = 'gRealSecure'		; 
	$srvcobjects_ref->{'gRemote_Storm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gRemote_Storm'}{'port'}{'tcp'} = 'gRemote_Storm'	; 
	$srvcobjects_ref->{'gRemote_Storm'}{'ports'}{'tcp'}{'gRemote_Storm'}++	; 
	$ports_ref->{'tcp'}{'gRemote_Storm'}{'name'} = 'gRemote_Storm'		; 
	$srvcobjects_ref->{'grtsp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'grtsp'}{'port'}{'tcp'} = 'grtsp'	; 
	$srvcobjects_ref->{'grtsp'}{'ports'}{'tcp'}{'grtsp'}++	; 
	$ports_ref->{'tcp'}{'grtsp'}{'name'} = 'grtsp'		; 
	$srvcobjects_ref->{'gSCCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gSCCP'}{'port'}{'tcp'} = 'gSCCP'	; 
	$srvcobjects_ref->{'gSCCP'}{'ports'}{'tcp'}{'gSCCP'}++	; 
	$ports_ref->{'tcp'}{'gSCCP'}{'name'} = 'gSCCP'		; 
	$srvcobjects_ref->{'gsecuridprop'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsecuridprop'}{'port'}{'tcp'} = 'gsecuridprop'	; 
	$srvcobjects_ref->{'gsecuridprop'}{'ports'}{'tcp'}{'gsecuridprop'}++	; 
	$ports_ref->{'tcp'}{'gsecuridprop'}{'name'} = 'gsecuridprop'		; 
	$srvcobjects_ref->{'gShadyshell'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gShadyshell'}{'port'}{'tcp'} = 'gShadyshell'	; 
	$srvcobjects_ref->{'gShadyshell'}{'ports'}{'tcp'}{'gShadyshell'}++	; 
	$ports_ref->{'tcp'}{'gShadyshell'}{'name'} = 'gShadyshell'		; 
	$srvcobjects_ref->{'gshell'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gshell'}{'port'}{'tcp'} = 'gshell'	; 
	$srvcobjects_ref->{'gshell'}{'ports'}{'tcp'}{'gshell'}++	; 
	$ports_ref->{'tcp'}{'gshell'}{'name'} = 'gshell'		; 
	$srvcobjects_ref->{'gsip_any-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsip_any-tcp'}{'port'}{'tcp'} = 'gsip_any-tcp'	; 
	$srvcobjects_ref->{'gsip_any-tcp'}{'ports'}{'tcp'}{'gsip_any-tcp'}++	; 
	$ports_ref->{'tcp'}{'gsip_any-tcp'}{'name'} = 'gsip_any-tcp'		; 
	$srvcobjects_ref->{'gsip-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsip-tcp'}{'port'}{'tcp'} = 'gsip-tcp'	; 
	$srvcobjects_ref->{'gsip-tcp'}{'ports'}{'tcp'}{'gsip-tcp'}++	; 
	$ports_ref->{'tcp'}{'gsip-tcp'}{'name'} = 'gsip-tcp'		; 
	$srvcobjects_ref->{'gSkyDance-T'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gSkyDance-T'}{'port'}{'tcp'} = 'gSkyDance-T'	; 
	$srvcobjects_ref->{'gSkyDance-T'}{'ports'}{'tcp'}{'gSkyDance-T'}++	; 
	$ports_ref->{'tcp'}{'gSkyDance-T'}{'name'} = 'gSkyDance-T'		; 
	$srvcobjects_ref->{'gsmtp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsmtp'}{'port'}{'tcp'} = 'gsmtp'	; 
	$srvcobjects_ref->{'gsmtp'}{'ports'}{'tcp'}{'gsmtp'}++	; 
	$ports_ref->{'tcp'}{'gsmtp'}{'name'} = 'gsmtp'		; 
	$srvcobjects_ref->{'Services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Services'}{'port'}{'tcp'} = 'Services'	; 
	$srvcobjects_ref->{'Services'}{'ports'}{'tcp'}{'Services'}++	; 
	$ports_ref->{'tcp'}{'Services'}{'name'} = 'Services'		; 
	$srvcobjects_ref->{'gsqlnet1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsqlnet1'}{'port'}{'tcp'} = 'gsqlnet1'	; 
	$srvcobjects_ref->{'gsqlnet1'}{'ports'}{'tcp'}{'gsqlnet1'}++	; 
	$ports_ref->{'tcp'}{'gsqlnet1'}{'name'} = 'gsqlnet1'		; 
	$srvcobjects_ref->{'gsqlnet2-1521'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsqlnet2-1521'}{'port'}{'tcp'} = 'gsqlnet2-1521'	; 
	$srvcobjects_ref->{'gsqlnet2-1521'}{'ports'}{'tcp'}{'gsqlnet2-1521'}++	; 
	$ports_ref->{'tcp'}{'gsqlnet2-1521'}{'name'} = 'gsqlnet2-1521'		; 
	$srvcobjects_ref->{'gsqlnet2-1525'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsqlnet2-1525'}{'port'}{'tcp'} = 'gsqlnet2-1525'	; 
	$srvcobjects_ref->{'gsqlnet2-1525'}{'ports'}{'tcp'}{'gsqlnet2-1525'}++	; 
	$ports_ref->{'tcp'}{'gsqlnet2-1525'}{'name'} = 'gsqlnet2-1525'		; 
	$srvcobjects_ref->{'gsqlnet2-1526'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gsqlnet2-1526'}{'port'}{'tcp'} = 'gsqlnet2-1526'	; 
	$srvcobjects_ref->{'gsqlnet2-1526'}{'ports'}{'tcp'}{'gsqlnet2-1526'}++	; 
	$ports_ref->{'tcp'}{'gsqlnet2-1526'}{'name'} = 'gsqlnet2-1526'		; 
	$srvcobjects_ref->{'gssh'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gssh'}{'port'}{'tcp'} = 'gssh'	; 
	$srvcobjects_ref->{'gssh'}{'ports'}{'tcp'}{'gssh'}++	; 
	$ports_ref->{'tcp'}{'gssh'}{'name'} = 'gssh'		; 
	$srvcobjects_ref->{'gssh_version_2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gssh_version_2'}{'port'}{'tcp'} = 'gssh_version_2'	; 
	$srvcobjects_ref->{'gssh_version_2'}{'ports'}{'tcp'}{'gssh_version_2'}++	; 
	$ports_ref->{'tcp'}{'gssh_version_2'}{'name'} = 'gssh_version_2'		; 
	$srvcobjects_ref->{'gssl_v3'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gssl_v3'}{'port'}{'tcp'} = 'gssl_v3'	; 
	$srvcobjects_ref->{'gssl_v3'}{'ports'}{'tcp'}{'gssl_v3'}++	; 
	$ports_ref->{'tcp'}{'gssl_v3'}{'name'} = 'gssl_v3'		; 
	$srvcobjects_ref->{'gStoneBeat-Control'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gStoneBeat-Control'}{'port'}{'tcp'} = 'gStoneBeat-Control'	; 
	$srvcobjects_ref->{'gStoneBeat-Control'}{'ports'}{'tcp'}{'gStoneBeat-Control'}++	; 
	$ports_ref->{'tcp'}{'gStoneBeat-Control'}{'name'} = 'gStoneBeat-Control'		; 
	$srvcobjects_ref->{'20061229'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'20061229'}{'port'}{'tcp'} = '20061229'	; 
	$srvcobjects_ref->{'20061229'}{'ports'}{'tcp'}{'20061229'}++	; 
	$ports_ref->{'tcp'}{'20061229'}{'name'} = '20061229'		; 
	$srvcobjects_ref->{'gStoneBeat-Daemon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gStoneBeat-Daemon'}{'port'}{'tcp'} = 'gStoneBeat-Daemon'	; 
	$srvcobjects_ref->{'gStoneBeat-Daemon'}{'ports'}{'tcp'}{'gStoneBeat-Daemon'}++	; 
	$ports_ref->{'tcp'}{'gStoneBeat-Daemon'}{'name'} = 'gStoneBeat-Daemon'		; 
	$srvcobjects_ref->{'gSubSeven'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gSubSeven'}{'port'}{'tcp'} = 'gSubSeven'	; 
	$srvcobjects_ref->{'gSubSeven'}{'ports'}{'tcp'}{'gSubSeven'}++	; 
	$ports_ref->{'tcp'}{'gSubSeven'}{'name'} = 'gSubSeven'		; 
	$srvcobjects_ref->{'gSubSeven-G'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gSubSeven-G'}{'port'}{'tcp'} = 'gSubSeven-G'	; 
	$srvcobjects_ref->{'gSubSeven-G'}{'ports'}{'tcp'}{'gSubSeven-G'}++	; 
	$ports_ref->{'tcp'}{'gSubSeven-G'}{'name'} = 'gSubSeven-G'		; 
	$srvcobjects_ref->{'gT.120'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gT.120'}{'port'}{'tcp'} = 'gT.120'	; 
	$srvcobjects_ref->{'gT.120'}{'ports'}{'tcp'}{'gT.120'}++	; 
	$ports_ref->{'tcp'}{'gT.120'}{'name'} = 'gT.120'		; 
	$srvcobjects_ref->{'gTACACSplus'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gTACACSplus'}{'port'}{'tcp'} = 'gTACACSplus'	; 
	$srvcobjects_ref->{'gTACACSplus'}{'ports'}{'tcp'}{'gTACACSplus'}++	; 
	$ports_ref->{'tcp'}{'gTACACSplus'}{'name'} = 'gTACACSplus'		; 
	$srvcobjects_ref->{'tcp-high-ports'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'port'}{'tcp'} = 'tcp-high-ports'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'ports'}{'tcp'}{'tcp-high-ports'}++	; 
	$ports_ref->{'tcp'}{'tcp-high-ports'}{'name'} = 'tcp-high-ports'		; 
	$srvcobjects_ref->{'gtcp-high-ports'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gtcp-high-ports'}{'port'}{'tcp'} = 'gtcp-high-ports'	; 
	$srvcobjects_ref->{'gtcp-high-ports'}{'ports'}{'tcp'}{'gtcp-high-ports'}++	; 
	$ports_ref->{'tcp'}{'gtcp-high-ports'}{'name'} = 'gtcp-high-ports'		; 
	$srvcobjects_ref->{'gtelnet'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gtelnet'}{'port'}{'tcp'} = 'gtelnet'	; 
	$srvcobjects_ref->{'gtelnet'}{'ports'}{'tcp'}{'gtelnet'}++	; 
	$ports_ref->{'tcp'}{'gtelnet'}{'name'} = 'gtelnet'		; 
	$srvcobjects_ref->{'gTerrortrojan'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gTerrortrojan'}{'port'}{'tcp'} = 'gTerrortrojan'	; 
	$srvcobjects_ref->{'gTerrortrojan'}{'ports'}{'tcp'}{'gTerrortrojan'}++	; 
	$ports_ref->{'tcp'}{'gTerrortrojan'}{'name'} = 'gTerrortrojan'		; 
	$srvcobjects_ref->{'gTheFlu'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gTheFlu'}{'port'}{'tcp'} = 'gTheFlu'	; 
	$srvcobjects_ref->{'gTheFlu'}{'ports'}{'tcp'}{'gTheFlu'}++	; 
	$ports_ref->{'tcp'}{'gTheFlu'}{'name'} = 'gTheFlu'		; 
	$srvcobjects_ref->{'gtime-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gtime-tcp'}{'port'}{'tcp'} = 'gtime-tcp'	; 
	$srvcobjects_ref->{'gtime-tcp'}{'ports'}{'tcp'}{'gtime-tcp'}++	; 
	$ports_ref->{'tcp'}{'gtime-tcp'}{'name'} = 'gtime-tcp'		; 
	$srvcobjects_ref->{'gTransScout'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gTransScout'}{'port'}{'tcp'} = 'gTransScout'	; 
	$srvcobjects_ref->{'gTransScout'}{'ports'}{'tcp'}{'gTransScout'}++	; 
	$ports_ref->{'tcp'}{'gTransScout'}{'name'} = 'gTransScout'		; 
	$srvcobjects_ref->{'gTrinoo'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gTrinoo'}{'port'}{'tcp'} = 'gTrinoo'	; 
	$srvcobjects_ref->{'gTrinoo'}{'ports'}{'tcp'}{'gTrinoo'}++	; 
	$ports_ref->{'tcp'}{'gTrinoo'}{'name'} = 'gTrinoo'		; 
	$srvcobjects_ref->{'gUltorsTrojan'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gUltorsTrojan'}{'port'}{'tcp'} = 'gUltorsTrojan'	; 
	$srvcobjects_ref->{'gUltorsTrojan'}{'ports'}{'tcp'}{'gUltorsTrojan'}++	; 
	$ports_ref->{'tcp'}{'gUltorsTrojan'}{'name'} = 'gUltorsTrojan'		; 
	$srvcobjects_ref->{'guucp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'guucp'}{'port'}{'tcp'} = 'guucp'	; 
	$srvcobjects_ref->{'guucp'}{'ports'}{'tcp'}{'guucp'}++	; 
	$ports_ref->{'tcp'}{'guucp'}{'name'} = 'guucp'		; 
	$srvcobjects_ref->{'gwais'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gwais'}{'port'}{'tcp'} = 'gwais'	; 
	$srvcobjects_ref->{'gwais'}{'ports'}{'tcp'}{'gwais'}++	; 
	$ports_ref->{'tcp'}{'gwais'}{'name'} = 'gwais'		; 
	$srvcobjects_ref->{'gwinframe'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gwinframe'}{'port'}{'tcp'} = 'gwinframe'	; 
	$srvcobjects_ref->{'gwinframe'}{'ports'}{'tcp'}{'gwinframe'}++	; 
	$ports_ref->{'tcp'}{'gwinframe'}{'name'} = 'gwinframe'		; 
	$srvcobjects_ref->{'gWinHole'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gWinHole'}{'port'}{'tcp'} = 'gWinHole'	; 
	$srvcobjects_ref->{'gWinHole'}{'ports'}{'tcp'}{'gWinHole'}++	; 
	$ports_ref->{'tcp'}{'gWinHole'}{'name'} = 'gWinHole'		; 
	$srvcobjects_ref->{'gX11'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gX11'}{'port'}{'tcp'} = 'gX11'	; 
	$srvcobjects_ref->{'gX11'}{'ports'}{'tcp'}{'gX11'}++	; 
	$ports_ref->{'tcp'}{'gX11'}{'name'} = 'gX11'		; 
	$srvcobjects_ref->{'gXanadu'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gXanadu'}{'port'}{'tcp'} = 'gXanadu'	; 
	$srvcobjects_ref->{'gXanadu'}{'ports'}{'tcp'}{'gXanadu'}++	; 
	$ports_ref->{'tcp'}{'gXanadu'}{'name'} = 'gXanadu'		; 
	$srvcobjects_ref->{'gYahoo_Messenger_messages'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_messages'}{'port'}{'tcp'} = 'gYahoo_Messenger_messages'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_messages'}{'ports'}{'tcp'}{'gYahoo_Messenger_messages'}++	; 
	$ports_ref->{'tcp'}{'gYahoo_Messenger_messages'}{'name'} = 'gYahoo_Messenger_messages'		; 
	$srvcobjects_ref->{'gYahoo_Messenger_Voice_Chat_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_Voice_Chat_TCP'}{'port'}{'tcp'} = 'gYahoo_Messenger_Voice_Chat_TCP'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_Voice_Chat_TCP'}{'ports'}{'tcp'}{'gYahoo_Messenger_Voice_Chat_TCP'}++	; 
	$ports_ref->{'tcp'}{'gYahoo_Messenger_Voice_Chat_TCP'}{'name'} = 'gYahoo_Messenger_Voice_Chat_TCP'		; 
	$srvcobjects_ref->{'gYahoo_Messenger_Webcams'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_Webcams'}{'port'}{'tcp'} = 'gYahoo_Messenger_Webcams'	; 
	$srvcobjects_ref->{'gYahoo_Messenger_Webcams'}{'ports'}{'tcp'}{'gYahoo_Messenger_Webcams'}++	; 
	$ports_ref->{'tcp'}{'gYahoo_Messenger_Webcams'}{'name'} = 'gYahoo_Messenger_Webcams'		; 
	$srvcobjects_ref->{'GateCrasher'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GateCrasher'}{'port'}{'tcp'} = 'GateCrasher'	; 
	$srvcobjects_ref->{'GateCrasher'}{'ports'}{'tcp'}{'GateCrasher'}++	; 
	$ports_ref->{'tcp'}{'GateCrasher'}{'name'} = 'GateCrasher'		; 
	$srvcobjects_ref->{'GNUtella_rtr_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GNUtella_rtr_TCP'}{'port'}{'tcp'} = 'GNUtella_rtr_TCP'	; 
	$srvcobjects_ref->{'GNUtella_rtr_TCP'}{'ports'}{'tcp'}{'GNUtella_rtr_TCP'}++	; 
	$ports_ref->{'tcp'}{'GNUtella_rtr_TCP'}{'name'} = 'GNUtella_rtr_TCP'		; 
	$srvcobjects_ref->{'GNUtella_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GNUtella_TCP'}{'port'}{'tcp'} = 'GNUtella_TCP'	; 
	$srvcobjects_ref->{'GNUtella_TCP'}{'ports'}{'tcp'}{'GNUtella_TCP'}++	; 
	$ports_ref->{'tcp'}{'GNUtella_TCP'}{'name'} = 'GNUtella_TCP'		; 
	$srvcobjects_ref->{'GoToMyPC'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'GoToMyPC'}{'port'}{'tcp'} = 'GoToMyPC'	; 
	$srvcobjects_ref->{'GoToMyPC'}{'ports'}{'tcp'}{'GoToMyPC'}++	; 
	$ports_ref->{'tcp'}{'GoToMyPC'}{'name'} = 'GoToMyPC'		; 
	$srvcobjects_ref->{'H323'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'H323'}{'port'}{'tcp'} = 'H323'	; 
	$srvcobjects_ref->{'H323'}{'ports'}{'tcp'}{'H323'}++	; 
	$ports_ref->{'tcp'}{'H323'}{'name'} = 'H323'		; 
	$srvcobjects_ref->{'H323_any'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'H323_any'}{'port'}{'tcp'} = 'H323_any'	; 
	$srvcobjects_ref->{'H323_any'}{'ports'}{'tcp'}{'H323_any'}++	; 
	$ports_ref->{'tcp'}{'H323_any'}{'name'} = 'H323_any'		; 
	$srvcobjects_ref->{'HackaTack_31785'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31785'}{'port'}{'tcp'} = 'HackaTack_31785'	; 
	$srvcobjects_ref->{'HackaTack_31785'}{'ports'}{'tcp'}{'HackaTack_31785'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31785'}{'name'} = 'HackaTack_31785'		; 
	$srvcobjects_ref->{'HackaTack_31787'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31787'}{'port'}{'tcp'} = 'HackaTack_31787'	; 
	$srvcobjects_ref->{'HackaTack_31787'}{'ports'}{'tcp'}{'HackaTack_31787'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31787'}{'name'} = 'HackaTack_31787'		; 
	$srvcobjects_ref->{'HackaTack_31788'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31788'}{'port'}{'tcp'} = 'HackaTack_31788'	; 
	$srvcobjects_ref->{'HackaTack_31788'}{'ports'}{'tcp'}{'HackaTack_31788'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31788'}{'name'} = 'HackaTack_31788'		; 
	$srvcobjects_ref->{'HackaTack_31790'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31790'}{'port'}{'tcp'} = 'HackaTack_31790'	; 
	$srvcobjects_ref->{'HackaTack_31790'}{'ports'}{'tcp'}{'HackaTack_31790'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31790'}{'name'} = 'HackaTack_31790'		; 
	$srvcobjects_ref->{'HackaTack_31792'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'HackaTack_31792'}{'port'}{'tcp'} = 'HackaTack_31792'	; 
	$srvcobjects_ref->{'HackaTack_31792'}{'ports'}{'tcp'}{'HackaTack_31792'}++	; 
	$ports_ref->{'tcp'}{'HackaTack_31792'}{'name'} = 'HackaTack_31792'		; 
	$srvcobjects_ref->{'Hotline_client'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Hotline_client'}{'port'}{'tcp'} = 'Hotline_client'	; 
	$srvcobjects_ref->{'Hotline_client'}{'ports'}{'tcp'}{'Hotline_client'}++	; 
	$ports_ref->{'tcp'}{'Hotline_client'}{'name'} = 'Hotline_client'		; 
	$srvcobjects_ref->{'ICKiller'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ICKiller'}{'port'}{'tcp'} = 'ICKiller'	; 
	$srvcobjects_ref->{'ICKiller'}{'ports'}{'tcp'}{'ICKiller'}++	; 
	$ports_ref->{'tcp'}{'ICKiller'}{'name'} = 'ICKiller'		; 
	$srvcobjects_ref->{'IKE_tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'IKE_tcp'}{'port'}{'tcp'} = 'IKE_tcp'	; 
	$srvcobjects_ref->{'IKE_tcp'}{'ports'}{'tcp'}{'IKE_tcp'}++	; 
	$ports_ref->{'tcp'}{'IKE_tcp'}{'name'} = 'IKE_tcp'		; 
	$srvcobjects_ref->{'IMAP-SSL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'IMAP-SSL'}{'port'}{'tcp'} = 'IMAP-SSL'	; 
	$srvcobjects_ref->{'IMAP-SSL'}{'ports'}{'tcp'}{'IMAP-SSL'}++	; 
	$ports_ref->{'tcp'}{'IMAP-SSL'}{'name'} = 'IMAP-SSL'		; 
	$srvcobjects_ref->{'iMesh'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'iMesh'}{'port'}{'tcp'} = 'iMesh'	; 
	$srvcobjects_ref->{'iMesh'}{'ports'}{'tcp'}{'iMesh'}++	; 
	$ports_ref->{'tcp'}{'iMesh'}{'name'} = 'iMesh'		; 
	$srvcobjects_ref->{'InCommand'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'InCommand'}{'port'}{'tcp'} = 'InCommand'	; 
	$srvcobjects_ref->{'InCommand'}{'ports'}{'tcp'}{'InCommand'}++	; 
	$ports_ref->{'tcp'}{'InCommand'}{'name'} = 'InCommand'		; 
	$srvcobjects_ref->{'IPSO_Clustering_Mgmt_Protocol'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'IPSO_Clustering_Mgmt_Protocol'}{'port'}{'tcp'} = 'IPSO_Clustering_Mgmt_Protocol'	; 
	$srvcobjects_ref->{'IPSO_Clustering_Mgmt_Protocol'}{'ports'}{'tcp'}{'IPSO_Clustering_Mgmt_Protocol'}++	; 
	$ports_ref->{'tcp'}{'IPSO_Clustering_Mgmt_Protocol'}{'name'} = 'IPSO_Clustering_Mgmt_Protocol'		; 
	$srvcobjects_ref->{'irc1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'irc1'}{'port'}{'tcp'} = 'irc1'	; 
	$srvcobjects_ref->{'irc1'}{'ports'}{'tcp'}{'irc1'}++	; 
	$ports_ref->{'tcp'}{'irc1'}{'name'} = 'irc1'		; 
	$srvcobjects_ref->{'irc2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'irc2'}{'port'}{'tcp'} = 'irc2'	; 
	$srvcobjects_ref->{'irc2'}{'ports'}{'tcp'}{'irc2'}++	; 
	$ports_ref->{'tcp'}{'irc2'}{'name'} = 'irc2'		; 
	$srvcobjects_ref->{'IS411-srvr'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'IS411-srvr'}{'port'}{'tcp'} = 'IS411-srvr'	; 
	$srvcobjects_ref->{'IS411-srvr'}{'ports'}{'tcp'}{'IS411-srvr'}++	; 
	$ports_ref->{'tcp'}{'IS411-srvr'}{'name'} = 'IS411-srvr'		; 
	$srvcobjects_ref->{'Jade'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Jade'}{'port'}{'tcp'} = 'Jade'	; 
	$srvcobjects_ref->{'Jade'}{'ports'}{'tcp'}{'Jade'}++	; 
	$ports_ref->{'tcp'}{'Jade'}{'name'} = 'Jade'		; 
	$srvcobjects_ref->{'Kaos'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Kaos'}{'port'}{'tcp'} = 'Kaos'	; 
	$srvcobjects_ref->{'Kaos'}{'ports'}{'tcp'}{'Kaos'}++	; 
	$ports_ref->{'tcp'}{'Kaos'}{'name'} = 'Kaos'		; 
	$srvcobjects_ref->{'KaZaA'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'KaZaA'}{'port'}{'tcp'} = 'KaZaA'	; 
	$srvcobjects_ref->{'KaZaA'}{'ports'}{'tcp'}{'KaZaA'}++	; 
	$ports_ref->{'tcp'}{'KaZaA'}{'name'} = 'KaZaA'		; 
	$srvcobjects_ref->{'Kazaa'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Kazaa'}{'port'}{'tcp'} = 'Kazaa'	; 
	$srvcobjects_ref->{'Kazaa'}{'ports'}{'tcp'}{'Kazaa'}++	; 
	$ports_ref->{'tcp'}{'Kazaa'}{'name'} = 'Kazaa'		; 
	$srvcobjects_ref->{'Kerberos_v5_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Kerberos_v5_TCP'}{'port'}{'tcp'} = 'Kerberos_v5_TCP'	; 
	$srvcobjects_ref->{'Kerberos_v5_TCP'}{'ports'}{'tcp'}{'Kerberos_v5_TCP'}++	; 
	$ports_ref->{'tcp'}{'Kerberos_v5_TCP'}{'name'} = 'Kerberos_v5_TCP'		; 
	$srvcobjects_ref->{'kerberos-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'kerberos-tcp'}{'port'}{'tcp'} = 'kerberos-tcp'	; 
	$srvcobjects_ref->{'kerberos-tcp'}{'ports'}{'tcp'}{'kerberos-tcp'}++	; 
	$ports_ref->{'tcp'}{'kerberos-tcp'}{'name'} = 'kerberos-tcp'		; 
	$srvcobjects_ref->{'Kuang2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Kuang2'}{'port'}{'tcp'} = 'Kuang2'	; 
	$srvcobjects_ref->{'Kuang2'}{'ports'}{'tcp'}{'Kuang2'}++	; 
	$ports_ref->{'tcp'}{'Kuang2'}{'name'} = 'Kuang2'		; 
	$srvcobjects_ref->{'ldap-ssl'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ldap-ssl'}{'port'}{'tcp'} = 'ldap-ssl'	; 
	$srvcobjects_ref->{'ldap-ssl'}{'ports'}{'tcp'}{'ldap-ssl'}++	; 
	$ports_ref->{'tcp'}{'ldap-ssl'}{'name'} = 'ldap-ssl'		; 
	$srvcobjects_ref->{'lotus'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'lotus'}{'port'}{'tcp'} = 'lotus'	; 
	$srvcobjects_ref->{'lotus'}{'ports'}{'tcp'}{'lotus'}++	; 
	$ports_ref->{'tcp'}{'lotus'}{'name'} = 'lotus'		; 
	$srvcobjects_ref->{'lpdw0rm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'lpdw0rm'}{'port'}{'tcp'} = 'lpdw0rm'	; 
	$srvcobjects_ref->{'lpdw0rm'}{'ports'}{'tcp'}{'lpdw0rm'}++	; 
	$ports_ref->{'tcp'}{'lpdw0rm'}{'name'} = 'lpdw0rm'		; 
	$srvcobjects_ref->{'Madster'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Madster'}{'port'}{'tcp'} = 'Madster'	; 
	$srvcobjects_ref->{'Madster'}{'ports'}{'tcp'}{'Madster'}++	; 
	$ports_ref->{'tcp'}{'Madster'}{'name'} = 'Madster'		; 
	$srvcobjects_ref->{'microsoft-ds'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'microsoft-ds'}{'port'}{'tcp'} = 'microsoft-ds'	; 
	$srvcobjects_ref->{'microsoft-ds'}{'ports'}{'tcp'}{'microsoft-ds'}++	; 
	$ports_ref->{'tcp'}{'microsoft-ds'}{'name'} = 'microsoft-ds'		; 
	$srvcobjects_ref->{'Mneah'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Mneah'}{'port'}{'tcp'} = 'Mneah'	; 
	$srvcobjects_ref->{'Mneah'}{'ports'}{'tcp'}{'Mneah'}++	; 
	$ports_ref->{'tcp'}{'Mneah'}{'name'} = 'Mneah'		; 
	$srvcobjects_ref->{'MSN_Messenger_File_Transfer'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MSN_Messenger_File_Transfer'}{'port'}{'tcp'} = 'MSN_Messenger_File_Transfer'	; 
	$srvcobjects_ref->{'MSN_Messenger_File_Transfer'}{'ports'}{'tcp'}{'MSN_Messenger_File_Transfer'}++	; 
	$ports_ref->{'tcp'}{'MSN_Messenger_File_Transfer'}{'name'} = 'MSN_Messenger_File_Transfer'		; 
	$srvcobjects_ref->{'MSNMS'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MSNMS'}{'port'}{'tcp'} = 'MSNMS'	; 
	$srvcobjects_ref->{'MSNMS'}{'ports'}{'tcp'}{'MSNMS'}++	; 
	$ports_ref->{'tcp'}{'MSNMS'}{'name'} = 'MSNMS'		; 
	$srvcobjects_ref->{'MSNP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MSNP'}{'port'}{'tcp'} = 'MSNP'	; 
	$srvcobjects_ref->{'MSNP'}{'ports'}{'tcp'}{'MSNP'}++	; 
	$ports_ref->{'tcp'}{'MSNP'}{'name'} = 'MSNP'		; 
	$srvcobjects_ref->{'MS-SQL-Monitor'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor'}{'port'}{'tcp'} = 'MS-SQL-Monitor'	; 
	$srvcobjects_ref->{'MS-SQL-Monitor'}{'ports'}{'tcp'}{'MS-SQL-Monitor'}++	; 
	$ports_ref->{'tcp'}{'MS-SQL-Monitor'}{'name'} = 'MS-SQL-Monitor'		; 
	$srvcobjects_ref->{'MS-SQL-Server'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MS-SQL-Server'}{'port'}{'tcp'} = 'MS-SQL-Server'	; 
	$srvcobjects_ref->{'MS-SQL-Server'}{'ports'}{'tcp'}{'MS-SQL-Server'}++	; 
	$ports_ref->{'tcp'}{'MS-SQL-Server'}{'name'} = 'MS-SQL-Server'		; 
	$srvcobjects_ref->{'Multidropper'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Multidropper'}{'port'}{'tcp'} = 'Multidropper'	; 
	$srvcobjects_ref->{'Multidropper'}{'ports'}{'tcp'}{'Multidropper'}++	; 
	$ports_ref->{'tcp'}{'Multidropper'}{'name'} = 'Multidropper'		; 
	$srvcobjects_ref->{'MySQL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'MySQL'}{'port'}{'tcp'} = 'MySQL'	; 
	$srvcobjects_ref->{'MySQL'}{'ports'}{'tcp'}{'MySQL'}++	; 
	$ports_ref->{'tcp'}{'MySQL'}{'name'} = 'MySQL'		; 
	$srvcobjects_ref->{'Napster_Client_6600-6699'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_Client_6600-6699'}{'port'}{'tcp'} = 'Napster_Client_6600-6699'	; 
	$srvcobjects_ref->{'Napster_Client_6600-6699'}{'ports'}{'tcp'}{'Napster_Client_6600-6699'}++	; 
	$ports_ref->{'tcp'}{'Napster_Client_6600-6699'}{'name'} = 'Napster_Client_6600-6699'		; 
	$srvcobjects_ref->{'Napster_directory_4444'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_4444'}{'port'}{'tcp'} = 'Napster_directory_4444'	; 
	$srvcobjects_ref->{'Napster_directory_4444'}{'ports'}{'tcp'}{'Napster_directory_4444'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_4444'}{'name'} = 'Napster_directory_4444'		; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'port'}{'tcp'} = 'Napster_directory_5555'	; 
	$srvcobjects_ref->{'Napster_directory_5555'}{'ports'}{'tcp'}{'Napster_directory_5555'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_5555'}{'name'} = 'Napster_directory_5555'		; 
	$srvcobjects_ref->{'Napster_directory_6666'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_6666'}{'port'}{'tcp'} = 'Napster_directory_6666'	; 
	$srvcobjects_ref->{'Napster_directory_6666'}{'ports'}{'tcp'}{'Napster_directory_6666'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_6666'}{'name'} = 'Napster_directory_6666'		; 
	$srvcobjects_ref->{'Napster_directory_7777'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_7777'}{'port'}{'tcp'} = 'Napster_directory_7777'	; 
	$srvcobjects_ref->{'Napster_directory_7777'}{'ports'}{'tcp'}{'Napster_directory_7777'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_7777'}{'name'} = 'Napster_directory_7777'		; 
	$srvcobjects_ref->{'Napster_directory_8888_primary'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_directory_8888_primary'}{'port'}{'tcp'} = 'Napster_directory_8888_primary'	; 
	$srvcobjects_ref->{'Napster_directory_8888_primary'}{'ports'}{'tcp'}{'Napster_directory_8888_primary'}++	; 
	$ports_ref->{'tcp'}{'Napster_directory_8888_primary'}{'name'} = 'Napster_directory_8888_primary'		; 
	$srvcobjects_ref->{'Napster_redirector'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Napster_redirector'}{'port'}{'tcp'} = 'Napster_redirector'	; 
	$srvcobjects_ref->{'Napster_redirector'}{'ports'}{'tcp'}{'Napster_redirector'}++	; 
	$ports_ref->{'tcp'}{'Napster_redirector'}{'name'} = 'Napster_redirector'		; 
	$srvcobjects_ref->{'nbsession'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'nbsession'}{'port'}{'tcp'} = 'nbsession'	; 
	$srvcobjects_ref->{'nbsession'}{'ports'}{'tcp'}{'nbsession'}++	; 
	$ports_ref->{'tcp'}{'nbsession'}{'name'} = 'nbsession'		; 
	$srvcobjects_ref->{'NCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'NCP'}{'port'}{'tcp'} = 'NCP'	; 
	$srvcobjects_ref->{'NCP'}{'ports'}{'tcp'}{'NCP'}++	; 
	$ports_ref->{'tcp'}{'NCP'}{'name'} = 'NCP'		; 
	$srvcobjects_ref->{'netshow'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'netshow'}{'port'}{'tcp'} = 'netshow'	; 
	$srvcobjects_ref->{'netshow'}{'ports'}{'tcp'}{'netshow'}++	; 
	$ports_ref->{'tcp'}{'netshow'}{'name'} = 'netshow'		; 
	$srvcobjects_ref->{'Services'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Services'}{'port'}{'tcp'} = 'Services'	; 
	$srvcobjects_ref->{'Services'}{'ports'}{'tcp'}{'Services'}++	; 
	$ports_ref->{'tcp'}{'Services'}{'name'} = 'Services'		; 
	$srvcobjects_ref->{'ntp-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ntp-tcp'}{'port'}{'tcp'} = 'ntp-tcp'	; 
	$srvcobjects_ref->{'ntp-tcp'}{'ports'}{'tcp'}{'ntp-tcp'}++	; 
	$ports_ref->{'tcp'}{'ntp-tcp'}{'name'} = 'ntp-tcp'		; 
	$srvcobjects_ref->{'OAS-NameServer'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'OAS-NameServer'}{'port'}{'tcp'} = 'OAS-NameServer'	; 
	$srvcobjects_ref->{'OAS-NameServer'}{'ports'}{'tcp'}{'OAS-NameServer'}++	; 
	$ports_ref->{'tcp'}{'OAS-NameServer'}{'name'} = 'OAS-NameServer'		; 
	$srvcobjects_ref->{'OAS-ORB'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'OAS-ORB'}{'port'}{'tcp'} = 'OAS-ORB'	; 
	$srvcobjects_ref->{'OAS-ORB'}{'ports'}{'tcp'}{'OAS-ORB'}++	; 
	$ports_ref->{'tcp'}{'OAS-ORB'}{'name'} = 'OAS-ORB'		; 
	$srvcobjects_ref->{'OpenWindows'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'OpenWindows'}{'port'}{'tcp'} = 'OpenWindows'	; 
	$srvcobjects_ref->{'OpenWindows'}{'ports'}{'tcp'}{'OpenWindows'}++	; 
	$ports_ref->{'tcp'}{'OpenWindows'}{'name'} = 'OpenWindows'		; 
	$srvcobjects_ref->{'Orbix-1570'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Orbix-1570'}{'port'}{'tcp'} = 'Orbix-1570'	; 
	$srvcobjects_ref->{'Orbix-1570'}{'ports'}{'tcp'}{'Orbix-1570'}++	; 
	$ports_ref->{'tcp'}{'Orbix-1570'}{'name'} = 'Orbix-1570'		; 
	$srvcobjects_ref->{'Orbix-1571'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Orbix-1571'}{'port'}{'tcp'} = 'Orbix-1571'	; 
	$srvcobjects_ref->{'Orbix-1571'}{'ports'}{'tcp'}{'Orbix-1571'}++	; 
	$ports_ref->{'tcp'}{'Orbix-1571'}{'name'} = 'Orbix-1571'		; 
	$srvcobjects_ref->{'pcANYWHERE-data'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pcANYWHERE-data'}{'port'}{'tcp'} = 'pcANYWHERE-data'	; 
	$srvcobjects_ref->{'pcANYWHERE-data'}{'ports'}{'tcp'}{'pcANYWHERE-data'}++	; 
	$ports_ref->{'tcp'}{'pcANYWHERE-data'}{'name'} = 'pcANYWHERE-data'		; 
	$srvcobjects_ref->{'pcTELECOMMUTE-FileSync'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pcTELECOMMUTE-FileSync'}{'port'}{'tcp'} = 'pcTELECOMMUTE-FileSync'	; 
	$srvcobjects_ref->{'pcTELECOMMUTE-FileSync'}{'ports'}{'tcp'}{'pcTELECOMMUTE-FileSync'}++	; 
	$ports_ref->{'tcp'}{'pcTELECOMMUTE-FileSync'}{'name'} = 'pcTELECOMMUTE-FileSync'		; 
	$srvcobjects_ref->{'pop-2'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pop-2'}{'port'}{'tcp'} = 'pop-2'	; 
	$srvcobjects_ref->{'pop-2'}{'ports'}{'tcp'}{'pop-2'}++	; 
	$ports_ref->{'tcp'}{'pop-2'}{'name'} = 'pop-2'		; 
	$srvcobjects_ref->{'pop-3'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pop-3'}{'port'}{'tcp'} = 'pop-3'	; 
	$srvcobjects_ref->{'pop-3'}{'ports'}{'tcp'}{'pop-3'}++	; 
	$ports_ref->{'tcp'}{'pop-3'}{'name'} = 'pop-3'		; 
	$srvcobjects_ref->{'Port_6667_trojans'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Port_6667_trojans'}{'port'}{'tcp'} = 'Port_6667_trojans'	; 
	$srvcobjects_ref->{'Port_6667_trojans'}{'ports'}{'tcp'}{'Port_6667_trojans'}++	; 
	$ports_ref->{'tcp'}{'Port_6667_trojans'}{'name'} = 'Port_6667_trojans'		; 
	$srvcobjects_ref->{'PostgreSQL'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'PostgreSQL'}{'port'}{'tcp'} = 'PostgreSQL'	; 
	$srvcobjects_ref->{'PostgreSQL'}{'ports'}{'tcp'}{'PostgreSQL'}++	; 
	$ports_ref->{'tcp'}{'PostgreSQL'}{'name'} = 'PostgreSQL'		; 
	$srvcobjects_ref->{'pptp-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'pptp-tcp'}{'port'}{'tcp'} = 'pptp-tcp'	; 
	$srvcobjects_ref->{'pptp-tcp'}{'ports'}{'tcp'}{'pptp-tcp'}++	; 
	$ports_ref->{'tcp'}{'pptp-tcp'}{'name'} = 'pptp-tcp'		; 
	$srvcobjects_ref->{'RainWall_Command'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'RainWall_Command'}{'port'}{'tcp'} = 'RainWall_Command'	; 
	$srvcobjects_ref->{'RainWall_Command'}{'ports'}{'tcp'}{'RainWall_Command'}++	; 
	$ports_ref->{'tcp'}{'RainWall_Command'}{'name'} = 'RainWall_Command'		; 
	$srvcobjects_ref->{'RAT'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'RAT'}{'port'}{'tcp'} = 'RAT'	; 
	$srvcobjects_ref->{'RAT'}{'ports'}{'tcp'}{'RAT'}++	; 
	$ports_ref->{'tcp'}{'RAT'}{'name'} = 'RAT'		; 
	$srvcobjects_ref->{'Real-Audio'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Real-Audio'}{'port'}{'tcp'} = 'Real-Audio'	; 
	$srvcobjects_ref->{'Real-Audio'}{'ports'}{'tcp'}{'Real-Audio'}++	; 
	$ports_ref->{'tcp'}{'Real-Audio'}{'name'} = 'Real-Audio'		; 
	$srvcobjects_ref->{'RealSecure'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'RealSecure'}{'port'}{'tcp'} = 'RealSecure'	; 
	$srvcobjects_ref->{'RealSecure'}{'ports'}{'tcp'}{'RealSecure'}++	; 
	$ports_ref->{'tcp'}{'RealSecure'}{'name'} = 'RealSecure'		; 
	$srvcobjects_ref->{'Remote_Storm'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Remote_Storm'}{'port'}{'tcp'} = 'Remote_Storm'	; 
	$srvcobjects_ref->{'Remote_Storm'}{'ports'}{'tcp'}{'Remote_Storm'}++	; 
	$ports_ref->{'tcp'}{'Remote_Storm'}{'name'} = 'Remote_Storm'		; 
	$srvcobjects_ref->{'SCCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SCCP'}{'port'}{'tcp'} = 'SCCP'	; 
	$srvcobjects_ref->{'SCCP'}{'ports'}{'tcp'}{'SCCP'}++	; 
	$ports_ref->{'tcp'}{'SCCP'}{'name'} = 'SCCP'		; 
	$srvcobjects_ref->{'securidprop'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'securidprop'}{'port'}{'tcp'} = 'securidprop'	; 
	$srvcobjects_ref->{'securidprop'}{'ports'}{'tcp'}{'securidprop'}++	; 
	$ports_ref->{'tcp'}{'securidprop'}{'name'} = 'securidprop'		; 
	$srvcobjects_ref->{'Shadyshell'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Shadyshell'}{'port'}{'tcp'} = 'Shadyshell'	; 
	$srvcobjects_ref->{'Shadyshell'}{'ports'}{'tcp'}{'Shadyshell'}++	; 
	$ports_ref->{'tcp'}{'Shadyshell'}{'name'} = 'Shadyshell'		; 
	$srvcobjects_ref->{'sip_any-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sip_any-tcp'}{'port'}{'tcp'} = 'sip_any-tcp'	; 
	$srvcobjects_ref->{'sip_any-tcp'}{'ports'}{'tcp'}{'sip_any-tcp'}++	; 
	$ports_ref->{'tcp'}{'sip_any-tcp'}{'name'} = 'sip_any-tcp'		; 
	$srvcobjects_ref->{'sip_any-tcp-ipv6'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sip_any-tcp-ipv6'}{'port'}{'tcp'} = 'sip_any-tcp-ipv6'	; 
	$srvcobjects_ref->{'sip_any-tcp-ipv6'}{'ports'}{'tcp'}{'sip_any-tcp-ipv6'}++	; 
	$ports_ref->{'tcp'}{'sip_any-tcp-ipv6'}{'name'} = 'sip_any-tcp-ipv6'		; 
	$srvcobjects_ref->{'sip-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sip-tcp'}{'port'}{'tcp'} = 'sip-tcp'	; 
	$srvcobjects_ref->{'sip-tcp'}{'ports'}{'tcp'}{'sip-tcp'}++	; 
	$ports_ref->{'tcp'}{'sip-tcp'}{'name'} = 'sip-tcp'		; 
	$srvcobjects_ref->{'sip-tcp-ipv6'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sip-tcp-ipv6'}{'port'}{'tcp'} = 'sip-tcp-ipv6'	; 
	$srvcobjects_ref->{'sip-tcp-ipv6'}{'ports'}{'tcp'}{'sip-tcp-ipv6'}++	; 
	$ports_ref->{'tcp'}{'sip-tcp-ipv6'}{'name'} = 'sip-tcp-ipv6'		; 
	$srvcobjects_ref->{'SkyDance-T'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SkyDance-T'}{'port'}{'tcp'} = 'SkyDance-T'	; 
	$srvcobjects_ref->{'SkyDance-T'}{'ports'}{'tcp'}{'SkyDance-T'}++	; 
	$ports_ref->{'tcp'}{'SkyDance-T'}{'name'} = 'SkyDance-T'		; 
	$srvcobjects_ref->{'SocketsdesTroie'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SocketsdesTroie'}{'port'}{'tcp'} = 'SocketsdesTroie'	; 
	$srvcobjects_ref->{'SocketsdesTroie'}{'ports'}{'tcp'}{'SocketsdesTroie'}++	; 
	$ports_ref->{'tcp'}{'SocketsdesTroie'}{'name'} = 'SocketsdesTroie'		; 
	$srvcobjects_ref->{'sqlnet1'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet1'}{'port'}{'tcp'} = 'sqlnet1'	; 
	$srvcobjects_ref->{'sqlnet1'}{'ports'}{'tcp'}{'sqlnet1'}++	; 
	$ports_ref->{'tcp'}{'sqlnet1'}{'name'} = 'sqlnet1'		; 
	$srvcobjects_ref->{'sqlnet2-1521'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet2-1521'}{'port'}{'tcp'} = 'sqlnet2-1521'	; 
	$srvcobjects_ref->{'sqlnet2-1521'}{'ports'}{'tcp'}{'sqlnet2-1521'}++	; 
	$ports_ref->{'tcp'}{'sqlnet2-1521'}{'name'} = 'sqlnet2-1521'		; 
	$srvcobjects_ref->{'sqlnet2-1525'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet2-1525'}{'port'}{'tcp'} = 'sqlnet2-1525'	; 
	$srvcobjects_ref->{'sqlnet2-1525'}{'ports'}{'tcp'}{'sqlnet2-1525'}++	; 
	$ports_ref->{'tcp'}{'sqlnet2-1525'}{'name'} = 'sqlnet2-1525'		; 
	$srvcobjects_ref->{'sqlnet2-1526'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'sqlnet2-1526'}{'port'}{'tcp'} = 'sqlnet2-1526'	; 
	$srvcobjects_ref->{'sqlnet2-1526'}{'ports'}{'tcp'}{'sqlnet2-1526'}++	; 
	$ports_ref->{'tcp'}{'sqlnet2-1526'}{'name'} = 'sqlnet2-1526'		; 
	$srvcobjects_ref->{'Squid_NTLM'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Squid_NTLM'}{'port'}{'tcp'} = 'Squid_NTLM'	; 
	$srvcobjects_ref->{'Squid_NTLM'}{'ports'}{'tcp'}{'Squid_NTLM'}++	; 
	$ports_ref->{'tcp'}{'Squid_NTLM'}{'name'} = 'Squid_NTLM'		; 
	$srvcobjects_ref->{'Groups'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Groups'}{'port'}{'tcp'} = 'Groups'	; 
	$srvcobjects_ref->{'Groups'}{'ports'}{'tcp'}{'Groups'}++	; 
	$ports_ref->{'tcp'}{'Groups'}{'name'} = 'Groups'		; 
	$srvcobjects_ref->{'ssl_v3'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ssl_v3'}{'port'}{'tcp'} = 'ssl_v3'	; 
	$srvcobjects_ref->{'ssl_v3'}{'ports'}{'tcp'}{'ssl_v3'}++	; 
	$ports_ref->{'tcp'}{'ssl_v3'}{'name'} = 'ssl_v3'		; 
	$srvcobjects_ref->{'StoneBeat-Control'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'StoneBeat-Control'}{'port'}{'tcp'} = 'StoneBeat-Control'	; 
	$srvcobjects_ref->{'StoneBeat-Control'}{'ports'}{'tcp'}{'StoneBeat-Control'}++	; 
	$ports_ref->{'tcp'}{'StoneBeat-Control'}{'name'} = 'StoneBeat-Control'		; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'port'}{'tcp'} = 'StoneBeat-Daemon'	; 
	$srvcobjects_ref->{'StoneBeat-Daemon'}{'ports'}{'tcp'}{'StoneBeat-Daemon'}++	; 
	$ports_ref->{'tcp'}{'StoneBeat-Daemon'}{'name'} = 'StoneBeat-Daemon'		; 
	$srvcobjects_ref->{'SubSeven'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SubSeven'}{'port'}{'tcp'} = 'SubSeven'	; 
	$srvcobjects_ref->{'SubSeven'}{'ports'}{'tcp'}{'SubSeven'}++	; 
	$ports_ref->{'tcp'}{'SubSeven'}{'name'} = 'SubSeven'		; 
	$srvcobjects_ref->{'SubSeven-G'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'SubSeven-G'}{'port'}{'tcp'} = 'SubSeven-G'	; 
	$srvcobjects_ref->{'SubSeven-G'}{'ports'}{'tcp'}{'SubSeven-G'}++	; 
	$ports_ref->{'tcp'}{'SubSeven-G'}{'name'} = 'SubSeven-G'		; 
	$srvcobjects_ref->{'T.120'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'T.120'}{'port'}{'tcp'} = 'T.120'	; 
	$srvcobjects_ref->{'T.120'}{'ports'}{'tcp'}{'T.120'}++	; 
	$ports_ref->{'tcp'}{'T.120'}{'name'} = 'T.120'		; 
	$srvcobjects_ref->{'TACACSplus'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'TACACSplus'}{'port'}{'tcp'} = 'TACACSplus'	; 
	$srvcobjects_ref->{'TACACSplus'}{'ports'}{'tcp'}{'TACACSplus'}++	; 
	$ports_ref->{'tcp'}{'TACACSplus'}{'name'} = 'TACACSplus'		; 
	$srvcobjects_ref->{'Terrortrojan'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Terrortrojan'}{'port'}{'tcp'} = 'Terrortrojan'	; 
	$srvcobjects_ref->{'Terrortrojan'}{'ports'}{'tcp'}{'Terrortrojan'}++	; 
	$ports_ref->{'tcp'}{'Terrortrojan'}{'name'} = 'Terrortrojan'		; 
	$srvcobjects_ref->{'TheFlu'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'TheFlu'}{'port'}{'tcp'} = 'TheFlu'	; 
	$srvcobjects_ref->{'TheFlu'}{'ports'}{'tcp'}{'TheFlu'}++	; 
	$ports_ref->{'tcp'}{'TheFlu'}{'name'} = 'TheFlu'		; 
	$srvcobjects_ref->{'time-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'time-tcp'}{'port'}{'tcp'} = 'time-tcp'	; 
	$srvcobjects_ref->{'time-tcp'}{'ports'}{'tcp'}{'time-tcp'}++	; 
	$ports_ref->{'tcp'}{'time-tcp'}{'name'} = 'time-tcp'		; 
	$srvcobjects_ref->{'TransScout'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'TransScout'}{'port'}{'tcp'} = 'TransScout'	; 
	$srvcobjects_ref->{'TransScout'}{'ports'}{'tcp'}{'TransScout'}++	; 
	$ports_ref->{'tcp'}{'TransScout'}{'name'} = 'TransScout'		; 
	$srvcobjects_ref->{'Trinoo'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Trinoo'}{'port'}{'tcp'} = 'Trinoo'	; 
	$srvcobjects_ref->{'Trinoo'}{'ports'}{'tcp'}{'Trinoo'}++	; 
	$ports_ref->{'tcp'}{'Trinoo'}{'name'} = 'Trinoo'		; 
	$srvcobjects_ref->{'UltorsTrojan'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'UltorsTrojan'}{'port'}{'tcp'} = 'UltorsTrojan'	; 
	$srvcobjects_ref->{'UltorsTrojan'}{'ports'}{'tcp'}{'UltorsTrojan'}++	; 
	$ports_ref->{'tcp'}{'UltorsTrojan'}{'name'} = 'UltorsTrojan'		; 
	$srvcobjects_ref->{'wais'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'wais'}{'port'}{'tcp'} = 'wais'	; 
	$srvcobjects_ref->{'wais'}{'ports'}{'tcp'}{'wais'}++	; 
	$ports_ref->{'tcp'}{'wais'}{'name'} = 'wais'		; 
	$srvcobjects_ref->{'winframe'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'winframe'}{'port'}{'tcp'} = 'winframe'	; 
	$srvcobjects_ref->{'winframe'}{'ports'}{'tcp'}{'winframe'}++	; 
	$ports_ref->{'tcp'}{'winframe'}{'name'} = 'winframe'		; 
	$srvcobjects_ref->{'WinHole'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'WinHole'}{'port'}{'tcp'} = 'WinHole'	; 
	$srvcobjects_ref->{'WinHole'}{'ports'}{'tcp'}{'WinHole'}++	; 
	$ports_ref->{'tcp'}{'WinHole'}{'name'} = 'WinHole'		; 
	$srvcobjects_ref->{'X11'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'X11'}{'port'}{'tcp'} = 'X11'	; 
	$srvcobjects_ref->{'X11'}{'ports'}{'tcp'}{'X11'}++	; 
	$ports_ref->{'tcp'}{'X11'}{'name'} = 'X11'		; 
	$srvcobjects_ref->{'Xanadu'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Xanadu'}{'port'}{'tcp'} = 'Xanadu'	; 
	$srvcobjects_ref->{'Xanadu'}{'ports'}{'tcp'}{'Xanadu'}++	; 
	$ports_ref->{'tcp'}{'Xanadu'}{'name'} = 'Xanadu'		; 
	$srvcobjects_ref->{'Yahoo_Messenger_messages'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_messages'}{'port'}{'tcp'} = 'Yahoo_Messenger_messages'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_messages'}{'ports'}{'tcp'}{'Yahoo_Messenger_messages'}++	; 
	$ports_ref->{'tcp'}{'Yahoo_Messenger_messages'}{'name'} = 'Yahoo_Messenger_messages'		; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_TCP'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_TCP'}{'port'}{'tcp'} = 'Yahoo_Messenger_Voice_Chat_TCP'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Voice_Chat_TCP'}{'ports'}{'tcp'}{'Yahoo_Messenger_Voice_Chat_TCP'}++	; 
	$ports_ref->{'tcp'}{'Yahoo_Messenger_Voice_Chat_TCP'}{'name'} = 'Yahoo_Messenger_Voice_Chat_TCP'		; 
	$srvcobjects_ref->{'Yahoo_Messenger_Webcams'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Webcams'}{'port'}{'tcp'} = 'Yahoo_Messenger_Webcams'	; 
	$srvcobjects_ref->{'Yahoo_Messenger_Webcams'}{'ports'}{'tcp'}{'Yahoo_Messenger_Webcams'}++	; 
	$ports_ref->{'tcp'}{'Yahoo_Messenger_Webcams'}{'name'} = 'Yahoo_Messenger_Webcams'		; 

# NOTE: Checkpoint Default TCP port addresses

	$srvcobjects_ref->{'domain-tcp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'domain-tcp'}{'port'}{'tcp'} = '53'	; 
	$srvcobjects_ref->{'domain-tcp'}{'ports'}{'tcp'}{'53'}++	; 
	$ports_ref->{'tcp'}{'53'}{'name'} = 'domain-tcp'		; 
	$srvcobjects_ref->{'tcp-high-ports'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'port'}{'tcp'} = '>1024'	; 
	$srvcobjects_ref->{'tcp-high-ports'}{'ports'}{'tcp'}{'>1024'}++	; 
	$srvcobjects_ref->{'udp-high-ports'}{'type'} = 'udp'	; 
	$srvcobjects_ref->{'udp-high-ports'}{'port'}{'udp'} = '>1024'	; 
	$srvcobjects_ref->{'udp-high-ports'}{'ports'}{'udp'}{'>1024'}++	; 
#	$srvcobjects_ref->{'tcp-8080-proxy_service'}{'type'} = 'tcp'	; 
#	$srvcobjects_ref->{'tcp-8080-proxy_service'}{'port'}{'tcp'} = '8080'	; 
#	$srvcobjects_ref->{'tcp-8080-proxy_service'}{'ports'}{'tcp'}{'8080'}++	; 
#	$ports_ref->{'tcp'}{'8080'}{'name'} = 'tcp-8080-proxy_service'		; 
	$srvcobjects_ref->{'exec'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'exec'}{'port'}{'tcp'} = '512'	; 
	$srvcobjects_ref->{'exec'}{'ports'}{'tcp'}{'512'}++	; 
	$ports_ref->{'tcp'}{'512'}{'name'} = 'exec'		; 
	$srvcobjects_ref->{'exec'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'exec'}{'port'}{'tcp'} = '512'	; 
	$srvcobjects_ref->{'exec'}{'ports'}{'tcp'}{'512'}++	; 
	$ports_ref->{'tcp'}{'512'}{'name'} = 'exec'		; 
	$srvcobjects_ref->{'finger'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'finger'}{'port'}{'tcp'} = '79'	; 
	$srvcobjects_ref->{'finger'}{'ports'}{'tcp'}{'79'}++	; 
	$ports_ref->{'tcp'}{'79'}{'name'} = 'finger'		; 
	$srvcobjects_ref->{'ftp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ftp'}{'port'}{'tcp'} = '21'	; 
	$srvcobjects_ref->{'ftp'}{'ports'}{'tcp'}{'21'}++	; 
	$ports_ref->{'tcp'}{'21'}{'name'} = 'ftp'		; 
	$srvcobjects_ref->{'gopher'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'gopher'}{'port'}{'tcp'} = '70'	; 
	$srvcobjects_ref->{'gopher'}{'ports'}{'tcp'}{'70'}++	; 
	$ports_ref->{'tcp'}{'70'}{'name'} = 'gopher'		; 
	$srvcobjects_ref->{'http'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'http'}{'port'}{'tcp'} = '80'	; 
	$srvcobjects_ref->{'http'}{'ports'}{'tcp'}{'80'}++	; 
	$ports_ref->{'tcp'}{'80'}{'name'} = 'http'		; 
	$srvcobjects_ref->{'https'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'https'}{'port'}{'tcp'} = '443'	; 
	$srvcobjects_ref->{'https'}{'ports'}{'tcp'}{'443'}++	; 
	$ports_ref->{'tcp'}{'443'}{'name'} = 'https'		; 
	$srvcobjects_ref->{'ident'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ident'}{'port'}{'tcp'} = '113'	; 
	$srvcobjects_ref->{'ident'}{'ports'}{'tcp'}{'113'}++	; 
	$ports_ref->{'tcp'}{'113'}{'name'} = 'ident'		; 
	$srvcobjects_ref->{'imap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'imap'}{'port'}{'tcp'} = '143'	; 
	$srvcobjects_ref->{'imap'}{'ports'}{'tcp'}{'143'}++	; 
	$ports_ref->{'tcp'}{'143'}{'name'} = 'imap'		; 
	$srvcobjects_ref->{'ldap'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ldap'}{'port'}{'tcp'} = '389'	; 
	$srvcobjects_ref->{'ldap'}{'ports'}{'tcp'}{'389'}++	; 
	$ports_ref->{'tcp'}{'389'}{'name'} = 'ldap'		; 
	$srvcobjects_ref->{'login'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'login'}{'port'}{'tcp'} = '513'	; 
	$srvcobjects_ref->{'login'}{'ports'}{'tcp'}{'513'}++	; 
	$ports_ref->{'tcp'}{'513'}{'name'} = 'login'		; 
	$srvcobjects_ref->{'nntp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'nntp'}{'port'}{'tcp'} = '119'	; 
	$srvcobjects_ref->{'nntp'}{'ports'}{'tcp'}{'119'}++	; 
	$ports_ref->{'tcp'}{'119'}{'name'} = 'nntp'		; 
	$srvcobjects_ref->{'rtsp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'rtsp'}{'port'}{'tcp'} = '554'	; 
	$srvcobjects_ref->{'rtsp'}{'ports'}{'tcp'}{'554'}++	; 
	$ports_ref->{'tcp'}{'554'}{'name'} = 'rtsp'		; 
	$srvcobjects_ref->{'shell'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'shell'}{'port'}{'tcp'} = '514'	; 
	$srvcobjects_ref->{'shell'}{'ports'}{'tcp'}{'514'}++	; 
	$ports_ref->{'tcp'}{'514'}{'name'} = 'shell'		; 
	$srvcobjects_ref->{'smtp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'smtp'}{'port'}{'tcp'} = '25'	; 
	$srvcobjects_ref->{'smtp'}{'ports'}{'tcp'}{'25'}++	; 
	$ports_ref->{'tcp'}{'25'}{'name'} = 'smtp'		; 
	$srvcobjects_ref->{'ssh'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'ssh'}{'port'}{'tcp'} = '22'	; 
	$srvcobjects_ref->{'ssh'}{'ports'}{'tcp'}{'22'}++	; 
	$ports_ref->{'tcp'}{'22'}{'name'} = 'ssh'		; 
	$srvcobjects_ref->{'telnet'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'telnet'}{'port'}{'tcp'} = '23'	; 
	$srvcobjects_ref->{'telnet'}{'ports'}{'tcp'}{'23'}++	; 
	$ports_ref->{'tcp'}{'23'}{'name'} = 'telnet'		; 
	$srvcobjects_ref->{'uucp'}{'type'} = 'tcp'	; 
	$srvcobjects_ref->{'uucp'}{'port'}{'tcp'} = '540'	; 
	$srvcobjects_ref->{'uucp'}{'ports'}{'tcp'}{'540'}++	; 
	$ports_ref->{'tcp'}{'540'}{'name'} = 'uucp'		; 

# NOTE: Checkpoint Default DCE-RPC ports with non numeric port addresses

	$srvcobjects_ref->{'ALL_DCE_RPC'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'ALL_DCE_RPC'}{'port'}{'dce-rpc'} = 'ALL_DCE_RPC'	; 
	$srvcobjects_ref->{'ALL_DCE_RPC'}{'ports'}{'dce-rpc'}{'ALL_DCE_RPC'}++	; 
	$ports_ref->{'dce-rpc'}{'ALL_DCE_RPC'}{'name'} = 'ALL_DCE_RPC'		; 
	$srvcobjects_ref->{'DCOM-RemoteActivation'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'DCOM-RemoteActivation'}{'port'}{'dce-rpc'} = 'DCOM-RemoteActivation'	; 
	$srvcobjects_ref->{'DCOM-RemoteActivation'}{'ports'}{'dce-rpc'}{'DCOM-RemoteActivation'}++	; 
	$ports_ref->{'dce-rpc'}{'DCOM-RemoteActivation'}{'name'} = 'DCOM-RemoteActivation'		; 
	$srvcobjects_ref->{'DCOM-SystemActivation'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'DCOM-SystemActivation'}{'port'}{'dce-rpc'} = 'DCOM-SystemActivation'	; 
	$srvcobjects_ref->{'DCOM-SystemActivation'}{'ports'}{'dce-rpc'}{'DCOM-SystemActivation'}++	; 
	$ports_ref->{'dce-rpc'}{'DCOM-SystemActivation'}{'name'} = 'DCOM-SystemActivation'		; 
	$srvcobjects_ref->{'DCOM-OXID_Resolver'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'DCOM-OXID_Resolver'}{'port'}{'dce-rpc'} = 'DCOM-OXID_Resolver'	; 
	$srvcobjects_ref->{'DCOM-OXID_Resolver'}{'ports'}{'dce-rpc'}{'DCOM-OXID_Resolver'}++	; 
	$ports_ref->{'dce-rpc'}{'DCOM-OXID_Resolver'}{'name'} = 'DCOM-OXID_Resolver'		; 
	$srvcobjects_ref->{'DCOM-RemUnknown2'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'DCOM-RemUnknown2'}{'port'}{'dce-rpc'} = 'DCOM-RemUnknown2'	; 
	$srvcobjects_ref->{'DCOM-RemUnknown2'}{'ports'}{'dce-rpc'}{'DCOM-RemUnknown2'}++	; 
	$ports_ref->{'dce-rpc'}{'DCOM-RemUnknown2'}{'name'} = 'DCOM-RemUnknown2'		; 
	$srvcobjects_ref->{'gALL_DCE_RPC'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gALL_DCE_RPC'}{'port'}{'dce-rpc'} = 'gALL_DCE_RPC'	; 
	$srvcobjects_ref->{'gALL_DCE_RPC'}{'ports'}{'dce-rpc'}{'gALL_DCE_RPC'}++	; 
	$ports_ref->{'dce-rpc'}{'gALL_DCE_RPC'}{'name'} = 'gALL_DCE_RPC'		; 
	$srvcobjects_ref->{'gDCOM-OXID_Resolver'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gDCOM-OXID_Resolver'}{'port'}{'dce-rpc'} = 'gDCOM-OXID_Resolver'	; 
	$srvcobjects_ref->{'gDCOM-OXID_Resolver'}{'ports'}{'dce-rpc'}{'gDCOM-OXID_Resolver'}++	; 
	$ports_ref->{'dce-rpc'}{'gDCOM-OXID_Resolver'}{'name'} = 'gDCOM-OXID_Resolver'		; 
	$srvcobjects_ref->{'gDCOM-RemoteActivation'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gDCOM-RemoteActivation'}{'port'}{'dce-rpc'} = 'gDCOM-RemoteActivation'	; 
	$srvcobjects_ref->{'gDCOM-RemoteActivation'}{'ports'}{'dce-rpc'}{'gDCOM-RemoteActivation'}++	; 
	$ports_ref->{'dce-rpc'}{'gDCOM-RemoteActivation'}{'name'} = 'gDCOM-RemoteActivation'		; 
	$srvcobjects_ref->{'gDCOM-RemUnknown2'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gDCOM-RemUnknown2'}{'port'}{'dce-rpc'} = 'gDCOM-RemUnknown2'	; 
	$srvcobjects_ref->{'gDCOM-RemUnknown2'}{'ports'}{'dce-rpc'}{'gDCOM-RemUnknown2'}++	; 
	$ports_ref->{'dce-rpc'}{'gDCOM-RemUnknown2'}{'name'} = 'gDCOM-RemUnknown2'		; 
	$srvcobjects_ref->{'gDCOM-SystemActivation'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gDCOM-SystemActivation'}{'port'}{'dce-rpc'} = 'gDCOM-SystemActivation'	; 
	$srvcobjects_ref->{'gDCOM-SystemActivation'}{'ports'}{'dce-rpc'}{'gDCOM-SystemActivation'}++	; 
	$ports_ref->{'dce-rpc'}{'gDCOM-SystemActivation'}{'name'} = 'gDCOM-SystemActivation'		; 
	$srvcobjects_ref->{'gHP-OpCctla'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gHP-OpCctla'}{'port'}{'dce-rpc'} = 'gHP-OpCctla'	; 
	$srvcobjects_ref->{'gHP-OpCctla'}{'ports'}{'dce-rpc'}{'gHP-OpCctla'}++	; 
	$ports_ref->{'dce-rpc'}{'gHP-OpCctla'}{'name'} = 'gHP-OpCctla'		; 
	$srvcobjects_ref->{'gHP-OpCctla-bulk'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gHP-OpCctla-bulk'}{'port'}{'dce-rpc'} = 'gHP-OpCctla-bulk'	; 
	$srvcobjects_ref->{'gHP-OpCctla-bulk'}{'ports'}{'dce-rpc'}{'gHP-OpCctla-bulk'}++	; 
	$ports_ref->{'dce-rpc'}{'gHP-OpCctla-bulk'}{'name'} = 'gHP-OpCctla-bulk'		; 
	$srvcobjects_ref->{'gHP-OpCctla-cfgpush'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gHP-OpCctla-cfgpush'}{'port'}{'dce-rpc'} = 'gHP-OpCctla-cfgpush'	; 
	$srvcobjects_ref->{'gHP-OpCctla-cfgpush'}{'ports'}{'dce-rpc'}{'gHP-OpCctla-cfgpush'}++	; 
	$ports_ref->{'dce-rpc'}{'gHP-OpCctla-cfgpush'}{'name'} = 'gHP-OpCctla-cfgpush'		; 
	$srvcobjects_ref->{'gHP-OpCdistm'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gHP-OpCdistm'}{'port'}{'dce-rpc'} = 'gHP-OpCdistm'	; 
	$srvcobjects_ref->{'gHP-OpCdistm'}{'ports'}{'dce-rpc'}{'gHP-OpCdistm'}++	; 
	$ports_ref->{'dce-rpc'}{'gHP-OpCdistm'}{'name'} = 'gHP-OpCdistm'		; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-coa'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-coa'}{'port'}{'dce-rpc'} = 'gHP-OpCmsgrd-coa'	; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-coa'}{'ports'}{'dce-rpc'}{'gHP-OpCmsgrd-coa'}++	; 
	$ports_ref->{'dce-rpc'}{'gHP-OpCmsgrd-coa'}{'name'} = 'gHP-OpCmsgrd-coa'		; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-m2m'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-m2m'}{'port'}{'dce-rpc'} = 'gHP-OpCmsgrd-m2m'	; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-m2m'}{'ports'}{'dce-rpc'}{'gHP-OpCmsgrd-m2m'}++	; 
	$ports_ref->{'dce-rpc'}{'gHP-OpCmsgrd-m2m'}{'name'} = 'gHP-OpCmsgrd-m2m'		; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-std'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-std'}{'port'}{'dce-rpc'} = 'gHP-OpCmsgrd-std'	; 
	$srvcobjects_ref->{'gHP-OpCmsgrd-std'}{'ports'}{'dce-rpc'}{'gHP-OpCmsgrd-std'}++	; 
	$ports_ref->{'dce-rpc'}{'gHP-OpCmsgrd-std'}{'name'} = 'gHP-OpCmsgrd-std'		; 
	$srvcobjects_ref->{'gMSExchangeADL'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeADL'}{'port'}{'dce-rpc'} = 'gMSExchangeADL'	; 
	$srvcobjects_ref->{'gMSExchangeADL'}{'ports'}{'dce-rpc'}{'gMSExchangeADL'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeADL'}{'name'} = 'gMSExchangeADL'		; 
	$srvcobjects_ref->{'gMSExchangeDirRef'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeDirRef'}{'port'}{'dce-rpc'} = 'gMSExchangeDirRef'	; 
	$srvcobjects_ref->{'gMSExchangeDirRef'}{'ports'}{'dce-rpc'}{'gMSExchangeDirRef'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeDirRef'}{'name'} = 'gMSExchangeDirRef'		; 
	$srvcobjects_ref->{'gMSExchangeDirRep'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeDirRep'}{'port'}{'dce-rpc'} = 'gMSExchangeDirRep'	; 
	$srvcobjects_ref->{'gMSExchangeDirRep'}{'ports'}{'dce-rpc'}{'gMSExchangeDirRep'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeDirRep'}{'name'} = 'gMSExchangeDirRep'		; 
	$srvcobjects_ref->{'gMSExchangeDSNSPI'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeDSNSPI'}{'port'}{'dce-rpc'} = 'gMSExchangeDSNSPI'	; 
	$srvcobjects_ref->{'gMSExchangeDSNSPI'}{'ports'}{'dce-rpc'}{'gMSExchangeDSNSPI'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeDSNSPI'}{'name'} = 'gMSExchangeDSNSPI'		; 
	$srvcobjects_ref->{'gMSExchangeDSRep'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeDSRep'}{'port'}{'dce-rpc'} = 'gMSExchangeDSRep'	; 
	$srvcobjects_ref->{'gMSExchangeDSRep'}{'ports'}{'dce-rpc'}{'gMSExchangeDSRep'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeDSRep'}{'name'} = 'gMSExchangeDSRep'		; 
	$srvcobjects_ref->{'gMSExchangeDSXDS'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeDSXDS'}{'port'}{'dce-rpc'} = 'gMSExchangeDSXDS'	; 
	$srvcobjects_ref->{'gMSExchangeDSXDS'}{'ports'}{'dce-rpc'}{'gMSExchangeDSXDS'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeDSXDS'}{'name'} = 'gMSExchangeDSXDS'		; 
	$srvcobjects_ref->{'gMSExchangeIS'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeIS'}{'port'}{'dce-rpc'} = 'gMSExchangeIS'	; 
	$srvcobjects_ref->{'gMSExchangeIS'}{'ports'}{'dce-rpc'}{'gMSExchangeIS'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeIS'}{'name'} = 'gMSExchangeIS'		; 
	$srvcobjects_ref->{'gMSExchangeMTA'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeMTA'}{'port'}{'dce-rpc'} = 'gMSExchangeMTA'	; 
	$srvcobjects_ref->{'gMSExchangeMTA'}{'ports'}{'dce-rpc'}{'gMSExchangeMTA'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeMTA'}{'name'} = 'gMSExchangeMTA'		; 
	$srvcobjects_ref->{'gMSExchangeStoreAdm'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeStoreAdm'}{'port'}{'dce-rpc'} = 'gMSExchangeStoreAdm'	; 
	$srvcobjects_ref->{'gMSExchangeStoreAdm'}{'ports'}{'dce-rpc'}{'gMSExchangeStoreAdm'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeStoreAdm'}{'name'} = 'gMSExchangeStoreAdm'		; 
	$srvcobjects_ref->{'gMSExchangeSysAtt'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeSysAtt'}{'port'}{'dce-rpc'} = 'gMSExchangeSysAtt'	; 
	$srvcobjects_ref->{'gMSExchangeSysAtt'}{'ports'}{'dce-rpc'}{'gMSExchangeSysAtt'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeSysAtt'}{'name'} = 'gMSExchangeSysAtt'		; 
	$srvcobjects_ref->{'gMSExchangeSysAttPriv'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'gMSExchangeSysAttPriv'}{'port'}{'dce-rpc'} = 'gMSExchangeSysAttPriv'	; 
	$srvcobjects_ref->{'gMSExchangeSysAttPriv'}{'ports'}{'dce-rpc'}{'gMSExchangeSysAttPriv'}++	; 
	$ports_ref->{'dce-rpc'}{'gMSExchangeSysAttPriv'}{'name'} = 'gMSExchangeSysAttPriv'		; 
	$srvcobjects_ref->{'HP-OpCctla'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'HP-OpCctla'}{'port'}{'dce-rpc'} = 'HP-OpCctla'	; 
	$srvcobjects_ref->{'HP-OpCctla'}{'ports'}{'dce-rpc'}{'HP-OpCctla'}++	; 
	$ports_ref->{'dce-rpc'}{'HP-OpCctla'}{'name'} = 'HP-OpCctla'		; 
	$srvcobjects_ref->{'HP-OpCctla-bulk'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'HP-OpCctla-bulk'}{'port'}{'dce-rpc'} = 'HP-OpCctla-bulk'	; 
	$srvcobjects_ref->{'HP-OpCctla-bulk'}{'ports'}{'dce-rpc'}{'HP-OpCctla-bulk'}++	; 
	$ports_ref->{'dce-rpc'}{'HP-OpCctla-bulk'}{'name'} = 'HP-OpCctla-bulk'		; 
	$srvcobjects_ref->{'HP-OpCctla-cfgpush'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'HP-OpCctla-cfgpush'}{'port'}{'dce-rpc'} = 'HP-OpCctla-cfgpush'	; 
	$srvcobjects_ref->{'HP-OpCctla-cfgpush'}{'ports'}{'dce-rpc'}{'HP-OpCctla-cfgpush'}++	; 
	$ports_ref->{'dce-rpc'}{'HP-OpCctla-cfgpush'}{'name'} = 'HP-OpCctla-cfgpush'		; 
	$srvcobjects_ref->{'HP-OpCdistm'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'HP-OpCdistm'}{'port'}{'dce-rpc'} = 'HP-OpCdistm'	; 
	$srvcobjects_ref->{'HP-OpCdistm'}{'ports'}{'dce-rpc'}{'HP-OpCdistm'}++	; 
	$ports_ref->{'dce-rpc'}{'HP-OpCdistm'}{'name'} = 'HP-OpCdistm'		; 
	$srvcobjects_ref->{'HP-OpCmsgrd-coa'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'HP-OpCmsgrd-coa'}{'port'}{'dce-rpc'} = 'HP-OpCmsgrd-coa'	; 
	$srvcobjects_ref->{'HP-OpCmsgrd-coa'}{'ports'}{'dce-rpc'}{'HP-OpCmsgrd-coa'}++	; 
	$ports_ref->{'dce-rpc'}{'HP-OpCmsgrd-coa'}{'name'} = 'HP-OpCmsgrd-coa'		; 
	$srvcobjects_ref->{'HP-OpCmsgrd-m2m'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'HP-OpCmsgrd-m2m'}{'port'}{'dce-rpc'} = 'HP-OpCmsgrd-m2m'	; 
	$srvcobjects_ref->{'HP-OpCmsgrd-m2m'}{'ports'}{'dce-rpc'}{'HP-OpCmsgrd-m2m'}++	; 
	$ports_ref->{'dce-rpc'}{'HP-OpCmsgrd-m2m'}{'name'} = 'HP-OpCmsgrd-m2m'		; 
	$srvcobjects_ref->{'HP-OpCmsgrd-std'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'HP-OpCmsgrd-std'}{'port'}{'dce-rpc'} = 'HP-OpCmsgrd-std'	; 
	$srvcobjects_ref->{'HP-OpCmsgrd-std'}{'ports'}{'dce-rpc'}{'HP-OpCmsgrd-std'}++	; 
	$ports_ref->{'dce-rpc'}{'HP-OpCmsgrd-std'}{'name'} = 'HP-OpCmsgrd-std'		; 
	$srvcobjects_ref->{'MSExchangeADL'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeADL'}{'port'}{'dce-rpc'} = 'MSExchangeADL'	; 
	$srvcobjects_ref->{'MSExchangeADL'}{'ports'}{'dce-rpc'}{'MSExchangeADL'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeADL'}{'name'} = 'MSExchangeADL'		; 
	$srvcobjects_ref->{'MSExchangeDatabase'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDatabase'}{'port'}{'dce-rpc'} = 'MSExchangeDatabase'	; 
	$srvcobjects_ref->{'MSExchangeDatabase'}{'ports'}{'dce-rpc'}{'MSExchangeDatabase'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDatabase'}{'name'} = 'MSExchangeDatabase'		; 
	$srvcobjects_ref->{'MSExchangeDirRef'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDirRef'}{'port'}{'dce-rpc'} = 'MSExchangeDirRef'	; 
	$srvcobjects_ref->{'MSExchangeDirRef'}{'ports'}{'dce-rpc'}{'MSExchangeDirRef'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDirRef'}{'name'} = 'MSExchangeDirRef'		; 
	$srvcobjects_ref->{'MSExchangeDirRep'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDirRep'}{'port'}{'dce-rpc'} = 'MSExchangeDirRep'	; 
	$srvcobjects_ref->{'MSExchangeDirRep'}{'ports'}{'dce-rpc'}{'MSExchangeDirRep'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDirRep'}{'name'} = 'MSExchangeDirRep'		; 
	$srvcobjects_ref->{'MSExchangeDS'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDS'}{'port'}{'dce-rpc'} = 'MSExchangeDS'	; 
	$srvcobjects_ref->{'MSExchangeDS'}{'ports'}{'dce-rpc'}{'MSExchangeDS'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDS'}{'name'} = 'MSExchangeDS'		; 
	$srvcobjects_ref->{'MSExchangeDSNSPI'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDSNSPI'}{'port'}{'dce-rpc'} = 'MSExchangeDSNSPI'	; 
	$srvcobjects_ref->{'MSExchangeDSNSPI'}{'ports'}{'dce-rpc'}{'MSExchangeDSNSPI'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDSNSPI'}{'name'} = 'MSExchangeDSNSPI'		; 
	$srvcobjects_ref->{'MSExchangeDSRep'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDSRep'}{'port'}{'dce-rpc'} = 'MSExchangeDSRep'	; 
	$srvcobjects_ref->{'MSExchangeDSRep'}{'ports'}{'dce-rpc'}{'MSExchangeDSRep'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDSRep'}{'name'} = 'MSExchangeDSRep'		; 
	$srvcobjects_ref->{'MSExchangeDirSync'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDirSync'}{'port'}{'dce-rpc'} = 'MSExchangeDirSync'	; 
	$srvcobjects_ref->{'MSExchangeDirSync'}{'ports'}{'dce-rpc'}{'MSExchangeDirSync'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDirSync'}{'name'} = 'MSExchangeDirSync'		; 
	$srvcobjects_ref->{'MSExchangeDSXDS'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeDSXDS'}{'port'}{'dce-rpc'} = 'MSExchangeDSXDS'	; 
	$srvcobjects_ref->{'MSExchangeDSXDS'}{'ports'}{'dce-rpc'}{'MSExchangeDSXDS'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeDSXDS'}{'name'} = 'MSExchangeDSXDS'		; 
	$srvcobjects_ref->{'MSExchangeInformationStore1'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeInformationStore1'}{'port'}{'dce-rpc'} = 'MSExchangeInformationStore1'	; 
	$srvcobjects_ref->{'MSExchangeInformationStore1'}{'ports'}{'dce-rpc'}{'MSExchangeInformationStore1'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeInformationStore1'}{'name'} = 'MSExchangeInformationStore1'		; 
	$srvcobjects_ref->{'MSExchangeInformationStore2'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeInformationStore2'}{'port'}{'dce-rpc'} = 'MSExchangeInformationStore2'	; 
	$srvcobjects_ref->{'MSExchangeInformationStore2'}{'ports'}{'dce-rpc'}{'MSExchangeInformationStore2'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeInformationStore2'}{'name'} = 'MSExchangeInformationStore2'		; 
	$srvcobjects_ref->{'MSExchangeInformationStore3'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeInformationStore3'}{'port'}{'dce-rpc'} = 'MSExchangeInformationStore3'	; 
	$srvcobjects_ref->{'MSExchangeInformationStore3'}{'ports'}{'dce-rpc'}{'MSExchangeInformationStore3'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeInformationStore3'}{'name'} = 'MSExchangeInformationStore3'		; 
	$srvcobjects_ref->{'MSExchangeIS'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeIS'}{'port'}{'dce-rpc'} = 'MSExchangeIS'	; 
	$srvcobjects_ref->{'MSExchangeIS'}{'ports'}{'dce-rpc'}{'MSExchangeIS'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeIS'}{'name'} = 'MSExchangeIS'		; 
	$srvcobjects_ref->{'MSExchangeMTA'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeMTA'}{'port'}{'dce-rpc'} = 'MSExchangeMTA'	; 
	$srvcobjects_ref->{'MSExchangeMTA'}{'ports'}{'dce-rpc'}{'MSExchangeMTA'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeMTA'}{'name'} = 'MSExchangeMTA'		; 
	$srvcobjects_ref->{'MSExchangeQAdmin'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeQAdmin'}{'port'}{'dce-rpc'} = 'MSExchangeQAdmin'	; 
	$srvcobjects_ref->{'MSExchangeQAdmin'}{'ports'}{'dce-rpc'}{'MSExchangeQAdmin'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeQAdmin'}{'name'} = 'MSExchangeQAdmin'		; 
	$srvcobjects_ref->{'MSExchangeRA'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeRA'}{'port'}{'dce-rpc'} = 'MSExchangeRA'	; 
	$srvcobjects_ref->{'MSExchangeRA'}{'ports'}{'dce-rpc'}{'MSExchangeRA'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeRA'}{'name'} = 'MSExchangeRA'		; 
	$srvcobjects_ref->{'MSExchangeStoreAdm'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeStoreAdm'}{'port'}{'dce-rpc'} = 'MSExchangeStoreAdm'	; 
	$srvcobjects_ref->{'MSExchangeStoreAdm'}{'ports'}{'dce-rpc'}{'MSExchangeStoreAdm'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeStoreAdm'}{'name'} = 'MSExchangeStoreAdm'		; 
	$srvcobjects_ref->{'MSExchangeStoreAdmin1'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeStoreAdmin1'}{'port'}{'dce-rpc'} = 'MSExchangeStoreAdmin1'	; 
	$srvcobjects_ref->{'MSExchangeStoreAdmin1'}{'ports'}{'dce-rpc'}{'MSExchangeStoreAdmin1'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeStoreAdmin1'}{'name'} = 'MSExchangeStoreAdmin1'		; 
	$srvcobjects_ref->{'MSExchangeStoreAdmin3'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeStoreAdmin3'}{'port'}{'dce-rpc'} = 'MSExchangeStoreAdmin3'	; 
	$srvcobjects_ref->{'MSExchangeStoreAdmin3'}{'ports'}{'dce-rpc'}{'MSExchangeStoreAdmin3'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeStoreAdmin3'}{'name'} = 'MSExchangeStoreAdmin3'		; 
	$srvcobjects_ref->{'MSExchangeSysAtt'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeSysAtt'}{'port'}{'dce-rpc'} = 'MSExchangeSysAtt'	; 
	$srvcobjects_ref->{'MSExchangeSysAtt'}{'ports'}{'dce-rpc'}{'MSExchangeSysAtt'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeSysAtt'}{'name'} = 'MSExchangeSysAtt'		; 
	$srvcobjects_ref->{'MSExchangeSysAttPriv'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSExchangeSysAttPriv'}{'port'}{'dce-rpc'} = 'MSExchangeSysAttPriv'	; 
	$srvcobjects_ref->{'MSExchangeSysAttPriv'}{'ports'}{'dce-rpc'}{'MSExchangeSysAttPriv'}++	; 
	$ports_ref->{'dce-rpc'}{'MSExchangeSysAttPriv'}{'name'} = 'MSExchangeSysAttPriv'		; 
	$srvcobjects_ref->{'MSMessenger'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSMessenger'}{'port'}{'dce-rpc'} = 'MSMessenger'	; 
	$srvcobjects_ref->{'MSMessenger'}{'ports'}{'dce-rpc'}{'MSMessenger'}++	; 
	$ports_ref->{'dce-rpc'}{'MSMessenger'}{'name'} = 'MSMessenger'		; 
	$srvcobjects_ref->{'MSMQ'}{'type'} = 'dce-rpc'	; 
	$srvcobjects_ref->{'MSMQ'}{'port'}{'dce-rpc'} = 'MSMQ'	; 
	$srvcobjects_ref->{'MSMQ'}{'ports'}{'dce-rpc'}{'MSMQ'}++	; 
	$ports_ref->{'dce-rpc'}{'MSMQ'}{'name'} = 'MSMQ'		; 
}

sub set_checkpoint_group_defaults {
	my ($netgroups_ref) = @_;

#	$srvcgroups_ref->{'empty'}{''}++;
}
sub set_netscreen_group_defaults {
	my ($srvcgroups_ref)   = @_;
	
	$srvcgroups_ref->{'MS-AD'}{'MS-AD-BR'}++;
	$srvcgroups_ref->{'MS-AD'}{'MS-AD-DRSUAPI'}++;
	$srvcgroups_ref->{'MS-AD'}{'MS-AD-DSROLE'}++;
	$srvcgroups_ref->{'MS-AD'}{'MS-AD-DSSETUP'}++;
	$srvcgroups_ref->{'MS-EXCHANGE'}{'MS-EXCHANGE-DATABASE'}++;
	$srvcgroups_ref->{'MS-EXCHANGE'}{'MS-EXCHANGE-DIRECTORY'}++;
	$srvcgroups_ref->{'MS-EXCHANGE'}{'MS-EXCHANGE-INFO-STORE'}++;
	$srvcgroups_ref->{'MS-EXCHANGE'}{'MS-EXCHANGE-MTA'}++;
	$srvcgroups_ref->{'MS-EXCHANGE'}{'MS-EXCHANGE-STORE'}++;
	$srvcgroups_ref->{'MS-EXCHANGE'}{'MS-EXCHANGE-SYSATD'}++;
	$srvcgroups_ref->{'MS-IIS'}{'MS-IIS-COM'}++;
	$srvcgroups_ref->{'MS-IIS'}{'MS-IIS-IMAP4'}++;
	$srvcgroups_ref->{'MS-IIS'}{'MS-IIS-INETINFO'}++;
	$srvcgroups_ref->{'MS-IIS'}{'MS-IIS-NNTP'}++;
	$srvcgroups_ref->{'MS-IIS'}{'MS-IIS-POP3'}++;
	$srvcgroups_ref->{'MS-IIS'}{'MS-IIS-SMTP'}++;
}

sub set_netscreen_defaults {
	my ($srvcobjects_ref)  = @_;

# NOTE: Netscreen default services created with servicebuilder.pl by dan !! SERVICES ONLY NO PORTS

	$srvcobjects_ref->{'AOL'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'AOL'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'AOL'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'AOL'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'AOL'}{'port'}{'tcp'}	= '5190-5194'	; 
	$srvcobjects_ref->{'AOL'}{'ports'}{'tcp'}{'AOL'}++ 	; 
	$srvcobjects_ref->{'AOL'}{'ports'}{'tcp'}{'aol'}++ 	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'port'}{'udp'}	= '5678'	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'ports'}{'udp'}{'APPLE-ICHAT-SNATMAP'}++ 	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'ports'}{'udp'}{'apple-ichat-snatmap'}++ 	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'ports'}{'other'}{'APPLE-ICHAT-SNATMAP'}++	; 
	$srvcobjects_ref->{'APPLE-ICHAT-SNATMAP'}{'ports'}{'other'}{'apple-ichat-snatmap'}++	; 
	$srvcobjects_ref->{'BGP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'BGP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'BGP'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'BGP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'BGP'}{'port'}{'tcp'}	= '179'	; 
	$srvcobjects_ref->{'BGP'}{'ports'}{'tcp'}{'BGP'}++ 	; 
	$srvcobjects_ref->{'BGP'}{'ports'}{'tcp'}{'bgp'}++ 	; 
	$srvcobjects_ref->{'BGP'}{'ports'}{'other'}{'BGP'}++	; 
	$srvcobjects_ref->{'BGP'}{'ports'}{'other'}{'bgp'}++	; 
	$srvcobjects_ref->{'CHARGEN'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'CHARGEN'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'CHARGEN'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'CHARGEN'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'CHARGEN'}{'port'}{'udp'}	= '19'	; 
	$srvcobjects_ref->{'CHARGEN'}{'ports'}{'udp'}{'CHARGEN'}++ 	; 
	$srvcobjects_ref->{'CHARGEN'}{'ports'}{'udp'}{'chargen'}++ 	; 
	$srvcobjects_ref->{'CHARGEN'}{'ports'}{'other'}{'CHARGEN'}++	; 
	$srvcobjects_ref->{'CHARGEN'}{'ports'}{'other'}{'chargen'}++	; 
	$srvcobjects_ref->{'DHCP-Relay'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'DHCP-Relay'}{'default'}    	= '1'	; 
	$srvcobjects_ref->{'DHCP-Relay'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'DHCP-Relay'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'DHCP-Relay'}{'port'}{'udp'}	= '67'	; 
	$srvcobjects_ref->{'DHCP-Relay'}{'ports'}{'udp'}{'DHCP-Relay'}++ 	; 
	$srvcobjects_ref->{'DHCP-Relay'}{'ports'}{'udp'}{'dhcp-relay'}++ 	; 
	$srvcobjects_ref->{'DISCARD'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'DISCARD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'DISCARD'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'DISCARD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'DISCARD'}{'port'}{'udp'}	= '9'	; 
	$srvcobjects_ref->{'DISCARD'}{'ports'}{'udp'}{'DISCARD'}++ 	; 
	$srvcobjects_ref->{'DISCARD'}{'ports'}{'udp'}{'discard'}++ 	; 
	$srvcobjects_ref->{'DISCARD'}{'ports'}{'other'}{'DISCARD'}++	; 
	$srvcobjects_ref->{'DISCARD'}{'ports'}{'other'}{'discard'}++	; 
	$srvcobjects_ref->{'DNS'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'DNS'}{'default'}    	= '1'	; 
	$srvcobjects_ref->{'DNS'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'DNS'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'DNS'}{'port'}{'udp'}	= '53'	; 
	$srvcobjects_ref->{'DNS'}{'port'}{'tcp'}	= '53'	; 
	$srvcobjects_ref->{'DNS'}{'ports'}{'udp'}{'DNS'}++ 	; 
	$srvcobjects_ref->{'DNS'}{'ports'}{'udp'}{'dns'}++ 	; 
	$srvcobjects_ref->{'DNS'}{'ports'}{'tcp'}{'DNS'}++ 	; 
	$srvcobjects_ref->{'DNS'}{'ports'}{'tcp'}{'dns'}++ 	; 
	$srvcobjects_ref->{'ECHO'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'ECHO'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'ECHO'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'ECHO'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'ECHO'}{'port'}{'udp'}	= '7'	; 
	$srvcobjects_ref->{'ECHO'}{'ports'}{'udp'}{'ECHO'}++ 	; 
	$srvcobjects_ref->{'ECHO'}{'ports'}{'udp'}{'echo'}++ 	; 
	$srvcobjects_ref->{'ECHO'}{'ports'}{'other'}{'ECHO'}++	; 
	$srvcobjects_ref->{'ECHO'}{'ports'}{'other'}{'echo'}++	; 
	$srvcobjects_ref->{'ESP'}{'type'}        	= 'other'	; 
	$srvcobjects_ref->{'ESP'}{'default'}    	= '1'	; 
	$srvcobjects_ref->{'ESP'}{'timeout'}    	= '60'	; 
	$srvcobjects_ref->{'ESP'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'ESP'}{'port'}{'other'}	= 'ESP'	; 
	#$srvcobjects_ref->{'ESP'}{'port'}{'AH'}	= 'esp'	; 
	$srvcobjects_ref->{'ESP'}{'ports'}{'other'}{'esp'}++	; 
	$srvcobjects_ref->{'ESP'}{'ports'}{'other'}{'ESP'}++ 	; 
	$srvcobjects_ref->{'ESP'}{'ports'}{'51'}{'ESP'}++ 	; 
	$srvcobjects_ref->{'ESP'}{'ports'}{'ESP'}{'esp'}++ 	; 
	$srvcobjects_ref->{'ESP'}{'ports'}{'AH'}{'esp'}++ 	; 
	$srvcobjects_ref->{'FINGER'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'FINGER'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'FINGER'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'FINGER'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'FINGER'}{'port'}{'tcp'}	= '79'	; 
	$srvcobjects_ref->{'FINGER'}{'ports'}{'tcp'}{'FINGER'}++ 	; 
	$srvcobjects_ref->{'FINGER'}{'ports'}{'tcp'}{'finger'}++ 	; 
	$srvcobjects_ref->{'FTP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'FTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'FTP'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'FTP'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'FTP'}{'port'}{'tcp'}	= '21'	; 
	$srvcobjects_ref->{'FTP'}{'ports'}{'tcp'}{'FTP'}++ 	; 
	$srvcobjects_ref->{'FTP'}{'ports'}{'tcp'}{'ftp'}++ 	; 
	$srvcobjects_ref->{'FTP-Get'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'FTP-Get'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'FTP-Get'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'FTP-Get'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'FTP-Get'}{'port'}{'tcp'}	= '21'	; 
	$srvcobjects_ref->{'FTP-Get'}{'ports'}{'tcp'}{'FTP-Get'}++ 	; 
	$srvcobjects_ref->{'FTP-Get'}{'ports'}{'tcp'}{'ftp-get'}++ 	; 
	$srvcobjects_ref->{'FTP-Put'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'FTP-Put'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'FTP-Put'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'FTP-Put'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'FTP-Put'}{'port'}{'tcp'}	= '21'	; 
	$srvcobjects_ref->{'FTP-Put'}{'ports'}{'tcp'}{'FTP-Put'}++ 	; 
	$srvcobjects_ref->{'FTP-Put'}{'ports'}{'tcp'}{'ftp-put'}++ 	; 
	$srvcobjects_ref->{'GNUTELLA'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'GNUTELLA'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'GNUTELLA'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'GNUTELLA'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'GNUTELLA'}{'port'}{'udp'}	= '6346-6347'	; 
	$srvcobjects_ref->{'GNUTELLA'}{'ports'}{'udp'}{'GNUTELLA'}++ 	; 
	$srvcobjects_ref->{'GNUTELLA'}{'ports'}{'udp'}{'gnutella'}++ 	; 
	$srvcobjects_ref->{'GOPHER'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'GOPHER'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'GOPHER'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'GOPHER'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'GOPHER'}{'port'}{'tcp'}	= '70'	; 
	$srvcobjects_ref->{'GOPHER'}{'ports'}{'tcp'}{'GOPHER'}++ 	; 
	$srvcobjects_ref->{'GOPHER'}{'ports'}{'tcp'}{'gopher'}++ 	; 
	$srvcobjects_ref->{'GRE'}{'type'}        	= 'gre'	; 
	$srvcobjects_ref->{'GRE'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'GRE'}{'timeout'}    	= '60'	; 
	$srvcobjects_ref->{'GRE'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'GRE'}{'port'}{'47'}	= '0-65535'	; 
	$srvcobjects_ref->{'GRE'}{'ports'}{'gre'}{'GRE'}++ 	; 
	$srvcobjects_ref->{'GRE'}{'ports'}{'GRE'}{'GRE'}++ 	; 
	$srvcobjects_ref->{'GRE'}{'ports'}{'47'}{'GRE'}++ 	; 
	$srvcobjects_ref->{'GRE'}{'ports'}{'gre'}{'gre'}++ 	; 
	$srvcobjects_ref->{'gre'}{'type'}        	= 'gre'	; 
	$srvcobjects_ref->{'gre'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'gre'}{'timeout'}    	= '60'	; 
	$srvcobjects_ref->{'gre'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'gre'}{'port'}{'47'}	= '0-65535'	; 
	$srvcobjects_ref->{'gre'}{'ports'}{'gre'}{'GRE'}++ 	; 
	$srvcobjects_ref->{'gre'}{'ports'}{'GRE'}{'GRE'}++ 	; 
	$srvcobjects_ref->{'gre'}{'ports'}{'47'}{'GRE'}++ 	; 
	$srvcobjects_ref->{'gre'}{'ports'}{'gre'}{'gre'}++ 	; 
	$srvcobjects_ref->{'GTP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'GTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'GTP'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'GTP'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'GTP'}{'port'}{'tcp'}	= '3386'	; 
	$srvcobjects_ref->{'GTP'}{'ports'}{'tcp'}{'GTP'}++ 	; 
	$srvcobjects_ref->{'GTP'}{'ports'}{'tcp'}{'gtp'}++ 	; 
	$srvcobjects_ref->{'H.323'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'H.323'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'H.323'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'H.323'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'H.323'}{'port'}{'tcp'}	= '1720'	; 
	$srvcobjects_ref->{'H.323'}{'ports'}{'tcp'}{'H.323'}++ 	; 
	$srvcobjects_ref->{'H.323'}{'ports'}{'tcp'}{'h.323'}++ 	; 
	$srvcobjects_ref->{'HTTP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'HTTP'}{'default'}    	= '5'	; 
	$srvcobjects_ref->{'HTTP'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'HTTP'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'HTTP'}{'port'}{'tcp'}	= '80'	; 
	$srvcobjects_ref->{'HTTP'}{'ports'}{'tcp'}{'HTTP'}++ 	; 
	$srvcobjects_ref->{'HTTP'}{'ports'}{'tcp'}{'http'}++ 	; 
	$srvcobjects_ref->{'HTTP-EXT'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'HTTP-EXT'}{'default'}    	= '5'	; 
	$srvcobjects_ref->{'HTTP-EXT'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'HTTP-EXT'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'HTTP-EXT'}{'port'}{'tcp'}	= '8000-8001'	; 
	$srvcobjects_ref->{'HTTP-EXT'}{'ports'}{'tcp'}{'HTTP-EXT'}++ 	; 
	$srvcobjects_ref->{'HTTP-EXT'}{'ports'}{'tcp'}{'http-ext'}++ 	; 
	$srvcobjects_ref->{'ICMP Time Exceeded'}{'type'}        	= 'icmp'	; 
	$srvcobjects_ref->{'ICMP Time Exceeded'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'ICMP Time Exceeded'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'ICMP Time Exceeded'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'ICMP Time Exceeded'}{'port'}{'icmp'}	= '100011-100011'	; 
	$srvcobjects_ref->{'ICMP Time Exceeded'}{'ports'}{'icmp'}{'ICMP Time Exceeded'}++ 	; 
	$srvcobjects_ref->{'ICMP-INFO'}{'type'}        	= 'icmp'	; 
	$srvcobjects_ref->{'ICMP Dest Unreachable'}{'type'}        	= 'icmp'	; 
	$srvcobjects_ref->{'ICMP Dest Unreachable'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'ICMP Dest Unreachable'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'ICMP Dest Unreachable'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'ICMP Dest Unreachable'}{'port'}{'icmp'}	= '100010-100010'	; 
	$srvcobjects_ref->{'ICMP Dest Unreachable'}{'ports'}{'icmp'}{'ICMP Dest Unreachable'}++ 	; 
	$srvcobjects_ref->{'ICMP-INFO'}{'type'}        	= 'icmp'	; 
	$srvcobjects_ref->{'ICMP-INFO'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'ICMP-INFO'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'ICMP-INFO'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'ICMP-INFO'}{'port'}{'icmp'}	= '100012-100012'	; 
	$srvcobjects_ref->{'ICMP-INFO'}{'ports'}{'icmp'}{'ICMP-INFO'}++ 	; 
	$srvcobjects_ref->{'ICMP-INFO'}{'ports'}{'icmp'}{'icmp-info'}++ 	; 
	$srvcobjects_ref->{'HTTPS'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'HTTPS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'HTTPS'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'HTTPS'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'HTTPS'}{'port'}{'tcp'}	= '443'	; 
	$srvcobjects_ref->{'HTTPS'}{'ports'}{'tcp'}{'HTTPS'}++ 	; 
	$srvcobjects_ref->{'HTTPS'}{'ports'}{'tcp'}{'https'}++ 	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'type'}        	= 'icmp'	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'ICMP-ANY'}{'port'}{'icmp'}	= '0-65535'	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'ports'}{'icmp'}{'ICMP-ANY'}++ 	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'ports'}{'icmp'}{'icmp-any'}++ 	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'ports'}{'icmp'}{'icmp'}++ 	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'ports'}{'other'}{'ICMP-ANY'}++	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'ports'}{'other'}{'icmp-any'}++	; 
	$srvcobjects_ref->{'ICMP-ANY'}{'ports'}{'other'}{'icmp'}++	; 
	$srvcobjects_ref->{'IDENT'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'IDENT'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'IDENT'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'IDENT'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'IDENT'}{'port'}{'tcp'}	= '113'	; 
	$srvcobjects_ref->{'IDENT'}{'ports'}{'tcp'}{'IDENT'}++ 	; 
	$srvcobjects_ref->{'IDENT'}{'ports'}{'tcp'}{'ident'}++ 	; 
	$srvcobjects_ref->{'IDENT'}{'ports'}{'other'}{'IDENT'}++	; 
	$srvcobjects_ref->{'IDENT'}{'ports'}{'other'}{'ident'}++	; 
	$srvcobjects_ref->{'IKE'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'IKE'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'IKE'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'IKE'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'IKE'}{'port'}{'udp'}	= '500'	; 
	$srvcobjects_ref->{'IKE'}{'ports'}{'udp'}{'IKE'}++ 	; 
	$srvcobjects_ref->{'IKE'}{'ports'}{'udp'}{'ike'}++ 	; 
	$srvcobjects_ref->{'IKE-NAT'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'IKE-NAT'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'IKE-NAT'}{'timeout'}    	= '3'	; 
	$srvcobjects_ref->{'IKE-NAT'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'IKE-NAT'}{'port'}{'udp'}	= '500'	; 
	$srvcobjects_ref->{'IKE-NAT'}{'ports'}{'udp'}{'IKE-NAT'}++ 	; 
	$srvcobjects_ref->{'IKE-NAT'}{'ports'}{'udp'}{'ike-nat'}++ 	; 
	$srvcobjects_ref->{'IMAP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'IMAP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'IMAP'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'IMAP'}{'description'}	= 'email'; 
	$srvcobjects_ref->{'IMAP'}{'port'}{'tcp'}	= '143'	; 
	$srvcobjects_ref->{'IMAP'}{'ports'}{'tcp'}{'IMAP'}++ 	; 
	$srvcobjects_ref->{'IMAP'}{'ports'}{'tcp'}{'imap'}++ 	; 
	$srvcobjects_ref->{'InternetLocatorService'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'InternetLocatorService'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'InternetLocatorService'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'InternetLocatorService'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'InternetLocatorService'}{'port'}{'tcp'}	= '389'	; 
	$srvcobjects_ref->{'InternetLocatorService'}{'ports'}{'tcp'}{'InternetLocatorService'}++ 	; 
	$srvcobjects_ref->{'InternetLocatorService'}{'ports'}{'tcp'}{'internetlocatorservice'}++ 	; 
	$srvcobjects_ref->{'IRC'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'IRC'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'IRC'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'IRC'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'IRC'}{'port'}{'tcp'}	= '6660-6669'	; 
	$srvcobjects_ref->{'IRC'}{'ports'}{'tcp'}{'IRC'}++ 	; 
	$srvcobjects_ref->{'IRC'}{'ports'}{'tcp'}{'irc'}++ 	; 
	$srvcobjects_ref->{'L2TP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'L2TP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'L2TP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'L2TP'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'L2TP'}{'port'}{'udp'}	= '1701'	; 
	$srvcobjects_ref->{'L2TP'}{'ports'}{'udp'}{'L2TP'}++ 	; 
	$srvcobjects_ref->{'L2TP'}{'ports'}{'udp'}{'l2tp'}++ 	; 
	$srvcobjects_ref->{'LDAP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'LDAP'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'LDAP'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'LDAP'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'LDAP'}{'port'}{'tcp'}	= '389'	; 
	$srvcobjects_ref->{'LDAP'}{'ports'}{'tcp'}{'LDAP'}++ 	; 
	$srvcobjects_ref->{'LDAP'}{'ports'}{'tcp'}{'ldap'}++ 	; 
	$srvcobjects_ref->{'LPR'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'LPR'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'LPR'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'LPR'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'LPR'}{'port'}{'tcp'}	= '515'	; 
	$srvcobjects_ref->{'LPR'}{'ports'}{'tcp'}{'LPR'}++ 	; 
	$srvcobjects_ref->{'LPR'}{'ports'}{'tcp'}{'lpr'}++ 	; 
	$srvcobjects_ref->{'LPR'}{'ports'}{'other'}{'LPR'}++	; 
	$srvcobjects_ref->{'LPR'}{'ports'}{'other'}{'lpr'}++	; 
	$srvcobjects_ref->{'MAIL'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'MAIL'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MAIL'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MAIL'}{'description'}	= 'email'; 
	$srvcobjects_ref->{'MAIL'}{'port'}{'tcp'}	= '25'	; 
	$srvcobjects_ref->{'MAIL'}{'ports'}{'tcp'}{'MAIL'}++ 	; 
	$srvcobjects_ref->{'MAIL'}{'ports'}{'tcp'}{'mail'}++ 	; 
	$srvcobjects_ref->{'MGCP-CA'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'MGCP-CA'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MGCP-CA'}{'timeout'}    	= '120'	; 
	$srvcobjects_ref->{'MGCP-CA'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MGCP-CA'}{'port'}{'udp'}	= '2727'	; 
	$srvcobjects_ref->{'MGCP-CA'}{'ports'}{'udp'}{'MGCP-CA'}++ 	; 
	$srvcobjects_ref->{'MGCP-CA'}{'ports'}{'udp'}{'mgcp-ca'}++ 	; 
	$srvcobjects_ref->{'MGCP-CA'}{'ports'}{'other'}{'MGCP-CA'}++	; 
	$srvcobjects_ref->{'MGCP-CA'}{'ports'}{'other'}{'mgcp-ca'}++	; 
	$srvcobjects_ref->{'MGCP-UA'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'MGCP-UA'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MGCP-UA'}{'timeout'}    	= '120'	; 
	$srvcobjects_ref->{'MGCP-UA'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MGCP-UA'}{'port'}{'udp'}	= '2427'	; 
	$srvcobjects_ref->{'MGCP-UA'}{'ports'}{'udp'}{'MGCP-UA'}++ 	; 
	$srvcobjects_ref->{'MGCP-UA'}{'ports'}{'udp'}{'mgcp-ua'}++ 	; 
	$srvcobjects_ref->{'MGCP-UA'}{'ports'}{'other'}{'MGCP-UA'}++	; 
	$srvcobjects_ref->{'MGCP-UA'}{'ports'}{'other'}{'mgcp-ua'}++	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-AD-BR'}{'port'}{'rcp'}	= 'ms-ad-br'	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'ports'}{'rcp'}{'MS-AD-BR'}++ 	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'ports'}{'rcp'}{'ms-ad-br'}++ 	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'ports'}{'other'}{'MS-AD-BR'}++	; 
	$srvcobjects_ref->{'MS-AD-BR'}{'ports'}{'other'}{'ms-ad-br'}++	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'port'}{'rcp'}	= 'ms-ad-drsuapi'	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'ports'}{'rcp'}{'MS-AD-DRSUAPI'}++ 	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'ports'}{'rcp'}{'ms-ad-drsuapi'}++ 	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'ports'}{'other'}{'MS-AD-DRSUAPI'}++	; 
	$srvcobjects_ref->{'MS-AD-DRSUAPI'}{'ports'}{'other'}{'ms-ad-drsuapi'}++	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'port'}{'rcp'}	= 'ms-ad-dsrole'	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'ports'}{'rcp'}{'MS-AD-DSROLE'}++ 	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'ports'}{'rcp'}{'ms-ad-dsrole'}++ 	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'ports'}{'other'}{'MS-AD-DSROLE'}++	; 
	$srvcobjects_ref->{'MS-AD-DSROLE'}{'ports'}{'other'}{'ms-ad-dsrole'}++	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'port'}{'rcp'}	= 'ms-ad-dssetup'	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'ports'}{'rcp'}{'MS-AD-DSSETUP'}++ 	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'ports'}{'rcp'}{'ms-ad-dssetup'}++ 	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'ports'}{'other'}{'MS-AD-DSSETUP'}++	; 
	$srvcobjects_ref->{'MS-AD-DSSETUP'}{'ports'}{'other'}{'ms-ad-dssetup'}++	; 
	$srvcobjects_ref->{'MS-DTC'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-DTC'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-DTC'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-DTC'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-DTC'}{'port'}{'rcp'}	= 'ms-dtc'	; 
	$srvcobjects_ref->{'MS-DTC'}{'ports'}{'rcp'}{'MS-DTC'}++ 	; 
	$srvcobjects_ref->{'MS-DTC'}{'ports'}{'rcp'}{'ms-dtc'}++ 	; 
	$srvcobjects_ref->{'MS-DTC'}{'ports'}{'other'}{'MS-DTC'}++	; 
	$srvcobjects_ref->{'MS-DTC'}{'ports'}{'other'}{'ms-dtc'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'port'}{'rcp'}	= 'ms-exchange-database'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'ports'}{'rcp'}{'MS-EXCHANGE-DATABASE'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'ports'}{'rcp'}{'ms-exchange-database'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'ports'}{'other'}{'MS-EXCHANGE-DATABASE'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DATABASE'}{'ports'}{'other'}{'ms-exchange-database'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'port'}{'rcp'}	= 'ms-exchange-directory'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'ports'}{'rcp'}{'MS-EXCHANGE-DIRECTORY'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'ports'}{'rcp'}{'ms-exchange-directory'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'ports'}{'other'}{'MS-EXCHANGE-DIRECTORY'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-DIRECTORY'}{'ports'}{'other'}{'ms-exchange-directory'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'port'}{'rcp'}	= 'ms-exchange-info-store'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'ports'}{'rcp'}{'MS-EXCHANGE-INFO-STORE'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'ports'}{'rcp'}{'ms-exchange-info-store'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'ports'}{'other'}{'MS-EXCHANGE-INFO-STORE'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-INFO-STORE'}{'ports'}{'other'}{'ms-exchange-info-store'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'port'}{'rcp'}	= 'ms-exchange-mta'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'ports'}{'rcp'}{'MS-EXCHANGE-MTA'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'ports'}{'rcp'}{'ms-exchange-mta'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'ports'}{'other'}{'MS-EXCHANGE-MTA'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-MTA'}{'ports'}{'other'}{'ms-exchange-mta'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'port'}{'rcp'}	= 'ms-exchange-store'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'ports'}{'rcp'}{'MS-EXCHANGE-STORE'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'ports'}{'rcp'}{'ms-exchange-store'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'ports'}{'other'}{'MS-EXCHANGE-STORE'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-STORE'}{'ports'}{'other'}{'ms-exchange-store'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'port'}{'rcp'}	= 'ms-exchange-sysatd'	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'ports'}{'rcp'}{'MS-EXCHANGE-SYSATD'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'ports'}{'rcp'}{'ms-exchange-sysatd'}++ 	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'ports'}{'other'}{'MS-EXCHANGE-SYSATD'}++	; 
	$srvcobjects_ref->{'MS-EXCHANGE-SYSATD'}{'ports'}{'other'}{'ms-exchange-sysatd'}++	; 
	$srvcobjects_ref->{'MS-FRS'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-FRS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-FRS'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-FRS'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-FRS'}{'port'}{'rcp'}	= 'ms-frs'	; 
	$srvcobjects_ref->{'MS-FRS'}{'ports'}{'rcp'}{'MS-FRS'}++ 	; 
	$srvcobjects_ref->{'MS-FRS'}{'ports'}{'rcp'}{'ms-frs'}++ 	; 
	$srvcobjects_ref->{'MS-FRS'}{'ports'}{'other'}{'MS-FRS'}++	; 
	$srvcobjects_ref->{'MS-FRS'}{'ports'}{'other'}{'ms-frs'}++	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'port'}{'rcp'}	= 'ms-iis-com'	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'ports'}{'rcp'}{'MS-IIS-COM'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'ports'}{'rcp'}{'ms-iis-com'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'ports'}{'other'}{'MS-IIS-COM'}++	; 
	$srvcobjects_ref->{'MS-IIS-COM'}{'ports'}{'other'}{'ms-iis-com'}++	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'port'}{'rcp'}	= 'ms-iis-imap4'	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'ports'}{'rcp'}{'MS-IIS-IMAP4'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'ports'}{'rcp'}{'ms-iis-imap4'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'ports'}{'other'}{'MS-IIS-IMAP4'}++	; 
	$srvcobjects_ref->{'MS-IIS-IMAP4'}{'ports'}{'other'}{'ms-iis-imap4'}++	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'port'}{'rcp'}	= 'ms-iis-inetinfo'	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'ports'}{'rcp'}{'MS-IIS-INETINFO'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'ports'}{'rcp'}{'ms-iis-inetinfo'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'ports'}{'other'}{'MS-IIS-INETINFO'}++	; 
	$srvcobjects_ref->{'MS-IIS-INETINFO'}{'ports'}{'other'}{'ms-iis-inetinfo'}++	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'port'}{'rcp'}	= 'ms-iis-nntp'	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'ports'}{'rcp'}{'MS-IIS-NNTP'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'ports'}{'rcp'}{'ms-iis-nntp'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'ports'}{'other'}{'MS-IIS-NNTP'}++	; 
	$srvcobjects_ref->{'MS-IIS-NNTP'}{'ports'}{'other'}{'ms-iis-nntp'}++	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'port'}{'rcp'}	= 'ms-iis-pop3'	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'ports'}{'rcp'}{'MS-IIS-POP3'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'ports'}{'rcp'}{'ms-iis-pop3'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'ports'}{'other'}{'MS-IIS-POP3'}++	; 
	$srvcobjects_ref->{'MS-IIS-POP3'}{'ports'}{'other'}{'ms-iis-pop3'}++	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'port'}{'rcp'}	= 'ms-iis-smtp'	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'ports'}{'rcp'}{'MS-IIS-SMTP'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'ports'}{'rcp'}{'ms-iis-smtp'}++ 	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'ports'}{'other'}{'MS-IIS-SMTP'}++	; 
	$srvcobjects_ref->{'MS-IIS-SMTP'}{'ports'}{'other'}{'ms-iis-smtp'}++	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'port'}{'rcp'}	= 'ms-ismserv'	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'ports'}{'rcp'}{'MS-ISMSERV'}++ 	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'ports'}{'rcp'}{'ms-ismserv'}++ 	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'ports'}{'other'}{'MS-ISMSERV'}++	; 
	$srvcobjects_ref->{'MS-ISMSERV'}{'ports'}{'other'}{'ms-ismserv'}++	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'port'}{'rcp'}	= 'ms-messenger'	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'ports'}{'rcp'}{'MS-MESSENGER'}++ 	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'ports'}{'rcp'}{'ms-messenger'}++ 	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'ports'}{'other'}{'MS-MESSENGER'}++	; 
	$srvcobjects_ref->{'MS-MESSENGER'}{'ports'}{'other'}{'ms-messenger'}++	; 
	$srvcobjects_ref->{'MS-MQQM'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-MQQM'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-MQQM'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-MQQM'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-MQQM'}{'port'}{'rcp'}	= 'ms-mqqm'	; 
	$srvcobjects_ref->{'MS-MQQM'}{'ports'}{'rcp'}{'MS-MQQM'}++ 	; 
	$srvcobjects_ref->{'MS-MQQM'}{'ports'}{'rcp'}{'ms-mqqm'}++ 	; 
	$srvcobjects_ref->{'MS-MQQM'}{'ports'}{'other'}{'MS-MQQM'}++	; 
	$srvcobjects_ref->{'MS-MQQM'}{'ports'}{'other'}{'ms-mqqm'}++	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'port'}{'rcp'}	= 'ms-netlogon'	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'ports'}{'rcp'}{'MS-NETLOGON'}++ 	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'ports'}{'rcp'}{'ms-netlogon'}++ 	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'ports'}{'other'}{'MS-NETLOGON'}++	; 
	$srvcobjects_ref->{'MS-NETLOGON'}{'ports'}{'other'}{'ms-netlogon'}++	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'port'}{'rcp'}	= 'ms-rpc-any'	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'port'}{'tcp'}	= 'msrpc'	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'ports'}{'rcp'}{'MS-RPC-ANY'}++ 	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'ports'}{'rcp'}{'ms-rpc-any'}++ 	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'ports'}{'rcp'}{'msrpc'}++ 	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'ports'}{'tcp'}{'msrpc'}++ 	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'ports'}{'other'}{'MS-RPC-ANY'}++	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'ports'}{'other'}{'ms-rpc-any'}++	; 
	$srvcobjects_ref->{'MS-RPC-ANY'}{'ports'}{'other'}{'msrpc'}++	; 
	$srvcobjects_ref->{'MS-RPC-EPM'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'MS-RPC-EPM'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-RPC-EPM'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-RPC-EPM'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'MS-RPC-EPM'}{'port'}{'udp'}	= '135'	; 
	$srvcobjects_ref->{'MS-RPC-EPM'}{'ports'}{'udp'}{'MS-RPC-EPM'}++ 	; 
	$srvcobjects_ref->{'MS-RPC-EPM'}{'ports'}{'udp'}{'ms-rpc-epm'}++ 	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'port'}{'rcp'}	= 'ms-scheduler'	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'ports'}{'rcp'}{'MS-SCHEDULER'}++ 	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'ports'}{'rcp'}{'ms-scheduler'}++ 	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'ports'}{'other'}{'MS-SCHEDULER'}++	; 
	$srvcobjects_ref->{'MS-SCHEDULER'}{'ports'}{'other'}{'ms-scheduler'}++	; 
	$srvcobjects_ref->{'MS-SQL'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'MS-SQL'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-SQL'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-SQL'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-SQL'}{'port'}{'tcp'}	= '1433'	; 
	$srvcobjects_ref->{'MS-SQL'}{'ports'}{'tcp'}{'MS-SQL'}++ 	; 
	$srvcobjects_ref->{'MS-SQL'}{'ports'}{'tcp'}{'ms-sql'}++ 	; 
	$srvcobjects_ref->{'MS-SQL'}{'ports'}{'other'}{'MS-SQL'}++	; 
	$srvcobjects_ref->{'MS-SQL'}{'ports'}{'other'}{'ms-sql'}++	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'port'}{'rcp'}	= 'ms-win-dns'	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'ports'}{'rcp'}{'MS-WIN-DNS'}++ 	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'ports'}{'rcp'}{'ms-win-dns'}++ 	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'ports'}{'other'}{'MS-WIN-DNS'}++	; 
	$srvcobjects_ref->{'MS-WIN-DNS'}{'ports'}{'other'}{'ms-win-dns'}++	; 
	$srvcobjects_ref->{'MS-WINS'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-WINS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-WINS'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'MS-WINS'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-WINS'}{'port'}{'rcp'}	= 'ms-wins'	; 
	$srvcobjects_ref->{'MS-WINS'}{'ports'}{'rcp'}{'MS-WINS'}++ 	; 
	$srvcobjects_ref->{'MS-WINS'}{'ports'}{'rcp'}{'ms-wins'}++ 	; 
	$srvcobjects_ref->{'MS-WINS'}{'ports'}{'other'}{'MS-WINS'}++	; 
	$srvcobjects_ref->{'MS-WINS'}{'ports'}{'other'}{'ms-wins'}++	; 
	$srvcobjects_ref->{'MS-WMIC'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'MS-WMIC'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MS-WMIC'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MS-WMIC'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'MS-WMIC'}{'port'}{'rcp'}	= 'ms-wmic'	; 
	$srvcobjects_ref->{'MS-WMIC'}{'ports'}{'rcp'}{'MS-WMIC'}++ 	; 
	$srvcobjects_ref->{'MS-WMIC'}{'ports'}{'rcp'}{'ms-wmic'}++ 	; 
	$srvcobjects_ref->{'MS-WMIC'}{'ports'}{'other'}{'MS-WMIC'}++	; 
	$srvcobjects_ref->{'MS-WMIC'}{'ports'}{'other'}{'ms-wmic'}++	; 
	$srvcobjects_ref->{'MSN'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'MSN'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'MSN'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'MSN'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'MSN'}{'port'}{'tcp'}	= '1863'	; 
	$srvcobjects_ref->{'MSN'}{'ports'}{'tcp'}{'MSN'}++ 	; 
	$srvcobjects_ref->{'MSN'}{'ports'}{'tcp'}{'msn'}++ 	; 
	$srvcobjects_ref->{'NBDS'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'NBDS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NBDS'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'NBDS'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'NBDS'}{'port'}{'udp'}	= '138'	; 
	$srvcobjects_ref->{'NBDS'}{'ports'}{'udp'}{'NBDS'}++ 	; 
	$srvcobjects_ref->{'NBDS'}{'ports'}{'udp'}{'nbds'}++ 	; 
	$srvcobjects_ref->{'NETBIOS'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'NETBIOS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NETBIOS'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'NETBIOS'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'NETBIOS'}{'port'}{'udp'}	= '137-139'	; 
	$srvcobjects_ref->{'NETBIOS'}{'port'}{'tcp'}	= '137-139'	; 
	$srvcobjects_ref->{'NETBIOS'}{'ports'}{'udp'}{'NETBIOS'}++ 	; 
	$srvcobjects_ref->{'NETBIOS'}{'ports'}{'tcp'}{'NETBIOS'}++ 	; 
	$srvcobjects_ref->{'NETBIOS'}{'ports'}{'udp'}{'netbios'}++ 	; 
	$srvcobjects_ref->{'NETBIOS'}{'ports'}{'tcp'}{'netbios'}++ 	; 
	$srvcobjects_ref->{'NETBIOS'}{'ports'}{'udp'}{'Netbios'}++ 	; 
	$srvcobjects_ref->{'NETBIOS'}{'ports'}{'tcp'}{'Netbios'}++ 	; 
	$srvcobjects_ref->{'NBNAME'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'NBNAME'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NBNAME'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'NBNAME'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'NBNAME'}{'port'}{'udp'}	= '137'	; 
	$srvcobjects_ref->{'NBNAME'}{'ports'}{'udp'}{'NBNAME'}++ 	; 
	$srvcobjects_ref->{'NBNAME'}{'ports'}{'udp'}{'nbname'}++ 	; 
	$srvcobjects_ref->{'NetMeeting'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'NetMeeting'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NetMeeting'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'NetMeeting'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'NetMeeting'}{'port'}{'tcp'}	= '1720'	; 
	$srvcobjects_ref->{'NetMeeting'}{'ports'}{'tcp'}{'NetMeeting'}++ 	; 
	$srvcobjects_ref->{'NetMeeting'}{'ports'}{'tcp'}{'netmeeting'}++ 	; 
	$srvcobjects_ref->{'NFS'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'NFS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NFS'}{'timeout'}    	= '40'	; 
	$srvcobjects_ref->{'NFS'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'NFS'}{'port'}{'udp'}	= '111'	; 
	$srvcobjects_ref->{'NFS'}{'ports'}{'udp'}{'NFS'}++ 	; 
	$srvcobjects_ref->{'NFS'}{'ports'}{'udp'}{'nfs'}++ 	; 
	$srvcobjects_ref->{'NNTP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'NNTP'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'NNTP'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'NNTP'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'NNTP'}{'port'}{'tcp'}	= '119'	; 
	$srvcobjects_ref->{'NNTP'}{'ports'}{'tcp'}{'NNTP'}++ 	; 
	$srvcobjects_ref->{'NNTP'}{'ports'}{'tcp'}{'nntp'}++ 	; 
	$srvcobjects_ref->{'NS-Global'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'NS-Global'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NS-Global'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'NS-Global'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'NS-Global'}{'port'}{'tcp'}	= '15397'	; 
	$srvcobjects_ref->{'NS-Global'}{'ports'}{'tcp'}{'NS-Global'}++ 	; 
	$srvcobjects_ref->{'NS-Global'}{'ports'}{'tcp'}{'ns-global'}++ 	; 
	$srvcobjects_ref->{'NS-Global-PRO'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'NS-Global-PRO'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NS-Global-PRO'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'NS-Global-PRO'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'NS-Global-PRO'}{'port'}{'tcp'}	= '15397'	; 
	$srvcobjects_ref->{'NS-Global-PRO'}{'ports'}{'tcp'}{'NS-Global-PRO'}++ 	; 
	$srvcobjects_ref->{'NS-Global-PRO'}{'ports'}{'tcp'}{'ns-global-pro'}++ 	; 
	$srvcobjects_ref->{'NSM'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'NSM'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NSM'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'NSM'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'NSM'}{'port'}{'udp'}	= '69'	; 
	$srvcobjects_ref->{'NSM'}{'ports'}{'udp'}{'NSM'}++ 	; 
	$srvcobjects_ref->{'NSM'}{'ports'}{'udp'}{'nsm'}++ 	; 
	$srvcobjects_ref->{'NSM'}{'ports'}{'other'}{'NSM'}++	; 
	$srvcobjects_ref->{'NSM'}{'ports'}{'other'}{'nsm'}++	; 
	$srvcobjects_ref->{'NTP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'NTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'NTP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'NTP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'NTP'}{'port'}{'udp'}	= '123'	; 
	$srvcobjects_ref->{'NTP'}{'ports'}{'udp'}{'NTP'}++ 	; 
	$srvcobjects_ref->{'NTP'}{'ports'}{'udp'}{'ntp'}++ 	; 
	$srvcobjects_ref->{'NTP'}{'ports'}{'udp'}{'Network'}++ 	; 
	$srvcobjects_ref->{'NTP'}{'ports'}{'other'}{'NTP'}++	; 
	$srvcobjects_ref->{'NTP'}{'ports'}{'other'}{'ntp'}++	; 
	$srvcobjects_ref->{'OSPF'}{'type'}        	= '89'	; 
	$srvcobjects_ref->{'OSPF'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'OSPF'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'OSPF'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'OSPF'}{'port'}{'89'}	= '0-65535'	; 
	$srvcobjects_ref->{'OSPF'}{'ports'}{'89'}{'OSPF'}++ 	; 
	$srvcobjects_ref->{'OSPF'}{'ports'}{'89'}{'ospf'}++ 	; 
	$srvcobjects_ref->{'OSPF'}{'ports'}{'other'}{'OSPF'}++	; 
	$srvcobjects_ref->{'OSPF'}{'ports'}{'other'}{'ospf'}++	; 
	$srvcobjects_ref->{'PC-Anywhere'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'PC-Anywhere'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'PC-Anywhere'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'PC-Anywhere'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'PC-Anywhere'}{'port'}{'udp'}	= '5632'	; 
	$srvcobjects_ref->{'PC-Anywhere'}{'ports'}{'udp'}{'PC-Anywhere'}++ 	; 
	$srvcobjects_ref->{'PC-Anywhere'}{'ports'}{'udp'}{'pc-anywhere'}++ 	; 
	$srvcobjects_ref->{'PING'}{'type'}        	= 'icmp'	; 
	$srvcobjects_ref->{'PING'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'PING'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'PING'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'PING'}{'port'}{'icmp'}	= '0-65535'	; 
	$srvcobjects_ref->{'PING'}{'ports'}{'icmp'}{'PING'}++ 	; 
	$srvcobjects_ref->{'PING'}{'ports'}{'icmp'}{'ping'}++ 	; 
	$srvcobjects_ref->{'PING'}{'ports'}{'other'}{'PING'}++	; 
	$srvcobjects_ref->{'PING'}{'ports'}{'other'}{'ping'}++	; 
	$srvcobjects_ref->{'POP3'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'POP3'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'POP3'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'POP3'}{'description'}	= 'email'; 
	$srvcobjects_ref->{'POP3'}{'port'}{'tcp'}	= '110'	; 
	$srvcobjects_ref->{'POP3'}{'ports'}{'tcp'}{'POP3'}++ 	; 
	$srvcobjects_ref->{'POP3'}{'ports'}{'tcp'}{'pop3'}++ 	; 
	$srvcobjects_ref->{'PPTP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'PPTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'PPTP'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'PPTP'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'PPTP'}{'port'}{'tcp'}	= '1723'	; 
	$srvcobjects_ref->{'PPTP'}{'ports'}{'tcp'}{'PPTP'}++ 	; 
	$srvcobjects_ref->{'PPTP'}{'ports'}{'tcp'}{'pptp'}++ 	; 
	$srvcobjects_ref->{'RADIUS'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'RADIUS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'RADIUS'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'RADIUS'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'RADIUS'}{'port'}{'udp'}	= '1812-1813'	; 
	$srvcobjects_ref->{'RADIUS'}{'ports'}{'udp'}{'RADIUS'}++ 	; 
	$srvcobjects_ref->{'RADIUS'}{'ports'}{'udp'}{'radius'}++ 	; 
	$srvcobjects_ref->{'RADIUS'}{'ports'}{'other'}{'RADIUS'}++	; 
	$srvcobjects_ref->{'RADIUS'}{'ports'}{'other'}{'radius'}++	; 
	$srvcobjects_ref->{'Real'}{'type'}        	= 'Media'	; 
	$srvcobjects_ref->{'Real'}{'default'}    	= 'seeking'	; 
	$srvcobjects_ref->{'Real'}{'timeout'}    	= 'info'	; 
	$srvcobjects_ref->{'Real'}{'description'}	= '7070'; 
	$srvcobjects_ref->{'Real'}{'port'}{'Media'}	= '6'	; 
	$srvcobjects_ref->{'Real'}{'ports'}{'Media'}{'Real'}++ 	; 
	$srvcobjects_ref->{'Real'}{'ports'}{'Media'}{'real'}++ 	; 
	$srvcobjects_ref->{'REXEC'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'REXEC'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'REXEC'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'REXEC'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'REXEC'}{'port'}{'tcp'}	= '512'	; 
	$srvcobjects_ref->{'REXEC'}{'ports'}{'tcp'}{'REXEC'}++ 	; 
	$srvcobjects_ref->{'REXEC'}{'ports'}{'tcp'}{'rexec'}++ 	; 
	$srvcobjects_ref->{'RIP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'RIP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'RIP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'RIP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'RIP'}{'port'}{'udp'}	= '520'	; 
	$srvcobjects_ref->{'RIP'}{'ports'}{'udp'}{'RIP'}++ 	; 
	$srvcobjects_ref->{'RIP'}{'ports'}{'udp'}{'rip'}++ 	; 
	$srvcobjects_ref->{'RIP'}{'ports'}{'other'}{'RIP'}++	; 
	$srvcobjects_ref->{'RIP'}{'ports'}{'other'}{'rip'}++	; 
	$srvcobjects_ref->{'RLOGIN'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'RLOGIN'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'RLOGIN'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'RLOGIN'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'RLOGIN'}{'port'}{'tcp'}	= '513'	; 
	$srvcobjects_ref->{'RLOGIN'}{'ports'}{'tcp'}{'RLOGIN'}++ 	; 
	$srvcobjects_ref->{'RLOGIN'}{'ports'}{'tcp'}{'rlogin'}++ 	; 
	$srvcobjects_ref->{'RSH'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'RSH'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'RSH'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'RSH'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'RSH'}{'port'}{'tcp'}	= '514'	; 
	$srvcobjects_ref->{'RSH'}{'ports'}{'tcp'}{'RSH'}++ 	; 
	$srvcobjects_ref->{'RSH'}{'ports'}{'tcp'}{'rsh'}++ 	; 
	$srvcobjects_ref->{'RTSP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'RTSP'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'RTSP'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'RTSP'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'RTSP'}{'port'}{'tcp'}	= '554'	; 
	$srvcobjects_ref->{'RTSP'}{'ports'}{'tcp'}{'RTSP'}++ 	; 
	$srvcobjects_ref->{'RTSP'}{'ports'}{'tcp'}{'rtsp'}++ 	; 
	$srvcobjects_ref->{'SCCP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'SCCP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SCCP'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SCCP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SCCP'}{'port'}{'tcp'}	= '2000'	; 
	$srvcobjects_ref->{'SCCP'}{'ports'}{'tcp'}{'SCCP'}++ 	; 
	$srvcobjects_ref->{'SCCP'}{'ports'}{'tcp'}{'sccp'}++ 	; 
	$srvcobjects_ref->{'SCCP'}{'ports'}{'other'}{'SCCP'}++	; 
	$srvcobjects_ref->{'SCCP'}{'ports'}{'other'}{'sccp'}++	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'type'}        	= '132'	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SCTP-ANY'}{'port'}{'132'}	= '0-65535'	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'ports'}{'132'}{'SCTP-ANY'}++ 	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'ports'}{'132'}{'sctp-any'}++ 	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'ports'}{'other'}{'SCTP-ANY'}++	; 
	$srvcobjects_ref->{'SCTP-ANY'}{'ports'}{'other'}{'sctp-any'}++	; 
	$srvcobjects_ref->{'SIP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'SIP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SIP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SIP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SIP'}{'port'}{'udp'}	= '5060'	; 
	$srvcobjects_ref->{'SIP'}{'ports'}{'udp'}{'SIP'}++ 	; 
	$srvcobjects_ref->{'SIP'}{'ports'}{'udp'}{'sip'}++ 	; 
	$srvcobjects_ref->{'SIP'}{'ports'}{'other'}{'SIP'}++	; 
	$srvcobjects_ref->{'SIP'}{'ports'}{'other'}{'sip'}++	; 
	$srvcobjects_ref->{'SMB'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'SMB'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SMB'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SMB'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'SMB'}{'port'}{'tcp'}	= '139'	; 
	$srvcobjects_ref->{'SMB'}{'ports'}{'tcp'}{'SMB'}++ 	; 
	$srvcobjects_ref->{'SMB'}{'ports'}{'tcp'}{'smb'}++ 	; 
	$srvcobjects_ref->{'SMTP'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'SMTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SMTP'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SMTP'}{'description'}	= 'email'; 
	$srvcobjects_ref->{'SMTP'}{'port'}{'tcp'}	= '25'	; 
	$srvcobjects_ref->{'SMTP'}{'ports'}{'tcp'}{'SMTP'}++ 	; 
	$srvcobjects_ref->{'SMTP'}{'ports'}{'tcp'}{'smtp'}++ 	; 
	$srvcobjects_ref->{'SNMP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'SNMP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SNMP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SNMP'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SNMP'}{'port'}{'udp'}	= '161'	; 
	$srvcobjects_ref->{'SNMP'}{'ports'}{'udp'}{'SNMP'}++ 	; 
	$srvcobjects_ref->{'SNMP'}{'ports'}{'udp'}{'snmp'}++ 	; 
	$srvcobjects_ref->{'SNMP'}{'ports'}{'other'}{'SNMP'}++	; 
	$srvcobjects_ref->{'SNMP'}{'ports'}{'other'}{'snmp'}++	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SQL-Monitor'}{'port'}{'udp'}	= '1434'	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'ports'}{'udp'}{'SQL-Monitor'}++ 	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'ports'}{'udp'}{'sql-monitor'}++ 	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'ports'}{'other'}{'SQL-Monitor'}++	; 
	$srvcobjects_ref->{'SQL-Monitor'}{'ports'}{'other'}{'sql-monitor'}++	; 
	$srvcobjects_ref->{'SQL*Net'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'SQL*Net'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SQL*Net'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SQL*Net'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SQL*Net'}{'port'}{'tcp'}	= '1525'	; 
	$srvcobjects_ref->{'SQL*Net'}{'ports'}{'tcp'}{'SQL*Net'}++ 	; 
	$srvcobjects_ref->{'SQL*Net'}{'ports'}{'tcp'}{'sql*net'}++ 	; 
	$srvcobjects_ref->{'SQL*Net'}{'ports'}{'other'}{'SQL*Net'}++	; 
	$srvcobjects_ref->{'SQL*Net'}{'ports'}{'other'}{'sql*net'}++	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SQL*Net V1'}{'port'}{'tcp'}	= '1525'	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'ports'}{'tcp'}{'SQL*Net-V1'}++ 	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'ports'}{'tcp'}{'sql*net-v1'}++ 	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'ports'}{'other'}{'SQL*Net-V1'}++	; 
	$srvcobjects_ref->{'SQL*Net V1'}{'ports'}{'other'}{'sql*net-v1'}++	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SQL*Net V2'}{'port'}{'tcp'}	= '1521'	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'ports'}{'tcp'}{'SQL*Net-V2'}++ 	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'ports'}{'tcp'}{'sql*net-v2'}++ 	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'ports'}{'other'}{'SQL*Net-V2'}++	; 
	$srvcobjects_ref->{'SQL*Net V2'}{'ports'}{'other'}{'sql*net-v2'}++	; 
	$srvcobjects_ref->{'SSH'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'SSH'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SSH'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SSH'}{'description'}	= 'security'; 
	$srvcobjects_ref->{'SSH'}{'port'}{'tcp'}	= '22'	; 
	$srvcobjects_ref->{'SSH'}{'ports'}{'tcp'}{'SSH'}++ 	; 
	$srvcobjects_ref->{'SSH'}{'ports'}{'tcp'}{'ssh'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SUN-RPC'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC'}{'port'}{'rcp'}	= 'sun-rpc'	; 
	$srvcobjects_ref->{'SUN-RPC'}{'port'}{'tcp'}	= 'sun-rpc'	; 
	$srvcobjects_ref->{'SUN-RPC'}{'port'}{'udp'}	= 'sun-rpc'	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'rcp'}{'SUN-RPC'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'rcp'}{'sun-rpc'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'rcp'}{'sunrpc'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'other'}{'SUN-RPC'}++	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'other'}{'sun-rpc'}++	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'other'}{'sunrpc'}++	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'udp'}{'sunrpc'}++	; 
	$srvcobjects_ref->{'SUN-RPC'}{'ports'}{'tcp'}{'sunrpc'}++	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'port'}{'rcp'}	= 'sun-rpc-any'	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'ports'}{'rcp'}{'SUN-RPC-ANY'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'ports'}{'rcp'}{'sun-rpc-any'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'ports'}{'other'}{'SUN-RPC-ANY'}++	; 
	$srvcobjects_ref->{'SUN-RPC-ANY'}{'ports'}{'other'}{'sun-rpc-any'}++	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'port'}{'rcp'}	= 'sun-rpc-mountd'	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'ports'}{'rcp'}{'SUN-RPC-MOUNTD'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'ports'}{'rcp'}{'sun-rpc-mountd'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'ports'}{'other'}{'SUN-RPC-MOUNTD'}++	; 
	$srvcobjects_ref->{'SUN-RPC-MOUNTD'}{'ports'}{'other'}{'sun-rpc-mountd'}++	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'timeout'}    	= '40'	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'port'}{'rcp'}	= 'sun-rpc-nfs'	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'ports'}{'rcp'}{'SUN-RPC-NFS'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'ports'}{'rcp'}{'sun-rpc-nfs'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'ports'}{'other'}{'SUN-RPC-NFS'}++	; 
	$srvcobjects_ref->{'SUN-RPC-NFS'}{'ports'}{'other'}{'sun-rpc-nfs'}++	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'port'}{'rcp'}	= 'sun-rpc-nlockmgr'	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'ports'}{'rcp'}{'SUN-RPC-NLOCKMGR'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'ports'}{'rcp'}{'sun-rpc-nlockmgr'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'ports'}{'other'}{'SUN-RPC-NLOCKMGR'}++	; 
	$srvcobjects_ref->{'SUN-RPC-NLOCKMGR'}{'ports'}{'other'}{'sun-rpc-nlockmgr'}++	; 
	$srvcobjects_ref->{'SUN-RPC-PORTMAPPER'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'SUN-RPC-PORTMAPPER'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-PORTMAPPER'}{'timeout'}    	= '40'	; 
	$srvcobjects_ref->{'SUN-RPC-PORTMAPPER'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'SUN-RPC-PORTMAPPER'}{'port'}{'udp'}	= '111'	; 
	$srvcobjects_ref->{'SUN-RPC-PORTMAPPER'}{'ports'}{'udp'}{'SUN-RPC-PORTMAPPER'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-PORTMAPPER'}{'ports'}{'udp'}{'sun-rpc-portmapper'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'port'}{'rcp'}	= 'sun-rpc-rquotad'	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'ports'}{'rcp'}{'SUN-RPC-RQUOTAD'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'ports'}{'rcp'}{'sun-rpc-rquotad'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'ports'}{'other'}{'SUN-RPC-RQUOTAD'}++	; 
	$srvcobjects_ref->{'SUN-RPC-RQUOTAD'}{'ports'}{'other'}{'sun-rpc-rquotad'}++	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'port'}{'rcp'}	= 'sun-rpc-rstatd'	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'ports'}{'rcp'}{'SUN-RPC-RSTATD'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'ports'}{'rcp'}{'sun-rpc-rstatd'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'ports'}{'other'}{'SUN-RPC-RSTATD'}++	; 
	$srvcobjects_ref->{'SUN-RPC-RSTATD'}{'ports'}{'other'}{'sun-rpc-rstatd'}++	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'port'}{'rcp'}	= 'sun-rpc-ruserd'	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'ports'}{'rcp'}{'SUN-RPC-RUSERD'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'ports'}{'rcp'}{'sun-rpc-ruserd'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'ports'}{'other'}{'SUN-RPC-RUSERD'}++	; 
	$srvcobjects_ref->{'SUN-RPC-RUSERD'}{'ports'}{'other'}{'sun-rpc-ruserd'}++	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'port'}{'rcp'}	= 'sun-rpc-sadmind'	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'ports'}{'rcp'}{'SUN-RPC-SADMIND'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'ports'}{'rcp'}{'sun-rpc-sadmind'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'ports'}{'other'}{'SUN-RPC-SADMIND'}++	; 
	$srvcobjects_ref->{'SUN-RPC-SADMIND'}{'ports'}{'other'}{'sun-rpc-sadmind'}++	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'port'}{'rcp'}	= 'sun-rpc-sprayd'	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'ports'}{'rcp'}{'SUN-RPC-SPRAYD'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'ports'}{'rcp'}{'sun-rpc-sprayd'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'ports'}{'other'}{'SUN-RPC-SPRAYD'}++	; 
	$srvcobjects_ref->{'SUN-RPC-SPRAYD'}{'ports'}{'other'}{'sun-rpc-sprayd'}++	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'port'}{'rcp'}	= 'sun-rpc-status'	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'ports'}{'rcp'}{'SUN-RPC-STATUS'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'ports'}{'rcp'}{'sun-rpc-status'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'ports'}{'other'}{'SUN-RPC-STATUS'}++	; 
	$srvcobjects_ref->{'SUN-RPC-STATUS'}{'ports'}{'other'}{'sun-rpc-status'}++	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'port'}{'rcp'}	= 'sun-rpc-walld'	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'ports'}{'rcp'}{'SUN-RPC-WALLD'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'ports'}{'rcp'}{'sun-rpc-walld'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'ports'}{'other'}{'SUN-RPC-WALLD'}++	; 
	$srvcobjects_ref->{'SUN-RPC-WALLD'}{'ports'}{'other'}{'sun-rpc-walld'}++	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'type'}        	= 'rcp'	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'port'}{'rcp'}	= 'sun-rpc-ypbind'	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'ports'}{'rcp'}{'SUN-RPC-YPBIND'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'ports'}{'rcp'}{'sun-rpc-ypbind'}++ 	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'ports'}{'other'}{'SUN-RPC-YPBIND'}++	; 
	$srvcobjects_ref->{'SUN-RPC-YPBIND'}{'ports'}{'other'}{'sun-rpc-ypbind'}++	; 
	$srvcobjects_ref->{'SYSLOG'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'SYSLOG'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'SYSLOG'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'SYSLOG'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'SYSLOG'}{'port'}{'udp'}	= '514'	; 
	$srvcobjects_ref->{'SYSLOG'}{'ports'}{'udp'}{'SYSLOG'}++ 	; 
	$srvcobjects_ref->{'SYSLOG'}{'ports'}{'udp'}{'syslog'}++ 	; 
	$srvcobjects_ref->{'SYSLOG'}{'ports'}{'other'}{'SYSLOG'}++	; 
	$srvcobjects_ref->{'SYSLOG'}{'ports'}{'other'}{'syslog'}++	; 
	$srvcobjects_ref->{'TALK'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'TALK'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'TALK'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'TALK'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'TALK'}{'port'}{'udp'}	= '517-518'	; 
	$srvcobjects_ref->{'TALK'}{'ports'}{'udp'}{'TALK'}++ 	; 
	$srvcobjects_ref->{'TALK'}{'ports'}{'udp'}{'talk'}++ 	; 
	$srvcobjects_ref->{'TALK'}{'ports'}{'other'}{'TALK'}++	; 
	$srvcobjects_ref->{'TALK'}{'ports'}{'other'}{'talk'}++	; 
	$srvcobjects_ref->{'TCP-ANY'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'TCP-ANY'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'TCP-ANY'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'TCP-ANY'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'TCP-ANY'}{'port'}{'tcp'}	= '0-65535'	; 
	$srvcobjects_ref->{'TCP-ANY'}{'ports'}{'tcp'}{'TCP-ANY'}++ 	; 
	$srvcobjects_ref->{'TCP-ANY'}{'ports'}{'tcp'}{'tcp-any'}++ 	; 
	$srvcobjects_ref->{'TCP-ANY'}{'ports'}{'other'}{'TCP-ANY'}++	; 
	$srvcobjects_ref->{'TCP-ANY'}{'ports'}{'other'}{'tcp-any'}++	; 
	$srvcobjects_ref->{'TELNET'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'TELNET'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'TELNET'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'TELNET'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'TELNET'}{'port'}{'tcp'}	= '23'	; 
	$srvcobjects_ref->{'TELNET'}{'ports'}{'tcp'}{'TELNET'}++ 	; 
	$srvcobjects_ref->{'TELNET'}{'ports'}{'tcp'}{'telnet'}++ 	; 
	$srvcobjects_ref->{'TFTP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'TFTP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'TFTP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'TFTP'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'TFTP'}{'port'}{'udp'}	= '69'	; 
	$srvcobjects_ref->{'TFTP'}{'ports'}{'udp'}{'TFTP'}++ 	; 
	$srvcobjects_ref->{'TFTP'}{'ports'}{'udp'}{'tftp'}++ 	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'type'}        	= 'icmp'	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'TRACEROUTE'}{'port'}{'icmp'}	= '0-65535'	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'ports'}{'icmp'}{'TRACEROUTE'}++ 	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'ports'}{'icmp'}{'traceroute'}++ 	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'ports'}{'other'}{'TRACEROUTE'}++	; 
	$srvcobjects_ref->{'TRACEROUTE'}{'ports'}{'other'}{'traceroute'}++	; 
	$srvcobjects_ref->{'UDP-ANY'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'UDP-ANY'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'UDP-ANY'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'UDP-ANY'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'UDP-ANY'}{'port'}{'udp'}	= '0-65535'	; 
	$srvcobjects_ref->{'UDP-ANY'}{'ports'}{'udp'}{'UDP-ANY'}++ 	; 
	$srvcobjects_ref->{'UDP-ANY'}{'ports'}{'udp'}{'udp-any'}++ 	; 
	$srvcobjects_ref->{'UDP-ANY'}{'ports'}{'other'}{'UDP-ANY'}++	; 
	$srvcobjects_ref->{'UDP-ANY'}{'ports'}{'other'}{'udp-any'}++	; 
	$srvcobjects_ref->{'UUCP'}{'type'}        	= 'udp'	; 
	$srvcobjects_ref->{'UUCP'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'UUCP'}{'timeout'}    	= '1'	; 
	$srvcobjects_ref->{'UUCP'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'UUCP'}{'port'}{'udp'}	= '540'	; 
	$srvcobjects_ref->{'UUCP'}{'ports'}{'udp'}{'UUCP'}++ 	; 
	$srvcobjects_ref->{'UUCP'}{'ports'}{'udp'}{'uucp'}++ 	; 
	$srvcobjects_ref->{'VDO'}{'type'}        	= 'Live'	; 
	$srvcobjects_ref->{'VDO'}{'default'}    	= 'seeking'	; 
	$srvcobjects_ref->{'VDO'}{'timeout'}    	= 'info'	; 
	$srvcobjects_ref->{'VDO'}{'description'}	= '7000/7010'; 
	$srvcobjects_ref->{'VDO'}{'port'}{'Live'}	= '6'	; 
	$srvcobjects_ref->{'VDO'}{'ports'}{'Live'}{'VDO'}++ 	; 
	$srvcobjects_ref->{'VDO'}{'ports'}{'Live'}{'vdo'}++ 	; 
	$srvcobjects_ref->{'VNC'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'VNC'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'VNC'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'VNC'}{'description'}	= 'other'; 
	$srvcobjects_ref->{'VNC'}{'port'}{'tcp'}	= '5800'	; 
	$srvcobjects_ref->{'VNC'}{'ports'}{'tcp'}{'VNC'}++ 	; 
	$srvcobjects_ref->{'VNC'}{'ports'}{'tcp'}{'vnc'}++ 	; 
	$srvcobjects_ref->{'VNC'}{'ports'}{'other'}{'VNC'}++	; 
	$srvcobjects_ref->{'VNC'}{'ports'}{'other'}{'vnc'}++	; 
	$srvcobjects_ref->{'WAIS'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'WAIS'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'WAIS'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'WAIS'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'WAIS'}{'port'}{'tcp'}	= '210'	; 
	$srvcobjects_ref->{'WAIS'}{'ports'}{'tcp'}{'WAIS'}++ 	; 
	$srvcobjects_ref->{'WAIS'}{'ports'}{'tcp'}{'wais'}++ 	; 
	$srvcobjects_ref->{'WHOIS'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'WHOIS'}{'default'}    	= '30'	; 
	$srvcobjects_ref->{'WHOIS'}{'timeout'}    	= 'seeking'	; 
	$srvcobjects_ref->{'WHOIS'}{'description'}	= 'info'; 
	$srvcobjects_ref->{'WHOIS'}{'port'}{'tcp'}	= '43'	; 
	$srvcobjects_ref->{'WHOIS'}{'ports'}{'tcp'}{'WHOIS'}++ 	; 
	$srvcobjects_ref->{'WHOIS'}{'ports'}{'tcp'}{'whois'}++ 	; 
	$srvcobjects_ref->{'WINFRAME'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'WINFRAME'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'WINFRAME'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'WINFRAME'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'WINFRAME'}{'port'}{'tcp'}	= '1494'	; 
	$srvcobjects_ref->{'WINFRAME'}{'ports'}{'tcp'}{'WINFRAME'}++ 	; 
	$srvcobjects_ref->{'WINFRAME'}{'ports'}{'tcp'}{'winframe'}++ 	; 
	$srvcobjects_ref->{'X-WINDOWS'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'X-WINDOWS'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'X-WINDOWS'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'X-WINDOWS'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'X-WINDOWS'}{'port'}{'tcp'}	= '6000-6063'	; 
	$srvcobjects_ref->{'X-WINDOWS'}{'ports'}{'tcp'}{'X-WINDOWS'}++ 	; 
	$srvcobjects_ref->{'X-WINDOWS'}{'ports'}{'tcp'}{'x-windows'}++ 	; 
	$srvcobjects_ref->{'X-WINDOWS'}{'ports'}{'tcp'}{'X-Windows'}++ 	; 
	$srvcobjects_ref->{'YMSG'}{'type'}        	= 'tcp'	; 
	$srvcobjects_ref->{'YMSG'}{'default'}    	= 'Pre-defined'	; 
	$srvcobjects_ref->{'YMSG'}{'timeout'}    	= '30'	; 
	$srvcobjects_ref->{'YMSG'}{'description'}	= 'remote'; 
	$srvcobjects_ref->{'YMSG'}{'port'}{'tcp'}	= '5050'	; 
	$srvcobjects_ref->{'YMSG'}{'ports'}{'tcp'}{'YMSG'}++ 	; 
	$srvcobjects_ref->{'YMSG'}{'ports'}{'tcp'}{'ymsg'}++ 	; 


}



